/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(wb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function ub(vb){var s=vb.a;var t=s.a;var u=t.buffer;t.grow=sb;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=NaN;var O=Infinity;var P=s.b;var Q=s.c;var R=s.d;var S=s.e;var T=s.f;var U=s.g;var V=s.h;var W=s.i;var X=s.j;var Y=s.k;var Z=s.l;var _=s.m;var $=s.n;var aa=s.o;var ba=s.p;var ca=s.q;var da=s.r;var ea=s.s;var fa=s.t;var ga=s.u;var ha=s.v;var ia=s.w;var ja=s.x;var ka=s.y;var la=s.z;var ma=s.A;var na=s.B;var oa=s.C;var pa=s.D;var qa=s.E;var ra=s.F;var sa=s.G;var ta=s.H;var ua=s.I;var va=s.J;var wa=s.K;var xa=s.L;var ya=s.M;var za=s.N;var Aa=s.O;var Ba=s.P;var Ca=s.Q;var Da=s.R;var Ea=s.S;var Fa=s.T;var Ga=s.U;var Ha=s.V;var Ia=s.W;var Ja=s.X;var Ka=s.Y;var La=s.Z;var Ma=s._;var Na=s.$;var Oa=s.aa;var Pa=s.ba;var Qa=s.ca;var Ra=s.da;var Sa=s.ea;var Ta=s.fa;var Ua=s.ga;var Va=s.ha;var Wa=s.ia;var Xa=s.ja;var Ya=s.ka;var Za=s.la;var _a=s.ma;var $a=s.na;var ab=s.oa;var bb=s.pa;var cb=s.qa;var db=s.ra;var eb=s.sa;var fb=s.ta;var gb=s.ua;var hb=535232;var ib=0;var jb=0;var kb=0;var lb=0;
// EMSCRIPTEN_START_FUNCS
function YI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,S=E(0),V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=E(0),wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=E(0),Ma=0;ba=hb-32|0;hb=ba;da=ba+24|0;x[da>>2]=50012;x[da>>2]=49912;d=XI(ba+16|0);f=XI(ba+8|0);fa=b;ja=c;ka=x[d>>2];xa=y[d+4|0];la=x[f>>2];ya=y[f+4|0];c=0;N=hb-112|0;hb=N;e=a;ma=a+24604|0;a=ma;a:{if(!x[a+16>>2]){break a}b=x[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=x[a+28>>2];if(a>>>0>4){break a}c=23>>>a&1}if(!c){a=N+96|0;jM(a,9035,12877,220,45);b=hb-48|0;hb=b;c=Xb(b+16|0,17601);x[23604]=0;U(5,b|0,1,17264);d=x[23604];x[23604]=0;b:{c:{d:{e:{if((d|0)!=1){x[23604]=0;U(2,b+32|0,c|0,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break e}x[23604]=0;ea(796,b|0,a|0,1,b|0,b+32|0);a=x[23604];x[23604]=0;if((a|0)!=1){break b}a=P()|0;xb(b+32|0);break d}a=P()|0;break c}a=P()|0}xb(b)}xb(c);T(a|0);p()}xb(b+32|0);xb(b);xb(c);hb=b+48|0}na=e+8204|0;oa=e+397452|0;pa=e+397448|0;Y=e+393352|0;J=e+397456|0;X=e+12|0;za=e+1074376|0;Aa=e+1298420|0;Ba=e+1074365|0;while(1){f:{g:{a=x[e+480208>>2];if(!(!fa|a&512)){h:{if(x[e+1074380>>2]){break h}ga=e;b=a|512;i:{if(a&256){break i}o=hb-48|0;hb=o;u=hb-32|0;hb=u;k=e+1074312|0;d=e+1074992|0;i=e+1298264|0;n=e+1074424|0;q=e+484360|0;m=e+1074448|0;t=e+1074376|0;b=x[e+1074392>>2];r=e+480188|0;C=e+480180|0;s=e+484376|0;j=e+484348|0;G=e+480210|0;I=e+484364|0;j:{k:{l:while(1){m:{a=b+1|0;x[e+1074392>>2]=a;if(Pk(t)>>>0>a>>>0){break m}BN(u+24|0,x[C>>2],z[r>>1],t,(x[e+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(y[e+480208|0]&32){f=x[j>>2];l=x[e+484344>>2];b=z[e+1074446>>1];break r}b=65535;a=x[e+484360>>2];h=y[s|0];c=_b(a,h);f=x[c>>2];g=Kc(f,x[c+4>>2]);c=z[e+1074448>>1];if(g>>>0>c>>>0){b=z[cc(f,c)>>1]}w[e+1074446>>1]=b;s:{t:{l=x[e+484344>>2];f=x[j>>2];g=b&65535;if(nf(l,f)>>>0<=g>>>0){break t}g=ac(l,g);if(Ob(x[g>>2],x[g+4>>2])){break t}g=0;break s}g=1}while(1){u:{v:{w:{if(!g){b=65534;w[e+1074446>>1]=65534;break w}g=b&65535;if(nf(l,f)>>>0>g>>>0){break v}x:{y:{z:{if((g|0)==65535){f=_b(a,h);break z}f=_b(a,h);if(Kc(x[f>>2],x[f+4>>2])>>>0>(c&65535)>>>0){break y}}b=z[f+28>>1];A:{if(b){g=x[f>>2];l=Kc(g,x[f+4>>2]);break A}b=0;g=x[f>>2];l=Kc(g,x[f+4>>2]);a=c&65535;if(l>>>0<a>>>0|!a){break A}while(1){a=c;c=a-1|0;h=c&65535;if(!h){break A}if(z[cc(g,h)>>1]!=65535){continue}break}b=a}w[e+1074448>>1]=b;x[e+480208>>2]=x[e+480208>>2]&-524289;while(1){a=b&65535;if(a>>>0>=l>>>0){break q}if(z[cc(g,a)>>1]==65534){b=b+1|0;w[m>>1]=b;continue}break}if(!jq(f,a)){break q}c=z[e+1074448>>1];a=x[e+484360>>2];h=y[s|0];f=_b(a,h);break x}c=c+1|0;w[m>>1]=c}b=65535;g=Kc(x[f>>2],x[f+4>>2]);f=c&65535;if(g>>>0>f>>>0){b=z[cc(x[_b(a,h)>>2],f)>>1]}w[e+1074446>>1]=b;l=x[e+484344>>2];f=x[j>>2];g=b&65535;if(nf(l,f)>>>0<=g>>>0){break w}g=ac(l,g);if(!Ob(x[g>>2],x[g+4>>2])){break u}}g=1;continue}w[e+1074450>>1]=c;break r}g=0;continue}}a=b&65535;if(!pe(l,f,a)){break k}b=x[n>>2];if(b>>>0>=A[ac(l,a)+12>>2]){x[n>>2]=0;b=0}if(x[e+480208>>2]&32?x[e+480272>>2]!=-1:0){break n}if(!Ts(i,z[m>>1],b,tp(u+16|0,d),y[u+24|0])){break n}a=x[e+480272>>2];if(a){if((a|0)>0){x[e+480272>>2]=a-1}Qn(i,1);Ts(i,z[m>>1],x[n>>2],tp(u+16|0,d),y[u+24|0]);break n}if(!(y[G|0]&64)){break q}b=0;if(QN(i,m,n)){break o}x[e+1074424>>2]=0;x[e+1074428>>2]=0;x[e+1074448>>2]=0;c=_i(x[e+484360>>2],x[I>>2])-1|0;a=y[s|0];if((c|0)>(a|0)){break p}ui(q,0)}Qn(i,1);break k}ui(q,a+1&255);Qn(i,1)}while(1){if((b|0)==256){_L(e);x[e+1074416>>2]=x[e+480196>>2];x[e+1074420>>2]=x[e+480204>>2];x[e+1074456>>2]=x[e+480200>>2];a=z[e+1074448>>1];w[e+1074450>>1]=a;b=x[e+1074424>>2];x[e+1074428>>2]=b;c=_b(x[e+484360>>2],y[s|0]);f=x[c>>2];if(Kc(f,x[c+4>>2])>>>0>a>>>0){Ja=e,Ka=z[cc(f,a)>>1],w[Ja+1074446>>1]=Ka}Ts(i,a,b,tp(u+16|0,d),y[u+24|0]);if(!pe(x[e+484344>>2],x[j>>2],z[e+1074446>>1])){break k}}else{Tn((D(b,872)+e|0)+1074992|0,e,b&65535,134217728);b=b+1|0;continue}break}}AN(e,t,(x[e+480208>>2]&32)>>>5|0);a=ac(x[e+484344>>2],z[e+1074446>>1]);c=cd(x[a>>2],x[x[a+48>>2]+12>>2],x[e+1074424>>2],0);f=d+D(z[r>>1],872)|0;b=d;while(1){if((b|0)==(f|0)){B:{C:{a=x[e+484344>>2];b=z[e+1074446>>1];if(wm(a,x[e+484348>>2],b)){a=ac(a,b);c=x[a+16>>2];b=x[a+20>>2];if(wN(c,b)){break C}}x[e+1074408>>2]=x[e+480216>>2];b=x[e+480220>>2];break B}x[e+1074408>>2]=c}x[e+1074412>>2]=b;if(!y[u+24|0]){break m}b=x[e+1074416>>2];x[e+1074392>>2]=b;continue l}Jb(u+16|0,k,82);D:{if(!Mb(x[x[u+16>>2]>>2],x[u+20>>2])|y[b+805|0]!=1){break D}a=y[c+3|0];if((a|0)!=2&(a|0)!=3){break D}Ja=b,Ka=Og(e,y[b+800|0],w[b+772>>1],x[b+704>>2]),x[Ja+700>>2]=Ka}Jb(u+16|0,k,91);E:{if(!Mb(x[x[u+16>>2]>>2],x[u+20>>2])){break E}if(Tc(y[c|0])){break E}a=y[b+788|0];if(!Tc(a)|y[b+791|0]!=19){break E}h=y[b+793|0];if((h&240)!=208|A[e+1074416>>2]>(h&15)>>>0){break E}Ja=b,Ka=Og(e,a,w[b+772>>1],0),x[Ja+700>>2]=Ka}Jb(u+16|0,k,92);F:{if(!Mb(x[x[u+16>>2]>>2],x[u+20>>2])){break F}Jb(u+8|0,k,5);if(Mb(x[x[u+8>>2]>>2],x[u+12>>2])|x[e+1074416>>2]!=1|y[b+791|0]!=17){break F}v[u+16|0]=1;Ja=e,Ka=D(y[Ye(u+16|0,b+793|0)|0],1e4),x[Ja+1074420>>2]=Ka}a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[b+788|0]=a;v[b+789|0]=a>>>8;v[b+790|0]=a>>>16;v[b+791|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[b+792|0]=a;v[b+793|0]=a>>>8;a=x[b+676>>2];x[b+20>>2]=x[b+672>>2];x[b+24>>2]=a;x[b+88>>2]=x[b+88>>2]&-393217;Jb(u+16|0,k,21);if(!Mb(x[x[u+16>>2]>>2],x[u+20>>2])){v[b+831|0]=0}x[b+860>>2]=0;v[b+805|0]=0;c=c+6|0;b=b+872|0;continue}}break}c=x[e+1074416>>2];if(!c){x[e+1074416>>2]=1;c=1}a=x[e+480208>>2];d=x[e+1074392>>2];G:{H:{if(d){b=a&-4097;x[e+480208>>2]=b;f=x[e+480180>>2];if(f&1048580|!(a&2097152)&(f|0)==1){break G}if(Pk(t)>>>0<=d>>>0){break G}if(!((d>>>0)%(x[e+1074400>>2]+c>>>0)|0)){break H}break G}b=a&-528385}x[e+480208>>2]=b|4096}l=0;j=hb-16|0;hb=j;w[e+1074444>>1]=65535;a=e+1074436|0;x[a>>2]=-1;x[a+4>>2]=-1;C=e+480180|0;$=e+1075809|0;r=e+1074312|0;G=e+480208|0;L=e+1074376|0;V=e+480188|0;Z=e+480210|0;_=e+480190|0;M=e+480192|0;while(1){if(z[V>>1]<=l>>>0){I:{if(!(y[G+1|0]&16)){break I}if(!oN(e,L,_b(x[e+484360>>2],y[e+484376|0]),1)){break I}x[G>>2]=x[G>>2]|524288}hb=j+16|0}else{q=D(l,872)+e|0;k=q+1075785|0;f=y[k|0];m=q+1075784|0;i=y[m|0];Q=q+1075781|0;d=y[Q|0];a=x[e+1074392>>2];c=x[e+1074400>>2];h=x[e+1074416>>2];R=q+1075782|0;g=y[R|0];t=q+1075783|0;K=y[t|0];b=Qs(g,K);n=q+1075843|0;v[n|0]=x[G>>2]>>>12&1|y[n|0]&254;h=(a>>>0)%(c+h>>>0)|0;H=q+1075780|0;c=y[H|0];J:{K:{L:{if((c|0)==252){s=Jj(g,i);I=Jj(K,f);c=252;if((d-1&255)>>>0>249){break L}a=x[(D(d,160)+e|0)+906140>>2];if(!a){break L}mb[x[x[a>>2]+44>>2]](a,s,E(E(I>>>0)/E(999)));c=y[H|0]}if((c&255)==251){break K}}if(B[q+1075852>>2]==E(0)|K){break J}}s=x[G>>2]&4096;M:{if(!s){a=y[q+1075862|0];break M}a=y[Q|0];v[q+1075862|0]=a}if((a-1&255)>>>0>249){break J}I=D(a&255,160)+e|0;a=x[I+906140>>2];if(!a){break J}N:{if(!s){c=z[q+1075860>>1];break N}c=zy(y[R|0],y[m|0]);w[q+1075860>>1]=c;S=E(E(zy(y[t|0],y[k|0])>>>0)/E(999));B[q+1075856>>2]=S;Ja=q+1075852|0,La=E(E(S-E(mb[x[x[a>>2]+48>>2]](a,c)))/E(Pk(L)>>>0)),B[Ja>>2]=La;a=x[I+906140>>2]}k=c;c=(x[e+1074392>>2]+1|0)==(Pk(L)|0);mb[x[x[a>>2]+(c?44:104)>>2]](a,k,B[(c?q+1075856|0:q+1075852|0)>>2]);c=y[H|0]}k=q+1074992|0;if(dN(c&255)){b=hb-16|0;hb=b;w[b+12>>1]=0;x[b+8>>2]=0;a=Oh(b+8|0);c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[k+788|0]=c;v[k+789|0]=c>>>8;v[k+790|0]=c>>>16;v[k+791|0]=c>>>24;a=y[a+4|0]|y[a+5|0]<<8;v[k+792|0]=a;v[k+793|0]=a>>>8;hb=b+16|0;K=0;i=0;g=0;d=0;f=0;b=0}O:{if(!(y[G+1|0]&16)){KM(e,k);break O}if(!d){break O}x[q+1075752>>2]=0}P:{Q:{if((K|0)==33){Jb(j+8|0,r,30);c=f>>>4|0;qy(e,l&65535,c+(f&15)|0,Mb(x[x[j+8>>2]>>2],x[j+12>>2]));break Q}c=0;if((K-19&255)>>>0>1){break Q}R:{if(!(!(x[C>>2]&16777250)|f)){f=y[q+1075825|0];break R}v[q+1075825|0]=f}a=f&240;if((a|0)==208){a=f&15;if(!a){a=x[C>>2];if(a&16777248){c=1;break Q}if((a|0)!=2){break Q}break P}if(a>>>0>=x[e+1074400>>2]+x[e+1074416>>2]>>>0){Jb(j+8|0,r,14);c=a;if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break Q}if(!d){break P}v[q+1075795|0]=d;break P}c=a;break Q}if(!(y[G+1|0]&16)|(a|0)!=224){break Q}a=x[C>>2];if(x[e+1074396>>2]?a&16777250:0){break Q}m=a&2;a=f&15;if(a?0:m){break Q}x[e+1074396>>2]=a+1}a=c;c=x[C>>2]==16&(K|0)==19&(f&240)==208;I=c?0:a;S:{if(!I|y[H|0]!=255|y[R|0]!=2){break S}Jb(j+8|0,r,74);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break S}v[R|0]=0}W=f&15;a=x[e+1074392>>2];Jb(j+8|0,r,72);T:{if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){s=0;if(I>>>0>=A[e+1074416>>2]){break T}}Jb(j+8|0,r,88);s=(h|0)==(I|0)|(a|0)==(I|0);if(!(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])|!I)){break T}s=(a|0)==(I|0)}Jb(j+8|0,r,44);f=c?W|144:f;U:{if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){a=y[n|0];break U}a=y[n|0]&-2|(h|0)==(I|0)}v[n|0]=a&253|(s?2:0);Jb(j+8|0,r,66);h=(!I|Mb(x[x[j+8>>2]>>2],x[j+12>>2])^1)&b;V:{W:{X:{if(!(x[e+1074392>>2]|(!(y[Z|0]&32)|!d))){x[q+1075652>>2]=0;if(s){b=y[H|0];break X}if(!ki(x[k+8>>2],x[k+12>>2])){break V}v[q+1075795|0]=d;if(z[_>>1]<d>>>0){break V}a=D(d,104)+e|0;x[q+1075680>>2]=z[a+484410>>1];w[q+1075764>>1]=v[a+484417|0];break V}if(!s){break V}b=y[H|0];if(!d){break W}}v[q+1075795|0]=d}Y:{Z:{a=b&255;if(!Tc(a)){break Z}Jb(j+8|0,r,67);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break Z}c=w[q+1075762>>1];_:{if(!d|h){break _}m=Ey(e,a,d);if(!m){break _}c=v[Rj(e,m)+36|0]}b=(a+c|0)-132>>>0>=4294967176?b:0;break Y}if(!(x[C>>2]&25165856)){break Y}c=z[M>>1];if(!c){break Y}if(a){a=Tc(a)}else{a=1}if(!a){break Y}a=d;$:{if(!a){a=y[q+1075796|0];if(!a){break $}}if(x[((a<<2)+e|0)+900380>>2]?a>>>0<=c>>>0:0){break Y}b=0}d=0}if(!((K|0)!=25|f)){Jb(j+8|0,r,55);a=Mb(x[x[j+8>>2]>>2],x[j+12>>2]);d=a?0:d;b=a?0:b}Jb(j+8|0,r,65);c=(d|0)!=0;a=b&255;t=!a;aa=Mb(x[x[j+8>>2]>>2],x[j+12>>2]);O=1;aa:{if(x[C>>2]&16777248){break aa}Jb(j+8|0,r,107);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break aa}Jb(j,r,85);O=0;if(!Mb(x[x[j>>2]>>2],x[j+4>>2])){break aa}if(ki(x[k+8>>2],x[k+12>>2])){break aa}O=1;m=x[q+1075096>>2];if(!m){break aa}O=Qd(x[m>>2],x[m+20>>2])^1}m=c&t;t=c&aa;ba:{ca:{da:{ea:{fa:{ga:{if(!(x[C>>2]&1048580)){break ga}ha:{if((a|0)!=255){break ha}if(!(!((g|0)==1|d)&(K|0)!=13)){Jb(j+8|0,r,55);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break ha}}c=x[q+1075648>>2];if(v[c+60|0]&1?c:0){break ha}x[q+1075680>>2]=0;a=q+1075080|0;x[a>>2]=x[a>>2]|2097152;ia:{if(!(x[G>>2]&4096)){break ia}Jb(j+8|0,r,86);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break ia}x[a>>2]=x[a>>2]|4096}d=0;b=0;a=0;c=0;m=1;if(t){break ca}break ba}Jb(j+8|0,r,59);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])|x[G>>2]&4096){break ga}ja:{if(!a){b=y[q+1075789|0]-y[q+1075762|0]|0;break ja}if(a>>>0>250){O=0;t=1;b=0;break ja}ka:{if(d){break ka}Jb(j+8|0,r,98);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break ka}d=0;break ja}O=1;t=1}c=b;h=0;break fa}c=0;if(!m){break ea}}Jb(j+8|0,r,65);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break da}b=c;c=1}a=b;m=1;if(t){break ca}break ba}b=c;c=1;m=t}la:{if(z[M>>1]){a=x[q+1075096>>2]}else{if(z[_>>1]<d>>>0){break la}a=(D(d,104)+e|0)+484380|0}if(!a){break la}ma:{if(w[a+34>>1]<0){break ma}if(x[C>>2]==2){if(!Qd(x[a>>2],x[a+20>>2])){break ma}}x[q+1075680>>2]=z[a+30>>1]}if(!m){break la}Bp(k,z[a+28>>1],e)}a=b}Jb(j+8|0,r,71);if(!(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])|!d)){v[q+1075831|0]=32}na:{if(!z[M>>1]){break na}Jb(j+8|0,r,100);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])|!d){break na}if(Tc(a&255)){break na}b=x[G>>2];oa:{if(h){if(b&8){break oa}break na}if(!(b&4)){break na}}Xl(k);x[q+1075688>>2]=65536;b=q+1075080|0;x[b>>2]=x[b>>2]|2097152}if(c){Jb(j+8|0,r,11);pa:{qa:{ra:{if(!(Mb(x[x[j+8>>2]>>2],x[j+12>>2])|x[C>>2]==268435456)){b=z[M>>1];break ra}Jb(j+8|0,r,87);c=0;if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){c=ki(x[k+8>>2],x[k+12>>2])^1}b=z[M>>1];sa:{if(b){if(b>>>0<d>>>0){break qa}if(x[q+1075648>>2]!=x[((d<<2)+e|0)+900380>>2]|c){break sa}break qa}if((c^-1)&x[q+1075096>>2]==((D(d,104)+e|0)+484380|0)){break pa}}a=y[q+1075789|0]}if(!(b&65535)){break pa}}if(!(x[C>>2]&1048588)){break pa}Xl(k);v[q+1075810|0]=0;x[q+1075748>>2]=0;x[q+1075688>>2]=65536;b=q+1075080|0;x[b>>2]=x[b>>2]&-2101249|2097152;Jb(j+8|0,r,86);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break pa}x[b>>2]=x[b>>2]&-2049}d=O?d:0}m=a&255;ta:{if(m>>>0<251){break ta}Jb(j+8|0,r,50);ua:{if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])|!d){break ua}b=Ey(e,y[q+1075791|0],d);if(!b){break ua}b=D(b,104)+e|0;if(w[b+484414>>1]<0){break ua}x[q+1075680>>2]=z[b+484410>>1]}Jb(j+8|0,r,100);if(Ja=Mb(x[x[j+8>>2]>>2],x[j+12>>2]),Ka=0,Ma=x[G>>2]&4,Ma?Ja:Ka){break ta}d=0}b=Tc(m);if(b){v[q+1075794|0]=a;v[q+1075791|0]=a;if(!h){LM(e,l&65535,d,m,0)}fP(k)}va:{wa:{xa:{ya:{za:{if(d){c=q+1075096|0;t=x[c>>2];sp(e,k,d,h,1,1);a=x[c>>2];Aa:{if(!a|!(y[a+35|0]&2)){break Aa}O=x[e+1298300>>2];if(!td(O)){break Aa}Zy(O,l&65535,a+68|0)}Ba:{Ca:{if(x[C>>2]==1){if(!h){break Ca}Jb(j+8|0,r,85);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break Ca}break Ba}Jb(j+8|0,r,50);if((b|Mb(x[x[j+8>>2]>>2],x[j+12>>2])^1)!=1){break Ba}}v[q+1075795|0]=0}Jb(j+8|0,r,42);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){if(!b|(t|0)==x[c>>2]){break ya}break za}if(x[C>>2]&16777248){a=0;if(b&(t|0)!=x[c>>2]){break xa}}Jb(j+8|0,r,107);Da:{if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])|(!(b^1|h)|(t|0)==x[c>>2])){break Da}a=q+1075068|0;if(A[a>>2]>=A[k+4>>2]){break Da}x[a>>2]=0;break ya}Jb(j+8|0,r,85);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break ya}if(!ki(x[k+8>>2],x[k+12>>2])){break za}break ya}if(!m){a=h;break va}c=0;t=q+1075795|0;a=y[t|0];if(!(!a|b^1)){sp(e,k,a,h,!(x[q+1075096>>2]?1:x[q+1075648>>2]),!(x[C>>2]&1048580));v[t|0]=0;c=1}a=h;break wa}x[k>>2]=0;x[k+4>>2]=0}a=h}c=0;if(!m){break va}}b=x[q+1075096>>2];Ea:{if(!b|!(y[b+35|0]&2)){break Ea}h=x[e+1298300>>2];if(!td(h)){break Ea}if(!c){if(MM(h,l&65535)){break Ea}}Zy(h,l&65535,b+68|0)}b=l&65535;Ps(e,k,m,a,!(x[C>>2]&1048580),0,b);tN(x[C>>2],z[V>>1],L,b);if(!(!a|(!(x[C>>2]&1048580)|!d))){c=q+1075080|0;x[c>>2]=x[c>>2]|2097152;Xl(k);v[q+1075810|0]=0;x[q+1075748>>2]=0}if(!(x[q+1075080>>2]&512)){break va}if(!td(x[e+1298300>>2])){break va}if(m>>>0<=253){if((m|0)!=253){break va}Jb(j+8|0,r,99);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break va}}Jb(j+8|0,r,110);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){_y(x[e+1298300>>2],b,0,1,0)}Kj(x[e+1298300>>2],b)}Fa:{Ga:{switch(g-1|0){case 0:i=i>>>0>=64?64:i;x[q+1075680>>2]=i<<2;b=q+1075080|0;x[b>>2]=x[b>>2]|2097152;break Fa;case 1:break Ga;default:break Fa}}Zl(e,k,i,6)}if(z[M>>1]){JM(e,l&65535)}h=a}Jb(j+8|0,r,77);if(Ja=Mb(x[x[j+8>>2]>>2],x[j+12>>2]),Ka=0,Ma=x[((l<<5)+e|0)+480280>>2]&1024,Ma?Ja:Ka){break P}a=x[e+1074392>>2];Jb(j+8|0,r,75);c=a>>>0>=I>>>0;Ha:{Ia:{Ja:{Ka:{if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])|!I){break Ka}b=x[e+1074392>>2];if(!b){break Ja}c=1;if((b|0)!=(I|0)){break Ka}c=!y[Q|0]&(g|0)!=11}a=g;if(!c|a>>>0<3){break Ja}if((a|0)==11){a=j+8|0;Dy(a,e,y[H+3|0],y[H+4|0],I);a=y[Re(a)|0];In(e,k,z[j+8>>1]);if(a){break Ia}g=11;break Ja}Jb(j+8|0,r,62);La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{if(!(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])|i)){i=0;g=0;Sa:{switch(a-8|0){case 0:break Ra;case 1:break Sa;default:break Ja}}if(y[G+1|0]&16){break Ja}x[q+1075684>>2]=0;break Ja}Jb(j+8|0,r,41);Ta:{if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break Ta}if(i){v[q+1075826|0]=i;break Ta}i=y[q+1075826|0]}Ua:{switch(a-3|0){case 0:case 1:Va:{Wa:{if(i){break Wa}Jb(j+8|0,r,41);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break Wa}i=y[q+1075826|0];if(i){break Va}i=0;break Ja}v[q+1075826|0]=i}On(e,k,((a|0)==3?i<<4:i)&255);break Ja;case 2:if((I|0)!=x[e+1074392>>2]){Jb(j+8|0,r,41);g=5;if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break Ja}}Jb(j+8|0,r,41);Nn(e,k,i,Mb(x[x[j+8>>2]>>2],x[j+12>>2]));g=5;break Ja;case 3:if((I|0)!=x[e+1074392>>2]){Jb(j+8|0,r,41);g=6;if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break Ja}}Jb(j+8|0,r,41);Mn(e,k,i,Mb(x[x[j+8>>2]>>2],x[j+12>>2]));g=6;break Ja;case 11:break La;case 12:break Ma;case 10:break Na;case 9:break Oa;case 7:break Pa;case 6:break Qa;case 5:break Ra;case 4:break Ua;default:break Ja}}Jb(j+8|0,r,53);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){v[q+1075815|0]=i&15;g=7;break Ja}Ok(k,i<<4);g=7;break Ja}Ok(k,i);g=8;break Ja}Jb(j+8|0,r,62);py(e,k,i,Mb(x[x[j+8>>2]>>2],x[j+12>>2])^1);g=9;break Ja}Jb(j+8|0,r,62);py(e,k,i<<4&240,Mb(x[x[j+8>>2]>>2],x[j+12>>2])^1);g=10;break Ja}g=12;Jb(j+8|0,r,12);IM(e,l&65535,i<<2&252,Mb(x[x[j+8>>2]>>2],x[j+12>>2]));break Ja}Jb(j+8|0,r,12);HM(e,l&65535,i<<2&252,Mb(x[x[j+8>>2]>>2],x[j+12>>2]));g=13;break Ja}g=15;if(!s){break Ja}a=x[q+1075096>>2];if(!a|i>>>0>9){break Ja}Xa:{if(!i){d=x[q+1075656>>2];break Xa}d=x[zb(a+68|0,i-1|0)>>2];x[q+1075656>>2]=d}Pn(e,k,d);break Ja}g=14;if(i>>>0>1){break Ja}v[n|0]=y[n|0]&247|!i<<3}d=f;Ya:{Za:{_a:{$a:{switch(K-1|0){case 12:if(!(y[G+1|0]&16)){break Ia}a=D(l,872)+e|0;x[a+1075680>>2]=f>>>0>=64?256:f<<2;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ia;case 1:if(!f){d=0;if(v[C|0]&1){break Ha}}IM(e,l&65535,f,0);break Ia;case 2:if(!f){d=0;if(v[C|0]&1){break Ha}}HM(e,l&65535,f,0);break Ia;case 10:if(!f){d=0;if(x[C>>2]==1){break Ha}}On(e,k,f);break Ia;case 3:In(e,k,f);break Ia;case 5:if(!(!f&x[C>>2]==1)){On(e,k,f)}In(e,k,0);break Ia;case 4:Ok(k,f);break Ia;case 6:if(!(!f&x[C>>2]==1)){On(e,k,f)}Ok(k,0);break Ia;case 15:if(!(y[G+1|0]&16)){break Ia}break Ya;case 16:Jb(j+8|0,r,5);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){if(!(y[G+1|0]&16)){break Ia}if(f){break Ya}break Ia}d=Ln(e,z[e+1074446>>1],x[e+1074424>>2],l&65535,0);ab:{if(!(x[e+480180>>2]&16777250)){break ab}if(d){v[(D(l,872)+e|0)+1075827|0]=d;break ab}d=y[(D(l,872)+e|0)+1075827|0]}x[j+8>>2]=D(d,1e4);wc(j+8|0,D(x[x[e+8>>2]+24>>2],1e4));a=hb-16|0;hb=a;c=x[j+8>>2];x[a+8>>2]=c;b=x[e+8>>2];bb:{if(c>>>0>=(x[e+480180>>2]&16393?1e4:32e4)>>>0){c=x[e+480208>>2];Jb(a,e+1074312|0,92);if((Mb(x[x[a>>2]>>2],x[a+4>>2])|0)==((c&4096)>>>12|0)){break bb}x[a>>2]=D(x[b+24>>2],1e4);Ja=e+1074420|0,Ka=x[Fb(a+8|0,a)>>2],x[Ja>>2]=Ka;break bb}if(y[e+480209|0]&16){break bb}f=e+1074420|0;c=(c>>>0)/1e4|0;h=D(c&15,1e4);x[f>>2]=x[f>>2]+((c&240)==16?h:0-h|0);c=x[b+20>>2];b=x[b+24>>2];Jb(a,e+1074312|0,8);yo(f,D(c,1e4),Mb(x[x[a>>2]>>2],x[a+4>>2])?255e4:D(b,1e4))}hb=a+16|0;break Ha;case 9:if(!s|x[C>>2]==4&h){break Ia}sN(e,k,l&65535,x[e+1074424>>2],z[e+1074446>>1]);break Ia;case 43:if(!s){break Ia}b=Jia(x[(D(l,872)+e|0)+1075068>>2],0,f,0);a=lb;h=a>>>8|0;Pn(e,k,Uc((a&255)<<24|b>>>8,h));break Ia;case 0:if(x[e+1074392>>2]){break Ia}a=D(l,872)+e|0;cb:{if(y[a+1075789|0]?x[a+1075692>>2]:0){break cb}a=x[a+1075648>>2];if(a){if(bj(y[a+31|0])){break cb}}Jb(j+8|0,r,13);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break cb}if(x[C>>2]&16777248){break Ia}}if(!f){d=0;if(y[C|0]&5){break Ha}v[(D(l,872)+e|0)+1075797|0]=1;break Ha}a=D(l,872)+e|0;v[a+1075798|0]=f;v[a+1075797|0]=1;break Ia;case 14:if(x[C>>2]&1048580){f=f&240?f:y[(D(l,872)+e|0)+1075799|0]&240|f;if(!(f&15)){f=y[(D(l,872)+e|0)+1075799|0]&15|f}d=f|256}else{d=f}Jb(j+8|0,r,23);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){b=l&65535;if(d){v[(D(l,872)+e|0)+1075799|0]=d;a=d}else{a=y[(D(l,872)+e|0)+1075799|0]}oy(e,b,a&255,(g|0)==15?i+1|0:0);break Ha}db:{if(d){v[(D(l,872)+e|0)+1075799|0]=d;break db}d=y[(D(l,872)+e|0)+1075799|0]}oy(e,l&65535,d,(g|0)==15?i+1|0:0);break Ha;case 17:if(!(y[G+1|0]&16)){break Ia}Jb(j+8|0,r,22);eb:{fb:{if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){if(!f){f=0;break fb}if(y[G|0]&4){break fb}a=f&240?f-16|0:f;f=a-((a&15)!=0)|0;v[(D(l,872)+e|0)+1075832|0]=f;break fb}Jb(j+8|0,r,71);if(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break eb}}a=(D(l,872)+e|0)+1075831|0;v[a|0]=y[a|0]|128}a=D(l,872)+e|0;v[a+1075797|0]=18;if(!f){d=0;break Ha}v[a+1075832|0]=f;break Ia;case 22:if(!(y[G+1|0]&16)){break Ia}a=x[C>>2];d=f<<!(a&59593760);if(d>>>0<=128){x[e+1074456>>2]=d<<1;break Ha}if(a&16777250){break Ha}x[e+1074456>>2]=256;break Ha;case 23:Jb(j+8|0,r,9);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){GM(e,f,(D(l,872)+e|0)+1075809|0);break Ia}GM(e,f,$);break Ia;case 8:if(!(y[G+1|0]&16)){break Ia}Zl(e,k,f,8);break Ia;case 28:py(e,k,f,1);break Ia;case 7:jN(k,f);break Ia;case 25:kN(e,k,f);break Ia;case 18:h=e+1074376|0;b=l&65535;d=D(b,872);c=(h+d|0)+616|0;a=f&15;gb:{hb:{switch(f>>>4|0){case 0:b=(f&1)<<14;c=z[e+480188>>1];a=0;while(1){if((a|0)==(c|0)){break gb}d=(D(a,872)+e|0)+1075080|0;x[d>>2]=(b|x[d>>2]&-16385)^16384;a=a+1|0;continue};case 1:if(a){my(e,c,a);break gb}if(!(x[e+480180>>2]&1048580)){break gb}my(e,c,0);break gb;case 2:if(a){ly(e,c,a);break gb}if(!(x[e+480180>>2]&1048580)){break gb}ly(e,c,0);break gb;case 3:b=(e+d|0)+1075080|0;x[b>>2]=x[b>>2]&-1048577|((a|0)!=0)<<20;break gb;case 4:v[(e+d|0)+1075814|0]=f&7;break gb;case 5:if(!(y[e+480209|0]&16)){break gb}d=x[e+480180>>2];if(d&69206025){c=D(b,872)+e|0;a=a<<28>>24;w[c+1075764>>1]=a;d=c+1075692|0;if(!x[d>>2]){break gb}if(!Tc(y[c+1075780|0])){break gb}b=D(b,872)+e|0;Ja=d,Ka=Og(e,y[b+1075789|0],a,x[b+1075696>>2]),x[Ja>>2]=Ka;break gb}c=Tc(y[(D(b,872)+e|0)+1075780|0]);if((d|0)==16){if(!c){break gb}c=D(b,872)+e|0;d=x[c+1075096>>2];if(!d){break gb}v[d+37|0]=a;w[c+1075764>>1]=a;c=c+1075692|0;if(!x[c>>2]){break gb}b=D(b,872)+e|0;Ja=c,Ka=Og(e,y[b+1075789|0],a,x[b+1075696>>2]),x[Ja>>2]=Ka;break gb}if(!c){break gb}a=D(b,872)+e|0;b=(f<<4^-128)<<24>>24;w[a+1075764>>1]=b;c=a+1075692|0;if(!x[c>>2]){break gb}Ja=c,Ka=Og(e,y[a+1075789|0],b,x[a+1075696>>2]),x[Ja>>2]=Ka;break gb;case 6:if(!(y[e+480209|0]&16)){break gb}Cy(e,h,b,a);break gb;case 7:v[(e+d|0)+1075817|0]=f&7;break gb;case 8:if(!(y[e+480209|0]&16)){break gb}Zl(e,c,a,4);break gb;case 9:oy(e,b,a,0);break gb;case 10:if(a){Nn(e,c,a,0);break gb}if(!(x[e+480180>>2]&1048580)){break gb}Nn(e,c,0,0);break gb;case 11:if(a){Mn(e,c,a,0);break gb}if(!(x[e+480180>>2]&1048580)){break gb}Mn(e,c,0,0);break gb;case 12:qy(e,b,a,0);break gb;case 15:break hb;default:break gb}}if(x[e+480180>>2]==1){v[(D(b,872)+e|0)+1075838|0]=a;if(!(y[e+480209|0]&16)){break gb}KM(e,c);break gb}v[(D(b,872)+e|0)+1075836|0]=a}break Ia;case 19:FM(e,l&65535,f);break Ia;case 24:Jb(j+8|0,r,55);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){if(x[e+1074392>>2]!=(f|0)){break Ia}a=x[(D(l,872)+e|0)+1075648>>2];if(v[a+60|0]&1?a:0){break Za}if(!(!(y[Q|0]|y[R|0])|f)){a=(D(l,872)+e|0)+1075080|0;x[a>>2]=x[a>>2]|4096;break Za}a=D(l,872)+e|0;x[a+1075680>>2]=0;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Za}if(y[G+1|0]&16){break Za}break Ia;case 27:a=(f&240)-16>>>4|0;if(a>>>0>9){break Ia}if(!(1<<a&880)){if(!a){break _a}if((a|0)!=1){break Ia}EM(e,k,f&15);break Ia}Jb(j+8|0,r,58);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break Ia}FM(e,l&65535,f);break Ia;case 34:case 35:if(!(y[G+1|0]&16)&(K|0)!=36){break Ia}b=l&65535;pN(e,b,L,(K|0)==36);a=Is(e,x[k+88>>2],x[k+656>>2]);if(!a){break Ia}mb[x[x[a>>2]+80>>2]](a,(z[k+774>>1]<<16>>16)+32768>>>2|0,b);break Ia;case 20:if(!(y[G+1|0]&16)|f>>>0>64){break Ia}a=D(l,872)+e|0;x[a+1075740>>2]=f;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ia;case 21:h=x[C>>2];d=x[G>>2];a=f;ib:{if(a){v[k+816|0]=a;break ib}a=y[k+816|0]}b=a&15;c=a&255;jb:{kb:{if(!((b|0)!=15|c>>>0<16)){if(!(d&4096)){break jb}a=c>>>4|0;break kb}d=d&4096;g=c&240;if(!(!b|(g|0)!=240)){if(!d){break jb}a=0-b|0;break kb}if(d){break jb}if(b){a=0-b|0;if(!(h&25690144)|!g){break kb}break jb}if((a&255)>>>0<16){break jb}a=c>>>4|0}Ja=k,Ka=Yb(a+x[k+748>>2]|0,0,64),x[Ja+748>>2]=Ka}break Ia;case 26:iN(k,f);break Ia;case 29:if(!(y[G+1|0]&16)){break Ia}a=D(l,872)+e|0;x[a+1075716>>2]=f;Jb(j+8|0,r,60);if(Ja=0,Ka=Mb(x[x[j+8>>2]>>2],x[j+12>>2]),Ma=y[a+1075722|0]&4,Ma?Ja:Ka){break Ia}a=D(l,872)+e|0;x[a+1075732>>2]=f;x[a+1075724>>2]=f;break Ia;case 11:nN(e,L,l&65535);break Ia;case 13:a=mN(e,L,l&65535,f);if((a|0)==-1){break Ia}x[e+1074436>>2]=a;if(!(y[e+480208|0]&32)){break Ia}w[e+1074444>>1]=z[e+1074448>>1];break Ia;case 37:case 38:case 39:case 40:b=(K|0)==38|(K|0)==40;c=(K&254)==40;lb:{mb:{nb:{if(y[e+480209|0]&16){a=y[k+848|0];d=f&240;if(d){a=d|a&15;v[k+848|0]=a}d=f&15;if(d){a=d|a&-16;v[k+848|0]=a}v[k+849|0]=(a&240)>>>4;if(x[e+480180>>2]!=32768){break lb}break nb}if(x[e+480180>>2]==32768){break nb}a=y[k+849|0]-1|0;v[k+849|0]=a;if(a&255){break lb}a=y[k+848|0];break mb}a=y[k+848|0];if((a&240)==16){break mb}if(!(y[e+480209|0]&16)){break lb}}v[k+849|0]=(a&240)>>>4;a=a&15;a=b?a:0-a|0;b=x[k+656>>2];ob:{if(cj(b)){x[k+852>>2]=x[k+852>>2]+D(a,x[x[b+44>>2]+36>>2]);break ob}Ja=k,Ka=Og(e,Hs(e,x[k+700>>2],w[k+772>>1],x[k+704>>2])+a|0,w[k+772>>1],x[k+704>>2]),x[Ja+700>>2]=Ka}if(!c){break lb}x[k>>2]=0;x[k+4>>2]=0}break Ia;case 41:rN(k,f);break Ia;case 42:if(x[e+1074392>>2]|W>>>0>1|f>>>0>47){break Ia}a=(f&240)==16;c=a?z[e+480188>>1]-1|0:l;d=a?0:l;a=((W|0)==1)<<26;while(1){b=d&65535;if(b>>>0>(c&65535)>>>0){break Ia}h=((b<<5)+e|0)+480280|0;x[h>>2]=a|x[h>>2]&-67108865;b=(D(b,872)+e|0)+1075080|0;x[b>>2]=a|x[b>>2]&-67108865;d=d+1|0;continue};case 44:break $a;default:break Ha}}qN(k,f);break Ia}DM(e,k,f&15);break Ia}Kn(e,k);break Ia}xN(e,L,f)}d=f}Jb(j+8|0,r,78);if(!(!Mb(x[x[j+8>>2]>>2],x[j+12>>2])|!d)){fN(k,d&255)}a=y[Q|0];if(!a){break P}v[q+1075796|0]=a}l=l+1|0;continue}break}a=1;break j}a=0}hb=u+32|0;M=!x[e+1074420>>2]|a^1;pb:{if(M){break pb}a=vN(e,e+1074376|0);x[e+1074380>>2]=a;x[e+1074404>>2]=a;b=Td(z[e+480188>>1],1,31);qb:{if(ud(y[e+1074366|0])){a=x[e+24628>>2];if((a|0)>=129){a=((D(a-128|0,b+4|0)|0)/16|0)+128|0}k=((D(x[e+480228>>2],a)<<1&-128)>>>0)/y[(b>>>1|0)+32512|0]|0;break qb}k=x[e+480228>>2]}w[e+480212>>1]=0;s=e+1074312|0;O=e+1074365|0;C=e+480180|0;L=e+480210|0;H=e+480209|0;Q=e+1074366|0;R=e+1074364|0;W=e+1074360|0;t=0;while(1){if((t|0)==256){a=x[e+24608>>2];b=z[e+480212>>1];if(a>>>0>b>>>0){break pb}i=hb-16|0;hb=i;x[i+8>>2]=e;c=e+1074478|0;f=c+(a<<1)|0;if((f|0)!=(c|0)){b=c+(b<<1)|0;rb:{a=f-c|0;if((a|0)<3){break rb}a=a>>1;h=a-2>>>1|0;while(1){if((h|0)<0){break rb}LL(c,x[i+8>>2],a,c+(h<<1)|0);h=h-1|0;continue}}d=f-c>>1;a=f;while(1){if((a|0)!=(b|0)){if(Lk(x[i+8>>2],z[a>>1],z[c>>1])){KL(a,c);LL(c,x[i+8>>2],d,c)}a=a+2|0;continue}break}a=f-c>>1;while(1){if((a|0)>1){g=z[c>>1];b=c;m=x[i+8>>2];h=0;d=a;l=a-2>>>1|0;while(1){a=h<<1;h=a|1;k=a+2|0;a=k+b|0;if((d|0)>(k|0)){n=k;k=Lk(m,z[a>>1],z[a+2>>1]);h=k?n:h;a=k?a+2|0:a}w[b>>1]=z[a>>1];b=a;if((h|0)<=(l|0)){continue}break}a=f-2|0;sb:{if((a|0)==(b|0)){w[b>>1]=g;break sb}w[b>>1]=z[a>>1];w[a>>1]=g;k=x[i+8>>2];b=b+2|0;a=b-c>>1;tb:{if((a|0)<2){break tb}h=a-2|0;a=c+(h&-2)|0;b=b-2|0;if(!Lk(k,z[a>>1],z[b>>1])){break tb}h=h>>>1|0;m=z[b>>1];while(1){ub:{g=b;b=a;w[g>>1]=z[a>>1];if(!h){break ub}a=h-1|0;h=a>>>1|0;a=c+(a&-2)|0;if(Lk(k,z[a>>1],m)){continue}}break}w[b>>1]=m}}a=d-1|0;f=f-2|0;continue}break}}hb=i+16|0}else{n=D(t,872)+e|0;j=n+1075080|0;vb:{if(!(x[j>>2]&4096)|(x[n+1075016>>2]|(x[n+1075012>>2]|x[n+1075688>>2]))){break vb}Jb(o+16|0,s,64);if(Mb(x[x[o+16>>2]>>2],x[o+20>>2])){break vb}x[n+1075068>>2]=0;a=n+1075084|0;x[a>>2]=0;x[a+4>>2]=0}a=z[e+480188>>1];c=x[j>>2];wb:{if(x[n+1075068>>2]|a>>>0>t>>>0?c&1024:1){if(a>>>0>t>>>0){QL(e,t&65535)}w[n+1075834>>1]=0;break wb}d=0;K=n+1075712|0;x[K>>2]=0;G=n+1075672|0;x[G>>2]=0;q=n+1075e3|0;b=q;x[b>>2]=0;x[b+4>>2]=0;x[n+1075092>>2]=0;x[o+44>>2]=1065353216;w[o+42>>1]=0;u=n+1075648|0;I=x[u>>2];x[o+36>>2]=0;l=0;r=n+1075692|0;l=x[r>>2]?x[n+1075068>>2]!=0:l;f=n+1074992|0;xb:{yb:{zb:{if(a>>>0<=t>>>0){break zb}if(y[((t<<5)+e|0)+480288|0]){break yb}if(!I){break zb}d=y[I+34|0]!=0}if((d|l)!=1){break xb}}x[o+8>>2]=x[n+1075680>>2];x[o+32>>2]=x[n+1075744>>2];Jb(o+16|0,s,28);b=o+8|0;a=Mb(x[x[o+16>>2]>>2],x[o+20>>2])?o+32|0:b;c=e+1074312|0;Ab:{if(Tb(c,28)){x[a>>2]=x[a>>2]+w[f+776>>1];fe(a,0,64);break Ab}d=Tb(c,1);c=w[f+776>>1];if(d){x[a>>2]=c+x[a>>2];fe(a,0,256);break Ab}x[f+688>>2]=c+x[f+688>>2];fe(f+688|0,0,256);x[a>>2]=x[f+688>>2];w[f+776>>1]=0}Bb:{Cb:{a=e+1074312|0;if(!Tb(a,28)){if(!Tb(a,1)){break Cb}}x[f+684>>2]=x[f+692>>2]+w[f+778>>1];fe(f+684|0,0,256);break Bb}x[f+692>>2]=x[f+692>>2]+w[f+778>>1];fe(f+692|0,0,256);w[f+778>>1]=0;x[f+684>>2]=x[f+692>>2]}Db:{if(!(y[f+90|0]&4)|(x[e+480208>>2]&2101248)==2101248){break Db}Eb:{if(x[b>>2]<=0){if(!Tb(e+1074312|0,21)){break Eb}}d=5;if(!(y[e+480180|0]&5)){d=Tb(e+1074312|0,21)?5:6}a=_x(e,y[f+825|0],y[f+820|0]);Fb:{if((y[f+825|0]&3)!=1){break Fb}if(!Tb(e+1074312|0,89)){break Fb}a=y[f+819|0];h=y[f+820|0];c=h<<2&124;a=(!(y[f+90|0]&2)|y[e+480209|0]&16?a:y[f+823|0]+a|0)&32?c^127:c;a=h&32?0-a|0:a}if(x[e+480180>>2]!=131072){a=x[b>>2]+((D(y[f+827|0],a)|0)/(1<<d)|0)|0}else{c=64-a|0;a=x[b>>2];a=((D(y[f+827|0],D(c,a))|0)/-8192|0)+a|0}x[b>>2]=a}a=x[e+480208>>2];if(!(x[e+480180>>2]&16777248)|a&4?a&4096:0){break Db}a=Tb(e+1074312|0,21);c=y[f+826|0];d=y[f+820|0];v[f+820|0]=(a?c<<2:d)+(a?d:c)}c=hb-16|0;hb=c;d=e+1074312|0;Jb(c+8|0,d,71);m=t&65535;a=D(m,872)+e|0;Gb:{if(Mb(x[x[c+8>>2]>>2],x[c+12>>2])){i=v[a+1075831|0];if((i|0)>=0){break Gb}if(!(y[e+480209|0]&16|y[a+1075797|0]!=18)){d=a+1075831|0;Hb:{Ib:{if((i&-33)!=-64){h=i&223;if((h|0)!=128){break Ib}i=y[a+1075832|0]>>>4|-64;break Hb}i=y[a+1075832|0]&15|-128;break Hb}i=h-1|0}v[d|0]=i;d=a+1075080|0;x[d>>2]=x[d>>2]|2097152}if((i&224)!=128){break Gb}x[b>>2]=0;break Gb}if(y[a+1075797|0]!=18){break Gb}Jb(c+8|0,d,22);Jb:{if(Mb(x[x[c+8>>2]>>2],x[c+12>>2])){d=y[a+1075831|0];i=d<<24>>24;if(!(!x[a+1075068>>2]|(i|0)>=0)){h=a+1075831|0;Kb:{Lb:{if((d|0)!=192){if((d|0)!=128){break Lb}i=y[a+1075832|0]>>>4|-64;break Kb}i=y[a+1075832|0]&15|-128;break Kb}i=i-1|0}v[h|0]=i}if((i&192)!=128){break Jb}x[b>>2]=0;break Jb}d=y[a+1075832|0];g=d>>>4|0;d=g+(d&15)|0;h=x[e+480180>>2];if(!(y[e+480208|0]&4?0:h&16777248)){g=g+1|0;d=d+2|0}i=y[a+1075831|0];if(!(h&4)){d=(i&255)>>>0<d>>>0?i:0;if((d&255)>>>0>=g>>>0){x[b>>2]=0}v[a+1075831|0]=d+1;break Jb}Mb:{if(y[e+480209|0]&16){i=i&255?i-1|0:0;break Mb}v[a+1075831|0]=i+1}if(((i&255)>>>0)%(d>>>0)>>>0<g>>>0){break Jb}x[b>>2]=0}d=a+1075080|0;x[d>>2]=x[d>>2]|2097152}Nb:{if(y[a+1075797|0]!=18){break Nb}h=x[a+1075648>>2];if(!h){break Nb}d=y[h+34|0];if(x[a+1075080>>2]&134218752|(!d|y[h+15|0]&2)){break Nb}g=y[a+1075791|0];if(!Tc(g)){break Nb}d=x[(D(d,160)+e|0)+906140>>2];if(!d){break Nb}g=mb[x[x[d>>2]+100>>2]](d,g,m)|0;i=x[b>>2];if(!(!g|i)){mb[x[x[d>>2]+92>>2]](d,h,y[a+1075791|0]+255|0,0,m);break Nb}if(g|!i){break Nb}mb[x[x[d>>2]+92>>2]](d,h,y[a+1075791|0],z[a+1075680>>1],m)}hb=c+16|0;fe(b,0,256);x[o+8>>2]=x[o+8>>2]<<6;Ob:{if(I){Jb(o+16|0,s,31);if(Mb(x[x[o+16>>2]>>2],x[o+20>>2])){Ms(e,f)}a=o+8|0;Pb:{if(!Yx(e,f,0)){break Pb}b=x[f+656>>2];d=e+1074312|0;h=Tb(d,31);c=x[f+724>>2];if(c?0:h){break Pb}g=c-Tb(d,31)|0;c=Ap(b+48|0,g,256,64);i=y[b+65|0];Qb:{if((i|0)==255){break Qb}h=w[f+728>>1];if((h|0)==-1){break Qb}i=zb(x[b+48>>2],i);V=y[i+2|0];b=V<<2;c=(g|0)==z[i>>1]?b:c;if(Tb(d,94)){c=h+(c-b<<1)|0;break Qb}if(!V){c=0;break Qb}c=(D(c,h)|0)/(b|0)|0}Ja=a,Ka=(D(Yb(c,0,512),x[a>>2])|0)/256|0,x[Ja>>2]=Ka}$M(f,a);Rb:{if(!Yx(e,f,1)){break Rb}a=x[f+656>>2];b=e+1074312|0;d=Tb(b,31);c=x[f+732>>2];if(c?0:d){break Rb}b=Ap(a+68|0,c-Tb(b,31)|0,64,64)-32|0;a=x[f+684>>2];Ja=f,Ka=Yb(((D(b,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),x[Ja+684>>2]=Ka}Jb(o+16|0,s,115);if(Mb(x[x[o+16>>2]>>2],x[o+20>>2])){break Ob}b=y[n+1075789|0];if(!b){break Ob}a=x[u>>2];if(!a|!y[a+26|0]){break Ob}bN(n+1075676|0,b,y[a+26|0],y[a+27|0]);break Ob}if(!(y[n+1075081|0]&16)){break Ob}x[n+1075688>>2]=0;x[o+8>>2]=0}Sb:{if(y[n+1075843|0]&8){i=0;x[o+8>>2]=0;break Sb}i=x[o+8>>2];if(!i){i=0;break Sb}if(y[n+1075083|0]&8){x[G>>2]=0;break Sb}if(ud(y[O|0])){a=D(x[o+32>>2],x[n+1075740>>2]);b=a;c=a>>31;a=i<<8;Ja=G,Ka=Ec(Kia(Jia(b,c,a,a>>31),lb,1048576,0),lb),x[Ja>>2]=Ka;break Sb}a=D(x[o+32>>2],x[n+1075740>>2]);b=a;c=a>>31;a=D(x[e+1074456>>2],i);Ja=G,Ka=Ec(Kia(Jia(b,c,a,a>>31),lb,1048576,0),lb),x[Ja>>2]=Ka}x[K>>2]=i;Tb:{Ub:{i=x[r>>2];if(!(x[C>>2]==2|(i|0)>=x[e+480260>>2])){if(!Xi(e)){break Ub}i=x[r>>2]}if((i|0)<x[e+480264>>2]){break Tb}Jb(o+16|0,s,113);if(!Mb(x[x[o+16>>2]>>2],x[o+20>>2])){break Tb}if(Xi(e)){break Tb}x[r>>2]=x[e+480264>>2];break Tb}x[r>>2]=x[e+480260>>2]}Jb(o+16|0,s,73);a=x[r>>2];x[o+36>>2]=a;Vb:{if((x[j>>2]&1572864)!=1572864){break Vb}b=x[e+480208>>2];if(b&2097152){if(!Qs(y[n+1075782|0],y[n+1075783|0])|b&4096){break Vb}}b=n+1075704|0;Wb:{if((a|0)==x[b>>2]){i=x[n+1075708>>2];break Wb}x[b>>2]=a;c=a;a=n+1075764|0;b=n+1075696|0;i=Og(e,Hs(e,c,w[a>>1],x[b>>2]),w[a>>1],x[b>>2]);x[n+1075708>>2]=i}x[o+36>>2]=i}g=hb-16|0;hb=g;h=D(m,872)+e|0;b=x[h+1075648>>2];Xb:{if(!b){break Xb}a=y[b+34|0];if(!a|y[b+15|0]&2|(!x[(D(a,160)+e|0)+906140>>2]|x[h+1075080>>2]&134218752)){break Xb}c=y[h+1075783|0];a=0;d=y[h+1075791|0];if(Tc(d)){a=y[Gb(b+108|0,d-1|0)|0]}Yb:{Zb:{if((c|0)==1){i=0;_b:{$b:{switch((A[e+1074392>>2]%3|0)-1|0){case 0:i=y[h+1075798|0]>>>4|0;break _b;case 1:break $b;default:break _b}}i=y[h+1075798|0]&15}v[h+1075793|0]=a;if(y[h+1075792|0]==(a+i|0)){break Yb}b=a;if(!(y[e+480209|0]&16)){break Zb}b=a;if(!Tc(y[h+1075780|0])){break Zb}break Yb}i=0;if(y[h+1075780|0]|!y[h+1075792|0]){break Yb}b=y[h+1075793|0]}Wl(e,m,(b&255)+i|0,z[h+1075680>>1])}d=y[h+1075792|0];ac:{if(!d){if(!(y[e+480209|0]&16)|(c|0)!=1){break ac}if(Tc(y[h+1075780|0])){break ac}d=a;if(!Tc(a)){break ac}}Wl(e,m,(d&255)+255|0,0)}v[h+1075792|0]=y[h+1075783|0]==1?y[h+1075793|0]+i|0:0}bc:{if(y[h+1075797|0]!=1){break bc}if(cj(x[h+1075648>>2])){c=0;cc:{dc:{ec:{switch(A[e+1074392>>2]%3|0){case 1:c=y[h+1075798|0]>>>4|0;break dc;case 0:break dc;case 2:break ec;default:break cc}}c=y[h+1075798|0]&15}w[o+42>>1]=c}a=h+1075843|0;v[a|0]=y[a|0]|96;break bc}if(!(!(y[e+480209|0]&16)|x[e+480180>>2]!=1048576)){a=Og(e,y[h+1075789|0],w[h+1075764>>1],x[h+1075696>>2]);x[o+36>>2]=a;x[h+1075692>>2]=a}b=e+1074312|0;Jb(g+8|0,b,13);if(Mb(x[x[g+8>>2]>>2],x[g+12>>2])){c=y[h+1075798|0];if(!c){break bc}a=65536;fc:{switch(((A[e+1074392>>2]%(x[e+1074400>>2]+x[e+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:c=c<<4;case 0:a=x[((c&240)<<2)+37664>>2];break;default:break fc}}d=Xi(e);b=x[o+36>>2];c=b>>31;if(d){a=Jia(b,c,a,a>>31);d=lb;a=a+32768|0;d=a>>>0<32768?d+1|0:d;a=Kia(a,d,65536,0);b=lb}else{d=(a|0)/2|0;h=d>>31;m=c<<16|b>>>16;c=b<<16;b=c+d|0;h=h+m|0;a=Kia(b,b>>>0<c>>>0?h+1|0:h,a,a>>31);b=lb}Ja=o,Ka=Ec(a,b),x[Ja+36>>2]=Ka;break bc}Jb(g+8|0,b,51);if(Mb(x[x[g+8>>2]>>2],x[g+12>>2])){if(y[e+480209|0]&16){break bc}gc:{hc:{a=x[e+1074416>>2];a=a-(A[e+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break hc}if((a|0)==16){break bc}i=0;ic:{switch((a|0)%3|0){case 0:break bc;case 2:break hc;case 1:break ic;default:break gc}}i=y[h+1075798|0]>>>4|0;break gc}i=y[h+1075798|0]&15}b=h+1075764|0;a=h+1075696|0;c=Hs(e,x[o+36>>2],w[b>>1],x[a>>2])+i|0;b=Og(e,c,w[b>>1],x[a>>2]);x[o+36>>2]=b;if(c>>>0<109){break bc}x[g+8>>2]=b;Ja=g,Ka=Og(e,109,0,x[a>>2]),x[Ja+4>>2]=Ka;Ja=o,Ka=x[_c(g+8|0,g+4|0)>>2],x[Ja+36>>2]=Ka;break bc}c=x[e+1074392>>2];d=e+480180|0;a=x[d>>2];jc:{if((a|0)!=1){i=y[h+1075789|0];break jc}i=Hs(e,x[o+36>>2],w[h+1075764>>1],x[h+1075696>>2]);a=x[d>>2]}kc:{lc:{switch((((a&67633152?c+2|0:c)>>>0)%3|0)-1|0){case 0:i=(y[h+1075798|0]>>>4|0)+i|0;break kc;case 1:break lc;default:break kc}}i=(y[h+1075798|0]&15)+i|0}if(!(a&67633408|y[h+1075789|0]!=(i&255))){Jb(g+8|0,b,82);if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break bc}}if(y[e+480210|0]&32){a=i&255;if((a|0)==85){x[o+36>>2]=2147483647;break bc}i=a>>>0>85?i-37|0:i}a=Og(e,i&255,w[h+1075764>>1],x[h+1075696>>2]);x[o+36>>2]=a;if(x[e+480180>>2]&71860480){x[h+1075692>>2]=a;break bc}Jb(g+8|0,b,82);if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break bc}v[h+1075792|0]=i}hb=g+16|0;if(!(!(y[L|0]&33)|x[o+36>>2]==2147483647)){mc:{if(x[C>>2]==2){i=452;a=3424;break mc}a=D(z[n+1075764>>1]>>>4&15,24);b=z[a+33398>>1]>>>1|0;i=b>>>0<=452?452:b;a=z[a+33376>>1]<<1}fe(o+36|0,i,a);fe(r,i,a)}gN(e,f);c=x[j>>2]}nc:{if(!(c&256)|y[H|0]&64){break nc}Jb(o+16|0,s,37);if(!Mb(x[x[o+16>>2]>>2],x[o+20>>2])){break nc}x[n+1075676>>2]=128}g=t&65535;QL(e,g);oc:{if(!l){break oc}a=aN(e,f,o+36|0);if((a|0)<0|!(y[n+1075081|0]&2)){break oc}b=x[e+1298300>>2];if(!td(b)){break oc}yp(b,g,a>>>2&255,1)}pc:{if(y[n+1075782|0]!=8){break pc}qc:{rc:{a=y[n+1075783|0];switch(a-5|0){case 1:break pc;case 0:case 2:break qc;default:break rc}}if((a|0)!=26){break pc}}a=x[C>>2];if((a|0)==4){if(y[H|0]&16){break pc}a=n+1075811|0;v[a|0]=y[a|0]+y[n+1075815|0];break pc}if(!(a&16777248)){break pc}Ok(f,y[n+1075784|0]);PL(e,g,o+36|0,o+44|0)}PL(e,g,o+36|0,o+44|0);sc:{if(!l){break sc}x[o+32>>2]=0;c=o+36|0;l=hb-16|0;hb=l;m=x[f+104>>2];tc:{if(!m|!y[m+40|0]){break tc}r=cj(x[f+656>>2]);i=Xi(e);a=i?38688:37664;h=i?37664:38688;b=e+480180|0;if(!(r|!Tb(e+1074312|0,21)|x[b>>2]==1048576)){r=y[m+41|0];if(!r){break tc}b=y[f+818|0];x[l+12>>2]=x[f+756>>2]+y[m+39|0];Rh(l+12|0,y[m+40|0]<<8);d=x[l+12>>2];v[f+818|0]=b+r;x[f+756>>2]=d;r=(d|0)/256|0;uc:{vc:{switch(y[m+38|0]-1|0){case 3:d=NL(Jn(e))+-64|0;break uc;case 2:d=64-(b+1>>>1|0)|0;break uc;case 1:d=(b+1>>>1|0)+-64|0;break uc;case 0:d=(b^-1)>>>1&64;break uc;default:break vc}}d=v[b+33968|0]}Rh(c,8388607);b=x[c>>2]<<8;x[c>>2]=b;V=D(d,r);m=(V|0)/64|0;d=m>>31;m=(d^m)-d|0;d=m&3;m=m>>>2|0;r=b>>31;wc:{xc:{if((V|0)<=-64){a=x[(m<<2)+a>>2];a=Ec(Kia(Jia(a,a>>31,b,r),lb,65536,0),lb)-b|0;if(!d){break wc}h=i?37600:37536;break xc}a=x[h+(m<<2)>>2];a=Ec(Kia(Jia(a,a>>31,b,r),lb,65536,0),lb)-b|0;if(!d){break wc}h=i?37536:37600}d=x[(d<<2)+h>>2];a=(Ec(Kia(Jia(b,r,d,d>>31),lb,65536,0),lb)+a|0)-b|0}x[c>>2]=(a+b|0)/256;x[o+32>>2]=a&255;break tc}d=x[b>>2]&16777248;b=y[m+39|0];yc:{if(!(d|b)){x[f+756>>2]=y[m+40|0]<<8;break yc}zc:{Ac:{if(d){i=b<<1;d=x[f+756>>2];b=f+756|0;break Ac}if(y[f+89|0]&8){break zc}d=((y[m+40|0]<<8&65280)>>>0)/(b>>>0)|0;i=x[f+756>>2];b=f+756|0}x[b>>2]=d+i}Rh(f+756|0,y[m+40|0]<<8)}b=y[f+818|0]+y[m+41|0]|0;v[f+818|0]=b;b=b<<24>>24;Bc:{Cc:{switch(y[m+38|0]-1|0){case 3:v[f+818|0]=b+1;d=v[(b&63)+33904|0];break Bc;case 2:d=(64-(b>>>1|0)&127)+-64|0;break Bc;case 1:d=((b>>>1|0)- -64&127)+-64|0;break Bc;case 0:d=(b|0)>=0?-64:64;break Bc;default:break Cc}}d=0-v[(b&255)+33968|0]|0;if(x[e+480180>>2]!=1048576){break Bc}d=(64-v[(b+-64&255)+33968|0]|0)/2<<16>>16}b=d;d=D(b,x[f+756>>2]);i=(d|0)/256|0;if(r){B[o+44>>2]=B[o+44>>2]+E(E(E(E(y[m+40|0])*E(.05000000074505806))*E(b|0))*E(.000244140625));v[f+851|0]=y[f+851|0]|64;break tc}if(x[e+480180>>2]!=4){Dc:{if((d|0)<=-256){i=0-i|0;d=i>>>8|0;b=(d<<2)+a|0;break Dc}a=h;d=i>>>8|0;b=a+(d<<2)|0}h=x[c>>2];d=x[((d<<2)+a|0)+4>>2];a=x[b>>2];a=((D(d-a|0,i>>>2&63)|0)/64|0)+a|0;a=Ec(Kia(Jia(h,h>>31,a,a>>31),lb,256,0),lb);x[c>>2]=a;x[o+32>>2]=a&255;x[c>>2]=x[c>>2]/256;break tc}x[c>>2]=x[c>>2]+((d|0)/16384|0)}hb=l+16|0;l=x[o+36>>2];if((l|0)<=x[e+480260>>2]){Jb(o+16|0,s,81);if(Mb(x[x[o+16>>2]>>2],x[o+20>>2])){x[n+1075068>>2]=0}l=x[e+480260>>2];x[o+36>>2]=l}Ec:{if(!cj(x[u>>2])){break Ec}a=n+1075843|0;b=y[a|0];if(!(x[e+1074392>>2]|!(b&32)?b&64:1)){break Ec}dP(f,B[o+44>>2],w[o+42>>1],e);b=a;a=y[a|0];v[b|0]=(a&64?-65:-33)&a}a=o+16|0;Fy(a,e,f,l,x[o+32>>2]);b=Cb(a);a=Jia(x[o+16>>2],x[o+20>>2],x[e+480240>>2],0);h=lb;c=Kia(a,h,65536,0);d=lb;i=c;a=a+65535|0;c=!(a>>>0<65535?h+1|0:h)&a>>>0<131071;a=c?1:i;x[o+16>>2]=a;c=c?0:d;x[o+20>>2]=c;x[q>>2]=a;x[q+4>>2]=c;if((x[j>>2]&134219264)!=512){break sc}if(!td(x[e+1298300>>2])){break sc}Jb(o+8|0,s,99);Fc:{Gc:{if(Ja=Mb(x[x[o+8>>2]>>2],x[o+12>>2]),Ka=1,Ma=y[n+1075081|0]&16,Ma?Ja:Ka){a=x[C>>2];break Gc}a=x[C>>2];if((a|0)!=2){break Fc}}c=x[j>>2];d=c&2048;Hc:{if(d?(a|0)==2:0){break Hc}a=Jia(x[b>>2],0,261625,0);h=lb;a=a+66904|0;h=a>>>0<66904?h+1|0:h;b=Uc(Mia(a,h,133808,0),lb);a=1;Ic:{if(d){break Ic}a=0;if(!(c&4096)){break Ic}a=!x[n+1075688>>2]}Jb(o+8|0,s,110);if(Ja=Mb(x[x[o+8>>2]>>2],x[o+12>>2]),Ka=0,Ma=a,Ma?Ja:Ka){break Hc}c=x[e+1298300>>2];Jb(o+8|0,s,95);_y(c,g,b,a,Mb(x[x[o+8>>2]>>2],x[o+12>>2]))}a=x[e+1298300>>2];b=Jia(D(x[n+1075744>>2],D(x[n+1075740>>2],x[K>>2])),0,63,0);h=lb;b=b+33554432|0;h=b>>>0<33554432?h+1|0:h;yp(a,g,Uc((h&67108863)<<6|b>>>26,h>>>26|0)&255,0);a=n+1075676|0;d=a;b=x[a>>2];i=0;a=x[e+1298300>>2];c=Vk(a,g);Jc:{if((c|0)==255){break Jc}h=x[a>>2];if(Lj(h)){break Jc}i=Gb(Zd(a+318|0,c),10);m=x[a+4>>2];c=Ys(c)|192;a=y[i|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;Qg(h,m,g,c,a&255);i=(a>>>5&1)+(a<<27>>31)|0}x[d>>2]=(i<<7)+128}Kc:{a=x[u>>2];if(!a|(y[a+60|0]&7)!=1){break Kc}b=x[a+48>>2];a=x[a+52>>2];if(tc(b,a)){break Kc}b=x[OL(f,0)>>2];a=Mk(a);if(b>>>0<z[a>>1]|y[a+2|0]){break Kc}Zi(x[e+1298300>>2],g,1);Jb(o+8|0,s,109);a=x[x[o+8>>2]>>2];b=x[o+12>>2];x[n+1075688>>2]=0;c=x[j>>2];Ja=j,Ka=(Mb(a,b)?c:c&-4609)|4096,x[Ja>>2]=Ka;break sc}Jb(o+8|0,s,99);if(!Mb(x[x[o+8>>2]>>2],x[o+12>>2])|!(y[n+1075081|0]&16)|x[n+1075688>>2]){break sc}Zi(x[e+1298300>>2],g,1);x[j>>2]=x[j>>2]&-513}Lc:{if(!I){break Lc}Jb(o+16|0,s,31);if(Mb(x[x[o+16>>2]>>2],x[o+20>>2])){break Lc}Ms(e,f)}b=n+1075664|0;a=b;x[a>>2]=0;x[a+4>>2]=0;h=n+1075834|0;a=y[h|0];c=a-4|0;c=a>>>0>=c>>>0?c:0;v[h|0]=c;g=n+1075835|0;a=y[g|0];d=a-4|0;a=a>>>0>=d>>>0?d:0;v[g|0]=a;i=x[j>>2];d=i&-65537;m=x[G>>2];r=n+1075012|0;i=m|(x[n+1075016>>2]|x[r>>2])?(d|i<<7&65536)^65536:d;x[j>>2]=i;Mc:{Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{Tc:{Uc:{d=x[n+1075096>>2];Vc:{if(!d){break Vc}l=x[d+20>>2];if(!Qd(x[d>>2],l)|!x[n+1075068>>2]){break Vc}if(ki(x[q>>2],x[q+4>>2])){break Uc}}x[n+1075008>>2]=0;break Tc}x[n+1075008>>2]=l;if(l){break Sc}}if(!Ij(x[u>>2])){break Rc}l=0;if(i&6144){break Rc}}G=x[n+1075676>>2];d=(D(m,256-G|0)|0)/16384|0;d=d>>>0>=127?127:d;if(c<<24>>24<0){v[h|0]=d;I=d}else{I=c}c=d>>>1|0;if((I&255)>>>0<c>>>0){v[h|0]=c}c=(D(m,G)|0)/16384|0;d=c>>>0>=127?127:c;c=d>>>1|0;if(a<<24>>24<0){v[g|0]=d;a=d}if((a&255)>>>0<c>>>0){break Qc}break Pc}if((c&255)>>>0>=129){v[h|0]=0}l=0;c=0;if((a&255)>>>0<129){break Oc}}v[g|0]=c}if(!l){break Oc}l=128;if(A[e+24624>>2]>=2){l=Yb(x[n+1075676>>2],0,256)}x[o+16>>2]=l;c=D(k,m)>>>(ud(y[Q|0])?7:8)|0;h=n+1075668|0;Wc:{Xc:{Yc:{switch(y[R|0]){case 0:if(!(y[e+24616|0]&16)){break Xc}case 1:if((l|0)<=127){a=c>>>1|0;x[b>>2]=a;d=(D(c,l)|0)/256|0;break Wc}a=(D(c,256-l|0)|0)/256|0;x[b>>2]=a;d=c>>>1|0;break Wc;case 3:break Yc;default:break Xc}}Rh(o+16|0,255);d=x[o+16>>2];if((d|0)<=0){a=65536}else{a=z[(0-d<<1)+40224>>1]}a=D(a,c)>>>16|0;x[b>>2]=a;d=D(c,z[(d<<1)+39712>>1])>>>16|0;break Wc}a=(D(c,256-l|0)|0)/256|0;x[b>>2]=a;d=(D(c,l)|0)/256|0}x[h>>2]=d;c=x[u>>2];Zc:{if(c){l=y[c+14|0];if(ro(l)){break Zc}}l=y[e+480268|0];if(ro(l)){break Zc}c=y[e+24648|0];l=y[L|0]&128?x[e+24668>>2]?-1:c:c}g=n+1075786|0;v[g|0]=l;c=x[q>>2];m=x[q+4>>2];if(!(i&131072|((c|0)!=0|(m|0)!=1)|(x[n+1075748>>2]|(l&255)==255))){v[g|0]=0}g=d;d=1<<x[W>>2];g=(g|0)/(d|0)|0;x[h>>2]=g;x[b>>2]=(a|0)/(d|0);if(!(!(i&256)|x[e+24624>>2]!=2)){x[h>>2]=0-g}if(i&128){x[q>>2]=0-c;x[q+4>>2]=0-(((c|0)!=0)+m|0)}g=0;h=hb-16|0;hb=h;x[f+28>>2]=0;x[f+32>>2]=0;Rh(f+672|0,524287);Rh(f+676|0,524287);I=f;_c:{$c:{c=x[f+88>>2];if(!(c&65536)){b=x[f+676>>2];a=x[f+672>>2];break $c}a=x[f+20>>2];i=x[f+672>>2];ad:{if((a|0)!=(i|0)){b=x[f+24>>2];d=x[f+676>>2];break ad}b=x[f+24>>2];d=x[f+676>>2];if((b|0)==(d|0)){break $c}}c=x[e+24620>>2];i=(a|0)<(i|0)|(b|0)<(d|0);bd:{if(i){a=bt(c,x[e+24636>>2]);break bd}a=bt(c,x[e+24640>>2])}if(!(!Tb(e+1074312|0,4)|!(y[e+480180|0]&4))){a=x[e+24620>>2];a=Jia(a,a>>31,5,0);d=lb;a=a+500|0;d=a>>>0<500?d+1|0:d;a=Ec(Kia(a,d,1e3,0),lb)}c=x[f+656>>2];cd:{if(!c){b=a;break cd}b=a;if(!i){break cd}c=z[c+12>>1];if(c){b=(D(c,x[e+24620>>2])>>>0)/1e5|0}g=(c|0)!=0}l=b?b:1;d=x[f+672>>2];m=x[f+20>>2];q=d-m<<12;c=x[f+676>>2];b=x[f+24>>2];i=c-b<<12;if(!(y[f+90|0]&32|(!(c|d)|(!(b|m)|g)))){x[h+12>>2]=x[e+1074380>>2];fe(h+12|0,a,2048);l=x[h+12>>2]}g=(i|0)/(l|0)|0;x[f+32>>2]=g;i=(q|0)/(l|0)|0;x[f+28>>2]=i;b=c+((D(g,l)|0)/-4096|0)|0;x[f+24>>2]=b;a=d+((D(i,l)|0)/-4096|0)|0;x[f+20>>2]=a;if(g|i){x[f+100>>2]=l;c=x[f+88>>2];break _c}x[f+24>>2]=c;x[f+20>>2]=d;b=c;a=d;c=x[f+88>>2]&-65537;break _c}x[f+24>>2]=b;x[f+20>>2]=a;c=c&-65537}x[I+88>>2]=c&-2097153;x[f+40>>2]=b<<12;x[f+36>>2]=a<<12;hb=h+16|0;i=x[j>>2];if(!(i&512)){break Nc}break Mc}x[n+1075068>>2]=0;x[r>>2]=0;x[r+4>>2]=0;if(x[n+1075088>>2]){break Nc}if(!x[n+1075084>>2]){break Mc}}a=z[e+480212>>1];w[e+480212>>1]=a+1;w[((a<<1)+e|0)+1074478>>1]=t}x[n+1075660>>2]=i}t=t+1|0;continue}break}}hb=o+48|0;if(M^1){a=x[e+480208>>2];break h}if(ud(y[Aa|0])){b=x[e+480208>>2]|512;break i}n=0;dd:{a=x[e+24620>>2]/10|0;c=Ec(a,a>>31);if(!c){break dd}b=c>>>0>=1048576?1048576:c;x[e+1074380>>2]=b;d=z[e+480212>>1];while(1){if((d|0)==(n|0)){break dd}a=D(z[((n<<1)+e|0)+1074478>>1],872)+e|0;f=a+1075664|0;x[f>>2]=0;x[f+4>>2]=0;x[a+1075092>>2]=b;f=x[a+1075016>>2]<<12;x[a+1075032>>2]=f;h=x[a+1075012>>2]<<12;x[a+1075028>>2]=h;g=a+1075080|0;x[g>>2]=x[g>>2]|65536;x[a+1075020>>2]=(0-h|0)/(b|0);x[a+1075024>>2]=(0-f|0)/(b|0);n=n+1|0;continue}}a=x[e+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;x[ga+480208>>2]=a}if(!(a&512)){break g}Ja=e+1074392|0,Ka=Pk(za),x[Ja>>2]=Ka}hb=N+112|0;break f}x[N+96>>2]=512;a=x[e+1074380>>2];x[N+104>>2]=fa;x[N+100>>2]=a;o=jB(N+96|0);if(x[e+24632>>2]){i=0;a=hb-48|0;hb=a;b=o<<2;while(1){if((i|0)==4){ed:{i=0;while(1){if((i|0)==4){break ed}x[(a+32|0)+(i<<2)>>2]=((i<<11)+e|0)+16396;i=i+1|0;continue}}}else{x[a+32>>2]=0;c=((i<<11)+e|0)+16396|0;rz(c,b+c|0,a+32|0);i=i+1|0;continue}break}b=$f(a+16|0,a+32|0,x[e+24632>>2],o);c=x[x[da>>2]+8>>2];x[a+8>>2]=x[b+8>>2];d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;mb[c|0](da,a);hb=a+48|0}if(ud(ya)){a=0;while(1){if((a|0)==4){a=$f(N+80|0,N+96|0,x[e+24632>>2],o);b=x[x[la>>2]+8>>2];x[N+40>>2]=x[a+8>>2];c=x[a+4>>2];x[N+32>>2]=x[a>>2];x[N+36>>2]=c;mb[b|0](la,N+32|0)}else{x[(N+96|0)+(a<<2)>>2]=((a<<11)+e|0)+16396;a=a+1|0;continue}break}}_=0;t=0;g=hb-48|0;hb=g;if(o){C=e+12|0;u=e+24592|0;G=e+24588|0;Gm(C,o,u,G);if(A[e+24624>>2]>=3){Gm(e+8204|0,o,e+24600|0,e+24596|0)}w[g+42>>1]=0;qa=e+1074312|0;Ca=e+24648|0;Da=e+24596|0;Ea=e+24600|0;Fa=e+8204|0;I=e+397452|0;L=e+397448|0;r=e+393352|0;ra=e+397456|0;Ga=e+1074376|0;Ha=e+480190|0;while(1){if(z[e+480212>>1]<=_>>>0){Ja=e,Ka=z[Se(e+480214|0,g+42|0)>>1],w[Ja+480214>>1]=Ka}else{d=((_<<1)+e|0)+1074478|0;h=z[d>>1];H=D(h,872)+e|0;R=H+1075008|0;fd:{if(!(x[R>>2]|x[H+1075088>>2]|x[H+1075084>>2])){break fd}a=y[H+1075786|0]+1&255;if(a>>>0<=5){k=x[(a<<2)+28144>>2]}else{k=0}M=H+1075080|0;f=x[M>>2];gd:{if(!(!(f&16777216)&y[e+24612|0]>>>5)){b=u;a=G;n=f;c=C;if(!(f&8388608)){break gd}}b=L;a=I;if(!y[ra+12|0]){Gm(r,o,b,a)}v[ra+12|0]=1;h=z[d>>1];n=x[M>>2];c=r}d=a;a=n>>>8&A[e+24624>>2]>2;K=a?Da:d;W=a?Ea:b;a=a?Fa:c;ha=sl(e,Ga,h,2,1);sa=(ha-1&255)>>>0>249;hd:{if(sa){break hd}c=x[(D(ha,160)+e|0)+906140>>2];if(!c){break hd}b=x[c+24>>2];if(!b){break hd}K=c+36|0;W=c+40|0;if(!(v[c+28|0]&1)){Gm(b,o,W,K);x[c+28>>2]=x[c+28>>2]|1}a=b}i=H+1074992|0;if(y[H+1075843|0]&8){TC(i,a,o);a=H+1075084|0;x[W>>2]=x[W>>2]+x[a>>2];x[K>>2]=x[K>>2]+x[H+1075088>>2];x[a>>2]=0;x[a+4>>2]=0;break fd}$=0;b=g+16|0;x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;c=e+1074312|0;Ja=b,Ka=Tb(c,33),v[Ja+16|0]=Ka;Ja=b,Ka=Tb(c,116)^1,v[Ja+17|0]=Ka;if(x[i+16>>2]){SC(b,i);c=x[i+12>>2];d=c>>31;m=d^x[i+8>>2];c=(c^d)-((d>>>0>m>>>0)+d|0)|0;x[b+12>>2]=c>>>0>8191?2:16384/(c+1>>>0)|0}Ia=f>>>12&8|(f>>>5&2|(k|f&1));ga=t&65535;O=H+1075068|0;q=b;b=o;while(1){id:{V=H+1075092|0;c=x[V>>2];Z=c?b>>>0>c>>>0?c:b:b;x[g+8>>2]=Z;jd:{kd:{if(!Z){break kd}Q=H+1075e3|0;c=Q;f=x[c>>2];c=x[c+4>>2];k=c;if(!(c|f)){break kd}m=x[O>>2];if(!m){break kd}c=x[q>>2];if(!c){break kd}n=x[M>>2];aa=H+1075072|0;s=x[aa>>2];x[R>>2]=c;c=x[i>>2];ld:{md:{l=s&n<<30>>31;d=x[i+4>>2];if((l|0)>(d|0)){if((k|0)<0){c=Dg(0,l<<1,c,d);x[i>>2]=c;d=lb;x[i+4>>2]=d;if(!(d>>>0<l+m>>>1>>>0&(d|0)>=(l|0))){c=0;x[i>>2]=c;d=l;x[i+4>>2]=d}nd:{if(n&4){k=0-(((f|0)!=0)+k|0)|0;f=0-f|0;x[Q>>2]=f;x[Q+4>>2]=k;n=n&-129;x[M>>2]=n;break nd}x[i>>2]=c;d=m-1|0;x[i+4>>2]=d}if(!(n&2)){break kd}if(d>>>0<m>>>0){break ld}break kd}if((d|0)>0|(d|0)>=0){break ld}d=0;break md}if(d>>>0<m>>>0){break ld}if(!(n&2)){break kd}if(n&4){if(!!f&(k|0)>=0|(k|0)>0){k=0-(((f|0)!=0)+k|0)|0;f=0-f|0;x[Q>>2]=f;x[Q+4>>2]=k}n=n|128;x[M>>2]=n;if(y[g+33|0]){h=y[g+32|0];j=x[H+1075076>>2]-(h+s|0)|0;c=Dg(c,d,0,m);d=lb;if(d>>>0<j>>>0){c=Dg(0,m-h|0,c,d);d=lb;break md}d=s;c=0;break md}h=0-c|0;j=(m<<1)-((1-((c|0)!=0)|0)+d|0)|0;d=j;c=h;x[i>>2]=c;ca=0;d=ca|d;x[i+4>>2]=d;if(j>>>0<m>>>0&j>>>0>s>>>0){break ld}x[g+44>>2]=y[g+32|0]+1;d=ca|m-x[Fb(O,g+44|0)>>2];break md}if((k|0)<0){d=0-(((f|0)!=0)+k|0)|0;k=d;f=0-f|0;x[Q>>2]=f;x[Q+4>>2]=d}Ub(i,0,l-m|0);n=x[M>>2]|8192;x[M>>2]=n;c=x[i>>2];d=x[i+4>>2];break ld}x[i>>2]=c;x[i+4>>2]=d}od:{if((d|0)<(l|0)){if((d|k)<0){break kd}x[g+44>>2]=Z;h=f;m=k;break od}h=x[O>>2];if(h>>>0<d>>>0|(!!f&(k|0)>=0|(k|0)>0)&(d|0)==(h|0)){break kd}x[g+44>>2]=Z;h=k>>31;m=h;j=h^f;h=j-h|0;m=(k^m)-((j>>>0<m>>>0)+m|0)|0}s=h;j=m;wc(g+8|0,x[g+28>>2]);h=x[aa>>2];ca=h+16|0;ta=x[g+8>>2];Cf(c,d,Ze(f,k,ta-1|0),lb);m=lb;ua=d>>>0<h>>>0;if(!(!ua&d>>>0<ca>>>0)){n=n&-8193;x[M>>2]=n}pd:{qd:{ia=x[g+20>>2];rd:{if(ia){h=x[g+24>>2];if(h>>>0<=d>>>0){sd:{if((k|0)<0){f=0;k=h;break sd}f=c;k=d;c=0;d=x[H+1075076>>2]}Ja=g,Ka=zo(Dg(Dg(c,d,f,k),lb,1,0),lb,s,j)+1|0,x[Ja+44>>2]=Ka;x[R>>2]=ia;break pd}if(!(ua|!(n&8192)|d>>>0>=ca>>>0)){Ja=g,Ka=zo(Dg(Dg(0,l+16|0,c,d),lb,1,0),lb,s,j)+1|0,x[Ja+44>>2]=Ka;Ja=R,Ka=ia+D(x[H+1075076>>2]-l|0,gk(z[x[H+1075096>>2]+34>>1]))|0,x[Ja>>2]=Ka;break pd}if(!f&(k|0)<=0|(k|0)<0){break rd}if(Z>>>0<2|h>>>0>m>>>0){break qd}Ja=g,Ka=zo(Dg(Dg(0,h,c,d),lb,1,0),lb,s,j)+1|0,x[Ja+44>>2]=Ka;break pd}if((k|0)>0|(k|0)>=0){break qd}}if((l|0)<=(m|0)){break pd}Ja=g,Ka=zo(Dg(Dg(c,d,0,l),lb,1,0),lb,s,j)+1|0,x[Ja+44>>2]=Ka;break pd}f=x[O>>2];if((f|0)>(m|0)){break pd}Ja=g,Ka=zo(Dg(Dg(0,f,c,d),lb,1,0),lb,s,j)+1|0,x[Ja+44>>2]=Ka}yo(g+44|0,1,ta);d=x[g+44>>2];if((d|0)>0){break jd}}x[O>>2]=0;x[R>>2]=0;x[V>>2]=0;x[i>>2]=0;x[i+4>>2]=0;TC(i,a,b);a=H+1075084|0;x[W>>2]=x[W>>2]+x[a>>2];x[K>>2]=x[K>>2]+x[H+1075088>>2];x[a>>2]=0;x[a+4>>2]=0;x[M>>2]=x[M>>2]&-129;break id}td:{ud:{if(ga>>>0<A[e+24608>>2]){h=4;if(x[V>>2]){break ud}h=0;if(x[H+1075016>>2]|x[H+1075012>>2]){break ud}}Ub(i,Ze(x[Q>>2],x[Q+4>>2],d),lb);c=H+1075084|0;x[c>>2]=0;x[c+4>>2]=0;$=0;a=(d<<3)+a|0;break td}f=H+1075084|0;c=(d<<3)+a|0;m=c-8|0;x[f>>2]=0-x[m>>2];k=H+1075088|0;l=c-4|0;x[k>>2]=0-x[l>>2];mb[x[((h|Ia)<<2)+27760>>2]](i,Ca,a,d);x[f>>2]=x[f>>2]+x[m>>2];x[k>>2]=x[k>>2]+x[l>>2];$=1;a=c}c=x[V>>2];vd:{if(!c){break vd}if(c>>>0<=d>>>0){x[V>>2]=0;c=H+1075020|0;x[c>>2]=0;x[c+4>>2]=0;f=H+1075664|0;h=x[f+4>>2];c=H+1075012|0;x[c>>2]=x[f>>2];x[c+4>>2]=h;if(x[H+1075688>>2]|!(y[H+1075081|0]&16)){break vd}x[R>>2]=0;x[O>>2]=0;break vd}x[V>>2]=c-d}f=0;h=0;m=H+1074996|0;c=x[m>>2];k=H+1075076|0;h=c>>>0>=A[k>>2]?(y[M|0]&2)>>>1|0:h;n=c;c=x[O>>2];f=n>>>0<c>>>0|(!c|y[M|0]&2)?f:!z[H+1075778>>1];b=b-d|0;Jb(g+8|0,qa,85);wd:{xd:{yd:{if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break yd}c=y[H+1075795|0];if(!c){break yd}if(c>>>0<=z[Ha>>1]){break xd}}n=0;break wd}l=H+1075096|0;s=x[l>>2];c=D(c,104)+e|0;d=c+484380|0;n=(s|0)!=(d|0);if((d|0)==(s|0)|(f|h)!=1){break wd}x[l>>2]=d;d=x[c+484400>>2];x[R>>2]=d;f=z[c+484414>>1];x[M>>2]=f|x[M>>2]&-768;h=f<<30>>31;f=x[c+484388>>2];x[O>>2]=h&f;c=x[c+484384>>2];x[k>>2]=f;x[aa>>2]=c;x[m>>2]=c;SC(q,i);if(!d){break id}if((b|0)>0){continue}break id}zd:{if(!h|n){break zd}Jb(g+8|0,qa,83);if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])|x[aa>>2]){break zd}x[i>>2]=x[i>>2];x[i+4>>2]=0;c=x[x[H+1075096>>2]+8>>2];x[k>>2]=c;x[O>>2]=c}if((b|0)>0){continue}}break}x[R>>2]=x[q>>2];t=t+$|0;w[g+42>>1]=t;if(sa|!$){break fd}a=x[(D(ha,160)+e|0)+906140>>2];if(!a){break fd}mb[x[x[a>>2]+148>>2]](a)}_=_+1|0;continue}break}}hb=g+48|0;s=x[e+1298300>>2];if(td(s)){a=X;c=o;b=(D(x[e+480232>>2],x[e+480236>>2])>>>0)/48|0;i=hb-16|0;hb=i;Ad:{if(!y[s+534|0]){break Ad}d=Jia(b,0,6169,0);b=lb;h=b>>>16|0;j=Uc((b&65535)<<16|d>>>16,h);while(1){if(!c){break Ad}h=x[s>>2];g=x[h>>2];b=x[h+4>>2];while(1){if((b|0)>=(g|0)){x[h+8>>2]=x[h+12>>2];g=0;l=0;k=0;b=hb-16|0;hb=b;while(1){if((k|0)==18){d=(g|0)>=32767?32767:g;w[h+12>>1]=(d|0)<=-32768?-32768:d;d=(l|0)>=32767?32767:l;w[h+14>>1]=(d|0)<=-32768?-32768:d;w[h+3832>>1]=z[h+3832>>1]+1;d=(z[h+3834>>1]+1>>>0)%13440|0;w[h+3834>>1]=d;d=d>>>0<6720?d:13440-d|0;w[h+3836>>1]=d>>>8;if(!y[h+3843|0]){w[h+3836>>1]=d>>>10}d=z[h+3838>>1]+1|0;w[h+3838>>1]=d;if((d&65535)>>>0>=1024){w[h+3838>>1]=0;w[h+3840>>1]=z[h+3840>>1]+1&7}hb=b+16|0}else{f=h+D(k,44)|0;Bd:{if(!y[f+56|0]){w[b+12>>1]=0;w[b+14>>1]=0;break Bd}m=x[f+32>>2];d=z[m+3840>>1];if(d&3){m=(z[f+36>>1]>>>7&7)>>>(y[m+3844|0]^1)>>>(d&1)<<z[f+38>>1];d=d&4?0-m|0:m}else{d=0}m=x[f+52>>2];Cd:{if(m){r=z[m+32>>1];q=z[f+48>>1];d=d<<16>>16;m=Sf(x[f+16>>2],x[f+40>>2],d,0,w[f+46>>1]);n=x[f+40>>2];t=x[f+20>>2];if(!r){if(!q){m=Sf(t,n,d,m,0);m=Sf(x[f+24>>2],x[f+40>>2],d,m,0);d=Sf(x[f+28>>2],x[f+40>>2],d,m,0);break Cd}n=Sf(t,n,d,0,0);n=Sf(x[f+24>>2],x[f+40>>2],d,n,0);d=Sf(x[f+28>>2],x[f+40>>2],d,n,0)+m|0;break Cd}if(!q){m=Sf(t,n,d,m,0);n=Sf(x[f+24>>2],x[f+40>>2],d,0,0);d=Sf(x[f+28>>2],x[f+40>>2],d,n,0)+m|0;break Cd}n=Sf(t,n,d,0,0);d=(Sf(x[f+24>>2],x[f+40>>2],d,n,0)+m|0)+Sf(x[f+28>>2],x[f+40>>2],d,0,0)|0;break Cd}q=z[f+48>>1];d=d<<16>>16;m=Sf(x[f+16>>2],x[f+40>>2],d,0,w[f+46>>1]);n=x[f+40>>2];t=x[f+20>>2];if(!q){d=Sf(t,n,d,m,0);break Cd}d=Sf(t,n,d,0,0)+m|0}w[b+14>>1]=y[f+57|0]?d:0;w[b+12>>1]=y[f+58|0]?d:0}k=k+1|0;l=w[b+12>>1]+l|0;g=w[b+14>>1]+g|0;continue}break}g=x[h>>2];b=x[h+4>>2]-g|0;x[h+4>>2]=b;continue}break}d=g-b|0;w[i+14>>1]=(D(w[h+12>>1],b)+D(d,w[h+8>>1])|0)/(g|0);w[i+12>>1]=(D(w[h+14>>1],b)+D(d,w[h+10>>1])|0)/(g|0);x[h+4>>2]=b+49716;x[a>>2]=x[a>>2]+D(j,w[i+14>>1]);x[a+4>>2]=x[a+4>>2]+D(j,w[i+12>>1]);a=a+8|0;c=c-1|0;continue}}hb=i+16|0}a=y[J+12|0];if(a|x[J+16>>2]){if(!a){Gm(Y,o,pa,oa)}a=x[J>>2];b=x[J+80>>2];c=D(a,b)>>>4|0;c=c>>>0>=32767?32767:c;w[J+98>>1]=c;w[J+96>>1]=c;c=x[J+49948>>2];d=D(c,a)>>>4|0;d=d>>>0>=65536?65536:d;f=d+127>>>3|0;w[J+49946>>1]=f;d=d+255>>>4|0;w[J+49944>>1]=d;w[J+49942>>1]=d;w[J+49940>>1]=f;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0<=8?8:a)|0;a=16-(D((b|0)>=32768?32768:b,a>>>0<=16?a:0)>>15)|0;i=0;while(1){if((i|0)!=(o|0)){b=i<<3;c=b+X|0;x[c>>2]=x[c>>2]+D(a,x[b+Y>>2]>>4);b=b|4;c=b+X|0;x[c>>2]=x[c>>2]+D(a,x[b+Y>>2]>>4);i=i+1|0;continue}break}i=J+68|0;n=0;c=w[J+84>>1];b=x[J+40>>2];g=x[J+36>>2];while(1){if((n|0)==(o|0)){x[J+40>>2]=b;x[J+36>>2]=g;f=o}else{a=(n<<3)+Y|0;d=x[a>>2]>>12;g=(D(c,d-g|0)>>15)+d|0;x[a>>2]=g;d=a;a=x[a+4>>2]>>12;b=(D(c,a-b|0)>>15)+a|0;x[d+4>>2]=b;n=n+1|0;continue}break}if(f){c=Y;a=f;b=x[i>>2]-1|0;h=z[i+22>>1];n=z[i+20>>1];d=w[i+26>>1];g=w[i+24>>1];t=w[i+18>>1];s=w[i+16>>1];l=x[i+4>>2];while(1){if(a){k=ed(x[c>>2]);m=ed(x[c+4>>2]);n=ed((n<<16>>16)-k|0);h=ed((h<<16>>16)-m|0);n=Vc(ed((D(n,s)|0)/65536<<1)+k|0);h=Vc(ed((D(h,t)|0)/65536<<1)+m|0);m=i+(l<<2)|0;j=w[m+32928>>1];k=Vc(((D(j,g)|0)/-65536|0)+n|0);l=l+1&127;q=i+(l<<2)|0;m=w[m+32930>>1];r=Vc(((D(m,d)|0)/-65536|0)+h|0);w[q+32930>>1]=r;w[q+32928>>1]=k;b=b+1&8191;q=i+(b<<2)|0;Ja=q,Ka=Vc(j+((D(g,k)|0)/65536|0)|0),w[Ja+160>>1]=Ka;Ja=q,Ka=Vc(m+((D(d,r)|0)/65536|0)|0),w[Ja+162>>1]=Ka;c=c+8|0;a=a-1|0;continue}break}w[i+22>>1]=h;w[i+20>>1]=n;x[i+4>>2]=l}g=J+49892|0;c=f;a=Y;while(1){if(c){d=x[J+76>>2];h=d&4095;k=(i+(h<<2)|0)+33440|0;b=a;h=4096-h|0;r=d-x[J+49892>>2]&4095;d=4096-r|0;d=d>>>0>h>>>0?h:d;d=c>>>0<d>>>0?c:d;h=d>>>0>=64?64:d;n=h;d=0;m=hb-32|0;hb=m;l=x[i>>2];while(1){if((d|0)==7){Dd:{j=w[i+28>>1]/8<<16>>16;Ed:while(1){if(!n){break Dd}n=n-1|0;d=0;t=0;s=0;while(1)if((d|0)==4){d=4;l=0;C=Vc((s|0)/32768|0);u=Vc((t|0)/32768|0);t=0;while(1)if((d|0)==7){d=Vc(C+((t|0)/32768|0)|0);w[k>>1]=d;x[b>>2]=D(d,j);d=Vc(u+((l|0)/32768|0)|0);w[k+2>>1]=d;x[b+4>>2]=D(d,j);b=b+8|0;k=k+4|0;continue Ed}else{s=m+(d<<2)|0;q=x[s>>2]+1&8191;x[s>>2]=q;I=l;l=i+(q<<2)|0;q=w[l+160>>1];s=i+(d<<4)|0;G=w[l+162>>1];l=(I+D(q,w[s+44>>1])|0)+D(G,w[s+46>>1])|0;t=(D(q,w[s+40>>1])+t|0)+D(G,w[s+42>>1])|0;d=d+1|0;continue}}else{l=m+(d<<2)|0;q=x[l>>2]+1&8191;x[l>>2]=q;I=t;t=i+(q<<2)|0;q=w[t+160>>1];l=i+(d<<4)|0;C=w[t+162>>1];t=(I+D(q,w[l+44>>1])|0)+D(C,w[l+46>>1])|0;s=(D(q,w[l+40>>1])+s|0)+D(C,w[l+42>>1])|0;d=d+1|0;continue}}}}else{x[m+(d<<2)>>2]=l+(x[(i+(d<<4)|0)+32>>2]^-1);d=d+1|0;continue}break}hb=m+32|0;t=((r<<2)+J|0)+33508|0;d=a;b=h;l=x[g+4>>2];while(1){m=l&2047;if(b){k=g+8256|0;q=w[k+((l+1206&2047)<<2)>>1];r=w[(k+((l+754&2047)<<2)|0)+2>>1];k=g- -64|0;j=w[(k+((l+1602&2047)<<2)|0)+2>>1];C=w[k+((l+1750&2047)<<2)>>1];k=w[t>>1];n=w[t+2>>1];s=g+24640|0;u=s+((l+502&2047)<<2)|0;G=w[u>>1];I=ed(w[g+32>>1]-G|0);u=w[u+2>>1];L=ed(w[g+34>>1]-u|0);H=w[g+26>>1];s=s+((l+22&2047)<<2)|0;K=w[s>>1];M=ed(w[g+36>>1]-K|0);O=w[g+28>>1];s=w[s+2>>1];Q=ed(w[g+38>>1]-s|0);R=w[g+30>>1];G=Vc(ed((D(I,w[g+24>>1])|0)/65536<<1)+G|0);w[g+32>>1]=G;Ja=g,Ka=Vc(ed((D(H,L)|0)/65536<<1)+u|0),w[Ja+34>>1]=Ka;Ja=g,Ka=Vc(ed((D(M,O)|0)/65536<<1)+K|0),w[Ja+36>>1]=Ka;s=Vc(ed((D(Q,R)|0)/65536<<1)+s|0);w[g+38>>1]=s;u=ed((D(G,w[g+16>>1])|0)/32768|0);s=ed((D(s,w[g+22>>1])|0)/32768|0);u=ed(u+((k|0)/4<<16>>16)|0);G=ed(s+((n|0)/4<<16>>16)|0);n=w[g+8>>1];I=ed(u+((D(n,C)|0)/-65536|0)|0);L=m<<2;k=L+g|0;s=w[g+10>>1];H=ed(G+((D(s,j)|0)/-65536|0)|0);w[k+66>>1]=H;w[k- -64>>1]=I;C=ed(C+((D(n,I)|0)/65536|0)|0);I=g+16448|0;L=I+L|0;j=ed(j+((D(s,H)|0)/65536|0)|0);w[L+2>>1]=j;w[L>>1]=C;C=ed(C+u|0);u=ed(j+G|0);j=I+((l+682&2047)<<2)|0;G=w[j+2>>1];I=w[j>>1];j=ed((D(G,w[g+42>>1])+D(I,w[g+40>>1])|0)/32768|0);l=g+((l+426&2047)<<2)|0;L=w[l+16450>>1];H=w[l+16448>>1];l=ed((D(L,w[g+46>>1])+D(H,w[g+44>>1])|0)/32768|0);I=ed(ed(C+I|0)-j|0);G=ed(ed(u+G|0)-l|0);C=ed(ed(C+H|0)-j|0);u=ed(ed(u+L|0)-l|0);j=ed(j+((D(n,q)|0)/-65536|0)|0);L=ed(l+((D(r,s)|0)/-65536|0)|0);w[k+8258>>1]=L;w[k+8256>>1]=j;n=(D(j,n)|0)/65536|0;l=ed(n+q|0);s=(D(s,L)|0)/65536|0;j=ed(s+r|0);w[k+24642>>1]=j;w[k+24640>>1]=l;Ja=d,Ka=(x[d>>2]+D(ed(l+I|0),w[g+48>>1])|0)+D(ed(j+G|0),w[g+50>>1])|0,x[Ja>>2]=Ka;Ja=d,Ka=(x[d+4>>2]+D(ed(ed(n)+C|0),w[g+52>>1])|0)+D(ed(ed(s)+u|0),w[g+54>>1])|0,x[Ja+4>>2]=Ka;d=d+8|0;l=m+1|0;t=t+4|0;b=b-1|0;continue}break}x[g+4>>2]=m;x[J+76>>2]=h+x[J+76>>2]&4095;x[J+68>>2]=h+x[J+68>>2]&8191;c=c-h|0;a=(h<<3)+a|0;continue}break}x[J+68>>2]=x[J+68>>2]&8191;n=Y;d=X;b=f;g=0;l=0;k=x[J+56>>2];c=x[J- -64>>2];i=x[J+52>>2];a=x[J+60>>2];while(1){if(b){g=x[n>>2];l=x[n+4>>2];c=c-l|0;c=(((c|0)/1024|0)-c|0)+k|0;x[d+4>>2]=c+x[d+4>>2];a=a-g|0;a=(((a|0)/1024|0)-a|0)+i|0;x[d>>2]=a+x[d>>2];k=c+((c|0)/-512|0)|0;i=a+((a|0)/-512|0)|0;d=d+8|0;n=n+8|0;b=b-1|0;a=g;c=l;continue}break}x[J+64>>2]=l;x[J+60>>2]=g;x[J+56>>2]=k;x[J+52>>2]=i;a=x[J+20>>2];Fd:{if(y[J+12|0]){break Fd}a=x[J+16>>2];if(a>>>0>f>>>0){a=a-f|0;break Fd}VJ(J,pa,oa);a=0}v[J+12|0]=0;x[J+16>>2]=a}if(x[e+946300>>2]){Gd:{t=0;d=0;f=o<<2;n=z[e+480214>>1]!=0;va=B[e+1074336>>2];S=B[e+1074332>>2];while(1)if((t|0)==250){h=e+12|0;m=e+12300|0;l=e+14348|0;Wu(h,m,l,o,S);a=e+1074476|0;C=y[a|0];v[a|0]=0;a=l;b=m;while(1){Hd:{Id:{Jd:{if((d|0)!=250){s=(D(d,160)+e|0)+906300|0;f=x[s>>2];if(!f|!x[f+24>>2]){break Hd}if(!Qh(f+44|0)){break Hd}k=f;Kd:{if(Vu(y[s+24|0])){break Kd}c=mb[x[x[f>>2]+144>>2]](f)|0;k=x[s>>2];if(c){break Kd}t=0;if(y[k+28|0]&2){break Kd}while(1){if((d|0)==(t|0)){break Hd}c=D(t,160);t=t+1|0;if((Em(x[(c+e|0)+906328>>2])|0)!=(d|0)){continue}break}}c=x[f+44>>2];j=Cc(c,0);q=Cc(c,1);r=(b|0)==(j|0);b=r?m:b;i=b;a=r?l:a;g=x[s+28>>2];c=a;Ld:{if(!g){break Ld}g=Em(g);c=a;if(g>>>0<=d>>>0){break Ld}c=a;if(g>>>0>249){break Ld}g=x[(D(g,160)+e|0)+906300>>2];c=a;if(!g){break Ld}if(!(y[k+28|0]&4)){mb[x[x[g>>2]+148>>2]](g)}c=a;if(!Qh(g+44|0)){break Ld}c=x[g+44>>2];i=Cc(c,0);c=Cc(c,1)}if(!Vu(y[s+24|0])){break Id}t=0;Md:{if(r){break Md}while(1){if((o|0)==(t|0)){break Md}g=t<<2;r=g+j|0;u=b+g|0;B[r>>2]=B[u>>2]+B[r>>2];r=g+q|0;g=a+g|0;B[r>>2]=B[g>>2]+B[r>>2];x[u>>2]=0;x[g>>2]=0;t=t+1|0;continue}}a=c;b=i;if(!(n&1)){break Id}a=x[s>>2];if(a){mb[x[x[a>>2]+148>>2]](a)}g=Em(x[s+28>>2]);a=d;while(1){b=g;g=b&255;if(g>>>0>249|g>>>0<=(a&255)>>>0){break Jd}t=D(g,160)+e|0;g=Em(x[t+906328>>2]);a=b;b=x[t+906300>>2];if(!b){continue}mb[x[x[b>>2]+148>>2]](b);continue}}c=0;while(1){if((c|0)!=(o|0)){S=E(B[b>>2]*va);Nd:{if(E(F(S))<E(2147483648)){d=~~S;break Nd}d=-2147483648}x[h>>2]=d;S=E(B[a>>2]*va);Od:{if(E(F(S))<E(2147483648)){d=~~S;break Od}d=-2147483648}x[h+4>>2]=d;c=c+1|0;h=h+8|0;a=a+4|0;b=b+4|0;continue}break}break Gd}a=c;b=i}t=0;Pd:{Qd:{g=y[s+24|0];if(!((g&2)>>>1|0)){if(!PC(g)|!(y[k+28|0]&4)){break Qd}}while(1){if((o|0)==(t|0)){break Pd}f=t<<2;g=f+i|0;B[g>>2]=B[f+j>>2]+B[g>>2];g=c+f|0;B[g>>2]=B[f+q>>2]+B[g>>2];t=t+1|0;continue}}if(C){mb[x[x[f>>2]+128>>2]](f)}mb[x[x[f>>2]+60>>2]](f,i,c,o);x[k+32>>2]=o+x[k+32>>2];if(!PC(y[s+24|0])){break Pd}if((mb[x[x[f>>2]+156>>2]](f)|0)<=0|A[k+32>>2]<x[e+24620>>2]<<2>>>0){break Pd}Rd:{while(1){if((o|0)==(t|0)){break Rd}f=t<<2;S=B[f+i>>2];Sd:{if(S>=E(1.1920928955078125e-7)|S<=E(-1.1920928955078125e-7)){break Sd}S=B[c+f>>2];if(S>=E(1.1920928955078125e-7)){break Sd}t=t+1|0;if(!(S<=E(-1.1920928955078125e-7))){continue}}break}x[k+32>>2]=0;break Pd}x[k+28>>2]=x[k+28>>2]|4}x[k+28>>2]=x[k+28>>2]&-3}d=d+1|0;continue}}else{h=D(t,160)+e|0;a=x[h+906300>>2];Td:{if(!a|!x[a+24>>2]){break Td}if(!Qh(a+44|0)){break Td}if(!(mb[x[x[a>>2]+112>>2]](a)|0)){mb[x[x[a>>2]+108>>2]](a,1);mb[x[x[a>>2]+120>>2]](a)}c=x[a+44>>2];b=Cc(c,0);c=Cc(c,1);Ud:{if(v[a+28|0]&1){Wu(x[a+24>>2],b,c,o,S);break Ud}g=a+40|0;if(x[g>>2]|x[a+36>>2]){Gm(x[a+24>>2],o,g,a+36|0);Wu(x[a+24>>2],b,c,o,S);break Ud}Zb(b,0,f);Zb(c,0,f)}b=a;a=x[a+28>>2];x[b+28>>2]=a&-2;if(Vu(y[h+906324|0])){break Td}n=!(a&4)|n}t=t+1|0;continue}}}if(x[e+24624>>2]==1){c=0;while(1){if((c|0)!=(o|0)){a=(c<<3)+X|0;x[(c<<2)+X>>2]=(x[a+4>>2]+x[a>>2]|0)/2;c=c+1|0;continue}break}}if(ud(y[Ba|0])){b=0;f=hb-16|0;hb=f;Vd:{if(!x[e+1074376>>2]){n=e+1074460|0;a=n;x[a>>2]=0;x[a+4>>2]=0;a=x[e+1074456>>2];x[e+1074468>>2]=a;break Vd}a=x[e+1074456>>2];c=x[e+1074468>>2];Wd:{if((a|0)==(c|0)){d=x[e+1074460>>2];break Wd}x[e+1074468>>2]=a;d=x[e+24620>>2];h=e+1074460|0;Xd:{if((a|0)>(c|0)){d=bt(d,x[e+24636>>2]);break Xd}d=bt(d,x[e+24640>>2])}x[h>>2]=d;x[e+1074464>>2]=d;c=a}n=e+1074460|0;if((d|0)<=0){break Vd}c=(c<<12)-x[e+1074472>>2]|0;b=(c|0)/(d|0)|0;if(y[e+1074368|0]!=2){break Vd}x[f+12>>2]=50;h=x[e+1074464>>2];x[f+8>>2]=1e4/(h+1|0);g=x[Je(f+12|0,f+8|0)>>2];while(1){i=b>>31;if((g|0)>=((i^b)-i|0)){break Vd}d=d+h|0;x[n>>2]=d;b=(c|0)/(d|0)|0;continue}}Yd:{Zd:{switch(x[e+24624>>2]-1|0){case 0:c=0;g=(o|0)>0?o:0;i=a<<12;d=e+12|0;k=a>>31;while(1){if((c|0)==(g|0)){break Yd}_d:{if(x[n>>2]>0){h=x[e+1074472>>2]+b|0;x[e+1074472>>2]=h;m=x[d>>2];Ja=d,Ka=Ec(Kia(Jia(m,m>>31,h,h>>31),lb,1048576,0),lb),x[Ja>>2]=Ka;x[e+1074460>>2]=x[e+1074460>>2]-1;break _d}h=x[d>>2];Ja=d,Ka=Ec(Kia(Jia(h,h>>31,a,k),lb,256,0),lb),x[Ja>>2]=Ka;x[e+1074472>>2]=i}c=c+1|0;d=d+4|0;continue};case 1:c=0;i=(o|0)>0?o:0;k=a<<12;d=e+12|0;h=a>>31;while(1){if((c|0)==(i|0)){break Yd}$d:{if(x[n>>2]>0){g=x[e+1074472>>2]+b|0;x[e+1074472>>2]=g;m=x[d>>2];Ja=d,Ka=Ec(Kia(Jia(m,m>>31,g,g>>31),lb,1048576,0),lb),x[Ja>>2]=Ka;g=x[e+1074472>>2];m=g;l=g>>31;g=x[d+4>>2];Ja=d,Ka=Ec(Kia(Jia(m,l,g,g>>31),lb,1048576,0),lb),x[Ja+4>>2]=Ka;x[e+1074460>>2]=x[e+1074460>>2]-1;break $d}g=x[d>>2];Ja=d,Ka=Ec(Kia(Jia(g,g>>31,a,h),lb,256,0),lb),x[Ja>>2]=Ka;g=x[d+4>>2];Ja=d,Ka=Ec(Kia(Jia(g,g>>31,a,h),lb,256,0),lb),x[Ja+4>>2]=Ka;x[e+1074472>>2]=k}c=c+1|0;d=d+8|0;continue};case 3:break Zd;default:break Yd}}l=0;i=(o|0)>0?o:0;k=a<<12;d=e+8204|0;c=e+12|0;h=a>>31;while(1){if((i|0)==(l|0)){break Yd}ae:{if(x[n>>2]>0){g=x[e+1074472>>2]+b|0;x[e+1074472>>2]=g;m=x[c>>2];Ja=c,Ka=Ec(Kia(Jia(m,m>>31,g,g>>31),lb,1048576,0),lb),x[Ja>>2]=Ka;g=x[e+1074472>>2];m=g;s=g>>31;g=x[c+4>>2];Ja=c,Ka=Ec(Kia(Jia(m,s,g,g>>31),lb,1048576,0),lb),x[Ja+4>>2]=Ka;g=x[e+1074472>>2];m=g;s=g>>31;g=x[d>>2];Ja=d,Ka=Ec(Kia(Jia(m,s,g,g>>31),lb,1048576,0),lb),x[Ja>>2]=Ka;g=x[e+1074472>>2];m=g;s=g>>31;g=x[d+4>>2];Ja=d,Ka=Ec(Kia(Jia(m,s,g,g>>31),lb,1048576,0),lb),x[Ja+4>>2]=Ka;x[e+1074460>>2]=x[e+1074460>>2]-1;break ae}g=x[c>>2];Ja=c,Ka=Ec(Kia(Jia(g,g>>31,a,h),lb,256,0),lb),x[Ja>>2]=Ka;g=x[c+4>>2];Ja=c,Ka=Ec(Kia(Jia(g,g>>31,a,h),lb,256,0),lb),x[Ja+4>>2]=Ka;g=x[d>>2];Ja=d,Ka=Ec(Kia(Jia(g,g>>31,a,h),lb,256,0),lb),x[Ja>>2]=Ka;g=x[d+4>>2];Ja=d,Ka=Ec(Kia(Jia(g,g>>31,a,h),lb,256,0),lb),x[Ja+4>>2]=Ka;x[e+1074472>>2]=k}l=l+1|0;d=d+8|0;c=c+8|0;continue}}hb=f+16|0}if(x[ma>>2]!=128){b=e+12|0;c=e+8204|0;a=x[e+24604>>2];d=x[e+24624>>2];be:{if((a|0)==128|d>>>0<2){break be}JL(b,o,a);if(d>>>0<4){break be}JL(c,o,a)}}if(x[e+24624>>2]==4){a=o;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+X|0;c=a<<3;d=c|4;x[b+12>>2]=x[d+na>>2];x[b+8>>2]=x[c+na>>2];x[b+4>>2]=x[d+X>>2];x[b>>2]=x[c+X>>2];continue}break}}if(ud(xa)){a=$f(N- -64|0,X,x[e+24624>>2],o);b=x[x[ka>>2]+8>>2];x[N+24>>2]=x[a+8>>2];c=x[a+4>>2];x[N+16>>2]=x[a>>2];x[N+20>>2]=c;mb[b|0](ka,N+16|0)}a=$f(N+48|0,X,x[e+24624>>2],o);b=x[x[ja>>2]+8>>2];x[N+8>>2]=x[a+8>>2];c=x[a+4>>2];x[N>>2]=x[a>>2];x[N+4>>2]=c;mb[b|0](ja,N);x[e+1074380>>2]=x[e+1074380>>2]-o;x[e+1074376>>2]=o+x[e+1074376>>2];fa=fa-o|0;wa=o+wa|0;continue}break}hb=ba+32|0;return wa}function fg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,m=0,o=0,q=0,s=0,t=0,u=E(0),G=0,H=0,I=0,J=E(0),K=0,L=0,M=0,N=0,O=0;k=hb-2288|0;hb=k;a:{b:{c:{d:{e:{f:{if(Yu(x[c>>2])){wc(b,268435456);L=x[c+8>>2];I=k+2264|0;f=I;x[f>>2]=0;x[f+4>>2]=0;Sb(f+8|0);x[k+2260>>2]=0;g:{h:{i:{j:{k:{l:{f=y[a+3|0];m:{n:{if((f-4&255)>>>0<=4){x[23604]=0;d=S(188,c|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break l}x[k+2260>>2]=d;break n}if(f>>>0>17){break m}o:{g=1<<f;if(!(g&63503)){if(!(g&198144)){break m}break o}if(y[a|0]){break o}break n}f=0;e=EA(a,x[b>>2]);x[23604]=0;U(189,k+96|0,c|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break k}d=k+96|0;e=x[d+4>>2];x[I>>2]=x[d>>2];x[I+4>>2]=e;mm(I+8|0,d+8|0);Lc(d);e=xe(I);d=x[I>>2];x[k+2260>>2]=d;if(!e){break g}}f=y[a+3|0]}h=1;p:{q:{switch(f&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=!y[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}h=0}g=x[b>>2];if(!(g>>>0<262145|h)){f=f&255;x[k+96>>2]=((f|0)==10)<<4;h=d-x[Fb(k+96|0,k+2260|0)>>2]|0;if(f>>>0>15){break j}r:{if(!(1<<f&63503)){if((f|0)==10){break r}break j}if(!(y[a|0]&7)){break j}}f=(h|0)<0?-1:h<<1;break i}f=f&255;if(f>>>0>8){break h}if(!(1<<f&432)){if((f|0)!=6){break h}f=0;if(d>>>0<10){break g}x[23604]=0;Q(174,c|0,4)|0;d=x[23604];x[23604]=0;if((d|0)==1){break l}x[23604]=0;f=S(143,c|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){x[k+96>>2]=f;x[k+72>>2]=x[k+2260>>2];d=x[Fb(k+96|0,k+72|0)>>2];hg(c,8);f=((d>>>0>50529027?-1:D(d,85))>>>0)/(y[a|0]>>>3>>>0)|0;break i}a=P()|0;break a}g=8/(Yp(y[a+1|0])>>>0)|0;f=D(g,d);Jia(g,0,d,0);f=lb?-1:f;break i}a=P()|0;break a}a=P()|0;break a}g=0;d=Yp(y[a+1|0]);s:{t:{switch(f|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:g=y[a|0];break s;case 9:g=16;break s;case 10:g=4;break s;case 16:case 17:break t;default:break s}}g=8}f=D(d,g&255)>>>3|0;d=(f+h|0)-1|0;f=((d>>>0<h>>>0?-1:d)>>>0)/(f>>>0)|0}wc(b,f);g=x[b>>2]}if(!g){f=0;break g}w[b+34>>1]=z[b+34>>1]&65470|y[a|0]>15|(y[a+1|0]!=1)<<6;if(!yg(b)){f=0;x[b>>2]=0;break g}u:{if(ce(a,Xc(k+96|0,8,1,0,10))){x[23604]=0;d=Q(190,c|0,k+96|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){f=0;if(!d){break u}a=x[b>>2];d=0;x[23604]=0;x[k+72>>2]=a+1>>>1;f=S(188,c|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break b}wc(k+72|0,f);a=e+16|0;b=x[b+20>>2];h=x[k+72>>2];f=h;while(1)if(f){g=k+96|0;e=d+y[g|y[a|0]&15]|0;v[b|0]=e;d=y[g|y[a|0]>>>4]+(e&255)|0;v[b+1|0]=d;f=f-1|0;a=a+1|0;b=b+2|0;continue}else{f=h+16|0;break u}}a=P()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{g=y[a+3|0];switch(g-4|0){case 3:break D;case 4:break E;case 5:break F;case 2:break G;case 0:case 1:break H;default:break B}}x[23604]=0;b=fa(191,k+1168|0,c|0,b|0,(g|0)==5|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break f}yb(b);f=x[c+8>>2]-L|0;break u}if(y[a+1|0]!=1){break C}x[23604]=0;Q(174,c|0,4)|0;a=x[23604];x[23604]=0;if((a|0)==1){break f}x[23604]=0;e=S(143,c|0)|0;a=x[23604];x[23604]=0;I:{J:{K:{if((a|0)!=1){x[23604]=0;x[k+72>>2]=e;h=S(192,c|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break K}x[23604]=0;U(193,k+96|0,c|0,e|0);a=x[23604];x[23604]=0;if((a|0)==1){break I}wc(k+72|0,x[k+96>>2]);g=x[k+72>>2];f=xe(k+96|0);d=z[b+34>>1];e=x[b+20>>2];b=x[b>>2];a=x[k+96>>2];x[23604]=0;ea(194,f|0,a|0,e|0,lj(b,d)|0,h<<24>>24);a=x[23604];x[23604]=0;if((a|0)!=1){break J}a=P()|0;Lc(k+96|0);break a}a=P()|0;break a}a=P()|0;break a}f=g+9|0;Lc(k+96|0);break u}a=P()|0;break a}if(y[a+1|0]!=1|y[a|0]!=16){break C}f=x[k+2260>>2];d=_l(k+1160|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];h=hb-16|0;hb=h;x[h+12>>2]=f>>>1;x[h+8>>2]=a;d=x[Fb(h+12|0,h+8|0)>>2];f=d;while(1){if(f){a=y[e|0]+g|0;g=a+y[e+1|0]|0;w[b>>1]=g<<8|a&255;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}hb=h+16|0;f=d<<1;break u}if(y[a+1|0]!=1|y[a|0]>16){break C}d=x[c+8>>2];e=x[c>>2];f=0;x[23604]=0;d=W(142,e|0,d|0,8)|0;e=x[23604];x[23604]=0;if((e|0)==1){break f}if(!d){break u}x[23604]=0;d=S(143,c|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break f}x[k+2260>>2]=d;if(d>>>0<4){break u}x[23604]=0;U(176,k+72|0,c|0,d|0);e=x[23604];x[23604]=0;if((e|0)==1){break c}e=k+72|0;t=Yq(k+96|0,e);yb(e);e=x[t>>2];x[23604]=0;d=S(195,e|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break e}f=d+4|0;m=y[a|0];s=(m|0)!=16;g=0;h=0;while(1){if(A[b>>2]<=h>>>0){break w}L:{if(s){break L}x[23604]=0;o=Q(150,t|0,8)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break L}a=V(30848)|0;break x}x[23604]=0;i=Q(150,t|0,1)|0;a=x[23604];x[23604]=0;if((a|0)==1){break y}x[23604]=0;e=Q(150,t|0,1)|0;a=x[23604];x[23604]=0;if((a|0)==1){break y}M:{N:{O:{if(!e){e=8;while(1){x[23604]=0;d=Q(150,t|0,1)|0;a=x[23604];x[23604]=0;if((a|0)==1){break M}if(d){break O}e=e+16|0;continue}}x[23604]=0;a=Q(150,t|0,3)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break N}break y}x[23604]=0;d=Q(150,t|0,4)|0;a=x[23604];x[23604]=0;if((a|0)==1){break y}a=e+d|0}g=(g&255)+(((i?-1:0)^a)&255)|0;P:{if((m|0)!=16){v[x[b+20>>2]+h|0]=g;break P}w[x[b+20>>2]+(h<<1)>>1]=o&255|g<<8}h=h+1|0;continue}break}a=V(30848)|0;break x}if(y[a+1|0]!=1){break B}break A}if((g|0)!=7){break B}if(y[a+1|0]==1){break A}}f=y[a|0];break z}f=y[a|0];if(f>>>0>16){break z}f=0;if(A[k+2260>>2]<5){break u}d=z[b+34>>1];e=x[b+20>>2];a=x[b>>2];x[23604]=0;f=W(196,c|0,e|0,lj(a,d)|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break u}break f}Q:{if((g&254)!=16|(f&255)!=16){break Q}d=y[a+1|0];if((d-1&255)>>>0>1){break Q}M=k,N=D(x[b>>2],Yp(d)),x[M+96>>2]=N;wc(k+96|0,x[k+2260>>2]);a=x[b+20>>2];f=x[k+96>>2];if((g|0)==16){b=f;while(1){if(!b){break u}M=a,N=z[cc(30880,y[e|0])>>1],w[M>>1]=N;a=a+2|0;e=e+1|0;b=b-1|0;continue}}b=f;while(1){if(!b){break u}M=a,N=z[cc(31392,y[e|0])>>1],w[M>>1]=N;a=a+2|0;e=e+1|0;b=b-1|0;continue}}d=(f&255)!=8;if(!(d|y[a+1|0]!=1)){R:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2];x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0];b=b+1|0;e=e+1|0;f=f-1|0;continue}break};hb=d+16|0;f=a;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2];x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0]^128;b=b+1|0;e=e+1|0;f=f-1|0;continue}break};hb=d+16|0;f=a;break u;default:f=0;if((g|0)!=11){break u}break;case 2:break R}}f=x[k+2260>>2];d=Jy(k- -64|0);a=x[b>>2];b=x[b+20>>2];g=y[d|0];d=hb-16|0;hb=d;x[d+12>>2]=f;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=y[e|0]+g|0;v[b|0]=g;b=b+1|0;e=e+1|0;f=f-1|0;continue}break}hb=d+16|0;f=a;break u}if(!(y[a+1|0]!=3|d)){S:{switch(g|0){case 0:i=hb-16|0;hb=i;f=x[k+2260>>2];x[i+12>>2]=f;d=x[b>>2];x[i+8>>2]=d;a=i+8|0;g=x[Fb(a,i+12|0)>>2];x[i+8>>2]=d;x[i+4>>2]=f-g;f=x[Fb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=e;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+e|0;a=f;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};hb=i+16|0;f=f+g|0;break u;case 1:i=hb-16|0;hb=i;f=x[k+2260>>2];x[i+12>>2]=f;d=x[b>>2];x[i+8>>2]=d;a=i+8|0;g=x[Fb(a,i+12|0)>>2];x[i+8>>2]=d;x[i+4>>2]=f-g;f=x[Fb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=e;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+e|0;a=f;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};hb=i+16|0;f=f+g|0;break u;default:f=0;if((g|0)!=11){break u}break;case 2:break S}}h=x[k+2260>>2];f=y[Jy(k+56|0)|0];m=hb-16|0;hb=m;x[m+12>>2]=h;g=x[b>>2];x[m+8>>2]=g;d=m+8|0;i=x[Fb(d,m+12|0)>>2];x[m+8>>2]=g;x[m+4>>2]=h-i;h=x[Fb(d,m+4|0)>>2];s=b;o=x[b+20>>2];d=f;b=i;g=e;while(1){if(b){d=y[g|0]+d|0;v[o|0]=d;o=o+2|0;g=g+1|0;b=b-1|0;continue}break}o=x[s+20>>2]+1|0;g=x[s>>2]+e|0;b=h;while(1){if(b){f=y[g|0]+f|0;v[o|0]=f;o=o+2|0;g=g+1|0;b=b-1|0;continue}break}hb=m+16|0;f=h+i|0;if(y[a+3|0]!=11){break u}a=x[s+20>>2];b=a+(x[s>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;continue}}d=f&255;if(!((d|0)!=8|y[a+1|0]!=2)){f=0;T:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0];v[b+1|0]=y[e+1|0];b=b+2|0;e=e+2|0;f=f-1|0;continue}break};hb=d+16|0;f=a<<1;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0]^128;v[b+1|0]=y[e+1|0]^128;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};hb=d+16|0;f=a<<1;break u;case 2:break T;default:break u}}f=x[k+2260>>2];a=Jy(k+48|0);d=x[b>>2];g=x[b+20>>2];a=y[a|0];h=hb-16|0;hb=h;x[h+12>>2]=f>>>1;x[h+8>>2]=d;b=a;f=x[Fb(h+12|0,h+8|0)>>2];d=f;while(1){if(d){a=y[e|0]+a|0;v[g|0]=a;b=y[e+1|0]+b|0;v[g+1|0]=b;g=g+2|0;e=e+2|0;d=d-1|0;continue}break}hb=h+16|0;f=f<<1;break u}if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=1))){U:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};hb=d+16|0;f=a<<1;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};hb=d+16|0;f=a<<1;break u;default:f=0;if((g|0)!=11){break u}break;case 2:break U}}f=x[k+2260>>2];d=_l(k+40|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];d=hb-16|0;hb=d;x[d+12>>2]=f>>>1;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=(y[e|0]+g|0)+(y[e+1|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}hb=d+16|0;f=a<<1;break u}d=f&255;if(!((d|0)!=16|y[a+1|0]!=1|y[a+2|0]!=1)){f=0;V:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=x[k+2260>>2]>>>1;x[g+8>>2]=a;d=x[Fb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=a<<8|a>>>8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};hb=g+16|0;f=d<<1;break u;case 1:a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=x[k+2260>>2]>>>1;x[g+8>>2]=a;d=x[Fb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};hb=g+16|0;f=d<<1;break u;case 2:break V;default:break u}}f=x[k+2260>>2];d=_l(k+32|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];d=hb-16|0;hb=d;x[d+12>>2]=f>>>1;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=(y[e+1|0]+g|0)+(y[e|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}hb=d+16|0;f=a<<1;break u}h=a;if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=3))){W:{switch(g|0){case 0:s=hb-16|0;hb=s;d=x[k+2260>>2];x[s+12>>2]=d;i=x[b>>2]<<1;x[s+8>>2]=i;a=s+8|0;g=x[Fb(a,s+12|0)>>2];x[s+8>>2]=i;x[s+4>>2]=d-g;a=x[Fb(a,s+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){w[f>>1]=y[d|0]|y[d+1|0]<<8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){w[d>>1]=y[f|0]|y[f+1|0]<<8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};hb=s+16|0;f=a+h<<1;break u;case 1:s=hb-16|0;hb=s;d=x[k+2260>>2];x[s+12>>2]=d;i=x[b>>2]<<1;x[s+8>>2]=i;a=s+8|0;g=x[Fb(a,s+12|0)>>2];x[s+8>>2]=i;x[s+4>>2]=d-g;a=x[Fb(a,s+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){w[f>>1]=(y[d|0]|y[d+1|0]<<8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){w[d>>1]=(y[f|0]|y[f+1|0]<<8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};hb=s+16|0;f=a+h<<1;break u;default:f=0;if((g|0)!=11){break u}break;case 2:break W}}g=x[k+2260>>2];a=z[_l(k+24|0)>>1];t=hb-16|0;hb=t;x[t+12>>2]=g;m=x[b>>2]<<1;x[t+8>>2]=m;d=t+8|0;f=x[Fb(d,t+12|0)>>2];x[t+8>>2]=m;x[t+4>>2]=g-f;s=x[Fb(d,t+4|0)>>2];g=b;d=x[g+20>>2];b=a;i=f>>>1|0;o=i;f=e;while(1){if(o){b=(y[f|0]+b|0)+(y[f+1|0]<<8)|0;w[d>>1]=b;d=d+4|0;f=f+2|0;o=o-1|0;continue}break}f=e+m|0;d=x[g+20>>2]+2|0;b=s>>>1|0;o=b;while(1){if(o){a=(y[f|0]+a|0)+(y[f+1|0]<<8)|0;w[d>>1]=a;d=d+4|0;f=f+2|0;o=o-1|0;continue}break}hb=t+16|0;f=b+i<<1;if(y[h+3|0]!=11){break u}a=x[g+20>>2];b=a+(x[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;continue}}a=f&255;if(!((a|0)!=16|y[h+1|0]!=3|y[h+2|0]!=1)){f=0;X:{switch(g|0){case 0:m=hb-16|0;hb=m;d=x[k+2260>>2];x[m+12>>2]=d;s=x[b>>2]<<1;x[m+8>>2]=s;a=m+8|0;g=x[Fb(a,m+12|0)>>2];x[m+8>>2]=s;x[m+4>>2]=d-g;i=x[Fb(a,m+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){a=y[d|0]|y[d+1|0]<<8;w[f>>1]=a<<8|a>>>8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+s|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=y[f|0]|y[f+1|0]<<8;w[d>>1]=a<<8|a>>>8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};hb=m+16|0;f=b+h<<1;break u;case 1:m=hb-16|0;hb=m;d=x[k+2260>>2];x[m+12>>2]=d;s=x[b>>2]<<1;x[m+8>>2]=s;a=m+8|0;g=x[Fb(a,m+12|0)>>2];x[m+8>>2]=s;x[m+4>>2]=d-g;i=x[Fb(a,m+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){a=y[d|0]|y[d+1|0]<<8;w[f>>1]=(a<<8|a>>>8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+s|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=y[f|0]|y[f+1|0]<<8;w[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};hb=m+16|0;f=b+h<<1;break u;case 2:break X;default:break u}}f=x[k+2260>>2];a=z[_l(k+16|0)>>1];o=hb-16|0;hb=o;x[o+12>>2]=f;m=x[b>>2]<<1;x[o+8>>2]=m;d=o+8|0;g=x[Fb(d,o+12|0)>>2];x[o+8>>2]=m;x[o+4>>2]=f-g;s=x[Fb(d,o+4|0)>>2];f=b;h=x[b+20>>2];b=a;i=g>>>1|0;d=i;g=e;while(1){if(d){b=(y[g+1|0]+b|0)+(y[g|0]<<8)|0;w[h>>1]=b;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}g=e+m|0;h=x[f+20>>2]+2|0;b=s>>>1|0;d=b;while(1){if(d){a=(y[g+1|0]+a|0)+(y[g|0]<<8)|0;w[h>>1]=a;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}hb=o+16|0;f=b+i<<1;break u}if(!(y[h+2|0]|((a|0)!=16|y[h+1|0]!=2))){f=0;Y:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>2;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;w[b+2>>1]=y[e+2|0]|y[e+3|0]<<8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};hb=d+16|0;f=a<<2;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>2;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;w[b+2>>1]=(y[e+2|0]|y[e+3|0]<<8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};hb=d+16|0;f=a<<2;break u;case 2:break Y;default:break u}}f=x[k+2260>>2];a=_l(k+8|0);d=x[b>>2];g=x[b+20>>2];a=z[a>>1];h=hb-16|0;hb=h;x[h+12>>2]=f>>>2;x[h+8>>2]=d;b=a;f=x[Fb(h+12|0,h+8|0)>>2];d=f;while(1){if(d){a=(y[e|0]+a|0)+(y[e+1|0]<<8)|0;w[g>>1]=a;b=(y[e+2|0]+b|0)+(y[e+3|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}hb=h+16|0;f=f<<2;break u}a=f&255;if(!((a|0)!=16|y[h+1|0]!=2|y[h+2|0]!=1)){f=0;Z:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=x[k+2260>>2]>>>2;x[g+8>>2]=a;d=x[Fb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=a<<8|a>>>8;a=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=a<<8|a>>>8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};hb=g+16|0;f=d<<2;break u;case 1:a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=x[k+2260>>2]>>>2;x[g+8>>2]=a;d=x[Fb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=(a<<8|a>>>8)^32768;a=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};hb=g+16|0;f=d<<2;break u;case 2:break Z;default:break u}}f=x[k+2260>>2];a=_l(k);d=x[b>>2];g=x[b+20>>2];a=z[a>>1];h=hb-16|0;hb=h;x[h+12>>2]=f>>>2;x[h+8>>2]=d;b=a;f=x[Fb(h+12|0,h+8|0)>>2];d=f;while(1){if(d){a=(y[e+1|0]+a|0)+(y[e|0]<<8)|0;w[g>>1]=a;b=(y[e+3|0]+b|0)+(y[e+2|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}hb=h+16|0;f=f<<2;break u}if(!(g|y[h+1|0]!=1|(a|0)!=24)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=(b>>>0)/3;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,N=gd(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=N;a=a+2|0;e=e+3|0;f=f-1|0;continue}break}hb=g+16|0;f=D(b,3);break u}g=hb-16|0;hb=g;x[g+12>>2]=(b>>>0)/3;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,N=gd(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=N;a=a+2|0;e=e+3|0;f=f-1|0;continue}break}hb=g+16|0;f=D(b,3);break u}a=f&255;if(!(g|y[h+1|0]!=2|(a|0)!=24)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=(b>>>0)/6;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,N=gd(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=N;M=a,N=gd(y[e+4|0]<<16|y[e+3|0]<<8|y[e+5|0]<<24,16),w[M+2>>1]=N;a=a+4|0;e=e+6|0;f=f-1|0;continue}break}hb=g+16|0;f=D(b,6);break u}g=hb-16|0;hb=g;x[g+12>>2]=(b>>>0)/6;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,N=gd(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=N;M=a,N=gd(y[e+4|0]<<16|y[e+5|0]<<8|y[e+3|0]<<24,16),w[M+2>>1]=N;a=a+4|0;e=e+6|0;f=f-1|0;continue}break}hb=g+16|0;f=D(b,6);break u}if(!(g|y[h+1|0]!=1|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,N=gd(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=N;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}hb=g+16|0;f=b<<2;break u}g=hb-16|0;hb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=a,N=gd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=N;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}hb=g+16|0;f=b<<2;break u}a=f&255;if(!(g|y[h+1|0]!=2|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,N=gd(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=N;M=a,N=gd(y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),16),w[M+2>>1]=N;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}hb=g+16|0;f=b<<3;break u}g=hb-16|0;hb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=a,N=gd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=N;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=a,N=gd(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M+2>>1]=N;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}hb=g+16|0;f=b<<3;break u}if(!(g|y[h+1|0]!=1|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,N=Nc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=N;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}hb=g+16|0;f=b<<3;break u}o=hb-16|0;hb=o;x[o+12>>2]=b>>>3;x[o+8>>2]=d;s=x[Fb(o+12|0,o+8|0)>>2];f=s;while(1){if(f){m=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=a,N=Nc(h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)),i|(b|g),48),w[M>>1]=N;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}hb=o+16|0;f=s<<3;break u}a=f&255;if(!(g|y[h+1|0]!=2|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>4;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,N=Nc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=N;M=a,N=Nc(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24),y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24),48),w[M+2>>1]=N;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}hb=g+16|0;f=b<<4;break u}o=hb-16|0;hb=o;x[o+12>>2]=b>>>4;x[o+8>>2]=d;s=x[Fb(o+12|0,o+8|0)>>2];f=s;while(1){if(f){m=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=a,N=Nc(h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)),i|(b|g),48),w[M>>1]=N;m=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);M=a,N=Nc(h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)),i|(b|g),48),w[M+2>>1]=N;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}hb=o+16|0;f=s<<4;break u}if(!(y[h+1|0]!=1|(g|0)!=3|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){j=wf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=Lh(E(Fd(Zf(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));_:{if(E(F(j))<E(2147483648)){d=~~j;break _}d=-2147483648}M=a,N=Vc(d),w[M>>1]=N;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}hb=g+16|0;f=b<<2;break u}g=hb-16|0;hb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=Lh(E(Fd(Zf(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));$:{if(E(F(j))<E(2147483648)){d=~~j;break $}d=-2147483648}M=a,N=Vc(d),w[M>>1]=N;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}hb=g+16|0;f=b<<2;break u}a=f&255;if(!(y[h+1|0]!=2|(g|0)!=3|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){j=wf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=Lh(E(Fd(Zf(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));aa:{if(E(F(j))<E(2147483648)){d=~~j;break aa}d=-2147483648}M=a,N=Vc(d),w[M>>1]=N;j=wf((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));j=Lh(E(Fd(Zf(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ba:{if(E(F(j))<E(2147483648)){d=~~j;break ba}d=-2147483648}M=a,N=Vc(d),w[M+2>>1]=N;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}hb=g+16|0;f=b<<3;break u}g=hb-16|0;hb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Fb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=Lh(E(Fd(Zf(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ca:{if(E(F(j))<E(2147483648)){d=~~j;break ca}d=-2147483648}M=a,N=Vc(d),w[M>>1]=N;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);j=wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=Lh(E(Fd(Zf(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));da:{if(E(F(j))<E(2147483648)){d=~~j;break da}d=-2147483648}M=a,N=Vc(d),w[M+2>>1]=N;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}hb=g+16|0;f=b<<3;break u}if(!(y[h+1|0]!=1|(g|0)!=3|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-32|0;hb=g;x[g+24>>2]=b>>>3;x[g+16>>2]=d;d=x[Fb(g+24|0,g+16|0)>>2];f=d;while(1){if(f){b=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,b|0);q=Yf(+n());M=g,O=$e(q)?q>=0?1:-1:q,C[M+24>>3]=O;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=ee(C[wg(g+24|0,g+16|0,g+8|0)>>3]*32768);ea:{if(F(q)<2147483648){b=~~q;break ea}b=-2147483648}M=a,N=Vc(b),w[M>>1]=N;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}hb=g+32|0;f=d<<3;break u}m=hb-32|0;hb=m;x[m+24>>2]=b>>>3;x[m+16>>2]=d;i=x[Fb(m+24|0,m+16|0)>>2];f=i;while(1){if(f){s=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);h=s<<24|(s&65280)<<8;g=s&-16777216;d=g>>>24|0;b=s&16711680;o=b<<24|g<<8;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,o|(((g&255)<<24|s>>>8)&-16777216|((g&16777215)<<8|s>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,h|(d|b>>>8));q=Yf(+n());M=m,O=$e(q)?q>=0?1:-1:q,C[M+24>>3]=O;x[m+16>>2]=0;x[m+20>>2]=-1074790400;x[m+8>>2]=0;x[m+12>>2]=1072693248;q=ee(C[wg(m+24|0,m+16|0,m+8|0)>>3]*32768);fa:{if(F(q)<2147483648){b=~~q;break fa}b=-2147483648}M=a,N=Vc(b),w[M>>1]=N;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}hb=m+32|0;f=i<<3;break u}a=f&255;if(!(y[h+1|0]!=2|(g|0)!=3|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-32|0;hb=g;x[g+24>>2]=b>>>4;x[g+16>>2]=d;d=x[Fb(g+24|0,g+16|0)>>2];f=d;while(1){if(f){b=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,b|0);q=Yf(+n());M=g,O=$e(q)?q>=0?1:-1:q,C[M+24>>3]=O;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=ee(C[wg(g+24|0,g+16|0,g+8|0)>>3]*32768);ga:{if(F(q)<2147483648){b=~~q;break ga}b=-2147483648}M=a,N=Vc(b),w[M>>1]=N;b=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24));l(1,b|0);q=Yf(+n());M=g,O=$e(q)?q>=0?1:-1:q,C[M+24>>3]=O;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=ee(C[wg(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(F(q)<2147483648){b=~~q;break ha}b=-2147483648}M=a,N=Vc(b),w[M+2>>1]=N;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}hb=g+32|0;f=d<<4;break u}o=hb-32|0;hb=o;x[o+24>>2]=b>>>4;x[o+16>>2]=d;s=x[Fb(o+24|0,o+16|0)>>2];f=s;while(1){if(f){m=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)));l(1,i|(b|g));q=Yf(+n());M=o,O=$e(q)?q>=0?1:-1:q,C[M+24>>3]=O;x[o+16>>2]=0;x[o+20>>2]=-1074790400;x[o+8>>2]=0;x[o+12>>2]=1072693248;q=ee(C[wg(o+24|0,o+16|0,o+8|0)>>3]*32768);ia:{if(F(q)<2147483648){b=~~q;break ia}b=-2147483648}M=a,N=Vc(b),w[M>>1]=N;i=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);h=i<<24|(i&65280)<<8;g=i&-16777216;d=g>>>24|0;b=i&16711680;m=b<<24|g<<8;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,m|(((g&255)<<24|i>>>8)&-16777216|((g&16777215)<<8|i>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,h|(d|b>>>8));q=Yf(+n());M=o,O=$e(q)?q>=0?1:-1:q,C[M+24>>3]=O;x[o+16>>2]=0;x[o+20>>2]=-1074790400;x[o+8>>2]=0;x[o+12>>2]=1072693248;q=ee(C[wg(o+24|0,o+16|0,o+8|0)>>3]*32768);ja:{if(F(q)<2147483648){b=~~q;break ja}b=-2147483648}M=a,N=Vc(b),w[M+2>>1]=N;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}hb=o+32|0;f=s<<4;break u}ka:{if((a|0)==24){if((g|0)!=15|(y[h+1|0]-1&255)>>>0>1){break ka}x[k+96>>2]=-2147483648;a=x[k+2260>>2];la:{if(!y[h+2|0]){o=k+96|0;f=0;t=hb-16|0;hb=t;M=t,N=D(x[b>>2],Gd(z[b+34>>1])),x[M+12>>2]=N;wc(t+12|0,(a>>>0)/3|0);a=e;g=x[t+12>>2];h=g;while(1){if(h){i=y[a+1|0]<<16|y[a|0]<<8|y[a+2|0]<<24;ma:{na:{oa:{if((i|0)>=0){d=i;break oa}d=-2147483648;if((i|0)==-2147483648){break na}d=0-i|0}if(d>>>0<=f>>>0){break ma}}f=d}h=h-1|0;a=a+3|0;continue}else{pa:{if(!f){break pa}m=f-1|0;s=f>>>1|0;h=x[b+20>>2];a=g;while(1){if(!a){break pa}d=y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24;i=d&-2147483648|d>>>1;d=s|d<<31;qa:{if((i|0)>0|(i|0)>=0){d=Mia(d,i,f,0);i=lb;break qa}i=Mia(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,f,0);d=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}M=h,N=gd(Ec(d,i),16),w[M>>1]=N;a=a-1|0;e=e+3|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=f}hb=t+16|0;f=D(g,3);break la}o=k+96|0;f=0;t=hb-16|0;hb=t;M=t,N=D(x[b>>2],Gd(z[b+34>>1])),x[M+12>>2]=N;wc(t+12|0,(a>>>0)/3|0);a=e;g=x[t+12>>2];h=g;while(1){if(h){i=y[a+1|0]<<16|y[a+2|0]<<8|y[a|0]<<24;ra:{sa:{ta:{if((i|0)>=0){d=i;break ta}d=-2147483648;if((i|0)==-2147483648){break sa}d=0-i|0}if(d>>>0<=f>>>0){break ra}}f=d}h=h-1|0;a=a+3|0;continue}else{ua:{if(!f){break ua}m=f-1|0;s=f>>>1|0;h=x[b+20>>2];a=g;while(1){if(!a){break ua}d=y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24;i=d&-2147483648|d>>>1;d=s|d<<31;va:{if((i|0)>0|(i|0)>=0){d=Mia(d,i,f,0);i=lb;break va}i=Mia(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,f,0);d=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}M=h,N=gd(Ec(d,i),16),w[M>>1]=N;a=a-1|0;e=e+3|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=f}hb=t+16|0;f=D(g,3)}if(!f){break u}a=x[k+96>>2];if((a|0)==-2147483648){break u}e=Jia(z[b+32>>1],0,a,0);a=lb;e=e+1073741824|0;a=e>>>0<1073741824?a+1|0:a;M=b,N=Td(Uc((a&2147483647)<<1|e>>>31,a>>>31|0),1,64),w[M+32>>1]=N;w[b+34>>1]=z[b+34>>1]|8192;break u}a=f&255;if((a|0)==32){if(!((g|0)!=15|(y[h+1|0]-1&255)>>>0>1)){x[k+96>>2]=-2147483648;d=x[k+2260>>2];wa:{if(!y[h+2|0]){o=k+96|0;a=0;t=hb-16|0;hb=t;M=t,N=D(x[b>>2],Gd(z[b+34>>1])),x[M+12>>2]=N;wc(t+12|0,d>>>2|0);f=e;h=e;g=x[t+12>>2];e=g;while(1){if(e){i=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);xa:{ya:{za:{if((i|0)>=0){d=i;break za}d=-2147483648;if((i|0)==-2147483648){break ya}d=0-i|0}if(d>>>0<=a>>>0){break xa}}a=d}e=e-1|0;h=h+4|0;continue}else{Aa:{if(!a){break Aa}m=a-1|0;s=a>>>1|0;h=x[b+20>>2];e=g;while(1){if(!e){break Aa}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);i=d&-2147483648|d>>>1;d=s|d<<31;Ba:{if((i|0)>0|(i|0)>=0){d=Mia(d,i,a,0);i=lb;break Ba}i=Mia(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}M=h,N=gd(Ec(d,i),16),w[M>>1]=N;e=e-1|0;f=f+4|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=a}hb=t+16|0;f=g<<2;break wa}o=k+96|0;a=0;t=hb-16|0;hb=t;M=t,N=D(x[b>>2],Gd(z[b+34>>1])),x[M+12>>2]=N;wc(t+12|0,d>>>2|0);f=e;h=e;g=x[t+12>>2];e=g;while(1){if(e){d=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);i=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);Ca:{Da:{Ea:{if((i|0)>=0){d=i;break Ea}d=-2147483648;if((i|0)==-2147483648){break Da}d=0-i|0}if(a>>>0>=d>>>0){break Ca}}a=d}e=e-1|0;h=h+4|0;continue}else{Fa:{if(!a){break Fa}m=a-1|0;s=a>>>1|0;h=x[b+20>>2];e=g;while(1){if(!e){break Fa}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);d=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);i=d&-2147483648|d>>>1;d=s|d<<31;Ga:{if((i|0)>0|(i|0)>=0){d=Mia(d,i,a,0);i=lb;break Ga}i=Mia(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}M=h,N=gd(Ec(d,i),16),w[M>>1]=N;e=e-1|0;f=f+4|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=a}hb=t+16|0;f=g<<2}if(!f){break u}a=x[k+96>>2];if((a|0)==-2147483648){break u}e=Jia(z[b+32>>1],0,a,0);a=lb;e=e+1073741824|0;a=e>>>0<1073741824?a+1|0:a;M=b,N=Td(Uc((a&2147483647)<<1|e>>>31,a>>>31|0),1,64),w[M+32>>1]=N;w[b+34>>1]=z[b+34>>1]|8192;break u}if((g|0)!=14|(y[h+1|0]-1&255)>>>0>1){break ka}x[k+96>>2]=1065353216;a=x[k+2260>>2];Ha:{if(!y[h+2|0]){f=k+96|0;h=hb-16|0;hb=h;M=h,N=D(x[b>>2],Gd(z[b+34>>1])),x[M+12>>2]=N;wc(h+12|0,a>>>2|0);g=e;d=x[h+12>>2];a=d;while(1){if(a){j=wf((l(2,y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)),r()));j=E(F(Zf(j)?j>=E(0)?E(1):E(-1):j));u=j>u?j:u;a=a-1|0;g=g+4|0;continue}else{Ia:{a=u==E(0);if(a){break Ia}J=a?E(1):E(E(1)/u);g=x[b+20>>2];a=d;while(1){if(!a){break Ia}j=wf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=Lh(E(Fd(E(J*(Zf(j)?j>=E(0)?E(1):E(-1):j)),E(-1))*E(32768)));Ja:{if(E(F(j))<E(2147483648)){i=~~j;break Ja}i=-2147483648}M=g,N=Vc(i),w[M>>1]=N;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(f){B[f>>2]=u}hb=h+16|0;f=d<<2}break}break Ha}f=k+96|0;i=hb-16|0;hb=i;M=i,N=D(x[b>>2],Gd(z[b+34>>1])),x[M+12>>2]=N;wc(i+12|0,a>>>2|0);g=e;d=x[i+12>>2];a=d;while(1){if(a){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);j=wf((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));j=E(F(Zf(j)?j>=E(0)?E(1):E(-1):j));u=j>u?j:u;a=a-1|0;g=g+4|0;continue}else{Ka:{a=u==E(0);if(a){break Ka}J=a?E(1):E(E(1)/u);g=x[b+20>>2];a=d;while(1){if(!a){break Ka}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=wf((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));j=Lh(E(Fd(E(J*(Zf(j)?j>=E(0)?E(1):E(-1):j)),E(-1))*E(32768)));La:{if(E(F(j))<E(2147483648)){h=~~j;break La}h=-2147483648}M=g,N=Vc(h),w[M>>1]=N;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(f){B[f>>2]=u}hb=i+16|0;f=d<<2}break}}if(!f){break u}j=B[k+96>>2];if(j==E(1)){break u}j=Lh(Iy(E(j*E(z[b+32>>1])),E(1),E(64)));a=65535;Ma:{if(j>=E(65535)){break Ma}a=0;if(j<=E(0)){break Ma}a=~~j>>>0;if(j<E(4294967296)&j>=E(0)){break Ma}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break u}if((g|0)!=14|(y[h+1|0]-1&255)>>>0>1|(a|0)!=64){break ka}x[k+96>>2]=0;x[k+100>>2]=1072693248;a=x[k+2260>>2];Na:{if(!y[h+2|0]){h=k+96|0;i=hb-32|0;hb=i;M=i,N=D(x[b>>2],Gd(z[b+34>>1])),x[M+4>>2]=N;wc(i+4|0,a>>>3|0);d=e;f=x[i+4>>2];a=f;while(1){if(a){g=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));l(1,g|0);q=Yf(+n());q=F($e(q)?q>=0?1:-1:q);H=q>H?q:H;a=a-1|0;d=d+8|0;continue}else{Oa:{a=H==0;if(a){break Oa}K=a?1:1/H;d=x[b+20>>2];a=f;while(1){if(!a){break Oa}g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,g|0);q=Yf(+n());M=i,O=K*($e(q)?q>=0?1:-1:q),C[M+24>>3]=O;x[i+16>>2]=0;x[i+20>>2]=-1074790400;x[i+8>>2]=0;x[i+12>>2]=1072693248;q=ee(C[wg(i+24|0,i+16|0,i+8|0)>>3]*32768);Pa:{if(F(q)<2147483648){g=~~q;break Pa}g=-2147483648}M=d,N=Vc(g),w[M>>1]=N;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(h){C[h>>3]=H}hb=i+32|0;f=f<<3}break}break Na}o=k+96|0;G=hb-32|0;hb=G;M=G,N=D(x[b>>2],Gd(z[b+34>>1])),x[M+4>>2]=N;wc(G+4|0,a>>>3|0);d=e;f=x[G+4>>2];a=f;while(1){if(a){m=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);s=m<<24|(m&65280)<<8;i=m&-16777216;h=i>>>24|0;g=m&16711680;t=g<<24|i<<8;i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,t|(((i&255)<<24|m>>>8)&-16777216|((i&16777215)<<8|m>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,s|(h|g>>>8));q=Yf(+n());q=F($e(q)?q>=0?1:-1:q);H=q>H?q:H;a=a-1|0;d=d+8|0;continue}else{Qa:{a=H==0;if(a){break Qa}K=a?1:1/H;d=x[b+20>>2];a=f;while(1){if(!a){break Qa}t=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);m=t<<24|(t&65280)<<8;s=t&16711680;i=s>>>8|0;h=t&-16777216;g=h>>>24|0;s=h<<8|s<<24;h=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,s|(((h&255)<<24|t>>>8)&-16777216|((h&16777215)<<8|t>>>24)&16711680|(h>>>8&65280|h>>>24)));l(1,m|(g|i));q=Yf(+n());M=G,O=K*($e(q)?q>=0?1:-1:q),C[M+24>>3]=O;x[G+16>>2]=0;x[G+20>>2]=-1074790400;x[G+8>>2]=0;x[G+12>>2]=1072693248;q=ee(C[wg(G+24|0,G+16|0,G+8|0)>>3]*32768);Ra:{if(F(q)<2147483648){g=~~q;break Ra}g=-2147483648}M=d,N=Vc(g),w[M>>1]=N;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(o){C[o>>3]=H}hb=G+32|0;f=f<<3}break}}if(!f){break u}q=C[k+96>>3];if(q==1){break u}q=ee(Hy(q*+z[b+32>>1],1,64));a=65535;Sa:{if(q>=65535){break Sa}a=0;if(q<=0){break Sa}a=~~q>>>0;if(q<4294967296&q>=0){break Sa}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break u}Ta:{Ua:{Va:{Wa:{a=(f&255)!=32;Xa:{if(!(a|(y[h+1|0]!=1|(g|0)!=12))){u=E(30517578125e-15);f=x[k+2260>>2];if(!y[h+2|0]){break Xa}break Ta}if(!(y[h+1|0]!=2|(g|0)!=12|a)){u=E(30517578125e-15);f=x[k+2260>>2];if(!y[h+2|0]){break Va}break Ua}a=(f&255)!=32;if(a|(y[h+1|0]!=1|(g|0)!=13)){break Wa}u=E(1.1920928955078125e-7);f=x[k+2260>>2];if(y[h+2|0]){break Ta}}a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=f>>>2;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){j=wf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=Lh(E(Fd(E((Zf(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Ya:{if(E(F(j))<E(2147483648)){g=~~j;break Ya}g=-2147483648}M=b,N=Vc(g),w[M>>1]=N;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}hb=d+16|0;f=a<<2;break u}f=0;if(y[h+1|0]!=2|(g|0)!=13|a){break u}u=E(1.1920928955078125e-7);f=x[k+2260>>2];if(y[h+2|0]){break Ua}}a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=f>>>3;x[d+8>>2]=a;a=x[Fb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){j=wf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=Lh(E(Fd(E((Zf(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Za:{if(E(F(j))<E(2147483648)){g=~~j;break Za}g=-2147483648}M=b,N=Vc(g),w[M>>1]=N;j=wf((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));j=Lh(E(Fd(E((Zf(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));_a:{if(E(F(j))<E(2147483648)){g=~~j;break _a}g=-2147483648}M=b,N=Vc(g),w[M+2>>1]=N;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}hb=d+16|0;f=a<<3;break u}a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=f>>>3;x[g+8>>2]=a;a=x[Fb(g+12|0,g+8|0)>>2];f=a;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=Lh(E(Fd(E((Zf(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));$a:{if(E(F(j))<E(2147483648)){d=~~j;break $a}d=-2147483648}M=b,N=Vc(d),w[M>>1]=N;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);j=wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=Lh(E(Fd(E((Zf(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));ab:{if(E(F(j))<E(2147483648)){d=~~j;break ab}d=-2147483648}M=b,N=Vc(d),w[M+2>>1]=N;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}hb=g+16|0;f=a<<3;break u}a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=f>>>2;x[g+8>>2]=a;a=x[Fb(g+12|0,g+8|0)>>2];f=a;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=Lh(E(Fd(E((Zf(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));bb:{if(E(F(j))<E(2147483648)){d=~~j;break bb}d=-2147483648}M=b,N=Vc(d),w[M>>1]=N;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}hb=g+16|0;f=a<<2;break u}a=V(30848)|0}if((ib|0)!=(da(30848)|0)){break d}_(a|0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break v}}yb(t);break u}a=P()|0;break d}x[23604]=0;Q(141,c|0,f+L|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break f}}Lc(I)}hb=k+2288|0;return f|0}a=P()|0;break a}a=P()|0}yb(t);break a}a=P()|0;break a}a=P()|0}Lc(I);T(a|0);p()}function xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=hb-640|0;hb=d;xc(b);f=hb-16|0;hb=f;g=d+448|0;sq(f+8|0,g);j=x[f+12>>2];h=b;mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(j|0)){bc(h,x[f+12>>2])}hb=f+16|0;b=(b|0)==(j|0);if(!b){cT(g)}a:{b:{c:{if(!b){break c}if(!eT(d+448|0)){break c}if(!Qb(x[h>>2],x[h+8>>2],Uc(dT(d+448|0),lb))){break c}if(!c){e=1;break c}Cd(a,32);v[d+447|0]=0;j=Kb(d+432|0);d:{e:{f:{g:{h:{i:{j:{k:{if(!Rb(d+448|0,16128,4)){x[23604]=0;R(349,a|0,16777216);b=x[23604];x[23604]=0;if((b|0)==1){break b}b=x[h>>2];x[23604]=0;b=S(146,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break b}x[23604]=0;Q(141,h|0,b-4|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break b}x[23604]=0;B=S(143,h|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break k}break b}l:{m:{n:{o:{p:{q:{if((z[d+488>>1]-2185&65535)>>>0>1910){break q}b=x[h>>2];x[23604]=0;b=S(146,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break b}x[23604]=0;Q(141,h|0,b-4|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break b}x[23604]=0;B=S(143,h|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break b}if(B>>>0<256){break q}b=x[h>>2];x[23604]=0;b=S(146,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break b}if(b>>>0<=B>>>0){break q}x[23604]=0;b=Q(141,h|0,B|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break b}if(!b){break q}x[23604]=0;b=S(350,h|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break b}if(!b){break q}x[23604]=0;R(349,a|0,16777216);b=x[23604];x[23604]=0;if((b|0)==1){break b}b=z[d+488>>1];if(b>>>0>=4096){x[23604]=0;c=Q(1,d+168|0,16343)|0;b=x[23604];x[23604]=0;if((b|0)==1){break j}a=x[a+1298464>>2];x[23604]=0;U(351,a|0,1,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(c);e=0;break d}b=P()|0;xb(c);break a}if(b>>>0<2194){break q}x[23604]=0;e=Q(1,d+416|0,15867)|0;b=x[23604];x[23604]=0;if((b|0)==1){break p}b=x[a+1298464>>2];x[23604]=0;U(351,b|0,4,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break o}xb(e)}if(x[a+480180>>2]!=32){break k}b=z[d+488>>1];if((b&61440)!=20480){break l}b=b&4095;e=b<<16;if(Rb(d+508|0,13478,4)){break n}v[d+447|0]=1;break m}b=P()|0;break a}b=P()|0;xb(e);break a}if(b>>>0<297){break m}e=z[d+508>>1]|e}x[a+1074308>>2]=e;break k}e=z[d+490>>1];if(!((e|0)!=2184&(b|0)!=2184)){v[d+447|0]=1;x[a+1074308>>2]=18284544;break k}r:{switch(b-532|0){default:if(x[d+508>>2]|((b|0)!=768|(e|0)!=768)|(z[d+480>>1]!=256|y[d+500|0]!=128)){break k}if(y[d+501|0]){break k}x[a+1074308>>2]=18285088;v[d+447|0]=1;break k;case 3:if(x[d+508>>2]|(e|0)!=512){break k}s:{if(IA(d+512|0,255,64)){x[a+1074308>>2]=18219008;x[23604]=0;b=Q(1,d+400|0,14694)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break s}b=P()|0;break a}x[a+1074308>>2]=18284544;x[23604]=0;b=Q(1,d+400|0,16717)|0;e=x[23604];x[23604]=0;if((e|0)==1){break i}}Ab(j,b);xb(b);v[d+447|0]=1;break k;case 1:case 2:break k;case 0:break r}}if(x[d+508>>2]|(e|0)!=514){break k}x[a+1074308>>2]=17367040;x[23604]=0;b=Q(1,d+400|0,14577)|0;e=x[23604];x[23604]=0;if((e|0)==1){break f}Ab(j,b);xb(b);v[d+447|0]=1}b=z[d+492>>1];e=b>>>2|0;x[a+480208>>2]=b<<3&32768|(e&8|(e&4|(x[a+480208>>2]&-32797|b<<1&16)));b=d+280|0;Hq(b,d+448|4);x[23604]=0;R(208,d+168|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break h}b=d+168|0;Ab(a+1298308|0,b);xb(b);if(!(!(y[d+494|0]&4)|x[a+1074308>>2]-18285314>>>0>4276681982)){x[a+480216>>2]=y[d+478|0];x[a+480220>>2]=y[d+479|0]}b=y[d+496|0];x[a+480200>>2]=b>>>0>128?256:b<<1;b=y[d+498|0];if(b){x[a+480196>>2]=b}v[d+168|0]=31;v[d+280|0]=y[d+499|0];b=d+168|0;e=d+280|0;J=a,K=D(y[Ye(b,e)|0],1e4),x[J+480204>>2]=K;v[d+168|0]=y[d+497|0];v[d+280|0]=128;J=a,K=y[Wb(b,e)|0],x[J+480228>>2]=K;e=0;while(1){if((e|0)==64){t:{x[23604]=0;Q(141,h|0,192)|0;b=x[23604];x[23604]=0;if((b|0)==1){break b}if(x[a+480180>>2]==16777216&(z[d+488>>1]-2187&65535)>>>0<=2){break t}b=y[a+484376|0];e=x[a+484360>>2];x[23604]=0;ea(324,_b(e,b)|0,h|0,z[d+480>>1],255,254);b=x[23604];x[23604]=0;if((b|0)==1){break b}break e}}else{g=(d+448|0)+e|0;i=g- -64|0;u:{if(y[i|0]==255){break u}f=(e<<5)+a|0;b=f+480280|0;Qe(b);J=f+480286|0,K=Td(y[g+128|0],0,64),w[J>>1]=K;g=v[i|0];if((g|0)<0){x[b>>2]=x[b>>2]|1024}g=g&127;if(g>>>0<=64){w[f+480284>>1]=g<<2;break u}if((g|0)!=100){break u}x[b>>2]=x[b>>2]|256}e=e+1|0;continue}break}e=0;x[23604]=0;b=S(180,h|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break g}if(b){break d}x[23604]=0;b=S(143,h|0)|0;f=x[23604];x[23604]=0;v:{if((f|0)==1){break v}if(b>>>0>4e3){break d}f=y[a+484376|0];g=x[a+484360>>2];x[23604]=0;b=W(352,_b(g,f)|0,h|0,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break v}if(!b){break d}break e}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}t=Sb(d+384|0);q=Sb(d+368|0);e=0;n=Sb(d+352|0);x[23604]=0;b=W(353,h|0,t|0,z[d+482>>1])|0;f=x[23604];x[23604]=0;w:{x:{y:{if((f|0)==1){break y}if(!b){break w}x[23604]=0;b=W(353,h|0,q|0,z[d+484>>1])|0;f=x[23604];x[23604]=0;if((f|0)==1){break y}if(!b){break w}x[23604]=0;b=W(353,h|0,n|0,z[d+486>>1])|0;f=x[23604];x[23604]=0;if((f|0)==1){break y}if(!b){break w}x[d+348>>2]=-1;J=d,K=Bb(x[t>>2]),x[J+168>>2]=K;e=Bb(x[t+4>>2]);while(1){b=x[d+168>>2];if(Ob(b,e)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!(!b|b>>>0>=A[d+348>>2])){x[d+348>>2]=b}Fe(d+168|0);continue}else{J=d,K=Bb(x[q>>2]),x[J+168>>2]=K;e=Bb(x[q+4>>2]);while(1){b=x[d+168>>2];if(Ob(b,e)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!(!b|b>>>0>=A[d+348>>2])){x[d+348>>2]=b}Fe(d+168|0);continue}else{J=d,K=Bb(x[n>>2]),x[J+168>>2]=K;e=Bb(x[n+4>>2]);z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{while(1){b=x[d+168>>2];if(Ob(b,e)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!(!b|b>>>0>=A[d+348>>2])){x[d+348>>2]=b}Fe(d+168|0);continue}else{if(v[d+494|0]&1){x[d+168>>2]=x[d+504>>2];J=d,K=x[Fb(d+348|0,d+168|0)>>2],x[J+348>>2]=K}e=0;if(z[d+490>>1]!=532){break H}b=z[d+488>>1];if(y[d+479|0]|(b?(b|0)!=532:0)|(y[d+478|0]|y[d+501|0])){break H}if(x[d+508>>2]|y[d+492|0]&192){break H}if(z[d+482>>1]){break I}f=z[d+484>>1];if(!f){break I}if((x[h+8>>2]+(rc(x[q>>2],x[q+4>>2])<<2)|0)+2>>>0>A[d+348>>2]){break I}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){x[23604]=0;b=S(143,h|0)|0;f=x[23604];x[23604]=0;J:{if((f|0)!=1){if(!b){break J}hg(h,((e&65535)<<2)+4|0);break I}b=P()|0;break x}e=e+1|0;f=z[d+484>>1];continue}break}x[23604]=0;b=Q(1,d+336|0,14838)|0;e=x[23604];x[23604]=0;if((e|0)==1){break G}Ab(j,b);xb(b)}e=1;if(z[d+488>>1]){break H}x[23604]=0;b=Q(1,d+320|0,15208)|0;f=x[23604];x[23604]=0;if((f|0)==1){break F}Ab(j,b);xb(b)}b=z[d+494>>1];K:{if(b&2){x[23604]=0;f=S(180,h|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break A}b=x[h+8>>2];g=x[h>>2];x[23604]=0;i=b;b=f<<3;g=W(142,g|0,i|0,b|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break A}if(!(!g|A[d+348>>2]<b+x[h+8>>2]>>>0)){x[23604]=0;b=a+1298408|0;R(354,b|0,f|0);g=x[23604];x[23604]=0;if((g|0)==1){break A}J=d,K=Bb(x[b>>2]),x[J+280>>2]=K;g=Bb(x[a+1298412>>2]);L:{M:{while(1){b=x[d+280>>2];if(!Ob(b,g)){if(!(!f&e)){break K}if(!(y[d+494|0]&4)){break L}x[23604]=0;b=Q(1,d+304|0,15241)|0;e=x[23604];x[23604]=0;if((e|0)==1){break M}Ab(j,b);xb(b);break K}x[23604]=0;R(355,h|0,d+168|0);i=x[23604];x[23604]=0;if((i|0)!=1){Zb(b,0,44);i=y[d+168|0]|y[d+169|0]<<8;if(i|(y[d+170|0]|y[d+171|0]<<8)){x[b+20>>2]=((i&65024)>>>9|0)+80;J=b,K=Yb((y[d+168|0]|y[d+169|0]<<8)>>>5&15,1,12)-1|0,x[J+16>>2]=K;J=b,K=Yb((y[d+168|0]|y[d+169|0]<<8)&31,1,31),x[J+12>>2]=K;J=b,K=Yb((y[d+170|0]|y[d+171|0]<<8)>>>11|0,0,23),x[J+8>>2]=K;J=b,K=Yb((y[d+170|0]|y[d+171|0]<<8)>>>5&63,0,59),x[J+4>>2]=K;J=b,K=Yb((y[d+170|0]|y[d+171|0]<<8)<<1&62,0,59),x[J>>2]=K}x[b+44>>2]=y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24);x[d+280>>2]=x[d+280>>2]+48;continue}break}b=P()|0;break x}b=P()|0;break x}x[23604]=0;b=Q(1,d+304|0,14865)|0;e=x[23604];x[23604]=0;if((e|0)!=1){Ab(j,b);xb(b);break K}b=P()|0;break x}hg(h,2);break K}if(!(b>>>0<2&e)){break K}x[23604]=0;b=S(180,h|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break z}if(!b){x[23604]=0;b=Q(1,d+304|0,14838)|0;e=x[23604];x[23604]=0;if((e|0)!=1){Ab(j,b);xb(b);break K}b=P()|0;break x}hg(h,2)}N:{if(!(y[d+492|0]&128|y[d+494|0]&8)){break N}x[23604]=0;b=a+901404|0;e=Q(356,h|0,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break E}if(!e){break N}HA(b)}if(z[d+488>>1]<=531){Zp(a+901404|0)}x[23604]=0;C=S(160,d+280|0)|0;b=x[23604];x[23604]=0;O:{P:{Q:{if((b|0)!=1){x[23604]=0;b=Q(346,h|0,13715)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Q}if(b){x[23604]=0;b=S(143,h|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break P}x[23604]=0;U(176,d+256|0,h|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break P}b=d+256|0;e=kc(d+168|0,b);$c(C,e);yb(e);yb(b)}w[a+480188>>1]=1;x[23604]=0;b=Q(346,h|0,13720)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Q}if(!b){break C}x[23604]=0;b=S(143,h|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){x[23604]=0;U(176,d+256|0,h|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break O}}b=P()|0;break B}b=P()|0;break x}b=P()|0;break B}b=P()|0;break B}b=d+256|0;f=kc(d+168|0,b);yb(b);b=x[f>>2];x[23604]=0;b=S(146,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break D}w[d+256>>1]=(b>>>0)/20;b=z[Wc(27012,d+256|0)>>1];w[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){yb(f);break C}x[23604]=0;U(357,f|0,((e<<5)+a|0)+480289|0,20);g=x[23604];x[23604]=0;if((g|0)!=1){e=e+1|0;continue}break}break D}b=P()|0;break x}b=P()|0;break x}b=P()|0;break x}b=P()|0;yb(f);break B}R:{b=x[d+348>>2];e=x[h+8>>2];S:{if(b>>>0>=e>>>0){e=b-e|0;break S}x[23604]=0;e=S(188,h|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break R}}x[23604]=0;U(176,d+168|0,h|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break R}b=d+168|0;E=kc(d+256|0,b);yb(b);x[23604]=0;F=Q(358,a|0,E|0)|0;b=x[23604];x[23604]=0;T:{U:{V:{if((b|0)==1){break V}if(!(v[d+494|0]&1)|!z[d+502>>1]){break U}x[23604]=0;b=Q(141,h|0,x[d+504>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break V}if(!b){break U}x[23604]=0;X(315,a+1298332|0,h|0,z[d+502>>1],4);b=x[23604];x[23604]=0;if((b|0)!=1){break U}}b=P()|0;break T}g=a+480192|0;w[g>>1]=0;f=0;if(y[d+492|0]&4){w[d+168>>1]=z[d+482>>1];w[d+96>>1]=255;f=z[Wc(d+168|0,d+96|0)>>1];w[g>>1]=f}e=0;W:{while(1){if((f&65535)>>>0<=e>>>0){x[d+252>>2]=0;e=z[d+484>>1];if(e){b=zb(x[q>>2],e-1|0);x[d+252>>2]=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))+80}w[d+168>>1]=e;w[d+96>>1]=3999;r=a+480190|0;f=z[Wc(d+168|0,d+96|0)>>1];w[r>>1]=f;m=c&2;o=d+188|0;u=a+1298464|0;e=0;b=0;while(1){X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((f&65535)>>>0>e>>>0){f=zb(x[q>>2],e);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!f){break Y}x[23604]=0;f=Q(141,h|0,f|0)|0;g=x[23604];x[23604]=0;da:{ea:{fa:{ga:{ha:{if((g|0)==1){break ha}if(!f){break Y}x[23604]=0;f=Q(359,h|0,d+168|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break ha}if(!f){break Y}x[23604]=0;i=e+1|0;f=D(i,104)+a|0;g=f+484380|0;k=Q(360,d+168|0,g|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break ga}l=d+152|0;Hq(l,o);x[23604]=0;R(208,d+96|0,l|0);l=x[23604];x[23604]=0;if((l|0)==1){break fa}l=d+96|0;Bc(((i<<5)+a|0)+946304|0,l);xb(l);x[23604]=0;k=Q(141,h|0,k|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break ga}if(!k){break Y}f=z[f+484414>>1];if(!(f&512)){break ea}x[23604]=0;f=Q(361,h|0,d+96|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break ca}if(!f){break da}x[d+8>>2]=x[d+104>>2];f=x[d+100>>2];x[d>>2]=x[d+96>>2];x[d+4>>2]=f;kl(g,1,d);break da}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}if(!(f&16384)){s=z[d+488>>1];k=y[d+186|0];l=k&2;f=y[d+214|0];i=Xc(d+96|0,l?16:8,1,0,(f^-1)&1);if(!(!(k&4)|s>>>0<532)){to(i,3)}ia:{ja:{if(k&8){k=f&4?5:4;break ja}if(!l){k=10;if((f|0)==255){break ja}}if(f&2){v[i+2|0]=1}if(f&4){Lf(i,2)}if(!(f&8)){break ia}k=9;if(!l){break ia}}Lf(i,k)}if(m){f=0;x[23604]=0;W(205,d+96|0,g|0,h|0)|0;i=x[23604];x[23604]=0;if((i|0)!=1){break _}break X}f=1;i=y[d+99|0];if(i>>>0>17){break Z}i=1<<i;if(!(i&63503)){if(!(i&198144)){break Z}break $}if(y[d+96|0]){break $}break _}x[23604]=0;R(362,h|0,d+80|0);f=x[23604];x[23604]=0;if((f|0)==1){break aa}g=x[d+80>>2];if(!(!m|!g)){f=Kb(d+96|0);x[23604]=0;U(253,h|0,f|0,g|0);g=x[23604];x[23604]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((g|0)!=1){x[23604]=0;R(363,d+136|0,16265);g=x[23604];x[23604]=0;if((g|0)==1){break qa}x[d+64>>2]=i;x[23604]=0;U(11,d+120|0,0,f|0);g=x[23604];x[23604]=0;if((g|0)==1){break pa}x[23604]=0;X(364,d+152|0,d+136|0,d- -64|0,d+120|0);g=x[23604];x[23604]=0;if((g|0)==1){break oa}g=x[u>>2];x[23604]=0;U(351,g|0,2,d+152|0);g=x[23604];x[23604]=0;if((g|0)==1){break na}xb(d+152|0);xb(d+120|0);Db(d+136|0);xb(f);break da}b=P()|0;break ka}b=P()|0;break ka}b=P()|0;break la}b=P()|0;break ma}b=P()|0;xb(d+152|0)}xb(d+120|0)}Db(d+136|0)}xb(f);break T}x[23604]=0;Q(174,h|0,g|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break aa}}f=0;break Z}w[d+168>>1]=1;w[d+96>>1]=f;J=a+480190|0,K=z[Se(d+168|0,d+96|0)>>1],w[J>>1]=K;if(!(z[d+488>>1]==516&b)|z[d+490>>1]!=512|(z[d+494>>1]|x[d+508>>2])){break ba}if((z[d+492>>1]&65527)!=21|y[d+496|0]!=128|(y[d+497|0]!=48|y[d+500|0]!=128)){break ba}if(y[d+501|0]|z[d+502>>1]){break ba}f=d+576|0;b=d+512|0;e=1;while(1)if((b|0)==(f|0)){b=d+640|0;while(1)if((b|0)==(f|0)){f=20;while(1){if((f|0)==26){ra:{if(!(e&1)){break ba}x[23604]=0;b=Q(1,d+152|0,9771)|0;e=x[23604];x[23604]=0;if((e|0)==1){break ra}Ab(j,b);xb(b);break ba}}else{e=!y[(d+f|0)+452|0]&e;f=f+1|0;continue}break}b=P()|0;break T}else{e=y[f|0]==64&e;f=f+1|0;continue}}else{e=(y[b|0]&127)==32&e;b=b+1|0;continue}}b=P()|0;break T}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;b=rc(x[n>>2],x[n+4>>2]);w[d+168>>1]=b;r=z[Wc(d+168|0,x[a+8>>2]+10|0)>>1];w[d+118>>1]=r;sa:{ta:{ua:{va:{if((b|0)!=(r|0)){x[23604]=0;Y(365,d+96|0);b=x[23604];x[23604]=0;if((b|0)==1){break sa}b=x[n+4>>2];e=x[n>>2];x[23604]=0;J=d,K=rc(e,b),x[J+136>>2]=K;X(366,d+168|0,d+96|0,d+136|0,d+118|0);b=x[23604];x[23604]=0;if((b|0)==1){break ua}b=x[a+1298464>>2];x[23604]=0;U(351,b|0,2,d+168|0);b=x[23604];x[23604]=0;if((b|0)==1){break va}xb(d+168|0);Db(d+96|0)}if(!(c&1)){w[d+118>>1]=0;r=0}m=a+480188|0;i=0;wa:{xa:{ya:{za:{Aa:{Ba:{while(1){Ca:{if((i|0)==(r|0)){Da:{Ea:{b=x[d+252>>2];if(!b){break Ea}x[23604]=0;Q(141,h|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Da}if(!(s&1)){break Ea}while(1){Fa:{b=x[h+8>>2];c=x[h>>2];x[23604]=0;b=W(142,c|0,b|0,4)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Fa}if(!b){break Ea}x[23604]=0;b=Q(346,h|0,13689)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Fa}Ga:{if(!b){x[23604]=0;b=Q(346,h|0,13694)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Fa}if(!b){break Ga}}x[23604]=0;b=S(143,h|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){hg(h,8);if(!(b&1616928864)|b&-2139062144){break Ga}break Ea}b=P()|0;break T}x[23604]=0;b=S(180,h|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Fa}x[23604]=0;Q(174,h|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}b=P()|0;break T}x[23604]=0;b=Q(367,a|0,h|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Da}b=b|y[d+447|0];v[d+447|0]=b;if(!(!(b&255)|F)){Qt(a+1074312|0);v[a+1074368|0]=0}x[23604]=0;X(368,a|0,h|0,0,d+447|0);b=x[23604];x[23604]=0;if((b|0)==1){break Da}x[23604]=0;o=a+484344|0;R(211,o|0,r|0);b=x[23604];x[23604]=0;if((b|0)==1){break Da}u=a+480188|0;I=a+480183|0;i=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{while(1){Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((i|0)!=(r|0)){b=zb(x[n>>2],i);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(b){x[23604]=0;b=Q(141,h|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break ab}if(b){break $a}}x[23604]=0;b=W(212,o|0,i&65535,64)|0;c=x[23604];x[23604]=0;if((c|0)==1){break ab}if(b){break bb}w[d+48>>1]=i;x[23604]=0;Y(369,d+96|0);b=x[23604];x[23604]=0;if((b|0)==1){break fb}x[23604]=0;U(370,d+168|0,d+96|0,d+48|0);b=x[23604];x[23604]=0;if((b|0)==1){break eb}b=x[a+1298464>>2];x[23604]=0;U(351,b|0,2,d+168|0);b=x[23604];x[23604]=0;if((b|0)==1){break db}xb(d+168|0);Db(d+96|0)}if(!x[a+1074308>>2]){e=z[d+488>>1];if((e|0)!=2184){break Za}x[a+1074308>>2]=18284544}if(!wd(x[j+4>>2],y[j+11|0])){break _a}x[23604]=0;c=Q(1,d+96|0,17462)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Ra}b=x[a+1074308>>2];x[23604]=0;R(126,d- -64|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break Ta}x[23604]=0;U(2,d+168|0,c|0,d- -64|0);b=x[23604];x[23604]=0;if((b|0)==1){break Ua}e=d+168|0;b=Ab(j,e);xb(e);xb(d- -64|0);xb(c);if(!Rb(d+508|0,13478,4)|(z[d+488>>1]&61440)!=20480){break Ya}x[23604]=0;c=Q(1,d+168|0,16729)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Va}x[23604]=0;Q(87,b|0,c|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Wa}xb(c);break Xa}b=P()|0;break T}b=P()|0;break cb}b=P()|0;xb(d+168|0)}Db(d+96|0);break T}b=x[o>>2];x[23604]=0;R(371,ac(b,i)|0,C|0);b=x[23604];x[23604]=0;if((b|0)!=1){break Pa}}b=P()|0;break T}x[23604]=0;b=S(180,h|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Ha}x[23604]=0;G=S(180,h|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Ia}x[23604]=0;c=Q(174,h|0,4)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ia}if(!c){break Pa}x[23604]=0;c=W(212,o|0,i&65535,G|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ia}if(!c){break Pa}x[23604]=0;U(176,d+96|0,h|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break Ja}b=d+96|0;m=kc(d+168|0,b);yb(b);b=x[o>>2];x[23604]=0;R(371,ac(b,i)|0,C|0);b=x[23604];x[23604]=0;if((b|0)==1){break La}b=z[u>>1];x[23604]=0;l=Q(372,d+120|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Ma}b=z[u>>1];c=d+96|0;sh(c);x[23604]=0;k=W(373,d+80|0,b|0,c|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Oa}J=d,K=Bb(x[ac(x[o>>2],i)>>2]),x[J+64>>2]=K;s=0;while(1){gb:{hb:{ib:{jb:{if(s>>>0>=G>>>0){break jb}b=x[m>>2];x[23604]=0;b=W(142,b|0,x[d+176>>2],1)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Qa}if(!b){break jb}x[23604]=0;b=S(192,m|0)|0;c=x[23604];x[23604]=0;kb:{if((c|0)!=1){b=b<<24>>24;if(b){break kb}pT(d- -64|0,z[u>>1]);s=s+1|0;continue}break Qa}lb:{c=b&127;g=c?c-1&65535:0;if(Rc(x[l>>2],x[d+124>>2])>>>0>g>>>0){break lb}x[23604]=0;v[d+96|0]=0;c=g+1|0;U(374,l|0,c|0,d+96|0);e=x[23604];x[23604]=0;if((e|0)==1){break Qa}e=d+96|0;sh(e);x[23604]=0;U(375,k|0,c|0,e|0);c=x[23604];x[23604]=0;if((c|0)!=1){break lb}break Qa}if((b|0)<0){x[23604]=0;b=S(192,m|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Qa}J=Gb(x[l>>2],g),K=b,v[J|0]=K}f=d+96|0;sh(f);if(g>>>0<z[u>>1]){f=Bd(x[d+64>>2],g)}b=Gb(x[l>>2],g);e=y[b|0];if(e&16){J=f,K=y[Bd(x[k>>2],g)|0],v[J|0]=K;e=y[b|0]}if(e&32){J=f,K=y[Bd(x[k>>2],g)+1|0],v[J+1|0]=K;e=y[b|0]}if(e&64){c=Bd(x[k>>2],g);v[f+2|0]=y[c+2|0];v[f+4|0]=y[c+4|0];e=y[b|0]}if(e<<24>>24<0){c=Bd(x[k>>2],g);v[f+3|0]=y[c+3|0];v[f+5|0]=y[c+5|0];e=y[b|0]}if(e&1){x[23604]=0;b=S(192,m|0)|0;c=x[23604];x[23604]=0;mb:{nb:{if((c|0)!=1){b=b<<24>>24;b=(((b^-1)&128)>>>7|0)+b|0;if(!(v[I|0]&1)){break nb}c=b;break mb}break Qa}c=253;if((b-121&255)>>>0<132){break mb}c=(b&255)!=253?b:0}v[f|0]=c;J=Bd(x[k>>2],g),K=c,v[J|0]=K;b=Gb(x[l>>2],g)}if(y[b|0]&2){x[23604]=0;b=S(192,m|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Qa}v[f+1|0]=b;J=Bd(x[k>>2],g),K=b,v[J+1|0]=K;b=Gb(x[l>>2],g)}if(!(y[b|0]&4)){break gb}x[23604]=0;b=S(192,m|0)|0;c=x[23604];x[23604]=0;ob:{pb:{if((c|0)!=1){if(b>>>0>64){break pb}v[f+4|0]=b;e=1;break ob}break Qa}if(b<<24>>24<=-64){e=2;v[f+2|0]=2;b=b^-128;v[f+4|0]=b;break hb}if(b>>>0<=74){e=5;v[f+2|0]=5;b=b-65|0;v[f+4|0]=b;break hb}if(b>>>0<=84){e=6;v[f+2|0]=6;b=b-75|0;v[f+4|0]=b;break hb}if(b>>>0<=94){e=3;v[f+2|0]=3;b=b-85|0;v[f+4|0]=b;break hb}if(b>>>0<=104){e=4;v[f+2|0]=4;b=b-95|0;v[f+4|0]=b;break hb}if(b>>>0<=114){e=13;v[f+2|0]=13;b=b-105|0;v[f+4|0]=b;break hb}if(b>>>0<=124){e=12;v[f+2|0]=12;b=b-115|0;v[f+4|0]=b;break hb}c=b+63|0;if((c&255)>>>0<=9){v[f+4|0]=c;e=11;v[f+2|0]=11;b=c;break hb}c=b+53|0;H=c&255;if(H>>>0<=9){v[f+4|0]=c;e=8;v[f+2|0]=8;if(!H){b=0;break hb}if(x[a+1074308>>2]-1>>>0>18285139){break ib}e=7;v[f+2|0]=7;break ib}b=b+33|0;if((b&255)>>>0>=10){b=y[f+4|0];e=y[f+2|0];break hb}v[f+4|0]=b;e=15}v[f+2|0]=e;break hb}Zj(k);fc(l);yb(m);break Pa}b=c}c=Bd(x[k>>2],g);v[c+4|0]=b;v[c+2|0]=e;b=Gb(x[l>>2],g)}if(!(y[b|0]&8)){continue}x[23604]=0;R(245,d+32|0,m|0);b=x[23604];x[23604]=0;if((b|0)!=1){v[f+3|0]=y[d+32|0];J=f,K=y[hd(d+32|0)|0],v[J+5|0]=K;FA(f,1);b=Bd(x[k>>2],g);v[b+3|0]=y[f+3|0];v[b+5|0]=y[f+5|0];continue}break}break Qa}e=z[d+488>>1]}qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{b=e&65535;switch(b>>>12|0){case 13:break rb;case 7:break sb;case 6:break tb;case 4:break ub;case 1:break wb;case 0:break xb;default:break Xa}}if(F){x[23604]=0;b=Q(1,d+168|0,8258)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Ab(j,b);xb(b);break Xa}b=P()|0;break T}yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((e&65535)==532){f=z[d+490>>1];if((f|0)!=532){if((f|0)!=512){e=532;break Kb}Mb:{if(z[d+494>>1]|z[d+492>>1]!=9|(y[d+479|0]|y[d+478|0])){break Mb}if(z[d+482>>1]|z[d+480>>1]!=(z[d+486>>1]+1|0)|(y[d+496|0]!=128|y[d+497|0]!=100)){break Mb}if(y[d+498|0]!=1|y[d+500|0]!=128|(y[d+501|0]|z[d+502>>1])){break Mb}if(x[d+504>>2]|x[d+508>>2]){break Mb}x[23604]=0;b=Q(1,d+168|0,9752)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Ab(j,b);xb(b);break Xa}b=P()|0;break T}e=532;if(x[d+508>>2]|(y[d+479|0]|y[d+478|0])){break Jb}x[a+1074308>>2]=16777381;x[23604]=0;b=Q(1,d+168|0,14775)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Ab(j,b);xb(b);v[d+447|0]=1;break Xa}b=P()|0;break T}if(!Rb(d+508|0,13954,4)){x[23604]=0;b=Q(1,d+168|0,8296)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Ab(j,b);xb(b);e=a+1074312|0;f=38;break vb}b=P()|0;break T}e=532;if(y[d+501|0]|z[d+494>>1]>1|(x[d+508>>2]|(z[d+492>>1]&4294)!=4)){break Lb}if(!z[a+480190>>1]){break Lb}x[23604]=0;e=Q(54,d+96|0,13343)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Hb}b=hb-32|0;hb=b;c=hb-16|0;hb=c;Pu(c+8|0,a+484527|0);NS(b+24|0,x[c+8>>2],x[c+12>>2]);hb=c+16|0;ve(b+16|0,e);c=x[b+20>>2];x[b+8>>2]=x[b+16>>2];x[b+12>>2]=c;c=Ic(x[b+24>>2],x[b+28>>2],b+8|0);hb=b+32|0;xb(e);if(c){break Ib}e=z[d+488>>1]}if(e&65535){break Lb}if(wd(x[j+4>>2],y[j+11|0])){break Fb}}f=z[d+490>>1]}if((f&65535)>>>0>767){break Xa}}if(!wd(x[j+4>>2],y[j+11|0])){break Xa}if((f&65535)>>>0<533){break Db}x[23604]=0;b=Q(1,d- -64|0,14808)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Eb}Ab(j,b);xb(b);break Cb}x[23604]=0;b=Q(1,d+168|0,8322)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Gb}Ab(j,b);xb(b);break Xa}b=P()|0;break T}b=P()|0;break T}x[23604]=0;b=Q(1,d+168|0,9642)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Ab(j,b);xb(b);break Xa}b=P()|0;break T}b=P()|0;break T}if((e&65535)>>>0>=533){x[23604]=0;R(376,d- -64|0,3976);b=x[23604];x[23604]=0;Nb:{if((b|0)!=1){x[23604]=0;x[d+48>>2]=z[d+488>>1]-532;U(377,d+168|0,d- -64|0,d+48|0);b=x[23604];x[23604]=0;if((b|0)==1){break Nb}b=d+168|0;Ab(j,b);xb(b);Db(d- -64|0);break Cb}b=P()|0;break T}b=P()|0;Db(d- -64|0);break T}x[23604]=0;R(251,d- -64|0,4275);b=x[23604];x[23604]=0;if((b|0)==1){break Bb}b=z[d+488>>1];x[d+32>>2]=b>>>8&15;x[23604]=0;x[d+16>>2]=b&255;R(378,d+48|0,d+16|0);b=x[23604];x[23604]=0;if((b|0)==1){break Ab}x[23604]=0;X(364,d+168|0,d- -64|0,d+32|0,d+48|0);b=x[23604];x[23604]=0;if((b|0)==1){break zb}b=d+168|0;Ab(j,b);xb(b);xb(d+48|0);Db(d- -64|0)}b=a+1298408|0;if(!tc(x[b>>2],x[a+1298412>>2])){break Xa}c=x[d+508>>2];if(!c){break Xa}c=EC(z[d+488>>1],c);e=kq(d+168|0);x[e+44>>2]=c;x[23604]=0;R(379,b|0,e|0);b=x[23604];x[23604]=0;if((b|0)!=1){break Xa}b=P()|0;break T}b=P()|0;break T}b=P()|0;break yb}b=P()|0;xb(d+48|0)}Db(d- -64|0);break T}c=x[d+508>>2];x[23604]=0;U(380,d+168|0,b|0,x[d+508>>2]);e=x[23604];x[23604]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{if((e|0)!=1){e=d+168|0;Ab(j,e);xb(e);b=(b|0)==8191?c:b-4176|0;if((b|0)>1915){break Tb}f=x[a+480208>>2];if(!(f&16)){break Sb}x[23604]=0;Q(250,a+1074312|0,7)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break Rb}break qb}b=P()|0;break T}if(b>>>0>4200){break Pb}f=x[a+480208>>2]}if(!(f&16)){x[23604]=0;Q(250,a+1074312|0,7)|0;c=x[23604];x[23604]=0;if((c|0)==1){break qb}}if((b|0)>2385){break Qb}}x[23604]=0;Q(250,a+1074312|0,38)|0;b=x[23604];x[23604]=0;if((b|0)==1){break qb}}x[23604]=0;b=Q(250,a+1074312|0,102)|0;c=x[23604];x[23604]=0;if((c|0)==1){break qb}x[23604]=0;Q(250,b|0,48)|0;b=x[23604];x[23604]=0;if((b|0)==1){break qb}break Ob}if(b>>>0>4383){break Xa}}x[23604]=0;e=W(249,a+1074312|0,116,1)|0;b=x[23604];x[23604]=0;f=115;if((b|0)==1){break qb}}x[23604]=0;Q(250,e|0,f|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break qb}break Xa}x[23604]=0;Y(381,d+96|0);b=x[23604];x[23604]=0;Ub:{Vb:{Wb:{if((b|0)!=1){b=z[d+488>>1];x[d+48>>2]=b>>>8&15;x[23604]=0;x[d+32>>2]=b&255;R(378,d- -64|0,d+32|0);b=x[23604];x[23604]=0;if((b|0)==1){break Wb}x[23604]=0;X(364,d+168|0,d+96|0,d+48|0,d- -64|0);b=x[23604];x[23604]=0;if((b|0)==1){break Vb}b=d+168|0;Ab(j,b);xb(b);xb(d- -64|0);Db(d+96|0);break Xa}b=P()|0;break T}b=P()|0;break Ub}b=P()|0;xb(d- -64|0)}Db(d+96|0);break T}x[23604]=0;b=Q(1,d+168|0,8258)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Ab(j,b);xb(b);break Xa}b=P()|0;break T}if(!((b|0)!=32767|z[d+490>>1]!=533)){x[23604]=0;b=Q(1,d+168|0,5003)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Ab(j,b);xb(b);break Xa}b=P()|0;break T}x[23604]=0;R(123,d+96|0,4111);b=x[23604];x[23604]=0;Xb:{if((b|0)!=1){b=z[d+488>>1];x[d+64>>2]=b>>>8&15;x[d+48>>2]=b>>>4&15;x[23604]=0;x[d+32>>2]=b&15;ea(124,d+168|0,d+96|0,d- -64|0,d+48|0,d+32|0);b=x[23604];x[23604]=0;if((b|0)==1){break Xb}b=d+168|0;Ab(j,b);xb(b);Db(d+96|0);break Xa}b=P()|0;break T}b=P()|0;Db(d+96|0);break T}x[23604]=0;b=Q(1,d+168|0,6084)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Ab(j,b);xb(b);break Xa}b=P()|0;break T}b=P()|0;break T}if(!MD(x[a+1074308>>2])){break Xa}x[23604]=0;c=Q(1,d+168|0,16965)|0;e=x[23604];x[23604]=0;Yb:{if((e|0)!=1){x[23604]=0;Q(87,b|0,c|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Yb}xb(c);break Xa}b=P()|0;break T}b=P()|0;xb(c);break T}e=x[a+480180>>2];if(!((e|0)!=16777216|z[d+488>>1]<2186)){x[23604]=0;b=Q(141,h|0,B|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Da}if(b){x[23604]=0;U(382,a|0,h|0,z[d+488>>1]);b=x[23604];x[23604]=0;if((b|0)==1){break Da}}e=x[a+480180>>2]}Zb:{_b:{$b:{ac:{bc:{cc:{if((e|0)==16777216){x[23604]=0;Q(1,d+48|0,13662)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break cc}b=P()|0;break T}x[23604]=0;R(251,d+32|0,4275);b=x[23604];x[23604]=0;if((b|0)==1){break bc}b=z[d+490>>1];x[d+28>>2]=b>>>8;x[23604]=0;x[d+12>>2]=b&255;R(378,d+16|0,d+12|0);b=x[23604];x[23604]=0;if((b|0)==1){break ac}x[23604]=0;X(364,d+48|0,d+32|0,d+28|0,d+16|0);b=x[23604];x[23604]=0;if((b|0)==1){break $b}}b=d+48|0;Ab(a+1298344|0,b);xb(b);if((e|0)!=16777216){xb(d+16|0);Db(d+32|0)}b=x[a+480180>>2];x[23604]=0;b=Q(1,d+48|0,((b|0)==16777216?10016:6088)|0)|0;c=x[23604];x[23604]=0;e=1;if((c|0)==1){break Zb}Ab(a+1298356|0,b);xb(b);Ab(a+1298368|0,j);x[a+1298404>>2]=x[a+1074308>>2]?8:5;yb(E);yb(C);break w}b=P()|0;break T}b=P()|0;break _b}b=P()|0;xb(d+16|0)}Db(d+32|0);break T}b=P()|0;break T}b=P()|0;xb(c);break T}b=P()|0;break T}b=P()|0;xb(d- -64|0);break Sa}b=P()|0}xb(c);break T}b=P()|0;break T}b=P()|0;Zj(k);break Na}i=i+1|0;continue}break}b=P()|0}fc(l);break Ka}b=P()|0;break Ka}b=P()|0}yb(m);break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}dc:{b=zb(x[n>>2],i);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);ec:{if(!b){break ec}x[23604]=0;b=Q(141,h|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Ba}if(!b){break ec}x[23604]=0;b=S(180,h|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break wa}x[23604]=0;l=S(180,h|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break xa}if((l-1025&65535)>>>0<64512){break ec}x[23604]=0;c=Q(174,h|0,4)|0;e=x[23604];x[23604]=0;if((e|0)==1){break xa}if(!c){break ec}x[23604]=0;U(176,d+96|0,h|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break ya}b=d+96|0;f=kc(d+168|0,b);yb(b);c=z[m>>1];b=0;x[23604]=0;g=Q(372,d+136|0,c|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Aa}fc:{while(1){if(b>>>0>=l>>>0){break fc}c=x[f>>2];x[23604]=0;c=W(142,c|0,x[d+176>>2],1)|0;e=x[23604];x[23604]=0;if((e|0)==1){break dc}if(!c){break fc}x[23604]=0;c=S(192,f|0)|0;e=x[23604];x[23604]=0;gc:{if((e|0)!=1){c=c<<24>>24;if(c){break gc}b=b+1|0;continue}break Ca}hc:{e=c&127;o=e?e-1|0:0;k=o&65535;if(Rc(x[g>>2],x[d+140>>2])>>>0>k>>>0){break hc}x[23604]=0;v[d+96|0]=0;U(374,g|0,k+1|0,d+96|0);e=x[23604];x[23604]=0;if((e|0)!=1){break hc}break Ca}ic:{if((c|0)<0){x[23604]=0;c=S(192,f|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break ic}J=Gb(x[g>>2],k),K=c,v[J|0]=K}e=Gb(x[g>>2],k);c=y[e|0];if(!(!(c&15)|k>>>0<z[m>>1])){w[m>>1]=o+1;c=y[e|0]}if(c&1){x[23604]=0;Q(174,f|0,1)|0;c=x[23604];x[23604]=0;if((c|0)==1){break ic}e=Gb(x[g>>2],k)}if(y[e|0]&2){x[23604]=0;Q(174,f|0,1)|0;c=x[23604];x[23604]=0;if((c|0)==1){break ic}e=Gb(x[g>>2],k)}if(y[e|0]&4){x[23604]=0;Q(174,f|0,1)|0;c=x[23604];x[23604]=0;if((c|0)==1){break ic}e=Gb(x[g>>2],k)}if(!(y[e|0]&8)){continue}x[23604]=0;Q(174,f|0,2)|0;c=x[23604];x[23604]=0;if((c|0)!=1){continue}}break}break Ca}x[d+96>>2]=x[h+8>>2];J=d,K=x[_c(d+252|0,d+96|0)>>2],x[J+252>>2]=K;fc(g);yb(f)}i=i+1|0;continue}}break}b=P()|0;fc(g);break za}b=P()|0;break T}b=P()|0}yb(f);break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;xb(d+168|0);break ta}b=P()|0}Db(d+96|0);break T}b=P()|0;break T}b=P()|0;break T}f=0;i=EA(d+96|0,x[g>>2]);x[23604]=0;Q(174,h|0,i|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break X}}if(y[d+99|0]!=1){break Z}b=x[g>>2]!=0|b}x[d+96>>2]=x[h+8>>2];J=d,K=x[_c(d+252|0,d+96|0)>>2],x[J+252>>2]=K;s=(f|0)!=0}e=e+1|0;f=z[r>>1];continue}break}b=P()|0;break T}jc:{b=zb(x[t>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);kc:{if(!b){break kc}x[23604]=0;b=Q(141,h|0,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break jc}if(!b){break kc}b=x[h+8>>2];f=x[h>>2];x[23604]=0;b=W(142,f|0,b|0,554)|0;f=x[23604];x[23604]=0;if((f|0)==1){break jc}if(!b){break kc}x[23604]=0;b=W(237,a|0,e+1&65535,0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break W}if(!b){break kc}x[23604]=0;X(383,a|0,h|0,b|0,z[d+490>>1]);f=x[23604];x[23604]=0;if((f|0)==1){break W}v[b+33|0]=y[d+501|0]}e=e+1|0;f=z[g>>1];continue}break}b=P()|0;break T}b=P()|0}yb(E);break B}b=P()|0}yb(C);break x}b=P()|0;break x}b=P()|0;break x}}}}}b=P()|0}sc(n);sc(q);sc(t);break a}sc(n);sc(q);sc(t)}xb(j)}hb=d+640|0;return e|0}b=P()|0}xb(j);T(b|0);p()}function Wfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=hb-1760|0;hb=d;xc(b);a:{if(!Th(b,d+1752|0)){break a}if(!WR(d+1752|0)){break a}if(!c){f=1;break a}r=y[d+1755|0];v[d+1751|0]=r;x[d+1744>>2]=-1;x[d+1740>>2]=1048576;if(r>>>0>=5){e=kg(b);x[d+1744>>2]=e;if(!Qb(x[b>>2],x[b+8>>2],e)){break a}x[d+320>>2]=134217727;N=d,O=x[Fb(d+320|0,d+1744|0)>>2]<<5,x[N+1740>>2]=O}C=Sb(d+1728|0);x[d+320>>2]=x[d+1756>>2];e=x[Fb(d+1740|0,d+320|0)>>2];x[23604]=0;R(487,C|0,e|0);e=x[23604];x[23604]=0;b:{c:{d:{e:{f:{if((e|0)!=1){x[23604]=0;e=W(488,b|0,C|0,x[d+1756>>2])|0;h=x[23604];x[23604]=0;g:{if((h|0)==1){break g}if(!e){break b}if(r>>>0>=5){x[23604]=0;Q(141,b|0,x[d+1744>>2]+12|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break g}}x[23604]=0;R(232,a|0,0);e=x[23604];x[23604]=0;if((e|0)==1){break g}Ag(a);ke(d+1696|0,x[C>>2],x[C+4>>2]);e=Yd(d+1688|0);x[23604]=0;h=x[e+4>>2];x[d+88>>2]=x[e>>2];x[d+92>>2]=h;n=rg(489,d+1704|0,x[d+1696>>2],x[d+1700>>2],d+88|0);e=x[23604];x[23604]=0;h:{i:{j:{if((e|0)!=1){x[23604]=0;U(334,n|0,a+1298308|0,-1);e=x[23604];x[23604]=0;if((e|0)==1){break j}x[23604]=0;U(334,n|0,a+1298332|0,-1);e=x[23604];x[23604]=0;if((e|0)==1){break j}x[23604]=0;e=Q(490,n|0,d+1264|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break f}if(!e){break c}e=v[d+1264|0];if((e|0)<=0|(y[d+1273|0]|y[d+1274|0]<<8)>>>0>255|(y[d+1275|0]|y[d+1276|0]<<8)>>>0>3999){break c}E=a+480188|0;w[E>>1]=e&255;Xe(_b(x[a+484360>>2],y[a+484376|0]),y[d+1267|0]|y[d+1268|0]<<8);w[a+480192>>1]=y[d+1273|0]|y[d+1274|0]<<8;w[a+480190>>1]=y[d+1275|0]|y[d+1276|0]<<8;e=y[d+1277|0];x[a+480196>>2]=e?e:6;e=y[d+1278|0];x[a+480204>>2]=D(e?e:125,1e4);h=y[d+1279|0]|y[d+1280|0]<<8|(y[d+1281|0]<<16|y[d+1282|0]<<24);e=32;k:{if(h&256){break k}e=2;if(h&2){break k}e=1;if(h&128){break k}e=h&8?16:4}x[23604]=0;R(349,a|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break f}e=x[a+480208>>2];g=e|16777216;x[a+480208>>2]=g;h=y[d+1279|0]|y[d+1280|0]<<8|(y[d+1281|0]<<16|y[d+1282|0]<<24);if(h&1){g=e|16777232;x[a+480208>>2]=g}e=x[a+480180>>2];k=(e|0)==32;f=k&!(h&1024);s=(e|0)==2;i=s&h>>>4;o=h&2097152;s=s&h>>>2;k=k&!(h&2048);if(f|(o|s|(k|i))){g=i?g|65536:g;g=s?g|2:g;g=k?g|4:g;x[a+480208>>2]=o>>>6|(f?g|8:g)}if(h&524288){x[23604]=0;W(249,a+1074312|0,5,1)|0;e=x[23604];x[23604]=0;if((e|0)==1){break f}e=x[a+480180>>2]}if((e|0)==2){break i}if((e|0)!=32){break h}v[d+320|0]=y[d+1283|0];v[d+240|0]=128;N=a,O=y[Wb(d+320|0,d+240|0)|0]<<1,x[N+480200>>2]=O;break h}a=P()|0;break d}a=P()|0;break e}v[d+320|0]=y[d+1283|0];v[d+240|0]=64;N=a,O=y[Wb(d+320|0,d+240|0)|0]<<2,x[N+480200>>2]=O}h=v[d+1285|0];l:{if((h|0)<0){h=h+52|0;break l}H=pr(+(h|0)*3.1/20);m:{if(H<4294967296&H>=0){h=~~H>>>0;break m}h=0}h=h+51|0}x[a+480228>>2]=h;w[d+320>>1]=64;i=z[Wc(E,d+320|0)>>1];g=0;k=(e|0)!=32;s=(e|0)==4;f=0;while(1)if((f|0)==(i|0)){f=0;i=0;while(1){if((g|0)!=16){i=y[(d+g|0)+1414|0]!=0|i;g=g+1|0;continue}break}while(1){if((f|0)!=128){i=y[((f<<1)+d|0)+1431|0]!=0|i;f=f+1|0;continue}break}n:{if(!(i&1)){break n}e=a+901692|0;f=0;while(1){if((f|0)==16){e=a+902204|0;f=0;while(1){if((f|0)!=128){h=(d+1264|0)+(f<<1)|0;o:{if(y[h+167|0]){x[23604]=0;Y(491,d+240|0);g=x[23604];x[23604]=0;p:{q:{r:{s:{t:{if((g|0)!=1){g=y[h+167|0];x[23604]=0;x[d+264>>2]=g-1;R(492,d+1208|0,d+264|0);g=x[23604];x[23604]=0;if((g|0)==1){break t}h=y[h+166|0];x[23604]=0;v[d+208|0]=h;R(493,d+1184|0,d+208|0);h=x[23604];x[23604]=0;if((h|0)==1){break s}x[23604]=0;X(494,d+320|0,d+240|0,d+1208|0,d+1184|0);h=x[23604];x[23604]=0;if((h|0)==1){break r}h=d+320|0;ve(d+1240|0,h);Oe(qe(e,f),x[d+1240>>2],x[d+1244>>2]);xb(h);xb(d+1184|0);xb(d+1208|0);Db(d+240|0);break o}a=P()|0;break e}a=P()|0;break p}a=P()|0;break q}a=P()|0;xb(d+1184|0)}xb(d+1208|0)}Db(d+240|0);break e}h=oc(d+1232|0,21502);Oe(qe(e,f),x[h>>2],x[d+1236>>2])}f=f+1|0;continue}break}e=x[a+480180>>2];break n}h=(d+f|0)+1414|0;u:{if(y[h|0]){x[23604]=0;Y(495,d+240|0);g=x[23604];x[23604]=0;v:{w:{x:{if((g|0)!=1){h=y[h|0];x[23604]=0;x[d+1184>>2]=h-1;R(492,d+1208|0,d+1184|0);h=x[23604];x[23604]=0;if((h|0)==1){break x}x[23604]=0;U(273,d+320|0,d+240|0,d+1208|0);h=x[23604];x[23604]=0;if((h|0)==1){break w}h=d+320|0;ve(d+1256|0,h);Oe(qe(e,f),x[d+1256>>2],x[d+1260>>2]);xb(h);xb(d+1208|0);Db(d+240|0);break u}a=P()|0;break e}a=P()|0;break v}a=P()|0;xb(d+1208|0)}Db(d+240|0);break e}h=oc(d+1248|0,21502);Oe(qe(e,f),x[h>>2],x[d+1252>>2])}f=f+1|0;continue}}h=y[a+484376|0];g=x[a+484360>>2];x[23604]=0;e=e&5;ea(324,_b(g,h)|0,n|0,y[d+1265|0]|y[d+1266|0]<<8,(e?65535:255)|0,(e?65535:254)|0);e=x[23604];x[23604]=0;if((e|0)!=1){x[23604]=0;U(176,d+320|0,n|0,D(y[d+1264|0],y[d+1269|0]|y[d+1270|0]<<8)<<1);e=x[23604];x[23604]=0;if((e|0)!=1){e=d+320|0;I=kc(d+1208|0,e);yb(e);x[23604]=0;U(176,e|0,n|0,(y[d+1269|0]|y[d+1270|0]<<8)<<1);e=x[23604];x[23604]=0;y:{if((e|0)!=1){e=d+320|0;J=kc(d+1184|0,e);yb(e);x[23604]=0;s=Q(204,d+1168|0,y[d+1271|0]|y[d+1272|0]<<8)|0;e=x[23604];x[23604]=0;z:{if((e|0)!=1){N=d,O=Bb(x[s>>2]),x[N+264>>2]=O;e=Bb(x[s+4>>2]);A:{B:{C:{while(1){h=x[d+264>>2];if(!Ob(h,e)){k=a+480180|0;e=x[k>>2];B=c&1;if(!B){break B}x[23604]=0;R(211,a+484344|0,y[d+1269|0]|y[d+1270|0]<<8);h=x[23604];x[23604]=0;if((h|0)!=1){break B}a=P()|0;break A}x[23604]=0;g=S(143,n|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){x[23604]=0;U(176,d+240|0,n|0,g|0);g=x[23604];x[23604]=0;if((g|0)==1){break C}f=h;h=d+240|0;g=kc(d+320|0,h);$c(f,g);yb(g);yb(h);rh(d+264|0);continue}break}a=P()|0;break A}a=P()|0;break A}u=(e|0)==16?14:(e|0)==32?1:13;K=a+484344|0;o=0;l=1;while(1){D:{E:{F:{G:{H:{I:{if((y[d+1269|0]|y[d+1270|0]<<8)>>>0<=o>>>0){switch(x[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}x[23604]=0;e=S(180,J|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break H}x[d+240>>2]=e;if(!B){break D}x[23604]=0;e=W(212,K|0,o&65535,e|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break H}h=0;if(!e){break D}while(1){f=h&65535;if(f>>>0>=y[d+1264|0]){break D}x[23604]=0;e=S(180,I|0)|0;g=x[23604];x[23604]=0;J:{if((g|0)!=1){g=x[s>>2];if(Bf(g,x[s+4>>2])>>>0<=e>>>0){break J}m=zg(g,e);xc(m);g=0;e=ac(x[K>>2],o);f=cd(x[e>>2],x[x[e+48>>2]+12>>2],0,f);K:while(1){if(A[d+240>>2]<=g>>>0){break J}x[23604]=0;e=S(192,m|0)|0;i=x[23604];x[23604]=0;if((i|0)!=1){if(!e){break J}q=e>>>4|0;t=e&15;sh(d+320|0);i=0;while(1){L:{M:{N:{if(t>>>0>(i&255)>>>0){x[23604]=0;R(496,m|0,d+264|0);e=x[23604];x[23604]=0;if((e|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{e=y[d+264|0];switch(e-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(e-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}e=y[d+265|0];fa:{if(e>>>0<=119){e=e+u|0;break fa}ga:{switch(e-254|0){case 1:e=255;break fa;case 0:e=254;break fa;default:break ga}}e=253}v[d+320|0]=e;l=LA(e)&l;break L}v[d+321|0]=y[d+265|0]+1;break L}ha:{if(y[d+322|0]){break ha}e=x[k>>2];if((e|0)!=32){if((e|0)!=4){break ha}e=y[d+265|0];if(e&15){break ha}v[d+322|0]=11;v[d+324|0]=e>>>4;break L}e=0;j=y[d+265|0];while(1){if((e|0)==10){break ha}if((j|0)==y[e+44272|0]){v[d+324|0]=e;v[d+322|0]=11;break L}else{e=e+1|0;continue}}}v[d+323|0]=4;v[d+325|0]=y[d+265|0];break L}e=y[d+265|0];if(!(y[d+322|0]|e>>>0>9|x[k>>2]!=32)){v[d+324|0]=e;v[d+322|0]=8;break L}v[d+325|0]=e;v[d+323|0]=5;break L}if(y[d+322|0]){e=y[d+265|0];break M}j=x[k>>2];F=(j|0)!=32;e=y[d+265|0];if(!(F|(e|0)!=255)){v[d+324|0]=64;v[d+322|0]=2;break L}ia:{if(!F){if(e&3){break M}break ia}if(e&15|(j|0)!=4){break M}}v[d+322|0]=2;v[d+324|0]=(e&252)>>>2;break L}e=y[d+265|0];if(!(y[d+322|0]|e>>>0>64|x[k>>2]==1)){v[d+324|0]=e;v[d+322|0]=1;break L}v[d+325|0]=e;v[d+323|0]=13;break L}v[d+323|0]=14;e=y[d+265|0];v[d+325|0]=e;if(x[k>>2]==32){break L}v[d+325|0]=D((e&240)>>>4|0,10)+(e&15);break L}e=y[d+265|0];v[d+325|0]=e;if(e>>>0<=31){v[d+323|0]=16;break L}v[d+323|0]=17;break L}j=y[d+265|0];if(j>>>0>=16){v[d+324|0]=j>>>4;v[d+322|0]=(e|0)==20?3:5;break L}v[d+324|0]=j;v[d+322|0]=(e|0)==20?4:6;break L}e=y[d+265|0];if(e>>>0>=16){v[d+322|0]=10;v[d+324|0]=e>>>4;break L}v[d+324|0]=e;v[d+322|0]=9;break L}v[d+323|0]=28;v[d+325|0]=y[d+265|0]|16;break L}v[d+323|0]=28;v[d+325|0]=y[d+265|0]|32;break L}v[d+324|0]=y[d+265|0];v[d+322|0]=y[e+27184|0];break L}v[d+325|0]=y[d+265|0];e=y[d+323|0];v[d+323|0]=(e|0)==4?6:(e|0)==5?7:11;break L}e=y[d+265|0];v[d+324|0]=(e>>>0)%10;if(e>>>0<=9){v[d+322|0]=5;break L}if(e>>>0<=19){v[d+322|0]=6;break L}if(e>>>0<=29){v[d+322|0]=3;break L}if(e>>>0>39){break L}v[d+322|0]=4;break L}v[d+324|0]=y[d+265|0];v[d+322|0]=y[e+27184|0];break L}e=y[d+265|0]+33|0;if((e&255)>>>0>9){break L}v[d+324|0]=e;v[d+322|0]=15;break L}if(e>>>0>57){break L}v[d+325|0]=y[d+265|0];v[d+323|0]=y[e+27184|0];break L}x[d+264>>2]=g+q;e=x[Fb(d+264|0,d+240|0)>>2];e=e>>>0<g>>>0?g:e;while(1){if((e|0)!=(g|0)){i=x[d+320>>2];v[f|0]=i;v[f+1|0]=i>>>8;v[f+2|0]=i>>>16;v[f+3|0]=i>>>24;i=z[d+324>>1];v[f+4|0]=i;v[f+5|0]=i>>>8;g=g+1|0;f=D(y[d+1264|0],6)+f|0;continue}break}g=e;continue K}a=P()|0;break A}v[d+325|0]=e;v[d+323|0]=9}i=i+1|0;continue}}break}a=P()|0;break A}a=P()|0;break A}h=h+1|0;continue}}k=0;e=z[a+480192>>1];break E}a=P()|0;break A}if((l^1)&1|z[E>>1]!=4){break F}x[a+480208>>2]=x[a+480208>>2]|8454144}k=!((y[d+1279|0]|y[d+1280|0]<<8|(y[d+1281|0]<<16|y[d+1282|0]<<24))&512);e=0}x[23604]=0;B=Q(497,d+1152|0,e|0)|0;e=x[23604];x[23604]=0;ja:{ka:{la:{ma:{na:{if((e|0)!=1){l=a+480192|0;f=r>>>0<5;o=a+480180|0;i=1;oa:{while(1){g=i&65535;if(g>>>0>z[l>>1]){break oa}pa:{qa:{ra:{sa:{if(!k){x[23604]=0;h=W(237,a|0,g|0,0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break sa}if(h){break ra}}while(1){x[23604]=0;e=S(192,n|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break ka}if(e){continue}break}if(!f){while(1){x[23604]=0;e=S(192,n|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){a=P()|0;break ja}if(e){continue}break}}x[23604]=0;Q(174,n|0,826)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break qa}}a=P()|0;break ja}e=Kb(d+240|0);x[23604]=0;U(334,n|0,e|0,-1);m=x[23604];x[23604]=0;if((m|0)==1){break pa}Bc(h+492|0,e);if(!f){x[23604]=0;U(334,n|0,e|0,-1);m=x[23604];x[23604]=0;if((m|0)==1){break pa}Bc(h+524|0,e)}x[23604]=0;m=Q(498,n|0,d+320|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break la}if(!m){break na}m=x[o>>2];x[23604]=0;U(499,d+320|0,h|0,m|0);h=x[23604];x[23604]=0;if((h|0)==1){break la}if(x[o>>2]==4){h=zb(x[B>>2],g-1|0);g=z[d+1122>>1]|z[d+1124>>1]<<16;v[h|0]=g;v[h+1|0]=g>>>8;v[h+2|0]=g>>>16;v[h+3|0]=g>>>24}xb(e)}i=i+1|0;continue}break}break la}if(!k){break ma}w[a+480192>>1]=0;break ma}a=P()|0;break A}xb(e)}e=z[a+480190>>1];x[23604]=0;o=Q(500,d+304|0,e|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){F=!(v[d+1279|0]&1)|r>>>0>4;u=c&2;M=a+480180|0;i=1;e=0;while(1){h=e;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{l=i&65535;if(l>>>0<=z[a+480190>>1]){f=Kb(d+288|0);x[23604]=0;U(334,n|0,f|0,-1);c=x[23604];x[23604]=0;Ga:{Ha:{if((c|0)!=1){Bc(((l<<5)+a|0)+946304|0,f);e=r>>>0<5;if(e){break Ha}x[23604]=0;U(334,n|0,f|0,-1);c=x[23604];x[23604]=0;if((c|0)!=1){break Ga}}a=P()|0;break wa}Ve(f)}x[23604]=0;c=Q(501,n|0,d+320|0)|0;g=x[23604];x[23604]=0;Ia:{Ja:{if((g|0)==1){break Ja}if(!c){break Ia}g=x[M>>2];x[23604]=0;k=D(l,104)+a|0;c=k+484380|0;X(502,d+320|0,c|0,g|0,F|0);g=x[23604];x[23604]=0;if((g|0)==1){break Ja}ze(k+484423|0,f);q=0;Ka:{if((z[d+340>>1]&61440)!=28672|e){break Ka}x[23604]=0;q=S(503,n|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break Ka}a=P()|0;break wa}if(!u){break ua}g=y[d+355|0]|y[d+356|0]<<8|(y[d+357|0]<<16|y[d+358|0]<<24);e=z[d+340>>1];m=e&61440;if(!(g|m)){e=Xc(d+240|0,e&1?16:8,e&1024?3:1,0,0);x[23604]=0;W(205,e|0,c|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break ua}a=P()|0;break wa}if((g|0)<0){e=g+l|0;if((e|0)<=0){break ua}VR(c,(D(e,104)+a|0)+484380|0);break ua}if((g|0)<=0){break ua}if(e&1){j=k+484414|0;w[j>>1]=z[j>>1]|1}if(e&1024){j=k+484414|0;w[j>>1]=z[j>>1]|64}x[23604]=0;U(176,d+240|0,b|0,g|0);g=x[23604];x[23604]=0;La:{Ma:{Na:{Oa:{Pa:{Qa:{if((g|0)!=1){j=d+240|0;g=kc(d+264|0,j);yb(j);j=Gd(z[c+34>>1]);L=(m|0)==16384;if(!L&(m|0)!=8192){break Oa}t=x[g>>2];x[23604]=0;t=S(146,t|0)|0;G=x[23604];x[23604]=0;if((G|0)==1){break La}G=4/(j>>>0)|0;Jia(G,0,t,0);wc(c,lb?-1:D(G,t));if((m|0)==8192){break Qa}if(!L){break Oa}if(!yg(c)){break Na}e=x[k+484400>>2];c=x[c>>2];if(!(v[d+340|0]&1)){break Pa}x[23604]=0;X(504,g|0,e|0,c|0,j|0);c=x[23604];x[23604]=0;e=h;if((c|0)==1){break ya}break Ma}a=P()|0;break wa}if(!yg(c)){break Na}e=x[k+484400>>2];c=x[c>>2];if(v[d+340|0]&1){x[23604]=0;X(505,g|0,e|0,c|0,j|0);c=x[23604];x[23604]=0;e=h;if((c|0)!=1){break Ma}break ya}x[23604]=0;X(506,g|0,e|0,c|0,j|0);c=x[23604];x[23604]=0;e=h;if((c|0)==1){break ya}break Ma}x[23604]=0;X(507,g|0,e|0,c|0,j|0);c=x[23604];x[23604]=0;e=h;if((c|0)==1){break ya}break Ma}if((e&45056)==12288){c=UR(d+240|0,g,y[d+359|0]|y[d+360|0]<<8,q);N=$c(bl(x[o>>2],l-1|0),c),O=x[c+20>>2],x[N+20>>2]=O;yb(c);break Na}if((m|0)!=32768){e=1;if((m|0)!=4096){break Ma}m=ge(d+240|0,g);x[23604]=0;e=Q(508,d+232|0,g|0)|0;j=x[23604];x[23604]=0;if((j|0)!=1){Ra:{Sa:{if(!y[d+237|0]){break Sa}q=y[d+359|0]|y[d+360|0]<<8;j=z[d+234>>1]<<1;if(q>>>0<(j&65535)>>>0){break Sa}j=q-j|0;v[d+359|0]=j;v[d+360|0]=j>>>8;e=z[e>>1];x[23604]=0;Q(141,g|0,e|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ra}x[23604]=0;e=S(188,g|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break Ra}x[23604]=0;U(176,d+184|0,g|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break Ra}e=d+184|0;j=kc(d+208|0,e);$c(m,j);yb(j);yb(e)}x[23604]=0;l=W(509,a|0,l|0,m|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ra}e=1;if(l){e=y[d+359|0]|y[d+360|0]<<8;Ta:{if(!e){break Ta}l=z[c+34>>1];j=lj(x[c>>2],l);if(j>>>0<=e>>>0){break Ta}l=gk(l);k=x[k+484400>>2];ah(k,e+k|0,j-e|0);x[c>>2]=x[c>>2]-((e>>>0)/(l>>>0)|0)}wc(c,x[d+328>>2]);e=h}yb(m);break Ma}}a=P()|0;yb(m);break xa}x[23604]=0;e=Q(361,g|0,d+240|0)|0;k=x[23604];x[23604]=0;if((k|0)==1){break Fa}if(!e){break Na}x[d+80>>2]=x[d+248>>2];e=x[d+244>>2];x[d+72>>2]=x[d+240>>2];x[d+76>>2]=e;kl(c,1,d+72|0)}e=h}yb(g);break ta}a=P()|0;break xa}a=P()|0;break wa}xb(f)}Ua:{Va:{Wa:{if(!u){break Wa}r=1;while(1){f=r&65535;if(f>>>0>z[a+480190>>1]){break Wa}b=bl(x[o>>2],f-1|0);c=x[b>>2];x[23604]=0;c=S(164,c|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ua}Xa:{Ya:{if(!c){break Ya}e=z[b+22>>1];c=e+r&65535;i=z[b+20>>1];l=(e|0)!=0&(c|0)!=0&c>>>0<=z[a+480190>>1]&(i|0)!=0;Za:{if(l){g=bl(x[o>>2],c-1|0);break Za}c=x[b>>2];x[23604]=0;i=S(146,c|0)|0;c=x[23604];x[23604]=0;g=b;if((c|0)==1){break Va}}xc(g);_a:{if(l){c=x[g+8>>2];e=x[g>>2];k=z[b+20>>1];x[23604]=0;c=W(142,e|0,c|0,k|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Va}if(!c){break Ya}x[d+240>>2]=0;x[d+264>>2]=0;x[23604]=0;U(189,d+320|0,g|0,i|0);c=x[23604];x[23604]=0;$a:{if((c|0)!=1){k=eA(xe(d+320|0),oi(x[d+320>>2]),d+240|0,d+264|0);x[23604]=0;Q(174,g|0,x[d+240>>2])|0;c=x[23604];x[23604]=0;if((c|0)==1){break $a}Lc(d+320|0);break _a}a=P()|0;break va}a=P()|0;Lc(d+320|0);break va}k=0;x[d+240>>2]=0;x[d+264>>2]=0}x[23604]=0;R(510,d+320|0,b|0);c=x[23604];x[23604]=0;ab:{bb:{if((c|0)!=1){e=xe(d+320|0);i=x[d+320>>2];if(!l){k=eA(e,oi(i),d+240|0,d+264|0);x[23604]=0;c=x[d+240>>2];Q(174,b|0,c|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break Xa}i=i-c|0;e=c+e|0}if(k){break bb}h=1;break ab}a=P()|0;break va}j=D(f,104)+a|0;u=j+484380|0;yg(u);g=0;f=x[d+264>>2];while(1){cb:{if(!i|(f|0)!=1?f:0){break cb}c=x[u>>2];if(c>>>0<=g>>>0){break cb}q=j+484400|0;if(!Qd(c,x[q>>2])){break cb}x[d+208>>2]=0;x[d+184>>2]=0;f=TR(k,e,oi(i),d+208|0,d+288|0,d+184|0);x[23604]=0;x[d+240>>2]=f;Q(174,b|0,f|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break za}Rh(d+184|0,oi(x[u>>2]-g|0));c=x[d+184>>2];db:{if((c|0)<=0){break db}l=x[d+208>>2];t=z[j+484414>>1];if((Gd(t)|0)!=(l|0)){break db}m=D(g,l);q=x[q>>2];if(t&1){l=$f(d+168|0,q+(m<<1)|0,l,c);m=$f(d+152|0,x[d+288>>2],x[d+208>>2],c);x[23604]=0;x[d- -64>>2]=x[l+8>>2];q=x[l+4>>2];x[d+56>>2]=x[l>>2];x[d+60>>2]=q;x[d+48>>2]=x[m+8>>2];l=x[m+4>>2];x[d+40>>2]=x[m>>2];x[d+44>>2]=l;R(511,d+56|0,d+40|0);l=x[23604];x[23604]=0;if((l|0)!=1){break db}break za}l=$f(d+136|0,m+q|0,l,c);m=$f(d+120|0,x[d+288>>2],x[d+208>>2],c);x[23604]=0;x[d+32>>2]=x[l+8>>2];q=x[l+4>>2];x[d+24>>2]=x[l>>2];x[d+28>>2]=q;x[d+16>>2]=x[m+8>>2];l=x[m+4>>2];x[d+8>>2]=x[m>>2];x[d+12>>2]=l;R(512,d+24|0,d+8|0);l=x[23604];x[23604]=0;if((l|0)==1){break za}}i=i-f|0;e=e+f|0;f=SR(k);x[d+264>>2]=f;g=c+g|0;continue}break}RR(k)}Lc(d+320|0)}r=r+1|0;continue}break}break za}eb:{if(x[a+480180>>2]!=4){break eb}f=0;c=a+480192|0;while(1){if(z[c>>1]<=f>>>0){break eb}b=zb(x[B>>2],f);e=y[b+3|0];g=y[b+2|0];i=y[b+1|0];b=y[b|0];x[23604]=0;f=f+1|0;ma(513,a|0,f&65535,b|0,i|0,g|0,e|0);b=x[23604];x[23604]=0;if((b|0)!=1){continue}break}a=P()|0;break va}fb:{gb:{hb:{if(!(y[d+1281|0]&16)){break hb}b=x[n+8>>2];c=x[n>>2];x[23604]=0;b=W(142,c|0,b|0,1)|0;c=x[23604];x[23604]=0;ib:{jb:{kb:{if((c|0)!=1){if(!b){break hb}f=0;x[23604]=0;b=S(192,n|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break kb}if(!(b&1)){break ib}while(1){if(z[E>>1]<=f>>>0){break ib}x[23604]=0;b=S(143,n|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break jb}v[((f<<5)+a|0)+480288|0]=b;f=f+1|0;continue}}a=P()|0;break va}a=P()|0;break va}a=P()|0;break va}while(1){b=x[n+8>>2];c=x[n>>2];x[23604]=0;b=W(142,c|0,b|0,1)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Aa}if(!b){break hb}x[23604]=0;b=S(192,n|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break fb}if(!b){break hb}x[23604]=0;c=S(143,n|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break gb}x[23604]=0;U(176,d+240|0,n|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break gb}e=d+240|0;c=kc(d+320|0,e);yb(e);lb:{if(b>>>0<=250){x[23604]=0;R(384,c|0,(D(b,160)+a|0)+906140|0);b=x[23604];x[23604]=0;if((b|0)==1){break lb}}yb(c);continue}break}a=P()|0;yb(c);break va}g=a+901404|0;c=Kb(d+208|0);i=a+480180|0;l=a+484348|0;k=0;r=0;while(1){b=x[n+8>>2];e=x[n>>2];x[23604]=0;b=W(142,e|0,b|0,8)|0;e=x[23604];x[23604]=0;mb:{nb:{ob:{pb:{qb:{if((e|0)!=1){if(b){x[23604]=0;e=S(143,n|0)|0;b=x[23604];x[23604]=0;rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{if((b|0)!=1){x[23604]=0;b=S(143,n|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break yb}x[23604]=0;U(176,d+320|0,n|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break xb}f=d+320|0;b=kc(d+240|0,f);yb(f);if((e|0)==1229211981){break ub}if((e|0)==1229476432){break vb}if((e|0)==1397900630){break wb}if((e|0)!=1414548815){break mb}x[23604]=0;e=Q(346,b|0,13715)|0;f=x[23604];x[23604]=0;if((f|0)==1){break Ea}if(!e){break nb}x[23604]=0;e=S(143,b|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){x[23604]=0;U(176,d+320|0,b|0,e|0);e=x[23604];x[23604]=0;if((e|0)!=1){break tb}}a=P()|0;break Da}a=P()|0;break Ba}a=P()|0;break Ba}a=P()|0;break Ba}zb:{Ab:{Bb:{e=x[i>>2];switch(e-2|0){case 1:break mb;case 0:break sb;case 2:break Ab;default:break Bb}}if((e|0)==16){break zb}if((e|0)!=32){break mb}x[23604]=0;k=S(180,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ea}x[23604]=0;r=S(180,b|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break mb}break Ea}x[d+320>>2]=32;e=x[b>>2];x[23604]=0;e=S(146,e|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){x[d+264>>2]=e;e=x[Fb(d+320|0,d+264|0)>>2];x[23604]=0;U(514,b|0,c|0,e|0);e=x[23604];x[23604]=0;if((e|0)!=1){break mb}}a=P()|0;break Da}x[23604]=0;e=S(192,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break rb}x[23604]=0;R(515,d+264|0,4172);f=x[23604];x[23604]=0;Cb:{if((f|0)!=1){x[d+288>>2]=e>>>4;x[23604]=0;x[d+104>>2]=e&15;X(286,d+320|0,d+264|0,d+288|0,d+104|0);e=x[23604];x[23604]=0;if((e|0)==1){break Cb}e=d+320|0;Ab(c,e);xb(e);Db(d+264|0);break mb}a=P()|0;break Da}a=P()|0;Db(d+264|0);break Da}x[23604]=0;e=S(192,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break Ea}x[a+480216>>2]=e;x[23604]=0;e=S(192,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break Ea}x[a+480220>>2]=e;break mb}x[23604]=0;Q(356,b|0,g|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ea}HA(g);break mb}f=d+320|0;e=kc(d+264|0,f);yb(f);f=x[e>>2];x[23604]=0;f=S(146,f|0)|0;m=x[23604];x[23604]=0;if((m|0)==1){break ob}w[d+320>>1]=f>>>5;N=d,O=nf(x[a+484344>>2],x[l>>2]),w[N+288>>1]=O;m=z[Wc(d+320|0,d+288|0)>>1];f=0;while(1){if((f|0)==(m|0)){yb(e);break nb}x[23604]=0;R(516,e|0,d+320|0);j=x[23604];x[23604]=0;Db:{if((j|0)==1){break Db}j=x[K>>2];x[23604]=0;R(517,ac(j,f)|0,d+320|0);j=x[23604];x[23604]=0;if((j|0)==1){break Db}f=f+1|0;continue}break}break ob}x[23604]=0;k=S(180,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ea}break mb}a=P()|0;break Da}b=x[a+480180>>2];Eb:{Fb:{Gb:{if((b|0)!=32){break Gb}e=k&65535;if(e>>>0<256){break Gb}if(e>>>0<532){break Fb}}b=(b|0)!=2;Hb:{if(b){break Hb}e=k&65535;if(e>>>0<12544){break Hb}if(e>>>0<12820){break Fb}}if(b){break Eb}b=k&65535;if(b>>>0<4864|b>>>0>4895){break Eb}}Zp(g)}f=1;Ib:{if(!(v[d+1281|0]&1)){break Ib}g=x[a+1074308>>2];if(!g){e=a+480192|0;g=a+480180|0;while(1){b=f&65535;if(b>>>0<=z[e>>1]){b=x[((b<<2)+a|0)+900380>>2];if(b){i=x[g>>2];x[23604]=0;R(518,xi(b,2)|0,i|0);i=x[23604];x[23604]=0;if((i|0)==1){break qb}v[b+19|0]=y[b+19|0]+3>>>2}f=f+1|0;continue}break}g=x[a+1074308>>2]}if(g>>>0<=18350079){x[23604]=0;b=Q(250,a+1074312|0,27)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ca}x[23604]=0;Q(250,b|0,57)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Ca}g=x[a+1074308>>2]}if(g>>>0<=19070975){x[23604]=0;Q(250,a+1074312|0,73)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Ca}g=x[a+1074308>>2]}if(g>>>0>19267583){break Ib}x[23604]=0;Q(250,a+1074312|0,50)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Ca}}Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{if(wd(x[c+4>>2],y[c+11|0])){x[23604]=0;Y(519,d+240|0);b=x[23604];x[23604]=0;Xb:{if((b|0)!=1){x[23604]=0;U(484,d+320|0,d+240|0,d+1751|0);b=x[23604];x[23604]=0;if((b|0)==1){break Xb}break Wb}a=P()|0;break Ba}a=P()|0;Db(d+240|0);break Ba}x[23604]=0;Y(520,d+240|0);b=x[23604];x[23604]=0;if((b|0)==1){break Vb}x[23604]=0;X(521,d+320|0,d+240|0,d+1751|0,c|0);b=x[23604];x[23604]=0;if((b|0)==1){break Ub}}b=d+320|0;Ab(c,b);xb(b);b=d+240|0;Db(b);x[23604]=0;R(483,b|0,3960);b=x[23604];x[23604]=0;if((b|0)==1){break Sb}x[23604]=0;U(484,d+320|0,d+240|0,d+1751|0);b=x[23604];x[23604]=0;if((b|0)==1){break Rb}b=d+320|0;Ab(a+1298344|0,b);xb(b);Db(d+240|0);x[23604]=0;b=Q(1,b|0,14856)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Qb}Ab(a+1298356|0,b);xb(b);b=x[a+480180>>2];switch(b-1|0){case 2:break pb;case 1:break Mb;case 3:break Nb;case 0:break Ob;default:break Tb}}a=P()|0;break Ba}a=P()|0;Db(d+240|0);break Ba}if((b|0)==16){break Pb}if((b|0)==32){break Lb}if((b|0)!=16777216){break pb}x[23604]=0;b=Q(1,d+240|0,10016)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Kb}Ab(a+1298392|0,b);xb(b);x[23604]=0;b=Q(1,d+264|0,13662)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Jb}Ab(a+1298380|0,b);xb(b);break pb}a=P()|0;break Ba}a=P()|0;Db(d+240|0);break Ba}a=P()|0;break Ba}x[23604]=0;b=Q(1,d+240|0,10021)|0;e=x[23604];x[23604]=0;Yb:{if((e|0)!=1){Ab(a+1298392|0,b);xb(b);x[23604]=0;b=Q(1,d+264|0,8283)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Yb}Ab(a+1298380|0,b);xb(b);break pb}a=P()|0;break Ba}a=P()|0;break Ba}x[23604]=0;b=Q(1,d+240|0,12193)|0;e=x[23604];x[23604]=0;Zb:{if((e|0)!=1){Ab(a+1298392|0,b);xb(b);x[23604]=0;b=Q(1,d+264|0,14125)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Zb}Ab(a+1298380|0,b);xb(b);break pb}a=P()|0;break Ba}a=P()|0;break Ba}x[23604]=0;b=Q(1,d+240|0,9994)|0;e=x[23604];x[23604]=0;_b:{if((e|0)!=1){Ab(a+1298392|0,b);xb(b);x[23604]=0;b=Q(1,d+264|0,15091)|0;e=x[23604];x[23604]=0;if((e|0)==1){break _b}Ab(a+1298380|0,b);xb(b);break pb}a=P()|0;break Ba}a=P()|0;break Ba}x[23604]=0;b=Q(1,d+240|0,10366)|0;e=x[23604];x[23604]=0;$b:{if((e|0)!=1){Ab(a+1298392|0,b);xb(b);x[23604]=0;b=Q(1,d+264|0,14902)|0;e=x[23604];x[23604]=0;if((e|0)==1){break $b}Ab(a+1298380|0,b);xb(b);break pb}a=P()|0;break Ba}a=P()|0;break Ba}x[23604]=0;b=Q(1,d+240|0,6088)|0;e=x[23604];x[23604]=0;ac:{bc:{cc:{dc:{ec:{if((e|0)!=1){Ab(a+1298392|0,b);xb(b);if(!(r&65535)){break ac}x[23604]=0;R(251,d+288|0,4275);b=x[23604];x[23604]=0;if((b|0)==1){break ec}x[d+116>>2]=(r&65280)>>>8;x[23604]=0;x[d+100>>2]=r&255;R(378,d+104|0,d+100|0);b=x[23604];x[23604]=0;if((b|0)==1){break dc}x[23604]=0;X(364,d+264|0,d+288|0,d+116|0,d+104|0);b=x[23604];x[23604]=0;if((b|0)==1){break cc}b=d+264|0;Ab(a+1298380|0,b);xb(b);xb(d+104|0);Db(d+288|0);break pb}a=P()|0;break Ba}a=P()|0;break Ba}a=P()|0;break bc}a=P()|0;xb(d+104|0)}Db(d+288|0);break Ba}x[23604]=0;b=Q(1,d+264|0,8459)|0;e=x[23604];x[23604]=0;if((e|0)!=1){Ab(a+1298380|0,b);xb(b);break pb}a=P()|0;break Ba}a=P()|0;break Ba}a=P()|0;break Ba}a=P()|0;break Ba}a=P()|0;break Ba}Ab(a+1298368|0,c);fc:{if(x[a+1074308>>2]){x[a+1298404>>2]=8;break fc}if(x[a+480180>>2]==1){x[a+1298404>>2]=13;break fc}x[a+1298404>>2]=5}f=1;gc:{hc:{if(h&1){x[23604]=0;b=Q(1,d+288|0,16477)|0;e=x[23604];x[23604]=0;if((e|0)==1){break hc}a=x[a+1298464>>2];x[23604]=0;U(351,a|0,2,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break gc}xb(b)}xb(c);QR(o);sc(B);jd(s);yb(J);yb(I);break c}a=P()|0;break Ba}a=P()|0;xb(b);break Ba}a=P()|0;yb(e);break Da}x[23604]=0;e=Q(346,b|0,13720)|0;f=x[23604];x[23604]=0;if((f|0)==1){break Ea}ic:{if(!e){break ic}x[23604]=0;e=S(143,b|0)|0;f=x[23604];x[23604]=0;jc:{if((f|0)!=1){x[23604]=0;U(176,d+264|0,b|0,e|0);e=x[23604];x[23604]=0;if((e|0)!=1){break jc}}a=P()|0;break Da}f=d+264|0;e=kc(d+320|0,f);yb(f);f=x[e>>2];x[23604]=0;f=S(146,f|0)|0;m=x[23604];x[23604]=0;if((m|0)!=1){w[d+264>>1]=(f>>>0)/20;w[d+288>>1]=z[E>>1];m=z[Wc(d+264|0,d+288|0)>>1];f=0;while(1){if((f|0)==(m|0)){yb(e);break ic}x[23604]=0;U(357,e|0,((f<<5)+a|0)+480289|0,20);j=x[23604];x[23604]=0;if((j|0)!=1){f=f+1|0;continue}break}}a=P()|0;yb(e);break Da}x[23604]=0;Q(367,a|0,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ea}x[23604]=0;X(368,a|0,b|0,1,0);e=x[23604];x[23604]=0;if((e|0)==1){break Ea}if((k-2186&65535)>>>0<=117){x[i>>2]=16777216;x[23604]=0;U(382,a|0,b|0,k&65535);e=x[23604];x[23604]=0;if((e|0)==1){break Ea}}if(!x[a+1074308>>2]){break mb}x[23604]=0;e=Q(1,d+184|0,17462)|0;f=x[23604];x[23604]=0;kc:{lc:{mc:{if((f|0)!=1){f=x[a+1074308>>2];x[23604]=0;R(126,d+264|0,f|0);f=x[23604];x[23604]=0;if((f|0)==1){break mc}x[23604]=0;U(2,d+320|0,e|0,d+264|0);f=x[23604];x[23604]=0;if((f|0)==1){break lc}f=d+320|0;Ab(c,f);xb(f);xb(d+264|0);xb(e);break mb}a=P()|0;break Da}a=P()|0;break kc}a=P()|0;xb(d+264|0)}xb(e);break Da}yb(b);continue}}a=P()|0;break va}a=P()|0;break va}a=P()|0;break va}a=P()|0;break va}a=P()|0;break xa}a=P()|0}yb(b);break Ba}a=P()|0}xb(c);break va}a=P()|0;break va}a=P()|0;Lc(d+320|0);break va}a=P()|0}yb(g)}xb(f)}QR(o);break ja}e=h}xb(f);i=i+1|0;continue}}a=P()|0;break ja}a=P()|0;xb(e);break ja}a=P()|0}sc(B);break A}o=o+1|0;continue}}jd(s);break z}a=P()|0}yb(J);break y}a=P()|0}yb(I);break e}a=P()|0;break e}a=P()|0;break e}else{nc:{oc:{if(!k){v[d+320|0]=y[(d+f|0)+1286|0];v[d+240|0]=64;N=((f<<5)+a|0)+480286|0,O=y[Wb(d+320|0,d+240|0)|0],w[N>>1]=O;break oc}if(s){break nc}}pc:{h=y[(d+f|0)+1350|0];if((h|0)!=255){if((h|0)!=127){break pc}x[((f<<5)+a|0)+480280>>2]=256;break nc}w[((f<<5)+a|0)+480284>>1]=256;break nc}w[((f<<5)+a|0)+480284>>1]=h}f=f+1|0;continue}}a=P()|0;break d}a=P()|0;break d}a=P()|0}yb(n)}fc(C);T(a|0);p()}yb(n)}fc(C)}hb=d+1760|0;return f|0}function hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,V=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;e=hb-976|0;hb=e;xc(b);a:{if(!fS(b,e+920|0)){break a}if(!jS(e+920|0)){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(iS(e+920|0),lb))){break a}if(!c){d=1;break a}Cd(a,8);Ag(a);aa=y[e+923|0];L=aa-48|0;v[e+919|0]=L;Yc(b,dc(x[e+928>>2]));f=e+608|0;Ud(f,b,504);_=kc(e+896|0,f);yb(f);x[23604]=0;R(456,b|0,f|0);f=x[23604];x[23604]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(y[e+891|0]>63){break b}if(Lb(z[e+608>>1])<<16>>16<0){break b}Zb(e+528|0,0,80);h:{d=dc(x[e+952>>2]);if(!d){break h}x[23604]=0;f=Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){if(!f){break h}x[23604]=0;R(457,b|0,e+528|0);d=x[23604];x[23604]=0;if((d|0)!=1){break h}}i=P()|0;break e}x[23604]=0;U(458,e+520|0,b|0,L&255);d=x[23604];x[23604]=0;if((d|0)!=1){ba=Re(e+520|0);d=0;f=z[e+520>>1];if((f-128&65535)>>>0<65409){break b}w[a+480188>>1]=f;M=Sb(e+504|0);f=dc(x[e+944>>2]);i:{if(f){x[23604]=0;Q(141,b|0,f|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break g}x[23604]=0;U(459,b|0,M|0,y[e+891|0]);d=x[23604];x[23604]=0;if((d|0)==1){break g}d=y[e+891|0];break i}f=0;if(y[e+891|0]){break c}}j=d&255;w[a+480192>>1]=j;w[a+480190>>1]=j;ca=(L&255)>>>0<2|v[e+872|0]>=0;r=!ca;o=c&2;A=1;s=1;while(1){j:{k:{l:{m:{n:{o:{g=s&65535;if(g>>>0<=(j&65535)>>>0){x[23604]=0;t=A&65535;f=W(237,a|0,g|0,t|0)|0;d=x[23604];x[23604]=0;p:{if((d|0)!=1){if(f){break p}break d}i=P()|0;break f}C=x[((g<<2)+a|0)+900380>>2];w[e+84>>1]=0;x[e+80>>2]=0;x[23604]=0;E=S(160,e+480|0)|0;d=x[23604];x[23604]=0;q:{if((d|0)!=1){d=zb(x[M>>2],g-1|0);d=dc(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r:{if(!d){break r}x[23604]=0;f=Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break k}if(!f){break r}x[23604]=0;R(460,b|0,e+80|0);d=x[23604];x[23604]=0;if((d|0)==1){break k}f=x[e+80>>2];d=z[e+84>>1];x[23604]=0;f=dc(f);d=Lb(d);U(176,e+120|0,b|0,f<<(d>>>5&1&d<<16>>16>0));d=x[23604];x[23604]=0;if((d|0)==1){break k}f=e+120|0;d=kc(e+192|0,f);$c(E,d);yb(d);yb(f)}d=Lb(z[e+84>>1]);f=d&15;q=d<<16>>16;if((q|0)>=0){break q}Jt(C,0);da=1;break o}i=P()|0;break f}if(f>>>0>6){break o}B=y[f+27062|0];if(!f){break m}w[a+480190>>1]=(z[a+480190>>1]+B|0)-1;l=C+108|0;u=C+236|0;m=B-2|0;j=4;s:while(1){g=1;if((j|0)==10){break n}k=D(j,12);d=(m<<3)+j|0;h=y[d+27068|0]+A|0;g=y[d+27116|0];d=0;while(1)if((d|0)==12){j=j+1|0;continue s}else{f=d+k|0;ea=cc(u,f),fa=h,w[ea>>1]=fa;f=Gb(l,f);v[f|0]=g+y[f|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=dc(x[e+532>>2]);if(!d){break D}if(!Lb(z[e+536>>1])){break D}x[23604]=0;f=Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break C}if(!f){break D}ea=e,fa=Lb(z[e+536>>1]),w[ea+192>>1]=fa;w[e+120>>1]=y[e+891|0];f=e+120|0;o=z[Wc(e+192|0,f)>>1];d=e+128|0;l=f|4;q=Lb(z[e+538>>1]);u=q>>>0<19;m=q>>>0<21;k=q>>>0<15;h=q>>>0<6;j=0;while(1){if((j|0)==(o|0)){break D}x[23604]=0;U(461,b|0,e+192|0,q|0);f=x[23604];x[23604]=0;E:{F:{G:{if((f|0)!=1){j=j+1|0;s=x[((j<<2)+a|0)+900380>>2];r=y[e+192|0];if(r){g=bo(e+120|0,0,64);bo(l,r-1&65535,64);f=y[e+193|0];if(f){f=64/(f>>>0)|0}else{f=0}bo(d,f+r|0,0);x[23604]=0;t=s+48|0;U(462,t|0,g|0,3);f=x[23604];x[23604]=0;if((f|0)==1){break G}if(y[e+192|0]==1){g=x[Ib(e+472|0,Bb(x[t>>2]))>>2];r=hb-16|0;hb=r;f=Bb(x[t>>2]);f=x[t>>2]+(Ht(g,f)<<2)|0;Id(t,Vt(f+4|0,x[t+4>>2],f));Ib(r+8|0,f);hb=r+16|0}f=y[e+193|0];x[s>>2]=f?f<<9:32767;v[s+60|0]=y[s+60|0]|1;H=1}H:{if(u){break H}x[s+4>>2]=y[e+210|0]+1>>>1;if(m){break H}w[s+28>>1]=z[e+212>>1]}g=D(z[cc(s+236|0,61)>>1],104)+a|0;v[g+484417|0]=y[e+195|0]<<4;if(k){break F}f=dc(z[e+202>>1]|z[e+204>>1]<<16);x[g+484384>>2]=f;ea=g+484388|0,fa=dc(z[e+206>>1]|z[e+208>>1]<<16)+f|0,x[ea>>2]=fa;break E}i=P()|0;break f}i=P()|0;break f}if(h){continue}}f=g+484414|0;i=f;n=z[f>>1]&65529;f=y[e+197|0];w[i>>1]=n|f<<1&2|f>>>1&4;if(!(f&4)){continue}w[g+484412>>1]=0;continue}}I:{d=dc(x[e+548>>2]);if(!d){break I}if(!Lb(z[e+552>>1])){break I}x[23604]=0;f=Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break C}if(!f){break I}ea=e,fa=Lb(z[e+552>>1]),w[ea+192>>1]=fa;w[e+120>>1]=y[e+891|0];m=z[Wc(e+192|0,e+120|0)>>1];k=Lb(z[e+554>>1]);d=0;J:while(1){if((d|0)==(m|0)){break I}x[23604]=0;U(463,b|0,e+192|0,k|0);f=x[23604];x[23604]=0;if((f|0)==1){break t}f=e+80|0;wT(f,e+192|0);x[23604]=0;R(208,e+120|0,f|0);f=x[23604];x[23604]=0;if((f|0)==1){break u}d=d+1|0;u=((d<<2)+a|0)+900380|0;g=e+120|0;Bc(x[u>>2]+492|0,g);xb(g);f=x[u>>2];x[23604]=0;R(464,g|0,f|0);f=x[23604];x[23604]=0;if((f|0)==1){break v}ea=e,fa=gj(x[e+120>>2]),x[ea+80>>2]=fa;h=xf(e+120|0);while(1){f=x[e+80>>2];if(Ob(f,h)){l=(z[Op(f)>>1]<<5)+a|0;g=l+946328|0;o=x[u>>2];f=x[o+520>>2];x[g>>2]=x[o+516>>2];x[g+4>>2]=f;f=x[o+512>>2];g=l+946320|0;x[g>>2]=x[o+508>>2];x[g+4>>2]=f;f=x[o+504>>2];g=l+946312|0;x[g>>2]=x[o+500>>2];x[g+4>>2]=f;f=x[o+496>>2];g=l+946304|0;x[g>>2]=x[o+492>>2];x[g+4>>2]=f;Tg(e+80|0);continue}else{jA(e+120|0);continue J}}}}Zp(a+901404|0);d=oc(e+464|0,4901);Oe(qe(a+901692|0,0),x[d>>2],x[d+4>>2]);xc(b);s=c&1;I=a+484344|0;J=a+1298332|0;C=a+1298308|0;$=a+484360|0;c=0;A=0;while(1){K:{f=c&255;if(f>>>0<y[ba|0]){x[23604]=0;X(465,b|0,e+920|0,e+528|0,e+608|0);d=x[23604];x[23604]=0;L:{M:{N:{O:{P:{if((d|0)==1){break P}Q:{if(!f){d=0;break Q}x[23604]=0;f=S(257,$|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break P}d=c;if((f|0)==255){break d}}n=fj(x[$>>2],d&255);F=ag(e+448|0);Fc(n);K=L&255;if(K>>>0>1){break N}i=0;f=Lb(z[e+610>>1]);if(f>>>0>256|z[a+480188>>1]>16){break L}d=e+192|0;cS(d,e+608|0);x[23604]=0;U(466,n|0,d|0,f|0);d=x[23604];x[23604]=0;if((d|0)==1){break O}ea=e,fa=Bb(x[n>>2]),x[ea+192>>2]=fa;d=Bb(x[n+4>>2]);while(1){f=x[e+192>>2];if(Ob(f,d)){w[f>>1]=z[f>>1]+A;Pe(e+192|0);continue}else{uh(a,1);f=z[a+480188>>1];d=0;while(1)if((d|0)==(f|0)){d=32;break M}else{v[e+192|0]=y[(d+e|0)+874|0];v[e+120|0]=64;ea=((d<<5)+a|0)+480286|0,fa=y[Wb(e+192|0,e+120|0)|0],w[ea>>1]=fa;d=d+1|0;continue}}}}i=P()|0;break f}i=P()|0;break w}cS(e+192|0,e+608|0);R:{S:{T:{U:{d=Lb(z[e+204>>1]);if(!(!d|d>>>0>64|z[a+480188>>1]>64)){r=dc(x[e+212>>2]);d=Lb(z[e+216>>1]);if(d){w[e+120>>1]=d;w[e+80>>1]=800;f=Uc(((z[Wc(e+120|0,e+80|0)>>1]<<5)+50>>>0)/100|0,0)}else{f=32}d=x[e+200>>2];x[23604]=0;g=Q(141,b|0,dc(d)|0)|0;d=x[23604];x[23604]=0;V:{if((d|0)==1){break V}d=0;W:{if(!g){break W}while(1){if(z[a+480188>>1]<=d>>>0){break W}x[23604]=0;h=S(192,b|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){v[e+120|0]=h;v[e+80|0]=64;ea=((d<<5)+a|0)+480286|0,fa=y[Wb(e+120|0,e+80|0)|0],w[ea>>1]=fa;d=d+1|0;continue}break}i=P()|0;break w}X:{Y:{d=dc(x[e+208>>2]);if(!d){break Y}x[23604]=0;g=Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break V}d=0;if(!g){break Y}while(1){if(z[a+480188>>1]<=d>>>0){break X}x[23604]=0;h=S(467,b|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){ea=((d<<5)+a|0)+480284|0,fa=(Yb(h,-16,16)<<3)+128|0,w[ea>>1]=fa;d=d+1|0;continue}break}i=P()|0;break w}uh(a,1)}q=Sb(e+176|0);d=x[e+196>>2];x[23604]=0;g=Q(141,b|0,dc(d)|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break U}i=1;d=0;if(!g){break R}k=z[e+610>>1];h=x[b+8>>2];g=x[b>>2];x[23604]=0;h=W(142,g|0,h|0,Lb(k)<<1)|0;g=x[23604];x[23604]=0;if((g|0)==1){break U}if(!h){break R}g=z[e+610>>1];x[23604]=0;h=W(468,b|0,q|0,Lb(g)|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break U}if(!h){break R}ea=e,fa=Bb(x[q>>2]),x[ea+168>>2]=fa;o=Bb(x[e+180>>2]);l=x[e+192>>2];u=z[e+206>>1];while(1){d=x[e+168>>2];if(!Ob(d,o)){i=0;d=1;break R}d=Lb(y[d|0]|y[d+1|0]<<8);Z:{if(Lb(u)>>>0<d>>>0){break Z}x[23604]=0;Q(141,b|0,dc(l)+(d<<2)|0)|0;d=x[23604];x[23604]=0;_:{$:{aa:{ba:{ca:{if((d|0)==1){break ca}x[23604]=0;g=S(264,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break ca}x[23604]=0;g=Q(141,b|0,g|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break ca}if(!g){break Z}g=x[b+8>>2];d=x[b>>2];x[23604]=0;g=W(142,d|0,g|0,42)|0;d=x[23604];x[23604]=0;if((d|0)==1){break ca}if(!g){break Z}x[23604]=0;R(469,b|0,e+120|0);d=x[23604];x[23604]=0;da:{if((d|0)!=1){if(tc(x[n>>2],x[n+4>>2])){break da}x[23604]=0;R(470,n|0,65534);d=x[23604];x[23604]=0;if((d|0)!=1){break da}}i=P()|0;break S}h=Lb(z[e+160>>1]);x[e+116>>2]=h;g=x[b+8>>2];d=x[b>>2];x[23604]=0;g=W(142,d|0,g|0,h|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break ba}if(!g){x[23604]=0;g=S(188,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break ba}wc(e+116|0,g)}wc(e+116|0,65534);h=x[n+4>>2];g=x[n>>2];d=0;x[23604]=0;m=x[e+116>>2];k=Kc(g,h);R(471,n|0,m+k|0);g=x[23604];x[23604]=0;if((g|0)==1){break $}while(1){ea:{if((d|0)==(m|0)){if(y[e+120|0]){break ea}break aa}x[23604]=0;h=S(256,b|0)|0;g=x[23604];x[23604]=0;fa:{if((g|0)!=1){g=h<<16>>16;if((g|0)<0){break fa}x[23604]=0;R(470,n|0,g+A&65535);g=x[23604];x[23604]=0;if((g|0)!=1){break fa}}i=P()|0;break S}d=d+1|0;continue}break}Cm(e+104|0,e+120|0);x[23604]=0;U(472,e+56|0,x[e+104>>2],x[e+108>>2]);d=x[23604];x[23604]=0;ga:{ha:{ia:{if((d|0)!=1){x[23604]=0;U(11,e+80|0,13,e+56|0);d=x[23604];x[23604]=0;if((d|0)==1){break ia}x[23604]=0;R(258,n|0,e+80|0);d=x[23604];x[23604]=0;if((d|0)==1){break ha}xb(e+80|0);xb(e+56|0);break aa}i=P()|0;break S}i=P()|0;break ga}i=P()|0;xb(e+80|0)}xb(e+56|0);break S}i=P()|0;break S}i=P()|0;break S}d=dc(x[e+152>>2]);if(!d){break Z}x[23604]=0;g=Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break _}}i=P()|0;break S}if(!g){break Z}while(1){ja:{x[23604]=0;g=Q(473,b|0,e+104|0)|0;d=x[23604];x[23604]=0;ka:{la:{ma:{na:{if((d|0)!=1){if(!g){break Z}x[23604]=0;U(176,e+56|0,b|0,y[e+107|0]);d=x[23604];x[23604]=0;if((d|0)==1){break na}d=e+56|0;m=kc(e+80|0,d);yb(d);g=Lb(z[e+104>>1]);d=bu(g+k|0);w[e+56>>1]=d;if((g|0)==65535){break ja}i=x[n>>2];if(Kc(i,x[n+4>>2])>>>0<=d>>>0){break ja}g=65535;switch(y[e+106|0]-1|0){case 0:break la;case 1:break ma;default:break ka}}i=P()|0;break S}i=P()|0;break S}x[23604]=0;h=S(256,m|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break T}x[23604]=0;g=Q(474,F|0,e+56|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break T}w[g>>1]=h;i=x[n>>2];g=65534;d=z[e+56>>1]}ea=cc(i,d),fa=g,w[ea>>1]=fa}yb(m);continue}break}yb(m)}Pe(e+168|0);continue}}i=P()|0;break w}i=0;break L}i=P()|0;break S}i=P()|0;yb(m)}nd(q);break w}nd(q);if(d){d=f>>>(r>>>1&1)|0;break M}Gt(F);if(!i){break d}break K}g=Lb(z[e+868>>1]);k=y[e+871|0];t=k&64;f=y[e+872|0];B=f&32;N=(f&31)+1|0;ea=a,fa=$R(g,t>>>6|0,B>>>5|0,N),x[ea+480204>>2]=fa;ea=a,fa=Td(y[e+873|0],1,32),x[ea+480196>>2]=fa;if(B){x[a+480216>>2]=N;x[a+480220>>2]=N<<2}f=y[e+890|0];if(f){v[e+192|0]=f;v[e+120|0]=64;ea=a,fa=y[Wb(e+192|0,e+120|0)|0]<<2,x[ea+480200>>2]=fa}x[a+480228>>2]=d;x[a+480232>>2]=d;x[a+480208>>2]=x[a+480208>>2]&-3|(k^-1)>>>4&2;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{d=dc(x[e+572>>2]);if(!d){break ya}x[23604]=0;f=Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break xa}if(!f){break ya}d=x[e+576>>2];x[23604]=0;U(253,b|0,C|0,dc(d)|0);d=x[23604];x[23604]=0;if((d|0)==1){break xa}if(y[ba|0]<2){break ya}x[23604]=0;U(11,e+192|0,13,C|0);d=x[23604];x[23604]=0;za:{if((d|0)!=1){x[23604]=0;R(258,n|0,e+192|0);d=x[23604];x[23604]=0;if((d|0)==1){break za}xb(e+192|0);break ya}i=P()|0;break w}i=P()|0;xb(e+192|0);break w}Aa:{if(dc(x[e+544>>2])>>>0<2){break Aa}d=x[e+540>>2];x[23604]=0;f=Q(141,b|0,dc(d)|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break xa}if(!f){break Aa}d=x[e+544>>2];x[23604]=0;X(315,J|0,b|0,dc(d)-1|0,4);d=x[23604];x[23604]=0;if((d|0)==1){break xa}}d=dc(x[e+584>>2]);if(!d){break oa}x[23604]=0;f=Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break xa}if(!f){break oa}f=x[b+8>>2];d=x[b>>2];x[23604]=0;f=W(142,d|0,f|0,12)|0;d=x[23604];x[23604]=0;if((d|0)==1){break xa}if(!f){break oa}x[23604]=0;Q(174,b|0,6)|0;d=x[23604];x[23604]=0;if((d|0)==1){break xa}x[23604]=0;f=S(256,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break xa}if((f|0)!=1){break oa}x[23604]=0;h=S(264,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break va}if(!h){break oa}f=x[b+8>>2];d=x[b>>2];x[23604]=0;f=W(142,d|0,f|0,h|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break va}if(f){break wa}break oa}i=P()|0;break w}g=dd(e+192|0,J);x[23604]=0;X(315,J|0,b|0,h|0,4);d=x[23604];x[23604]=0;if((d|0)==1){break qa}if(!wd(x[e+196>>2],y[e+203|0])){x[23604]=0;f=W(475,e+24|0,2,13)|0;d=x[23604];x[23604]=0;if((d|0)==1){break ua}x[23604]=0;U(476,e+120|0,g|0,f|0);d=x[23604];x[23604]=0;if((d|0)==1){break ta}x[23604]=0;U(477,e+40|0,e+120|0,J|0);d=x[23604];x[23604]=0;if((d|0)==1){break sa}d=e+40|0;Ab(J,d);xb(d);xb(e+120|0);xb(f)}xb(g);break oa}i=P()|0;break w}i=P()|0;break pa}i=P()|0;break ra}i=P()|0;xb(e+120|0)}xb(f);break pa}i=P()|0}xb(g);break w}Ba:{if(K>>>0<2){break Ba}i=0;if(!dc(x[e+596>>2])){break Ba}while(1){if(z[a+480188>>1]<=i>>>0){break Ba}d=x[e+596>>2];x[23604]=0;f=Q(141,b|0,dc(d)+(i<<2)|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break x}Ca:{if(!f){break Ca}x[23604]=0;f=S(264,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break x}x[23604]=0;f=Q(141,b|0,f|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break x}g=0;d=0;if(!f){break Ca}while(1){Da:{h=x[b+8>>2];f=x[b>>2];x[23604]=0;h=W(142,f|0,h|0,8)|0;f=x[23604];x[23604]=0;Ea:{Fa:{Ga:{if((f|0)!=1){if(!h){break Da}x[23604]=0;R(478,b|0,e+192|0);f=x[23604];x[23604]=0;if((f|0)==1){break Ga}f=dc(x[e+192>>2]);if(!f){break Da}switch((f&536870911)-1|0){case 1:break Ea;case 0:break Fa;default:continue}}i=P()|0;break w}i=P()|0;break w}g=dc(x[e+196>>2]);continue}d=dc(x[e+196>>2]);continue}break}if(!g|!d){break Ca}x[23604]=0;g=Q(141,b|0,g|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break y}if(!g){break Ca}x[23604]=0;U(357,b|0,((i<<5)+a|0)+480289|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break y}}i=i+1|0;continue}}d=z[e+608>>1];x[23604]=0;G=Lb(d);R(211,I|0,A+G&65535);d=x[23604];x[23604]=0;if((d|0)==1){break z}q=k&16;r=A&65535;g=0;Ha:{Ia:{while(1){if((g|0)==(G|0)){ea=e,fa=gj(x[F>>2]),x[ea+120>>2]=fa;g=xf(F);while(1){d=x[e+120>>2];if(!xg(d,g)){i=1;d=dc(x[e+528>>2]);if(!d){break L}x[23604]=0;f=Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break z}if(!f){break L}A=A+G|0;Gt(F);break K}k=Op(d);h=Re(k);Ja:{Ka:{La:{Ma:{d=z[k>>1];if(!d){j=0;break Ma}x[23604]=0;f=Q(295,n|0,d-1&65535)|0;d=x[23604];x[23604]=0;if((d|0)==1){break Ja}j=z[k>>1];if(!f){break Ma}x[23604]=0;j=Q(344,n|0,j-1&65535)|0;d=x[23604];x[23604]=0;if((d|0)==1){break Ja}break La}if(z[h>>1]==((j&65535)+1|0)){break Ka}x[23604]=0;j=Q(343,I|0,1)|0;d=x[23604];x[23604]=0;if((d|0)==1){break Ja}if((j|0)==65535){break Ka}ea=cc(x[n>>2],z[k>>1]),fa=j,w[ea>>1]=fa}d=ac(x[I>>2],j);he(d,om(Ce(ye(e+192|0,12,Yt(z[h>>1])),x[d+12>>2]-1|0)));G=(G&65535)>>>0>j>>>0?G:j+1|0}Tg(e+120|0);continue}break}i=P()|0;break w}Na:{Oa:{if(!s){break Oa}d=x[e+936>>2];x[23604]=0;f=Q(141,b|0,dc(d)+(g<<2)|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break Ia}if(!f){break Oa}x[23604]=0;f=S(264,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break Ia}x[23604]=0;f=Q(141,b|0,f|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break Ia}if(!f){break Oa}O=Kb(e+56|0);x[23604]=0;V=S(160,e|0)|0;d=x[23604];x[23604]=0;Pa:{Qa:{if((d|0)!=1){if(K){break Qa}x[23604]=0;R(479,b|0,e+192|0);d=x[23604];x[23604]=0;if((d|0)==1){break Na}w[e+104>>1]=y[e+192|0];Y=y[e+193|0]+1|0;f=48;break Pa}i=P()|0;break A}x[23604]=0;m=v[e+870|0];R(480,b|0,e+176|0);d=x[23604];x[23604]=0;Ra:{Sa:{if((d|0)!=1){k=Lb(z[e+176>>1]);w[e+104>>1]=k;Y=Lb(z[e+178>>1])+1|0;d=dc(x[e+180>>2]);if(!d){break Ra}h=x[b+8>>2];x[23604]=0;Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}x[23604]=0;R(481,b|0,e+192|0);d=x[23604];x[23604]=0;if((d|0)==1){break B}d=x[e+196>>2];x[23604]=0;f=Q(141,b|0,dc(d)|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}if(!f){break Sa}d=x[e+200>>2];x[23604]=0;U(253,b|0,O|0,dc(d)|0);d=x[23604];x[23604]=0;if((d|0)!=1){break Sa}break B}break B}d=dc(x[e+208>>2]);Ta:{if(!d){break Ta}x[23604]=0;f=Q(141,b|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}if(!f){break Ta}x[23604]=0;f=S(264,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}x[23604]=0;f=Q(141,b|0,f|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}if(!f){break Ta}x[23604]=0;U(176,e+80|0,b|0,D(k,Y)|0);d=x[23604];x[23604]=0;if((d|0)==1){break B}f=e+80|0;d=kc(e+120|0,f);$c(V,d);yb(d);yb(f)}x[23604]=0;Q(141,b|0,h|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}}f=m+(K>>>0<3?48:24)|0}x[23604]=0;k=g+r|0;h=W(212,I|0,k&65535,Y|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}Ua:{if(!h){break Ua}d=x[I>>2];x[23604]=0;E=ac(d,k);R(266,E|0,O|0);d=x[23604];x[23604]=0;if((d|0)==1){break Ha}pg(e+104|0,z[a+480188>>1]);Z=0;o=z[e+104>>1];Va:while(1){if((Y|0)==(Z|0)){break Ua}i=0;d=cd(x[E>>2],x[x[E+48>>2]+12>>2],Z,0);while(1){if((i&65535)>>>0>=o>>>0){Z=Z+1|0;continue Va}Wa:{if(!K){x[23604]=0;R(482,e+192|0,b|0);h=x[23604];x[23604]=0;if((h|0)!=1){m=y[e+192|0];k=e+192|0;h=hd(k);v[d+1|0]=m>>>3&16|y[h|0]>>>4|m>>>1&32;v[d+3|0]=y[h|0]&15;ea=d,fa=y[Re(k)|0],v[ea+5|0]=fa;h=m&63;j=h?h+f|0:0;break Wa}break B}x[23604]=0;R(333,e+192|0,b|0);h=x[23604];x[23604]=0;Xa:{Ya:{if((h|0)!=1){h=e+192|0;l=hd(h);u=Re(h);m=wi(h);x[23604]=0;k=S(192,V|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break B}v[d+4|0]=k;k=y[e+192|0];h=k&127;if(!h){break Ya}j=f+h|0;break Xa}break B}j=0;if((k|0)!=128){break Xa}v[d|0]=254}v[d+1|0]=y[l|0]&63;v[d+3|0]=y[u|0];v[d+5|0]=y[m|0]}if(j-1>>>0<=119){v[d|0]=j}H=(j|0)>84&ca|H;u=(t|0)!=0;m=(B|0)!=0;k=(q|0)!=0;l=hb-16|0;hb=l;Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{h=y[d+3|0];switch(h-4|0){case 42:break $a;case 37:break ab;case 28:break bb;case 27:break cb;case 26:break db;case 25:break eb;case 24:break fb;case 23:break gb;case 22:break hb;case 21:break ib;case 20:break jb;case 18:break kb;case 17:break lb;case 16:break mb;case 14:break nb;case 13:break ob;case 12:break pb;case 11:break qb;case 10:break rb;case 9:break sb;case 8:break tb;case 5:break ub;case 4:break vb;case 0:break wb;default:break _a}}v[d+3|0]=5;k=y[d+5|0];v[l+15|0]=k>>>3;v[l+14|0]=15;h=y[Wb(l+15|0,l+14|0)|0];v[l+13|0]=k<<1&30;v[l+12|0]=15;ea=d,fa=y[Wb(l+13|0,l+12|0)|0]|h<<4,v[ea+5|0]=fa;break Za}v[d+3|0]=0;break Za}if((y[d+5|0]-1&255)>>>0<=19){v[d+3|0]=16;break Za}v[d+3|0]=0;break Za}v[d+3|0]=13;h=y[d+5|0];xb:{if(!k){if(h>>>0>152){break xb}v[d+5|0]=D((h&240)>>>4|0,10)+(h&15);break Za}v[d+5|0]=(h&127)+1>>>1;break Za}v[d+3|0]=0;break Za}v[d+3|0]=11;break Za}v[d+3|0]=0;break Za}h=y[d+5|0];if(!h){v[d+3|0]=14;break Za}if(h>>>0<=240){v[d+3|0]=17;if(h>>>0<=2){v[d+5|0]=112;break Za}ea=d,fa=ao(+($R(h,u,m,N)>>>0)/1e4),v[ea+5|0]=fa;break Za}v[d+3|0]=0;break Za}v[d+3|0]=31;v[d+5|0]=y[d+5|0]|128;break Za}v[d+3|0]=19;v[l+11|0]=15;ea=d,fa=y[Wb(d+5|0,l+11|0)|0]|16,v[ea+5|0]=fa;break Za}v[d+3|0]=19;v[l+10|0]=15;ea=d,fa=y[Wb(d+5|0,l+10|0)|0]|32,v[ea+5|0]=fa;break Za}v[d+3|0]=5;h=y[d+5|0];v[l+9|0]=(h>>>4|0)+1;v[l+8|0]=15;ea=d,fa=h&15|y[Wb(l+9|0,l+8|0)|0]<<4,v[ea+5|0]=fa;break Za}v[d+3|0]=19;v[d+5|0]=y[d+5|0]&15|80;break Za}v[d+3|0]=19;v[l+7|0]=15;ea=d,fa=y[Wb(d+5|0,l+7|0)|0]|96,v[ea+5|0]=fa;break Za}v[d+3|0]=19;v[l+6|0]=15;ea=d,fa=y[Wb(d+5|0,l+6|0)|0]|192,v[ea+5|0]=fa;break Za}v[d+3|0]=10;break Za}v[d+3|0]=19;v[l+5|0]=15;ea=d,fa=y[Wb(d+5|0,l+5|0)|0]|160,v[ea+5|0]=fa;break Za}v[d+3|0]=19;v[l+4|0]=15;ea=d,fa=y[Wb(d+5|0,l+4|0)|0]|176,v[ea+5|0]=fa;break Za}h=y[d+5|0]-1<<24>>24;if((h|0)>=0){v[d+5|0]=h;v[d+3|0]=31;break Za}v[d+3|0]=0;break Za}v[d+3|0]=14;break Za}v[d+3|0]=19;v[l+3|0]=15;ea=d,fa=y[Wb(d+5|0,l+3|0)|0]|224,v[ea+5|0]=fa;break Za}h=y[d+5|0];if(h>>>0>=16){v[d+3|0]=19;v[d+5|0]=h>>>4|208;break Za}if(h){v[d+3|0]=19;v[d+5|0]=h|144;break Za}v[d+3|0]=0;break Za}if(!(y[d+5|0]|y[d+4|0])){if(!Tc(y[d|0])){break Za}v[d+5|0]=159;v[d+3|0]=20;break Za}v[d+3|0]=0;break Za}h=y[d+4|0];if(h){v[d+3|0]=44;ea=d,fa=zm(Uc(((y[d+5|0]<<8&65280)>>>0)/(h>>>0)|0,0)),v[ea+5|0]=fa;break Za}v[d+3|0]=0;break Za}h=y[d+5|0];if((h+16&255)>>>0<=32){v[d+3|0]=9;ea=d,fa=ri(((h^128)<<3)-896|0),v[ea+5|0]=fa;break Za}v[d+3|0]=0;break Za}if(h>>>0<=15){Hf(d);break Za}v[d+3|0]=0}hb=l+16|0;d=d+6|0;i=i+1|0;continue}}}yb(V);xb(O)}g=g+1|0;continue}break}break B}i=P()|0;break w}break B}Gt(F);f=0;if(!i){break c}}ui($,0);d=1;yb:{if(H&1){break yb}while(1){b=d&65535;if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=0;break yb}c=((b<<2)+a|0)+900380|0;b=x[c>>2];if(b){Hb(It(b))}x[c>>2]=0;d=d+1|0;continue}}zb:{if(!da){break zb}x[23604]=0;c=Q(1,e+192|0,16218)|0;b=x[23604];x[23604]=0;Ab:{if((b|0)!=1){b=x[a+1298464>>2];x[23604]=0;U(351,b|0,2,c|0);b=x[23604];x[23604]=0;if((b|0)==1){break Ab}xb(c);break zb}i=P()|0;break f}i=P()|0;xb(c);break f}j=21502;Bb:{Cb:{switch(aa-48|0){case 0:j=z[a+480188>>1]>4?17113:17099;break Bb;case 1:j=17081;break Bb;case 2:j=17063;break Bb;case 3:break Cb;default:break Bb}}j=17036}x[23604]=0;R(483,e+80|0,16651);b=x[23604];x[23604]=0;Db:{Eb:{Fb:{if((b|0)!=1){x[23604]=0;U(484,e+120|0,e+80|0,e+919|0);b=x[23604];x[23604]=0;if((b|0)==1){break Fb}b=e+120|0;Ab(a+1298344|0,b);xb(b);Db(e+80|0);x[23604]=0;c=Q(1,b|0,12513)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Eb}Ab(a+1298356|0,c);xb(c);x[23604]=0;R(122,a+1298368|0,j|0);b=x[23604];x[23604]=0;if((b|0)==1){break Db}x[a+1298404>>2]=13;f=1;break c}i=P()|0;break f}i=P()|0;Db(e+80|0);break f}i=P()|0;break f}i=P()|0;break f}c=c+1|0;continue}}i=P()|0;break f}i=P()|0;yb(V)}xb(O);break w}i=P()|0;break w}i=P()|0;break w}i=P()|0}Gt(F);break f}i=P()|0;break f}i=P()|0;break f}i=P()|0;break f}B=1;if((f|0)!=7){break m}d=C+108|0;f=Vz(d);while(1){if((d|0)!=(f|0)){ea=d,fa=nm(y[d|0]-24|0),v[ea|0]=fa;d=d+1|0;continue}break}g=0}H=1;break l}g=0;Gb:{if(r|(q|0)<0){break Gb}m=C+108|0;j=7;Hb:while(1){if((j|0)==10){break Gb}k=D(j,12);h=D(j,-12)+72|0;d=0;while(1)if((d|0)==12){j=j+1|0;continue Hb}else{f=Gb(m,d+k|0);v[f|0]=h+y[f|0];d=d+1|0;continue}}}}x[23604]=0;R(485,_|0,e+192|0);d=x[23604];x[23604]=0;if((d|0)!=1){Ib:{d=y[e+196|0];if((d-1&255)>>>0<=15){v[C+31|0]=d;H=1}d=y[e+197|0];if(d-1<<24>>24>=0){v[C+30|0]=d}d=0;Jb:{while(1){if((d|0)==(B|0)){if(!o){break j}if((q|0)>=0){break Jb}break j}x[23604]=0;h=D(d+t|0,104)+a|0;R(262,h+484380|0,8);f=x[23604];x[23604]=0;if((f|0)!=1){v[e+120|0]=y[e+198|0];v[e+56|0]=64;ea=h+484410|0,fa=y[Wb(e+120|0,e+56|0)|0]<<2,w[ea>>1]=fa;v[h+484416|0]=y[e+199|0];d=d+1|0;continue}break}break k}m=Xc(e+120|0,8,1,1,0);h=Lb(z[e+194>>1]);i=Lb(z[e+192>>1]);d=x[E>>2];x[23604]=0;j=S(146,d|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){d=Lb(z[e+84>>1]);if(d&16){id(m,16);j=j>>>1|0}if(d&32){to(m,3);j=j>>>1|0}if(d&64){Lf(m,2)}j=g?(j>>>0)/((-1<<B^-1)>>>0)|0:j;g=h+i|0;d=0;while(1){if((d|0)==(B|0)){break j}k=D(d+t|0,104)+a|0;f=k+484380|0;x[f>>2]=j;x[23604]=0;W(205,m|0,f|0,E|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break Ib}i=i<<1;g=g<<1;if(h>>>0>=2){x[k+484388>>2]=g;x[k+484384>>2]=i;f=k+484414|0;w[f>>1]=z[f>>1]|2}d=d+1|0;j=j<<1;continue}}}}}i=P()|0;yb(E);break f}yb(E);s=s+1|0;A=A+B|0;j=z[a+480192>>1];continue}}i=P()|0;break e}i=P()|0;break e}i=P()|0}sc(M)}yb(_);T(i|0);p()}f=0}d=f;sc(M)}yb(_)}hb=e+976|0;return d|0}function Mda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=E(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=E(0),ea=0,ga=0,ha=0,ia=0,ka=0,la=0;e=hb-688|0;hb=e;xc(b);a:{b:{c:{if(!Th(b,e+680|0)){break c}if(!WP(e+680|0)){break c}if((rm(b)|0)>=0){break c}if(!c){d=1;break c}Cd(a,16777216);d=a+480208|0;x[d>>2]=x[d>>2]|1681e4;Bz(e+288|0,32);g=x[e+300>>2];d=a+1074320|0;x[d>>2]=x[e+296>>2];x[d+4>>2]=g;d=x[e+292>>2];x[a+1074312>>2]=x[e+288>>2];x[a+1074316>>2]=d;zf(a+1074312|0,38);q=Sb(e+664|0);r=Sb(e+648|0);u=Sb(e+632|0);l=Sb(e+616|0);hg(b,4);m=a+480190|0;K=c&1;J=a+1298332|0;s=2500;I=!(c&2);G=a+1298464|0;d:{e:{f:{while(1){c=x[b+8>>2];d=x[b>>2];x[23604]=0;c=W(142,d|0,c|0,4)|0;d=x[23604];x[23604]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){x[23604]=0;c=S(633,b|0)|0;d=x[23604];x[23604]=0;o:{if((d|0)==1){break o}n=4;d=0;p:{q:{r:{switch(c+21|0){case 20:x[23604]=0;c=S(264,b|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){d=c&65535;if(z[a+480188>>1]|d-1>>>0>126){continue}w[a+480188>>1]=c;ka=a,la=Yb(512/(d>>>0)|0,16,128),x[ka+480228>>2]=la;continue}c=P()|0;break a;case 19:x[23604]=0;L=S(264,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break o}if(L>>>0<=1024){continue}break m;case 16:x[23604]=0;c=S(264,b|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){if((c&65535)==4){continue}break m}c=P()|0;break a;case 15:x[23604]=0;c=S(264,b|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){x[e+288>>2]=c;x[e+184>>2]=800;ka=a,la=Ge(+A[Fb(e+288|0,e+184|0)>>2]*1.24*1e4),x[ka+480204>>2]=la;continue}c=P()|0;break a;case 31:x[23604]=0;c=S(264,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break o}V=1;s=Td(c,0,1e4);continue;case 32:case 33:x[23604]=0;c=S(264,b|0)|0;d=x[23604];x[23604]=0;s:{t:{if((d|0)!=1){V=1;if(!c){continue}x[23604]=0;d=Q(1,e+600|0,12422)|0;c=x[23604];x[23604]=0;if((c|0)==1){break t}c=x[G>>2];x[23604]=0;U(351,c|0,2,d|0);c=x[23604];x[23604]=0;if((c|0)==1){break s}xb(d);continue}c=P()|0;break a}c=P()|0;break a}c=P()|0;xb(d);break a;case 14:x[23604]=0;Q(174,b|0,4)|0;c=x[23604];x[23604]=0;if((c|0)==1){break o}i=!z[m>>1]|i;continue;case 11:if(!K){break q}if(!tc(x[q>>2],x[q+4>>2])){break q}x[23604]=0;R(634,e+288|0,b|0);c=x[23604];x[23604]=0;if((c|0)!=1){if(x[q>>2]){Fc(q);c=x[q>>2];$n(q);Hb(c);ka=Cb(q),la=0,x[ka>>2]=la;x[q>>2]=0;x[q+4>>2]=0}c=e+288|0;x[q>>2]=x[c>>2];x[q+4>>2]=x[c+4>>2];d=Cb(c);ka=Cb(q),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;ni(c);continue}c=P()|0;break a;case 3:case 4:case 10:g=mh(x[l>>2],x[l+4>>2]);d=z[m>>1];if(g>>>0<=d>>>0){continue}if((i|I)&1){break q}if(!Nh(d)){break q}d=d+1|0;w[m>>1]=d;t=Sb(e+584|0);x[23604]=0;i=S(160,e+560|0)|0;g=x[23604];x[23604]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}x[23604]=0;c=S(264,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break u}x[23604]=0;U(176,e+184|0,b|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break u}c=e+184|0;g=kc(e+288|0,c);$c(i,g);yb(g);break g}c=P()|0;break d}x[23604]=0;R(635,e+288|0,b|0);c=x[23604];x[23604]=0;x:{if((c|0)!=1){c=e+288|0;g=mm(t,c);fc(c);ke(e+528|0,x[g>>2],x[e+588>>2]);c=Yd(e+520|0);x[23604]=0;g=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=g;c=rg(312,e+536|0,x[e+528>>2],x[e+532>>2],e+16|0);g=x[23604];x[23604]=0;if((g|0)==1){break x}$c(i,c);break g}c=P()|0;break e}c=P()|0;break e}x[23604]=0;R(636,e+288|0,b|0);c=x[23604];x[23604]=0;y:{if((c|0)!=1){c=e+288|0;g=mm(t,c);fc(c);ke(e+488|0,x[g>>2],x[e+588>>2]);c=Yd(e+480|0);x[23604]=0;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;c=rg(312,e+496|0,x[e+488>>2],x[e+492>>2],e+8|0);g=x[23604];x[23604]=0;if((g|0)==1){break y}$c(i,c);break g}c=P()|0;break e}c=P()|0;break e}c=P()|0;break e;case 9:c=z[m>>1];if(!Nh(c)){continue}w[m>>1]=c+1;continue;case 8:if(!K){break q}if(!tc(x[u>>2],x[u+4>>2])){break q}x[23604]=0;R(637,e+288|0,b|0);c=x[23604];x[23604]=0;if((c|0)!=1){c=e+288|0;VP(u,c);sc(c);continue}c=P()|0;break a;case 7:if(!tc(x[l>>2],x[l+4>>2])){break q}x[23604]=0;R(638,e+288|0,b|0);c=x[23604];x[23604]=0;if((c|0)!=1){if(x[l>>2]){Fc(l);c=x[l>>2];Az(l);Hb(c);ka=Cb(l),la=0,x[ka>>2]=la;x[l>>2]=0;x[l+4>>2]=0}c=e+288|0;x[l>>2]=x[c>>2];x[l+4>>2]=x[c+4>>2];d=Cb(c);ka=Cb(l),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;nt(c);continue}c=P()|0;break a;case 6:if(!K){break q}if(!tc(x[r>>2],x[r+4>>2])){break q}x[23604]=0;R(639,e+288|0,b|0);c=x[23604];x[23604]=0;if((c|0)!=1){if(x[r>>2]){Fc(r);c=x[r>>2];lr(r);Hb(c);ka=Cb(r),la=0,x[ka>>2]=la;x[r>>2]=0;x[r+4>>2]=0}c=e+288|0;x[r>>2]=x[c>>2];x[r+4>>2]=x[c+4>>2];d=Cb(c);ka=Cb(r),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;fl(c);continue}c=P()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}x[23604]=0;R(640,e+288|0,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break n}z:{c=x[e+288>>2];d=x[e+292>>2];if(tc(c,d)){break z}x[23604]=0;X(321,J|0,c|0,Rc(c,d)|0,1);c=x[23604];x[23604]=0;if((c|0)!=1){break z}c=P()|0;fc(e+288|0);break a}fc(e+288|0);continue}x[23604]=0;n=S(264,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break o}}x[23604]=0;Q(174,b|0,n|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){continue}}c=P()|0;break a}d=0;if(!z[a+480188>>1]|!L){break m}b=x[l>>2];c=x[l+4>>2];if(tc(b,c)){break m}if(K){if(tc(x[q>>2],x[q+4>>2])){break m}if(tc(x[u>>2],x[u+4>>2])){break m}if(tc(x[r>>2],x[r+4>>2])){break m}}b=mh(b,c);if(b>>>0>=256){x[23604]=0;R(641,l|0,255);b=x[23604];x[23604]=0;if((b|0)==1){break b}b=mh(x[l>>2],x[l+4>>2])}w[a+480192>>1]=b;h=a+480190|0;n=a+480192|0;ka=h,la=z[Se(m,n)>>1],w[ka>>1]=la;if(i&1){x[23604]=0;b=Q(1,e+584|0,16307)|0;c=x[23604];x[23604]=0;if((c|0)==1){break h}c=x[a+1298464>>2];x[23604]=0;U(351,c|0,2,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break i}xb(b)}i=0;A:while(1){if((i|0)!=2){d=1;while(1){f=d&65535;if(f>>>0>z[n>>1]){i=i+1|0;continue A}B:{c=em(x[l>>2],f-1|0);if(!y[c|0]|y[c+128|0]<<24>>24<0){break B}if((jt(c)|0)==((i|0)!=1|0)){break B}C:{D:{E:{g=0;F:{if(!jt(c)){break F}if(Lb(y[c+6|0]|y[c+7|0]<<8)){break F}if(Lb(y[c+14|0]|y[c+15|0]<<8)>>>0>20){break F}g=(Lb(y[c+18|0]|y[c+19|0]<<8)|0)==4}G:{H:{if(g){g=y[c+23|0];b=y[c+140|0];x[23604]=0;b=ja(642,c|0,a|0,(b&2)>>>1|0,(D(f,104)+a|0)+484380|0,s&65535)|0;k=x[23604];x[23604]=0;I:{J:{if((k|0)!=1){if(!b){break I}x[23604]=0;b=Q(54,e+416|0,10618)|0;k=x[23604];x[23604]=0;if((k|0)==1){break J}Bc(((f<<5)+a|0)+946304|0,b);xb(b);k=x[l>>2];b=d;if(mh(k,x[l+4>>2])>>>0<=g>>>0){break G}ka=c,la=y[c+143|0]+y[em(k,g)+143|0]|0,v[ka+143|0]=la;break H}c=P()|0;break a}c=P()|0;break a}b=g+1|0;break G}g=0;K:{if(!jt(c)){break K}if((Lb(y[c+6|0]|y[c+7|0]<<8)|0)!=1){break K}if((Lb(y[c+14|0]|y[c+15|0]<<8)|0)!=2){break K}g=(Lb(y[c+18|0]|y[c+19|0]<<8)|0)==10}b=d;if(!g){break G}vc(e+288|0,c,128);b=Lb(z[e+308>>1]);if(b>>>0>=z[m>>1]){break H}x[23604]=0;g=S(632,e+184|0)|0;k=x[23604];x[23604]=0;if((k|0)==1){break E}k=z[e+324>>1];o=z[h>>1];x[23604]=0;t=D(b,104);b=a+484380|0;k=Lb(k);b=fa(643,e+288|0,(t+b|0)+104|0,(k>>>0<o>>>0?(b+D(k,104)|0)+104|0:g)|0,b+D(f,104)|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break D}if(!b){break H}x[23604]=0;b=Q(54,e+168|0,11128)|0;g=x[23604];x[23604]=0;if((g|0)==1){break C}Bc(((f<<5)+a|0)+946304|0,b);xb(b);v[c+139|0]=y[c+139|0]+12}b=d}x[23604]=0;b=b&65535;g=W(237,a|0,f|0,b|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){if(!g|b>>>0>z[m>>1]){break B}x[23604]=0;X(644,c|0,g|0,(D(b,104)+a|0)+484380|0,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){break B}}c=P()|0;break a}c=P()|0;break a}c=P()|0;break a}c=P()|0;break a}d=d+1|0;continue}}break}J=ag(e+152|0);t=ag(e+136|0);b=rc(x[u>>2],x[u+4>>2]);Z=D(z[a+480188>>1],L);_=bu((b>>>0)/(Z>>>0)|0);x[23604]=0;N=a+484344|0;R(211,N|0,_|0);b=x[23604];x[23604]=0;if((b|0)==1){break k}$=a+484376|0;Fc(_b(x[a+484360>>2],y[$|0]));b=z[a+480188>>1];x[23604]=0;G=Q(645,e+120|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break l}ka=e,la=Bb(x[r>>2]),x[ka+64>>2]=la;ea=a+902204|0;ga=Bb(x[r+4>>2]);ha=a+480208|0;while(1){L:{M:{N:{k=x[e+64>>2];if(!Ob(k,ga)){break N}b=Lb(y[k+6|0]|y[k+7|0]<<8);if((b|0)==1){break L}if((b|0)==65535){break N}g=Lb(y[k|0]|y[k+1|0]<<8);b=x[q>>2];f=x[q+4>>2];c=_f(b,f);if(g>>>0>=c>>>0){break L}d=Lb(y[k+2|0]|y[k+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(_f(b,f)<<5)|0;x[e+288>>2]=b;x[e+292>>2]=c-b>>5;b=x[e+288>>2];ec(e+96|0,b+(Lb(y[k|0]|y[k+1|0]<<8)<<5)|0,Lb(y[k+2|0]|y[k+3|0]<<8));O:{I=_b(x[a+484360>>2],y[$|0]);if(tc(x[I>>2],x[I+4>>2])){break O}x[23604]=0;R(470,I|0,65534);b=x[23604];x[23604]=0;if((b|0)!=1){break O}break M}c=x[e+96>>2];ia=qe(c,x[e+100>>2]);while(1){if((c|0)==(ia|0)){break L}b=Lb(Lb(y[k+8|0]|y[k+9|0]<<8)+Lb(y[c+16|0]|y[c+17|0]<<8)&65535);v[c+16|0]=b;v[c+17|0]=b>>>8;g=c;b=Sd(J);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!gt(g,d)){c=1;if(!gt(d,g)){break P}b=b+4|0}b=x[b>>2];continue}break}Q:{R:{S:{if(c){x[23604]=0;b=Q(646,J|0,g|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break M}F=z[b>>1];break S}F=0;if(!K){break S}b=y[g+12|0]|y[g+13|0]<<8;x[23604]=0;F=Q(343,N|0,Lb(b)|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break M}if((F|0)==65535){break L}x[23604]=0;b=Q(646,J|0,g|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break M}w[b>>1]=F;if(Lb(y[g+8|0]|y[g+9|0]<<8)>>>0>=_>>>0){break R}if(Lb(y[g+10|0]|y[g+11|0]<<8)>>>0>=L>>>0){break R}m=Lb(y[g+14|0]|y[g+15|0]<<8);c=Pj(Bb(x[u>>2]),D(Lb(y[g+8|0]|y[g+9|0]<<8),Z));b=z[a+480188>>1];ka=e,la=Pj(c,D(b,Lb(y[g+10|0]|y[g+11|0]<<8))),x[ka+48>>2]=la;M=0;x[e+32>>2]=0;o=Oh(e+80|0);T:while(1){U:{d=Lb(y[g+12|0]|y[g+13|0]<<8);c=ac(x[N>>2],F);if(d>>>0<=M>>>0){break U}n=0;O=cd(x[c>>2],x[x[c+48>>2]+12>>2],M,0);c=0;while(1){if((b&65535)>>>0<=n>>>0){M=M+1|0;continue T}b=Bb(x[u+4>>2]);d=x[e+48>>2];h=Ob(d,b)?d:e+32|0;b=Bb(x[u+4>>2]);if(Ob(x[e+48>>2],b)){TP(e+48|0)}d=D(n,6)+O|0;f=y[h+1|0];b=(f>>>0>=85?-1:f+25|0)<<24>>24;s=0;i=x[l>>2];aa=mh(i,x[l+4>>2]);H=y[h+3|0];V:{if(aa>>>0<=H>>>0){break V}s=H+1|0;if(v[em(i,H)+142|0]&1|(b|0)<0){break V}b=nm(Lb(y[g+16|0]|y[g+17|0]<<8)+b<<24>>24)}W:{if(!y[d|0]|!(H|(y[h|0]|(f|0)!=255)|y[h+2|0])){break W}f=y[d+1|0];if(!f|f>>>0>aa>>>0){break W}if(y[em(i,f-1|0)+132|0]!=2){break W}Zn(d)}f=mt(x[G>>2],n);X:{Y:{if(c&1){c=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;c=y[o+4|0]|y[o+5|0]<<8;v[d+4|0]=c;v[d+5|0]=c>>>8;Z:{if(y[d+3|0]){break Z}i=y[f+21|0];c=y[mt(x[G>>2],n-1|0)+21|0];if((i|0)==(c|0)){break Z}v[d+3|0]=21;v[f+21|0]=c;v[d+5|0]=c}c=0;i=y[h|0];if(i-24>>>0<2|(i|0)==9|!i&(y[h+2|0]+7&255)>>>0<2){break Y}break X}i=y[h|0]}_:{$:{aa:{ba:{ca:{da:{switch(i|0){case 5:c=y[f+17|0];break ca;case 0:ea:{c=y[h+2|0];if(c>>>0>=201){i=0;fa:{switch(c-242|0){case 11:v[d+4|0]=1;v[d+2|0]=14;v[f+16|0]=0;break $;case 9:if(!y[d|0]){v[d|0]=y[f+17|0]}v[d+4|0]=1;v[d+2|0]=15;break $;case 8:if((m&255)>>>0<2){break $}m=m-1|0;break aa;case 7:if((m&255)==255){m=255;break $}m=m+1|0;break aa;case 6:v[f+17|0]=b;if(y[f+18|0]!=(s&255)){break $}v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;w[f+32>>1]=0;x[f+8>>2]=0;break $;case 5:v[d+5|0]=242;v[d+3|0]=2;break $;case 4:v[d+5|0]=242;v[d+3|0]=3;break $;case 3:v[d+5|0]=244;v[d+3|0]=2;break $;case 2:v[d+5|0]=244;v[d+3|0]=3;break $;case 1:v[d+5|0]=248;v[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}v[d+5|0]=248;v[d+3|0]=3;break $}ga:{if(v[h+1|0]<0){i=0;if(c>>>0<100){break ga}break $}v[f+17|0]=b;v[d|0]=b;v[f+18|0]=s;v[d+1|0]=s;w[f+32>>1]=0;x[f+8>>2]=0;c=y[h+2|0]}b=c&255;if(!b){i=0;break $}ka=f,la=ao(+(b>>>0)*.64),v[ka+19|0]=la;j=B[f>>2];x[f>>2]=0;i=j!=E(0);break $}v[d+4|0]=0;v[d+2|0]=14;v[f+16|0]=1;break $;case 1:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(.0333000011742115);break _;case 2:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(-.0333000011742115);break _;case 12:v[e+288|0]=15;v[e+116|0]=y[h+3|0]>>>3;b=y[Wb(e+288|0,e+116|0)|0];v[e+288|0]=15;v[e+116|0]=y[h+2|0]>>>3;ka=f,la=y[Wb(e+288|0,e+116|0)|0]|b<<4,v[ka+24|0]=la;break _;case 3:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(.0333000011742115);break _;case 4:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(-.0333000011742115);break _;case 15:if(!y[h+2|0]|(b|0)<0){break _}i=b-y[f+17|0]<<5;c=i>>31;c=(c^i)-c|0;x[e+288>>2]=c;v[f+17|0]=b;x[f+8>>2]=0;v[d|0]=b;v[d+3|0]=4;b=ri((c>>>0)/(y[h+2|0]<<1>>>0)|0);v[d+5|0]=b;v[f+27|0]=b;x[e+116>>2]=D(b,(m&255)-1|0);ka=f,la=c-x[rd(e+288|0,e+116|0)>>2]|0,w[ka+32>>1]=la;break _;case 10:case 11:v[d+3|0]=0;v[d+5|0]=0;break _;case 13:v[e+288|0]=15;v[e+116|0]=y[h+3|0]>>>3;b=y[Wb(e+288|0,e+116|0)|0];v[e+288|0]=15;v[e+116|0]=y[h+2|0];ka=f,la=y[Wb(e+288|0,e+116|0)|0]|b<<4,v[ka+23|0]=la;break _;case 18:b=y[h+2|0]+y[f+17|0]&255;b=b?b>>>0>=120?120:b:1;v[f+17|0]=b;v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;break ba;case 23:case 24:case 25:b=Sd(t);while(1){ha:{c=0;if(!b){break ha}i=b+13|0;if(!ht(h,i)){c=1;if(!ht(i,h)){break ha}b=b+4|0}b=x[b>>2];continue}break};if(c){v[d+3|0]=31;x[23604]=0;b=Q(647,t|0,h|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break M}v[d+5|0]=y[b|0];break _}b=x[Cb(t)>>2];if(b>>>0>127){break _}x[e+112>>2]=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);c=qe(ea,b&255);i=x[ha>>2];x[23604]=0;x[e+28>>2]=x[e+112>>2];c=W(648,e+28|0,c|0,i|0)|0;i=x[23604];x[23604]=0;ia:{if((i|0)==1){break ia}if(!c){break _}v[d+3|0]=31;x[23604]=0;c=Q(647,t|0,h|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break ia}b=b|-128;v[c|0]=b;v[d+5|0]=b;ba=(y[h|0]&254)==24|ba;break _}break M;case 16:if(!y[h+2|0]){break _}v[d+3|0]=15;x[e+288>>2]=15;x[e+116>>2]=y[h+3|0]+1;ka=d,la=x[rd(e+288|0,e+116|0)>>2],v[ka+5|0]=la;w[f+30>>1]=D(y[h+2|0],y[h+3|0]+1|0);break _;case 9:v[d+3|0]=16;b=y[h+2|0];m=b?b:4;v[d+5|0]=m;break _;case 19:ja:{ka:{switch(y[h+1|0]){case 0:b=128;break ja;case 4:break ka;default:break _}}b=y[h+3|0]}v[e+111|0]=b;v[e+288|0]=y[h+2|0];v[e+116|0]=100;c=e+288|0;s=e+116|0;i=y[Wb(c,s)|0];x[e+288>>2]=128;x[e+116>>2]=256-(b&255);b=x[rd(c,s)>>2];v[e+288|0]=128;c=y[Wb(c,e+111|0)|0];b=(D(b,i)|0)/128|0;s=b&255;if((s|0)!=y[f+20|0]){v[f+20|0]=b;v[d+3|0]=21;b=Uc(((D(s,y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=b;v[d+5|0]=b}if(y[h+1|0]!=4|(z[a+480188>>1]-1|0)<=(n|0)){break _}b=n+1|0;h=mt(x[G>>2],b);c=D(c,i)>>>7|0;if(y[h+20|0]==(c&255)){break _}v[h+20|0]=c;b=D(b,6)+O|0;v[b+3|0]=21;c=Uc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=c;v[b+5|0]=c;break _;case 17:case 20:v[d+3|0]=0;break _;case 7:b=y[h+2|0];v[f+25|0]=0;v[f+26|0]=0;v[f+22|0]=b;break _;case 8:v[f+22|0]=y[f+22|0]+y[h+2|0];break _;case 14:v[f+25|0]=y[h+3|0];v[f+26|0]=y[h+2|0];break _;case 6:break da;default:break _}}v[f+18|0]=s;v[f+17|0]=b;v[d+1|0]=s;c=b}v[d|0]=c;if((b|0)>=0){v[f+18|0]=s;v[d+1|0]=s}if(y[h|0]==5){v[d+4|0]=1;v[d+2|0]=11}b=y[f+26|0];c=y[f+22|0];if(!(b|(c|y[h+2|0]))){break ba}if(b){ca=(mi(+z[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{ca=0}v[d+3|0]=44;ka=d,la=ao(ca+ +(c+y[h+2|0]|0)),v[ka+5|0]=la}w[f+32>>1]=0;break _}v[d+5|0]=m;v[d+3|0]=16}b=Uc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!i&y[f+21|0]==(b&255))){v[f+21|0]=b;v[d+5|0]=b;v[d+3|0]=21}if(n&1|v[h+1|0]<=0|(z[a+480188>>1]-1|0)<=(n|0)){break _}b=x[l>>2];if(mh(b,x[l+4>>2])>>>0<=H>>>0){break _}if(y[em(b,H)+132|0]!=1){break _}h=n+1|0;b=D(h,6)+O|0;c=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[d+4|0]|y[d+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;v[b+1|0]=y[b+1|0]+1;b=mt(x[G>>2],h);v[b+19|0]=y[f+19|0];B[b>>2]=B[f>>2];B[b+4>>2]=B[f+4>>2];B[b+8>>2]=B[f+8>>2];B[b+12>>2]=B[f+12>>2];w[b+30>>1]=z[f+30>>1]}la:{if(y[d|0]){v[f+16|0]=0;break la}c=0;if(y[f+16|0]){break X}}ma:{if(!z[f+30>>1]){break ma}b=m&255;w[e+288>>1]=b;c=f+30|0;ka=c,la=z[Se(c,e+288|0)>>1]-b|0,w[ka>>1]=la;if(y[d+3|0]){break ma}v[d+3|0]=15;v[d+5|0]=0}j=B[f>>2];na:{if(j==E(0)){break na}b=m&255;j=E(E(j*E(b>>>0))+B[f+4>>2]);B[f+4>>2]=j;if(y[d+3|0]){break na}oa:{pa:{qa:{ra:{if(b>>>0>=2){h=b-1|0;C=E(h|0);if(!(C<=j)){break ra}v[e+288|0]=15;ka=e,la=Rg(E(j/C)),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+4>>2]=j-E(D(b,h)|0);v[d+3|0]=22;c=b<<4;break oa}if(!(j>=E(1))){break qa}break pa}if(j>=E(1)){break pa}if(!(j<=E(1-b|0))){break qa}v[e+288|0]=15;ka=e,la=Rg(E(E(-j)/C)),v[ka+116|0]=la;c=y[Wb(e+288|0,e+116|0)|0];B[f+4>>2]=j+E(D(h,c)|0);v[d+3|0]=22;break oa}if(!(j<=E(-1))){break na}v[e+288|0]=14;ka=e,la=Rg(E(-j)),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+4>>2]=j+E(b>>>0);v[d+3|0]=22;c=b|-16;break oa}v[e+288|0]=15;ka=e,la=Rg(j),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+4>>2]=j-E(b>>>0);v[d+3|0]=22;c=b<<4|15}v[d+5|0]=c}j=B[f+8>>2];sa:{if(j==E(0)){break sa}b=m&255;j=E(E(j*E(b>>>0))+B[f+12>>2]);B[f+12>>2]=j;ta:{if(!y[d+3|0]){ua:{va:{if(b>>>0>=2){c=b-1|0;C=E(c|0);if(!(C<=j)){break va}v[e+288|0]=223;ka=e,la=Rg(E(j/C)),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j-E(D(b,c)|0);v[d+3|0]=2;v[d+5|0]=b;break sa}if(!(j>=E(1))){break ua}break ta}if(j>=E(1)){break ta}if(!(j<=E(1-b|0))){break ua}v[e+288|0]=223;ka=e,la=Rg(E(E(-j)/C)),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j+E(D(b,c)|0);v[d+3|0]=3;v[d+5|0]=b;break sa}if(!(j<=E(-1))){break sa}v[e+288|0]=14;ka=e,la=Rg(E(-j)),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j+E(b>>>0);v[d+3|0]=3;v[d+5|0]=b|240;break sa}if(y[d+2|0]|b>>>0<2){break sa}da=E(j*E(.25));c=b-1|0;C=E(c|0);if(da>=C){v[e+288|0]=9;ka=e,la=Rg(E(j/C))>>>2|0,v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j-E(D(b,c)<<2);v[d+2|0]=12;v[d+4|0]=b;break sa}if(!(E(1-b|0)>=da)){break sa}v[e+288|0]=9;ka=e,la=Rg(E(E(-j)/C))>>>2|0,v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j+E(D(b,c)<<2);v[d+2|0]=13;v[d+4|0]=b;break sa}v[e+288|0]=15;ka=e,la=Rg(j),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j-E(b>>>0);v[d+3|0]=2;v[d+5|0]=b|240}wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{b=y[d+3|0];switch(b|0){case 4:break wa;case 0:break Ca;default:break Ba}}Da:{b=y[f+23|0];if(!b){b=y[f+24|0];if(b){break Da}if(!z[f+32>>1]){break wa}c=f+32|0;break Aa}v[d+3|0]=5;v[d+5|0]=b;if(!z[f+32>>1]){break wa}break za}v[d+3|0]=8;v[d+5|0]=b;if(z[f+32>>1]){break za}break wa}if(!z[f+32>>1]){break wa}c=f+32|0;if(b){break ya}}v[d+3|0]=4;break xa}c=f+32|0}v[d+2|0]=11}w[e+288>>1]=D(y[f+27|0],(m&255)-1|0);ka=f,la=z[f+32>>1]-z[Wc(c,e+288|0)>>1]|0,w[ka+32>>1]=la}w[f+28>>1]=z[f+28>>1]+D(y[f+25|0],m&255)&1023;c=0;if(n&1){break X}b=y[f+18|0];if(!b){break X}f=x[l>>2];if(mh(f,x[l+4>>2])>>>0<b>>>0){break X}f=em(f,b-1|0);if(!(y[f+142|0]&4)){break X}b=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[o|0]=b;v[o+1|0]=b>>>8;v[o+2|0]=b>>>16;v[o+3|0]=b>>>24;b=y[d+4|0]|y[d+5|0]<<8;v[o+4|0]=b;v[o+5|0]=b>>>8;c=1;b=y[e+81|0];if(!b|y[f+132|0]!=1){break X}v[e+81|0]=b+1}n=n+1|0;b=z[a+480188>>1];continue}}break}he(c,vh(Ce(ye(e+288|0,16,Lb(y[g+14|0]|y[g+15|0]<<8)&255),0)))}b=il(x[I>>2],x[I+4>>2]);ka=e,la=Lb(y[g+4|0]|y[g+5|0]<<8),w[ka+288>>1]=la;w[e+80>>1]=1;c=z[Se(e+288|0,e+80|0)>>1];x[23604]=0;X(649,I|0,b|0,c|0,F&65535);b=x[23604];x[23604]=0;if((b|0)==1){break Q}b=Lb(y[k+8|0]|y[k+9|0]<<8);b=Lb(Lb(y[g+16|0]|y[g+17|0]<<8)-b&65535);v[g+16|0]=b;v[g+17|0]=b>>>8}c=g+32|0;continue}break}break M}c=ba&1;if(c){x[23604]=0;Y(269,a+906300|0);b=x[23604];x[23604]=0;if((b|0)==1){break M}b=a+906324|0;x[b>>2]=655376;x[b+4>>2]=0;b=a+906316|0;x[b>>2]=1299020115;x[b+4>>2]=1869112133;x[e+288>>2]=0;d=a+906348|0;b=e+288|0;nB(a+906332|0,d,b);x[23604]=0;b=Q(54,b|0,9458)|0;g=x[23604];x[23604]=0;if((g|0)==1){break M}iu(d,b);xb(b);x[23604]=0;b=Q(54,e+96|0,9451)|0;d=x[23604];x[23604]=0;if((d|0)==1){break M}oq(a+906380|0,b);xb(b);x[23604]=0;b=Q(54,e+80|0,9443)|0;d=x[23604];x[23604]=0;if((d|0)==1){break M}iu(a+906508|0,b);xb(b)}b=0;while(1){if(z[a+480188>>1]>b>>>0){WA(a,b&65535);d=(b<<5)+a|0;v[d+480288|0]=c;w[d+480284>>1]=b<<8&256;b=b+1|0;continue}break}x[23604]=0;b=Q(1,e- -64|0,11972)|0;c=x[23604];x[23604]=0;Ea:{Fa:{Ga:{if((c|0)!=1){Ab(a+1298344|0,b);xb(b);x[23604]=0;b=Q(1,e+48|0,12190)|0;c=x[23604];x[23604]=0;if((c|0)==1){break M}Ab(a+1298356|0,b);xb(b);if(V){break Ga}x[23604]=0;b=Q(1,e+32|0,11972)|0;c=x[23604];x[23604]=0;if((c|0)==1){break M}break Fa}break M}if(mh(x[l>>2],x[l+4>>2])>>>0<=128){x[23604]=0;b=Q(1,e+32|0,9200)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break Fa}break M}x[23604]=0;b=Q(1,e+32|0,14666)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Ea}}Ab(a+1298368|0,b);xb(b);x[a+1298404>>2]=13;SP(G);JP(t);IP(J);d=1;break m}}c=P()|0;SP(G);break j}Yn(e- -64|0);continue}}c=P()|0;break a}c=P()|0;break a}nt(l);sc(u);fl(r);ni(q);break c}c=P()|0;break j}c=P()|0}JP(t);IP(J);break a}c=P()|0;xb(b);break a}c=P()|0;break a}yb(c);x[23604]=0;c=d&65535;d=W(650,a|0,c|0,i|0)|0;g=x[23604];x[23604]=0;Ha:{Ia:{Ja:{Ka:{if((g|0)==1){break Ka}if(d){break Ha}x[23604]=0;d=W(651,a|0,c|0,i|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break Ka}if(d){break Ha}x[23604]=0;d=W(652,a|0,c|0,i|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break Ka}if(d){break Ha}x[23604]=0;d=Q(653,(D(c,104)+a|0)+484380|0,i|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break Ka}if(d){break Ha}x[23604]=0;d=Q(1,e+464|0,16013)|0;g=x[23604];x[23604]=0;if((g|0)==1){break Ja}g=x[G>>2];x[23604]=0;U(351,g|0,2,d|0);g=x[23604];x[23604]=0;if((g|0)==1){break Ia}xb(d);break Ha}c=P()|0;break e}c=P()|0;break e}c=P()|0;xb(d);break e}La:{Ma:{Na:{F=D(c,104)+a|0;if(y[F+484414|0]&64){d=z[m>>1];if(Nh(d)){break Na}}d=x[l>>2];if(mh(d,x[l+4>>2])>>>0<=c>>>0){break Ma}if(y[em(d,c)+132|0]!=2){break Ma}c=z[m>>1];if(!Nh(c)){break Ma}w[m>>1]=c+1;break Ma}c=d+1|0;w[m>>1]=c;H=D(c&65535,104)+a|0;o=H+484380|0;h=F+484380|0;g=x[h>>2];c=x[h+20>>2];Oa:{if(!Qd(g,c)){break Oa}f=z[h+34>>1];if((h|0)==(o|0)|(Gd(f)|0)!=2){break Oa}d=(h|0)==(o|0);if(!(Qd(x[o>>2],x[o+20>>2])?d:1)){break Oa}Qd(x[h>>2],x[h+20>>2]);if(!d){c=it(g,Fm(f))}f=x[h+20>>2];if(!(f?c:0)){if(!d){jz(c)}break Oa}Pa:{Qa:{switch(Fm(z[h+34>>1])-1|0){case 1:g=c;d=f;n=x[h+20>>2];k=x[h>>2];while(1){if(k){w[g>>1]=z[n>>1];w[d>>1]=z[n+2>>1];n=n+4|0;d=d+2|0;g=g+2|0;k=k-1|0;continue}break};break Pa;case 0:break Qa;default:break Pa}}g=c;d=f;n=x[h+20>>2];k=x[h>>2];while(1){if(k){v[g|0]=y[n|0];v[d|0]=y[n+1|0];n=n+2|0;d=d+1|0;g=g+1|0;k=k-1|0;continue}break}}d=_n(o,h);w[d+34>>1]=z[d+34>>1]&65471;x[o+20>>2]=c;g=_n(h,h);w[g+34>>1]=z[g+34>>1]&65471;x[h+20>>2]=f;f=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(f|0)){h=x[c+104>>2];if(!((h|0)!=(d|0)&(g|0)!=(h|0))){x[c+88>>2]=x[c+88>>2]&-65}c=c+872|0;continue}break}aj(d,a);aj(g,a)}x[23604]=0;c=Q(54,e+448|0,6281)|0;d=x[23604];x[23604]=0;if((d|0)==1){break La}ze(H+484423|0,c);xb(c);x[23604]=0;c=Q(54,e+432|0,6184)|0;d=x[23604];x[23604]=0;if((d|0)==1){break f}ze(F+484423|0,c);xb(c)}yb(i);fc(t);i=0;continue}break}c=P()|0;break e}c=P()|0}yb(i)}fc(t);break a}hb=e+688|0;return d|0}c=P()|0}nt(l);sc(u);fl(r);ni(q);T(c|0);p()}function yt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,S=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,za=0,Aa=0,Ba=0,Ca=0,Da=E(0),Ea=0,Fa=0,Ga=0,Ha=E(0);i=hb-208|0;hb=i;_=Sb(a);t=i+176|0;v[t+26|0]=0;w[t+24>>1]=0;x[t+16>>2]=0;x[t+20>>2]=-1;x[t+8>>2]=-1;x[t+12>>2]=-1;x[t>>2]=0;x[t+4>>2]=0;L=x[d+16>>2];a=y[d+6|0];ka=b+484360|0;h=x[ka>>2];la=(Ea=a,Fa=y[b+484376|0],Ga=_i(h,x[b+484364>>2])>>>0>a>>>0,Ga?Ea:Fa);a=la&255;H=fj(h,a);x[23604]=0;u=Q(531,i+144|0,b|0)|0;h=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((h|0)!=1){l=x[u+4>>2];x[23604]=0;I=W(532,i+104|0,b|0,a|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break i}ba=c&7;e=x[d>>2];a=z[d+4>>1];while(1){h=a&65535;if(Kc(x[H>>2],x[H+4>>2])>>>0<=h>>>0){break g}x[23604]=0;h=Q(295,H|0,h|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break h}if(h){break g}a=a+1|0;e=0;continue}}a=P()|0;break d}a=P()|0;break e}a=P()|0;break f}x[d>>2]=e;w[d+4>>1]=a;x[l+52>>2]=e;K=l+48|0;x[K>>2]=e;x[t+16>>2]=e;w[l+74>>1]=a;w[l+72>>1]=a;w[t+24>>1]=a;na=Yd(i+96|0);oa=zc(i+88|0);j:{if((ba|0)!=7){break j}Qk(Qk(Qk(Qk(Qk(Qk(Qk(Qk(na,1),2),3),28),38),40),39),41);DN(DN(oa,12),13);if((L|0)!=2){break j}a=x[H>>2];e=Kc(a,x[H+4>>2]);h=z[d+12>>1];if(e>>>0<=h>>>0){break j}e=x[b+484344>>2];f=x[b+484348>>2];a=z[cc(a,h)>>1];if(!pe(e,f,a)){break j}h=ac(e,a);e=x[d+8>>2];if(A[h+12>>2]<=e>>>0){break j}a=0;m=cd(x[h>>2],x[x[h+48>>2]+12>>2],e,0);h=z[b+480188>>1];e=x[u+8>>2];f=z[b+480192>>1];while(1){if((a|0)==(h|0)){break j}k:{l:{m:{n:{k=y[m|0];switch(k-253|0){case 1:case 2:break l;case 0:break n;default:break m}}if(f){break l}}if(!Tc(k)){break k}if(Qs(y[m+2|0],y[m+3|0])){break k}}Ea=Ne(e,a),Fa=-1,x[Ea>>2]=Fa}m=m+6|0;a=a+1|0;continue}}$=c&1;if($){CN(l+223860|0)}N=l+74|0;va=l+223872|0;wa=(L|0)!=3;O=l+80|0;xa=b+901692|0;za=b+902204|0;fa=l+44|0;aa=l+20|0;G=b+1074312|0;pa=l+616|0;ca=32768;qa=C[d+8>>3];o(+qa);a=j(1)|0;Aa=j(0)|0;ga=a;Z=b+480188|0;F=b+480180|0;ha=b+484348|0;ra=(L|0)!=2;Ba=l+223884|0;sa=b+480192|0;Ca=(ba|0)!=7;d=0;o:{p:{q:{r:{s:while(1){h=ga;while(1){BN(i+24|0,x[F>>2],z[Z>>1],l,r&1);t:{u:{v:{w:{if(!(!(C[u+24>>3]>=qa)|wa)){break w}k=y[i+24|0];a=65535;e=x[H>>2];g=Kc(e,x[H+4>>2]);f=z[l+72>>1];if(g>>>0>f>>>0){a=z[cc(e,f)>>1]}w[l+70>>1]=a;g=x[b+484344>>2];e=x[ha>>2];q=a&65535;if(!(pe(g,e,q)|(q|0)==65535|ra)&(f|0)==(h&65535)){break w}x:{y:{while(1){a=a&65535;if(nf(g,e)>>>0>a>>>0){break x}q=z[l+72>>1];z:{A:{if((a|0)!=65535){n=x[H>>2];f=Kc(n,x[H+4>>2]);if(q>>>0<f>>>0){break A}}a=z[H+28>>1];if((q|0)==(a|0)){break x}n=x[H>>2];f=Kc(n,x[H+4>>2]);break z}a=q+1|0}w[l+72>>1]=a;m=65535;q=f;f=a&65535;if(q>>>0>f>>>0){m=z[cc(n,f)>>1]}w[l+74>>1]=a;w[l+70>>1]=m;B:{if(!pe(g,e,m&65535)){e=tp(i+24|0,pa);x[23604]=0;a=ja(533,I|0,a&65535,0,e|0,(k|0)!=0|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break B}if(a){break y}g=x[b+484344>>2];e=x[ha>>2]}a=z[l+70>>1];continue}break}a=P()|0;break f}if(L>>>0<=1){a=z[l+72>>1];x[t+8>>2]=0;w[t+20>>1]=a;if(!L){break x}}x[23604]=0;a=W(534,I|0,N|0,K|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break p}if(!a){break x}C[t>>3]=C[u+24>>3];x[23604]=0;R(535,_|0,t|0);a=x[23604];x[23604]=0;if((a|0)==1){break p}x[t+16>>2]=x[K>>2];w[t+24>>1]=z[N>>1];x[23604]=0;Y(536,u|0);a=x[23604];x[23604]=0;if((a|0)==1){break p}a=z[l+74>>1];w[l+72>>1]=a;Ea=l,Fa=z[cc(x[H>>2],a)>>1],w[Ea+70>>1]=Fa;x[l+52>>2]=x[l+48>>2]}if(z[N>>1]==65535){break o}a=x[b+484344>>2];e=z[l+70>>1];if(!pe(a,x[ha>>2],e)){a=z[l+72>>1];if((a|0)==z[H+28>>1]){if(!L){break o}x[23604]=0;a=W(534,I|0,N|0,K|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break p}if(!a){break o}C[t>>3]=C[u+24>>3];x[23604]=0;R(535,_|0,t|0);a=x[23604];x[23604]=0;if((a|0)==1){break p}x[t+16>>2]=x[K>>2];w[t+24>>1]=z[N>>1];x[23604]=0;Y(536,u|0);a=x[23604];x[23604]=0;if((a|0)==1){break p}x[l+52>>2]=x[l+48>>2];continue}w[N>>1]=a+1;continue}g=x[K>>2];if(g>>>0>=A[ac(a,e)+12>>2]){x[K>>2]=0;g=0}if(ra){break v}if(z[l+72>>1]!=(h&65535)|(g|0)!=(Aa|0)){break u}}v[t+26|0]=1;break o}a=0;if((L|0)==3){break t}}a=0;if(A[I+28>>2]<ca>>>0){break t}x[u+24>>2]=0;x[u+28>>2]=2146435072;x[I+28>>2]=0;ca=ca>>>(ca>>>0>256)|0;g=x[K>>2];a=1}e=z[l+72>>1];f=tp(i+24|0,pa);x[23604]=0;e=ja(533,I|0,e|0,g|0,f|0,(k|0)!=0|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break r}if((a|e)==1){if(L>>>0<=1){w[t+20>>1]=z[l+72>>1];x[t+8>>2]=x[l+48>>2];if(!L){break o}}x[23604]=0;a=W(534,I|0,N|0,K|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break q}if(!a){break o}C[t>>3]=C[u+24>>3];x[23604]=0;R(535,_|0,t|0);a=x[23604];x[23604]=0;if((a|0)==1){break q}x[t+16>>2]=x[K>>2];w[t+24>>1]=z[N>>1];x[23604]=0;Y(536,u|0);a=x[23604];x[23604]=0;if((a|0)==1){break q}x[l+52>>2]=x[l+48>>2];continue}w[t+22>>1]=z[l+72>>1];x[t+12>>2]=x[l+48>>2];AN(b,l,0);m=x[l+48>>2];e=ac(x[b+484344>>2],z[l+70>>1]);if(m>>>0>=A[e+12>>2]){x[K>>2]=0;m=0}if(k){continue}break}a=0;m=cd(x[e>>2],x[x[e+48>>2]+12>>2],m,0);Jb(i+24|0,G,77);k=Mb(x[x[i+24>>2]>>2],x[i+28>>2]);C:{while(1){if(z[Z>>1]>a>>>0){D:{if(!(!Gy(m)&(!k|!(y[((a<<5)+b|0)+480281|0]&4)))){Zn((l+D(a,872)|0)+1404|0);break D}if(Pg(y[m|0])){E:{if(!ud(y[Ba|0])){break E}h=y[m+1|0];if(h-251>>>0<5|!h){break E}f=y[m+5|0];r=y[m+3|0];q=Jj(y[m+2|0],y[m+4|0]);e=i+24|0;v[e|0]=h-1;x[e+4>>2]=q&65535;x[23604]=0;h=Q(537,va|0,e|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break C}Ea=h,Ha=E(E(Jj(r,f)>>>0)/E(999)),B[Ea>>2]=Ha}Zn((l+D(a,872)|0)+1404|0);break D}h=l+D(a,872)|0;e=h+1408|0;f=y[m+4|0]|y[m+5|0]<<8;v[e|0]=f;v[e+1|0]=f>>>8;e=h+1404|0;f=y[m|0]|y[m+1|0]<<8|(y[m+2|0]<<16|y[m+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;F:{G:{H:{I:{switch(y[m+3|0]-16|0){case 0:e=y[m+5|0];break H;case 3:break F;case 4:break G;case 1:break I;default:break D}}Jb(i+24|0,G,5);if(!Mb(x[x[i+24>>2]>>2],x[i+28>>2])){break D}e=y[m+5|0];if(!e){break D}}xN(b,l,e&255);break D}e=h+1409|0;f=y[e|0];J:{if(!(f|!(x[F>>2]&16777250))){v[e|0]=y[h+1449|0];break J}v[h+1449|0]=f}h=y[m+5|0];e=h&240;if((e|0)!=224){if((e|0)!=96){break D}x[l+24>>2]=x[l+24>>2]+(h&15);break D}if(x[aa>>2]){break D}h=h&15;if(h?0:y[F|0]&2){break D}x[aa>>2]=h+1;break D}h=y[m+5|0];if((h&240)!=224){break D}x[aa>>2]=(h&15)+1}m=m+6|0;a=a+1|0;continue}break}h=Pk(l);x[i+24>>2]=1;a=x[_c(aa,i+24|0)>>2];w[l+68>>1]=65535;x[l+60>>2]=-1;x[l+64>>2]=-1;S=h-1|0;a=h-a|0;M=D(a,1e4);m=0;while(1){if(z[Z>>1]<=m>>>0){if(x[F>>2]==4&x[l+40>>2]==65535){break o}x[l+32>>2]=x[b+480216>>2];a=ac(x[b+484344>>2],z[l+70>>1]);e=x[a+16>>2];if(wN(e,x[a+20>>2])){x[l+32>>2]=e}e=vN(b,l);a=D(e,h);C[u+24>>3]=C[u+24>>3]+ +(a>>>0)/+A[b+24620>>2];x[l>>2]=a+x[l>>2];K:{L:{if(Ca){break L}m=0;da=(d|0)!=0&(d|0)!=(e|0);while(1){if(z[Z>>1]<=m>>>0){break L}s=Ne(x[u+8>>2],m);M:{if(x[s>>2]==-1){break M}n=l+D(m,872)|0;S=n+1404|0;J=x[n+1316>>2];if(!J){if(Gy(S)){break M}}q=n+1409|0;f=1;N:{O:{M=n+1407|0;switch(y[M|0]-4|0){case 0:case 2:break N;default:break O}}f=y[n+1406|0]==11}a=y[q|0];if(y[n+1405|0]){x[n+1276>>2]=0}k=n+616|0;g=a&15;r=0;P:{Q:{R:{if(!Tc(y[S|0])){break R}if(!(!f|!y[s+4|0])){Fy(i+24|0,b,k,J,0);r=x[i+28>>2];x[n+624>>2]=x[i+24>>2];x[n+628>>2]=r}v[n+1418|0]=y[n+1415|0];J=n+1308|0;V=x[J>>2];r=y[n+1419|0];if(r){sp(b,k,r,f,1,1)}r=y[S|0];x[23604]=0;ia(538,b|0,k|0,r|0,f|0,1,0,65535);r=x[23604];x[23604]=0;if((r|0)==1){break Q}a=a>>>4|0;tN(x[F>>2],z[Z>>1],l,m&65535);ta=Ne(x[u+8>>2],m);v[ta+4|0]=1;s=y[M|0];S:{if(!((y[q|0]&240)!=208|(s-19&255)>>>0>1)){r=g;if(g>>>0<h>>>0){break S}}r=(s|0)==33?a>>>0<h>>>0?a:0:0}ua=x[aa>>2];if(!(!(x[F>>2]&16777250)|(!r|ua>>>0<2))){r=D(ua-1|0,x[l+24>>2]+x[l+40>>2]|0)+r|0}if(!f){x[ta>>2]=0}T:{if((s|0)==9){break T}U:{if((s|0)!=19){if((s|0)!=20|(a|0)!=8){break U}break T}if((a|0)==8){break T}}if(y[n+1406|0]!=2){break R}}x[J>>2]=V}V:{if(!Tc(y[S|0])){Jb(i+24|0,G,114);if(!Mb(x[x[i+24>>2]>>2],x[i+28>>2])){break V}}W:{X:{Y:{Z:{a=y[M|0];switch(a-42|0){case 1:break W;case 0:break X;case 2:break Y;default:break Z}}if((a|0)!=10){break W}a=z[l+70>>1];s=x[l+48>>2];x[23604]=0;ea(539,b|0,k|0,m&65535,s|0,a|0);a=x[23604];x[23604]=0;if((a|0)!=1){break V}break K}J=Jia(y[q|0],0,x[n+692>>2],0);s=lb;a=s>>>8|0;Pn(b,k,Uc((s&255)<<24|J>>>8,a));break V}if(!x[n+720>>2]){break W}x[23604]=0;X(540,u|0,m&65535,d|0,-1);a=x[23604];x[23604]=0;if((a|0)==1){break K}rN(k,y[q|0]);r=x[l+40>>2]-1|0;break V}if(y[n+1406|0]!=15){break V}s=x[n+720>>2];if(!s){break V}a=y[n+1408|0];if(a>>>0>9){break V}_:{if(!a){s=x[n+1280>>2];break _}s=x[zb(s+68|0,a-1|0)>>2];x[n+1280>>2]=s}Pn(b,k,s)}$:{aa:{ba:{switch(y[S|0]-253|0){case 0:if(z[sa>>1]){break aa}break;case 1:case 2:break aa;default:break ba}}a=y[M|0];if(!((y[q|0]&240)!=192|(a-19&255)>>>0>1)&g>>>0<h>>>0){break aa}s=0;if((a|0)==33&(g|0)!=0&h>>>0>g+r>>>0){break aa}if((a|0)!=25){break $}}a=y[M|0];s=1}J=n+1304|0;ca:{if((a|0)!=13){if(y[n+1406|0]!=1){break ca}g=n+1408|0}else{g=q}x[J>>2]=y[g|0]<<2}da:{if(!(!x[n+720>>2]|s)){s=0;ea:{fa:{ga:{if(a>>>0>45){break ga}Jb(i+24|0,na,a);if(Mb(x[x[i+24>>2]>>2],x[i+28>>2])){break fa}if(y[M|0]!=19){break ga}s=(y[q|0]-16&255)>>>0<32}a=y[n+1406|0];if(a>>>0<16){break ea}if(s){break da}break P}s=1;a=y[n+1406|0];if(a>>>0>=16){break da}}zl(i+24|0,oa,a);a=Mb(x[x[i+24>>2]>>2],x[i+28>>2]);if(s){break da}if(!a){break P}break da}if(!s){break P}}hP(k);Ea=Ne(x[u+8>>2],m),Fa=0,x[Ea>>2]=Fa;break M}a=P()|0;break f}if(da){x[23604]=0;X(540,u|0,m&65535,d|0,-1);a=x[23604];x[23604]=0;if((a|0)==1){break K}}ha:{ia:{ja:{ka:{la:{a=y[M|0];if(a-6>>>0>=2){ma:{switch(a-19|0){case 1:break ka;case 0:break la;default:break ma}}if(a-35>>>0<2){break ia}if((a|0)==45){break ja}if((a|0)!=11){break ha}}if(!y[q|0]&x[F>>2]==1){break ha}a=n+1467|0;g=0;while(1){if((g|0)==(h|0)){break ha}v[a|0]=!g|y[a|0]&254;On(b,k,y[q|0]);g=g+1|0;continue}}q=y[q|0];a=q&15;if(!(a|x[F>>2]&1048580)){break ha}g=n+1467|0;v[g|0]=y[g|0]|1;q=q&240;if((q|0)!=176){if((q|0)!=160){break ha}Nn(b,k,a,0);break ha}Mn(b,k,a,0);break ha}na:{oa:{pa:{a=y[q|0];switch(a-158|0){case 1:break oa;case 0:break pa;default:break na}}x[23604]=0;X(540,u|0,m&65535,d|0,-1);a=x[23604];x[23604]=0;if((a|0)==1){break K}x[n+704>>2]=x[n+704>>2]&-129;break ha}x[23604]=0;X(540,u|0,m&65535,d|0,-1);a=x[23604];x[23604]=0;if((a|0)==1){break K}a=x[n+704>>2];x[n+704>>2]=a|128;if(x[k+4>>2]){break ha}q=x[n+692>>2];if(!q){break ha}if(!(Ea=Tc(y[S|0]),Fa=1,Ga=a&2,Ga?Ea:Fa)){break ha}x[k>>2]=-1;x[k+4>>2]=q-1;break ha}if((a&240)!=112|a>>>0<115){break ha}cP(k,a,x[F>>2]);break ha}qN(k,y[q|0]);break ha}x[23604]=0;a=m&65535;X(540,u|0,a|0,d|0,-1);q=x[23604];x[23604]=0;if((q|0)==1){break K}pN(b,a,l,0)}q=n+1467|0;a=y[q|0]|1;v[q|0]=a;qa:{ra:{sa:{ta:{ua:{g=n+1406|0;switch(y[g|0]-3|0){case 11:break ra;case 0:case 1:break sa;case 3:break ta;case 2:break ua;default:break qa}}a=y[n+1408|0];Jb(i+24|0,G,41);Nn(b,k,a,Mb(x[x[i+24>>2]>>2],x[i+28>>2]));break qa}a=y[n+1408|0];Jb(i+24|0,G,41);Mn(b,k,a,Mb(x[x[i+24>>2]>>2],x[i+28>>2]));break qa}a=y[n+1408|0];va:{if(a){break va}Jb(i+24|0,G,41);a=0;if(!Mb(x[x[i+24>>2]>>2],x[i+28>>2])){break va}a=y[n+1450|0];if(!a){break qa}}g=y[g|0]==3?a<<4:a;a=0;while(1){if((a|0)==(h|0)){break qa}v[q|0]=!a|y[q|0]&254;On(b,k,g&255);a=a+1|0;continue}}k=y[n+1408|0];if(k>>>0>1){break qa}v[q|0]=a&247|!k<<3}if(y[q|0]&8){break M}if(f){f=Ne(x[u+8>>2],m);a=x[f>>2];x[f>>2]=a+h;x[23604]=0;X(540,u|0,m&65535,e|0,(a+r|0)+1|0);a=x[23604];x[23604]=0;if((a|0)!=1){break M}a=P()|0;break f}a=Ne(x[u+8>>2],m);x[a>>2]=x[a>>2]+(h-r|0)}m=m+1|0;continue}}r=oN(b,l,H,0);d=e;continue s}a=P()|0;break f}k=l+D(m,872)|0;e=k+1404|0;wa:{if(Gy(e)){break wa}r=k+616|0;da=k+1409|0;g=y[da|0];J=k+1407|0;q=y[J|0];xa:{ya:{if(!$){break ya}n=y[e|0];f=n;s=k+1405|0;V=y[s|0];if(V){v[k+1415|0]=0;v[k+1419|0]=V;Ea=Ne(x[u+8>>2],m),Fa=255,v[Ea+5|0]=Fa;f=y[e|0]}if(Tc(f)){v[k+1415|0]=n;fP(r);f=y[e|0]}za:{if(!(Tc(f)|y[s|0])){break za}V=k+1419|0;f=y[V|0];Aa:{if(!f){f=0;break Aa}if(z[sa>>1]<f>>>0){break Aa}s=x[((f<<2)+b|0)+900380>>2];if(!s|!(v[s+15|0]&1)){break Aa}Bp(r,x[s+8>>2],b);f=y[V|0]}f=Ey(b,n,f);if(!f){break za}f=D(f,104)+b|0;if(!(y[f+484414|0]&32)){break za}Bp(r,z[f+484408>>1],b)}Ba:{Ca:{Da:{f=y[k+1406|0];switch(f-1|0){case 1:break ya;case 2:case 3:break Ca;case 0:break Da;default:break Ba}}Ea=Ne(x[u+8>>2],m),Fa=y[k+1408|0],v[Ea+5|0]=Fa;break ya}e=y[k+1408|0];if(!e){break ya}v[k+1450|0]=e;break ya}if((f|0)!=11){break ya}f=y[k+1408|0];if(!f){break ya}n=i+24|0;Dy(n,b,y[e+3|0],f,0);w[k+1384>>1]=z[i+24>>1];if(y[Re(n)|0]){break xa}}Ea:{Fa:{Ga:{Ha:{Ia:{switch(q-12|0){case 0:nN(b,l,m&65535);break Ea;case 2:e=mN(b,l,m&65535,g);if((e|0)==-1){break Ea}x[l+60>>2]=e;break Ea;case 5:Jb(i+24|0,G,5);if(Mb(x[x[i+24>>2]>>2],x[i+28>>2])){break Ea}e=D(Ln(b,z[l+70>>1],x[l+48>>2],m&65535,0),1e4);Ja:{if(!$|!(x[F>>2]&16777250)){break Ja}if(e>>>0>=1e4){v[k+1451|0]=(e>>>0)/1e4;break Ja}e=D(y[k+1451|0],1e4)}Ka:{if(e>>>0>319999){break Ka}n=(e>>>0)/1e4|0;f=D(M,n&15);e=x[fa>>2];if((n&240)==16){e=e+f|0;break Ka}f=e-f|0;e=e>>>0>=f>>>0?f:0}x[fa>>2]=e;e=x[b+8>>2];f=x[e+20>>2];e=x[e+24>>2];Jb(i+24|0,G,8);yo(fa,D(f,1e4),Mb(x[x[i+24>>2]>>2],x[i+28>>2])?255e4:D(e,1e4));break Ea;case 8:La:{switch((g&240)-144>>>4|0){case 0:if(g>>>0>145){break Ea}x[k+704>>2]=x[k+704>>2]&-257|((g|0)==145)<<8;break Ea;case 1:v[k+1452|0]=g&15;break Ea;case 2:break Ha;case 6:break La;default:break Ea}}v[k+1460|0]=g&15;break Ea;case 1:case 3:case 4:case 6:break Ea;case 7:break Ia;default:break Fa}}e=g&240;if((e|0)==240){break Ga}if((e|0)!=96){break Ea}}Cy(b,l,m&65535,g&15);break Ea}v[k+1460|0]=g&15;break Ea}if((q|0)!=28|(g&240)!=160){break Ea}Jb(i+24|0,G,58);if(Mb(x[x[i+24>>2]>>2],x[i+28>>2])){break Ea}v[k+1452|0]=g&15}if(!$){break wa}Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{switch(q-2|0){case 0:if(!g){break Ma}Jb(i+24|0,G,90);if(!Mb(x[x[i+24>>2]>>2],x[i+28>>2])){v[k+1428|0]=g}v[k+1427|0]=g;break xa;case 1:if(!g){break Ma}Jb(i+24|0,G,90);if(!Mb(x[x[i+24>>2]>>2],x[i+28>>2])){v[k+1427|0]=g}v[k+1428|0]=g;break xa;case 2:if(!g){break Ma}w[k+1384>>1]=g;break xa;case 8:if(!g){break Ma}x[k+1280>>2]=g<<8;break xa;case 4:case 9:if(!g){break Ma}v[k+1425|0]=g;break xa;case 11:Ea=Ne(x[u+8>>2],m),Fa=g,v[Ea+5|0]=Fa;break xa;case 21:e=x[F>>2];g=g<<(!(e&59593760)&g<<24>>24>=0);f=g&255;if(f>>>0<=128){x[O>>2]=f<<1;break xa}if(e&16777250){break xa}x[O>>2]=256;break xa;case 22:Jb(i+24|0,G,9);Va:{if(Mb(x[x[i+24>>2]>>2],x[i+28>>2])){e=k+1433|0;if(g){v[e|0]=g;break Va}g=y[e|0];break Va}if(g){v[l+1433|0]=g;break Va}g=y[l+1433|0]}e=g&15;f=g&255;Wa:{if(!((e|0)!=15|f>>>0<16)){g=(g&240)>>>4<<!(x[F>>2]&59593760);e=x[O>>2]+(g<<1)|0;break Wa}f=f&240;if(!(!e|(f|0)!=240)){g=e<<(x[F>>2]&59593760?1:2);e=x[O>>2]-g|0;break Wa}if(f){g=(g>>>3&30)<<!(x[F>>2]&59593760);e=x[O>>2]+D(a,g)|0;break Wa}g=e<<(x[F>>2]&59593760?1:2);e=x[O>>2]-D(a,g)|0}x[O>>2]=e;fe(O,0,256);break xa;case 19:if(g>>>0>64){break xa}x[k+1364>>2]=g;break xa;case 20:e=k+1432|0;Xa:{if(g){v[e|0]=g;break Xa}g=y[e|0]}n=k+1364|0;e=x[n>>2];f=g&15;q=g&255;Ya:{if(!((f|0)!=15|q>>>0<16)){x[i+24>>2]=e+(q>>>4|0);break Ya}if(!(!f|(q&240)!=240)){x[i+24>>2]=e-f;break Ya}if(f){x[i+24>>2]=e-D(a,f);break Ya}x[i+24>>2]=e+D(a,q>>>4|0)}fe(i+24|0,0,64);x[n>>2]=x[i+24>>2];break xa;case 7:Zl(b,r,g,8);break xa;case 29:case 30:break Na;case 25:break Oa;case 6:break Pa;case 24:break Qa;case 3:break Ra;case 5:break Sa;case 18:break Ta;case 17:break Ua;default:break xa}}if(g>>>0>15){break Ta}f=(g&1)<<14;q=z[Z>>1];e=0;while(1){if((e|0)==(q|0)){break Ta}n=l+D(e,872)|0;x[n+704>>2]=(f|x[n+704>>2]&-16385)^16384;e=e+1|0;continue}}if((g&240)!=128){break xa}Zl(b,r,g&15,4);break xa}if(g){v[k+1425|0]=g}g=0}Ok(r,g);break xa}kN(b,r,g);break xa}jN(r,g);break xa}iN(r,g);break xa}Za:{if(g<<24>>24>=0){e=qe(xa,y[k+1460|0]);break Za}e=qe(za,g&127)}f=y[da|0];x[23604]=0;ma(541,b|0,l|0,m&65535,0,e|0,f|0);e=x[23604];x[23604]=0;if((e|0)!=1){break xa}a=P()|0;break f}g=0}_a:{$a:{switch(y[k+1406|0]-2|0){case 0:Zl(b,r,y[k+1408|0],6);break _a;case 5:Jb(i+24|0,G,53);e=y[k+1408|0];if(Mb(x[x[i+24>>2]>>2],x[i+28>>2])){v[k+1439|0]=e&15;break _a}Ok(r,e<<4);break _a;case 6:break $a;default:break _a}}Ok(r,y[k+1408|0])}ab:{bb:{cb:{db:{eb:{e=y[J|0];switch(e-5|0){case 1:break ab;case 3:break cb;case 0:case 2:break db;default:break eb}}switch(e-26|0){case 1:break bb;case 0:break db;default:break ab}}fb:{if(x[F>>2]&16777248){e=h;if(!(y[b+480208|0]&4)){break fb}}e=a}f=y[k+1439|0];Jb(i+24|0,G,21);k=k+1435|0;q=y[k|0];e=D(e,f);Ea=k,Fa=(Mb(x[x[i+24>>2]>>2],x[i+28>>2])?e<<2:e)+q|0,v[Ea|0]=Fa;break ab}gb:{if(x[F>>2]&16777248){e=h;if(!(y[b+480208|0]&4)){break gb}}e=a}f=y[k+1442|0];Jb(i+24|0,G,21);k=k+1436|0;q=y[k|0];e=D(e,f);Ea=k,Fa=(Mb(x[x[i+24>>2]>>2],x[i+28>>2])?e<<2:e)+q|0,v[Ea|0]=Fa;break ab}e=k+1437|0;v[e|0]=y[e|0]+D(S,y[k+1445|0]);gN(b,r)}Jb(i+24|0,G,78);if(!Mb(x[x[i+24>>2]>>2],x[i+28>>2])){break wa}e=g&255;if(!e){break wa}fN(r,e)}m=m+1|0;continue}}break}a=P()|0;break f}a=P()|0;break f}a=P()|0;break f}a=P()|0;break f}hb:{if((ba|0)!=7){break hb}a=0;h=b+480188|0;while(1){if(z[h>>1]<=a>>>0){break hb}ib:{if(x[Ne(x[u+8>>2],a)>>2]==-1){break ib}x[23604]=0;X(540,u|0,a&65535,d|0,-1);e=x[23604];x[23604]=0;if((e|0)!=1){break ib}a=P()|0;break f}a=a+1|0;continue}}if(y[t+26|0]){w[t+20>>1]=z[l+72>>1];x[t+8>>2]=x[l+48>>2]}C[t>>3]=C[u+24>>3];x[23604]=0;R(535,_|0,t|0);a=x[23604];x[23604]=0;if((a|0)!=1){if(!$){break a}if(!(L?y[t+26|0]:1)){break c}f=vy(i+56|0);a=l+223860|0;if(ud(y[a+24|0])){VM(f,a)}By(a);a=vc(b+1074376|0,l,614);e=0;while(1){if((e|0)==256){mm(a+223848|0,l+223848|0);d=a+223860|0;e=y[d+24|0];h=l+223860|0;jb:{if((ud(y[h+24|0])|0)==(e|0)){if(!e){break jb}e=jc(d);Ls(d,x[e>>2]);x[d>>2]=x[h>>2];x[d+4>>2]=x[h+4>>2];x[d+8>>2]=x[h+8>>2];kb:{if(!x[Cb(d)>>2]){x[d>>2]=e;break kb}x[x[e>>2]+8>>2]=e;e=jc(h);x[h>>2]=e;x[e>>2]=0;Ea=Cb(h),Fa=0,x[Ea>>2]=Fa}d=d+12|0;e=jc(d);Ks(d,x[e>>2]);h=h+12|0;x[d>>2]=x[h>>2];x[d+4>>2]=x[h+4>>2];x[d+8>>2]=x[h+8>>2];lb:{if(!x[Cb(d)>>2]){x[d>>2]=e;break lb}x[x[e>>2]+8>>2]=e;d=jc(h);x[h>>2]=d;x[d>>2]=0;Ea=Cb(h),Fa=0,x[Ea>>2]=Fa}break jb}if(e){By(d);break jb}VM(d,h)}}else{d=D(e,872);qp((d+a|0)+616|0,(d+l|0)+616|0);e=e+1|0;continue}break}Ay(a);a=0;x[b+1074400>>2]=0;v[b+1074476|0]=1;d=b+1074392|0;x[d>>2]=-2;x[d+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];mb:{nb:{d=x[b+1298300>>2];if(!td(d)){break nb}x[23604]=0;Y(542,d|0);d=x[23604];x[23604]=0;if((d|0)!=1){break nb}break mb}while(1){if(z[b+480188>>1]<=a>>>0){a=Qz(i+24|0);Ea=i,Fa=gj(x[f+12>>2]),x[Ea+16>>2]=Fa;k=xf(f+12|0);while(1){d=x[i+16>>2];if(!xg(d,k)){ob:{e=250;d=a;pb:{while(1){if(e>>>0>=32){if(x[a>>2]){a=1;break pb}else{e=e-32|0;a=a+4|0;continue}}break}a=(x[d+28>>2]&67108863)!=0}if(!a){break ob}a=0;while(1){if((a|0)==250){break ob}Jb(i+8|0,d,a);qb:{if(!Mb(x[x[i+8>>2]>>2],x[i+12>>2])){break qb}h=x[(D(a,160)+b|0)+906300>>2];e=x[x[h>>2]+176>>2];x[23604]=0;Y(e|0,h|0);h=x[23604];x[23604]=0;if((h|0)!=1){break qb}break mb}a=a+1|0;continue}}Ea=i,Fa=gj(x[f>>2]),x[Ea+8>>2]=Fa;a=xf(f);while(1){d=x[i+8>>2];if(xg(d,a)){d=sd(d);Ea=(D(y[d|0],160)+b|0)+906444|0,Ha=B[jc(d)>>2],B[Ea>>2]=Ha;Tg(i+8|0);continue}else{rp(f);break b}}}h=sd(d);r=Cb(h);rb:{e=y[h|0];d=x[(D(e,160)+b|0)+906300>>2];if(d){Jb(i+8|0,a,e);if(!Mb(x[x[i+8>>2]>>2],x[i+12>>2])){x[23604]=0;Q(543,a|0,e|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break rb}e=x[x[d>>2]+172>>2];x[23604]=0;R(e|0,d|0,-1);e=x[23604];x[23604]=0;if((e|0)==1){break rb}}Da=B[r>>2];h=x[h+4>>2];e=x[x[d>>2]+44>>2];x[23604]=0;ya(e|0,d|0,h|0,E(Da));d=x[23604];x[23604]=0;if((d|0)==1){break rb}}Tg(i+16|0);continue}break}break mb}d=D(a,872)+b|0;h=y[d+1075791|0];if(h){v[d+1075794|0]=h}h=Ne(x[u+8>>2],a);if(!((ba|0)==7|y[h+5|0]==255)){v[i+24|0]=64;Ea=d+1075680|0,Fa=y[Wb(h+5|0,i+24|0)|0]<<2,x[Ea>>2]=Fa}sb:{h=x[d+1075096>>2];tb:{if(!h|!(y[h+35|0]&2)){break tb}e=x[b+1298300>>2];if(!td(e)){break tb}x[23604]=0;ga=e;e=a&65535;U(544,ga|0,e|0,h+68|0);h=x[23604];x[23604]=0;if((h|0)==1){break sb}h=x[b+1298300>>2];x[23604]=0;U(545,h|0,e|0,1);h=x[23604];x[23604]=0;if((h|0)==1){break sb}}x[d+1075008>>2]=0;a=a+1|0;continue}break}}a=P()|0;rp(f);break f}a=P()|0}Os(I)}eN(u)}ni(_);T(a|0);p()}if((c|0)==3){break b}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074456>>2]=x[b+480200>>2]}a=la&255;if((a|0)==y[b+484376|0]){break a}ui(ka,a)}if(c&9){a=b+1298264|0;if(x[a>>2]){$N(a);b=x[a>>2];ik(a);Hb(b);Ea=Cb(a),Fa=0,x[Ea>>2]=Fa;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[I>>2];x[a+4>>2]=x[I+4>>2];b=Cb(I);Ea=Cb(a),Fa=x[b>>2],x[Ea>>2]=Fa;x[b>>2]=0;x[I>>2]=0;x[I+4>>2]=0;a=a+12|0;c=jc(a);vp(a,x[c>>2]);b=I+12|0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];ub:{if(!x[Cb(a)>>2]){x[a>>2]=c;break ub}x[x[c>>2]+8>>2]=c;a=jc(b);x[b>>2]=a;x[a>>2]=0;Ea=Cb(b),Fa=0,x[Ea>>2]=Fa}}Os(I);eN(u);hb=i+208|0}function TR(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,q=0,r=0,s=E(0),t=E(0),u=0,C=0,F=0,G=0,H=E(0),I=0,J=E(0),K=0,L=E(0),M=E(0),N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=E(0),W=E(0),X=0,Y=0,Z=0,_=E(0),$=E(0),ba=E(0),ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0;Y=hb-16|0;hb=Y;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;d=0;while(1){e=x[a+1420>>2];if((h|0)<(e|0)){x[(D(h,20)+a|0)+1436>>2]=0;h=h+1|0;continue}break}b:{c:{d:{if((e|0)>3){break d}h=0;if((c|0)<4){break c}c=c-3|0;while(1){if((c|0)==(d|0)){break d}e:{f:{j=b+d|0;if(y[j|0]!=79){break f}if(Rb(j,93444,4)){break f}r=d+26|0;if((r|0)>=(c|0)){break e}g=d+27|0;i=b+r|0;f=y[i|0];if((g+f|0)>=(c|0)){break e}k=f+27|0;h=0;N=0;while(1)if((f|0)==(N|0)){N=0;while(1){f=22;if((h|0)!=22){N=Mw(N,y[(d+h|0)+b|0]);h=h+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;N=Mw(N,0);continue}break}x[a+1420>>2]=e+1;e=D(e,20)+a|0;x[e+1432>>2]=N;x[e+1428>>2]=k-26;x[e+1424>>2]=y[j+22|0]|y[j+23|0]<<8|(y[j+24|0]<<16|y[j+25|0]<<24);f=y[(r+y[i|0]|0)+b|0]==255?-1:y[j+6|0]|y[j+7|0]<<8|(y[j+8|0]<<16|y[j+9|0]<<24);x[e+1436>>2]=r;x[e+1440>>2]=f;e=x[a+1420>>2];if((e|0)!=4){break f}e=4;break d}else{k=y[(g+N|0)+b|0]+k|0;N=N+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(e|0)?d:e;while(1){if((d|0)==(i|0)){break b}h=0;f=D(d,20)+a|0;m=f+1428|0;j=x[m>>2];r=x[f+1436>>2];g=c-r|0;k=(g|0)>(j|0)?j:g;q=(k|0)>0?k:0;o=f+1432|0;N=x[o>>2];while(1){if((h|0)!=(q|0)){N=Mw(N,y[(h+r|0)+b|0]);h=h+1|0;continue}break}x[m>>2]=j-k;x[o>>2]=N;if((g|0)>=(j|0)){f=f+1424|0;if(x[f>>2]==(N|0)){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(d,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;h=k+r|0;break c}e=e-1|0;x[a+1420>>2]=e;e=D(e,20)+a|0;x[f+16>>2]=x[e+1440>>2];j=e+1432|0;h=x[j+4>>2];x[f+8>>2]=x[j>>2];x[f+12>>2]=h;e=e+1424|0;j=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=j;e=x[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=h}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!NH(a)){x[f>>2]=0;c=0;break a}fa=hb-16|0;hb=fa;ia=Y+4|0;x[a+1504>>2]=0;x[a+1508>>2]=0;h:{if(x[a+96>>2]){break h}i:{j:{k:{if(x[a+1380>>2]!=-1){break k}c=Ke(a);if(x[a+96>>2]){break i}if((c|0)!=79){break j}if((Ke(a)|0)!=103){break j}if((Ke(a)|0)!=103){break j}if((Ke(a)|0)!=83){break j}if(!MH(a)){break i}if(!(v[a+1375|0]&1)){break k}v[a+1376|0]=0;x[a+1384>>2]=0;gc(a,32);break i}j=Iw(a);break i}gc(a,30)}if(!j){break h}if(nc(a,1)){gc(a,35);break h}l:{m:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=nc(a,Kl(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break h}x[fa+12>>2]=c;r=D(c,6)+a|0;if(!y[r+412|0]){h=x[a+112>>2];j=h>>1;break m}h=x[a+116>>2];j=h>>1;c=nc(a,1);k=nc(a,1);if(c|!y[r+412|0]){break m}x[ia>>2]=h-x[a+112>>2]>>2;c=x[a+112>>2]+h>>2;break l}aa(6286,13065,3152,10626);p()}x[ia>>2]=0;c=j}x[fa+8>>2]=c;n:{if(!(!y[r+412|0]|k)){c=D(h,3);x[Y+8>>2]=c-x[a+112>>2]>>2;h=c+x[a+112>>2]>>2;break n}x[Y+8>>2]=j}x[fa+4>>2]=h;h=1}if(h){ca=x[ia>>2];ma=x[Y+8>>2];ja=x[fa+4>>2];k=0;Q=hb-2368|0;hb=Q;K=x[a+404>>2];pa=D(x[fa+12>>2],6)+a|0;C=y[pa+413|0];u=D(C,40);S=K+u|0;T=x[((y[pa+412|0]<<2)+a|0)+104>>2];da=T>>1;sa=0-da|0;o:{while(1){c=x[a+4>>2];if((c|0)>(k|0)){c=y[(x[S+4>>2]+D(k,3)|0)+2|0];G=(Q+1344|0)+(k<<2)|0;x[G>>2]=0;j=y[(u+(c+K|0)|0)+9|0];if(z[((j<<1)+a|0)+132>>1]){h=x[a+260>>2];p:{q:{if(!nc(a,1)){break q}c=2;i=x[((k<<2)+a|0)+996>>2];r=h+D(j,1596)|0;o=x[(y[r+1588|0]<<2)+72060>>2];j=Kl(o)-1|0;va=i,wa=nc(a,j),w[va>>1]=wa;va=i,wa=nc(a,j),w[va+2>>1]=wa;g=0;while(1){if(y[r|0]>g>>>0){O=y[(g+r|0)+1|0];j=O+r|0;n=y[j+49|0];q=-1<<n;I=y[j+33|0];r:{if(!n){j=0;break r}j=D(y[j+65|0],2096);m=x[a+124>>2];if(x[a+1396>>2]<=9){Bk(a)}h=j+m|0;R=x[a+1392>>2];j=w[(j+(m+((R&1023)<<1)|0)|0)+36>>1];s:{if((j|0)>=0){m=j&65535;j=y[m+x[h+8>>2]|0];x[a+1392>>2]=R>>>j;j=x[a+1396>>2]-j|0;x[a+1396>>2]=(j|0)>0?j:0;j=(j|0)<0?-1:m;break s}j=Jl(a,h)}if(!y[h+23|0]){break r}j=x[x[h+2088>>2]+(j<<2)>>2]}R=q^-1;h=c+I|0;while(1){if((c|0)!=(h|0)){m=0;q=w[((r+(O<<4)|0)+((j&R)<<1)|0)+82>>1];t:{if((q|0)<0){break t}m=x[a+124>>2];if(x[a+1396>>2]<=9){Bk(a)}I=D(q&65535,2096);q=I+m|0;P=x[a+1392>>2];m=w[(I+(m+((P&1023)<<1)|0)|0)+36>>1];u:{if((m|0)>=0){I=m&65535;m=y[I+x[q+8>>2]|0];x[a+1392>>2]=P>>>m;m=x[a+1396>>2]-m|0;x[a+1396>>2]=(m|0)>0?m:0;m=(m|0)<0?-1:I;break u}m=Jl(a,q)}if(!y[q+23|0]){break t}m=x[x[q+2088>>2]+(m<<2)>>2]}j=j>>n;w[i+(c<<1)>>1]=m;c=c+1|0;continue}break}g=g+1|0;c=h;continue}break}if(x[a+1396>>2]==-1){break q}w[Q+320>>1]=257;c=2;while(1){m=x[r+1592>>2];if((m|0)<=(c|0)){c=0;while(1){if((c|0)>=(m|0)){break p}if(!y[(Q+320|0)+c|0]){w[i+(c<<1)>>1]=65535;m=x[r+1592>>2]}c=c+1|0;continue}}else{q=r+338|0;j=c<<1;g=j+r|0;n=y[g+1088|0];m=n<<1;h=z[q+m>>1];G=y[g+1089|0];O=G<<1;I=w[i+m>>1];g=w[O+i>>1]-I|0;m=g>>31;h=(D((g^m)-m|0,z[j+q>>1]-h|0)|0)/(z[(r+O|0)+338>>1]-h|0)|0;m=I+((g|0)<0?0-h|0:h)|0;q=j+i|0;h=z[q>>1];v:{w:{if(h){j=Q+320|0;v[j+G|0]=1;v[j+n|0]=1;v[c+j|0]=1;j=h<<16>>16;g=o-m|0;if((j|0)>=((g|0)<(m|0)?g:m)<<1){if((g|0)>(m|0)){break v}m=o+(h^-1)|0;break w}if(j&1){m=m-(j+1>>>1|0)|0;break w}m=(j>>1)+m|0;break w}v[(Q+320|0)+c|0]=0}w[q>>1]=m}c=c+1|0;continue}}}x[G>>2]=1}k=k+1|0;continue}else{gc(a,21);c=0;break o}}break}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){vc(Q+320|0,Q+1344|0,c<<2);h=z[S>>1];c=0;while(1){if((c|0)==(h|0)){Z=D(C,40);c=Z+K|0}else{k=x[S+4>>2]+D(c,3)|0;j=y[k+1|0];i=Q+1344|0;k=i+(y[k|0]<<2)|0;if(!(x[(j<<2)+i>>2]?x[k>>2]:0)){x[(Q+1344|0)+(j<<2)>>2]=0;x[k>>2]=0}c=c+1|0;continue}break}ga=c;j=0;while(1){x:{if(y[ga+8|0]>j>>>0){m=0;c=x[a+4>>2];r=(c|0)>0?c:0;c=0;while(1){if((c|0)==(r|0)){break x}if(y[(x[S+4>>2]+D(c,3)|0)+2|0]==(j|0)){i=m+Q|0;k=c<<2;y:{if(x[k+(Q+1344|0)>>2]){k=0;h=1;break y}k=x[(a+k|0)+800>>2];h=0}v[i|0]=h;x[(Q+256|0)+(m<<2)>>2]=k;m=m+1|0}c=c+1|0;continue}}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){j=(da|0)>0?da:0;h=z[S>>1];z:while(1){if((h|0)<=0){O=da<<2;m=0;c=0;while(1){j=x[a+4>>2];if((j|0)<=(c|0)){while(1){if((j|0)>(m|0)){k=y[pa+412|0];S=T>>1;h=S<<2;ka=x[a+92>>2];o=T>>3;I=T>>2;j=x[((m<<2)+a|0)+800>>2];c=S<<2;u=j+c|0;A:{if(x[a+80>>2]){r=qn(a,h);break A}r=Ld(h)}h=(r+c|0)-8|0;R=(k<<2)+a|0;q=x[R+1068>>2];g=q;c=j;while(1){if((c|0)!=(u|0)){B[h+4>>2]=E(B[c>>2]*B[g>>2])-E(B[g+4>>2]*B[c+8>>2]);B[h>>2]=E(B[c>>2]*B[g+4>>2])+E(B[c+8>>2]*B[g>>2]);c=c+16|0;g=g+8|0;h=h-8|0;continue}break}c=((S<<2)+j|0)-12|0;while(1){if(h>>>0>=r>>>0){B[h+4>>2]=E(B[c>>2]*B[g+4>>2])-E(B[c+8>>2]*B[g>>2]);B[h>>2]=E(E(-B[c+8>>2])*B[g+4>>2])-E(B[g>>2]*B[c>>2]);c=c-16|0;g=g+8|0;h=h-8|0;continue}break}c=I<<2;i=c+j|0;h=c+r|0;g=(q+(S<<2)|0)-32|0;c=r;k=j;while(1){if(g>>>0>=q>>>0){l=B[c>>2];s=B[h>>2];t=B[h+4>>2];H=B[c+4>>2];B[i+4>>2]=t+H;B[i>>2]=B[h>>2]+B[c>>2];t=E(t-H);l=E(s-l);B[k+4>>2]=E(t*B[g+16>>2])-E(B[g+20>>2]*l);B[k>>2]=E(l*B[g+16>>2])+E(t*B[g+20>>2]);l=B[c+8>>2];s=B[h+8>>2];t=B[h+12>>2];H=B[c+12>>2];B[i+12>>2]=t+H;B[i+8>>2]=B[h+8>>2]+B[c+8>>2];t=E(t-H);l=E(s-l);B[k+12>>2]=E(t*B[g>>2])-E(B[g+4>>2]*l);B[k+8>>2]=E(l*B[g>>2])+E(t*B[g+4>>2]);c=c+16|0;h=h+16|0;k=k+16|0;i=i+16|0;g=g-32|0;continue}break}h=Kl(T);c=T>>4;k=S-1|0;g=0-o|0;JH(c,j,k,g,q);JH(c,j,k-I|0,g,q);O=T>>5;c=0-c|0;Xo(O,j,k,c,q,16);Xo(O,j,k-o|0,c,q,16);Xo(O,j,k-(o<<1)|0,c,q,16);Xo(O,j,k+D(o,-3)|0,c,q,16);c=h-4>>1;i=(c|0)<=2?2:c;c=2;while(1){B:{C:{D:{if((c|0)==(i|0)){la=h-7|0;break D}g=0;o=2<<c;o=(o|0)>0?o:0;n=8<<c;C=T>>c+4;G=T>>c+2;P=0-(G>>1)|0;while(1){if((g|0)==(o|0)){break C}Xo(C,j,k-D(g,G)|0,P,q,n);g=g+1|0;continue}}while(1){E:{if((i|0)<(la|0)){na=32<<i;n=2<<i;P=8<<i;g=T>>i+6;X=T>>i+2;ea=0-(X>>1)|0;h=k;c=q;while(1){if((g|0)<=0){break E}o=n;C=(h<<2)+j|0;G=C+(ea<<2)|0;U=D(P,12)+c|0;l=B[U>>2];K=(P<<3)+c|0;s=B[K>>2];F=(P<<2)+c|0;t=B[F>>2];H=B[U+4>>2];L=B[K+4>>2];V=B[F+4>>2];W=B[c+4>>2];ba=B[c>>2];U=0-X<<2;while(1){if((o|0)>0){K=G-4|0;M=B[K>>2];_=B[C>>2];$=B[G>>2];B[C>>2]=_+$;F=C-4|0;J=B[F>>2];B[F>>2]=J+B[K>>2];J=E(J-M);M=E(_-$);B[K>>2]=E(J*ba)+E(W*M);B[G>>2]=E(M*ba)-E(W*J);K=G-12|0;_=B[K>>2];F=C-8|0;J=B[F>>2];ga=F;F=G-8|0;$=B[F>>2];B[ga>>2]=J+$;Z=C-12|0;M=B[Z>>2];B[Z>>2]=M+B[K>>2];M=E(M-_);J=E(J-$);B[K>>2]=E(M*t)+E(V*J);B[F>>2]=E(J*t)-E(V*M);K=G-20|0;_=B[K>>2];F=C-16|0;J=B[F>>2];ga=F;F=G-16|0;$=B[F>>2];B[ga>>2]=J+$;Z=C-20|0;M=B[Z>>2];B[Z>>2]=M+B[K>>2];M=E(M-_);J=E(J-$);B[K>>2]=E(M*s)+E(L*J);B[F>>2]=E(J*s)-E(L*M);K=G-28|0;_=B[K>>2];F=C-24|0;J=B[F>>2];ga=F;F=G-24|0;$=B[F>>2];B[ga>>2]=J+$;Z=C-28|0;M=B[Z>>2];B[Z>>2]=M+B[K>>2];M=E(M-_);J=E(J-$);B[K>>2]=E(M*l)+E(H*J);B[F>>2]=E(J*l)-E(H*M);o=o-1|0;G=G+U|0;C=C+U|0;continue}break}g=g-1|0;h=h-8|0;c=(na<<2)+c|0;continue}}c=(k<<2)+j|0;k=c-(O<<6)|0;l=B[q+(T>>3<<2)>>2];ba=E(-l);while(1){if(c>>>0>k>>>0){L=B[c>>2];h=c-32|0;V=B[h>>2];B[c>>2]=L+V;g=c-4|0;s=B[g>>2];i=g;g=c-36|0;W=B[g>>2];B[i>>2]=s+W;i=c-8|0;t=B[i>>2];F=i;i=c-40|0;J=B[i>>2];B[F>>2]=t+J;q=c-12|0;H=B[q>>2];F=q;q=c-44|0;M=B[q>>2];B[F>>2]=H+M;B[h>>2]=L-V;B[g>>2]=s-W;g=c-16|0;s=B[g>>2];F=g;g=c-48|0;_=B[g>>2];B[F>>2]=s+_;t=E(t-J);H=E(H-M);B[i>>2]=l*E(t+H);B[q>>2]=l*E(H-t);i=c-28|0;t=B[i>>2];q=c-60|0;H=B[q>>2];o=c-24|0;L=B[o>>2];n=c-56|0;V=B[n>>2];C=c-20|0;W=B[C>>2];F=C;C=c-52|0;J=B[C>>2];B[F>>2]=W+J;B[o>>2]=L+V;B[i>>2]=t+H;B[g>>2]=W-J;B[C>>2]=-E(s-_);s=E(t-H);t=E(L-V);B[n>>2]=l*E(s-t);B[q>>2]=E(t+s)*ba;IH(c);IH(h);c=c+-64|0;continue}break}q=S-4|0;h=r+(q<<2)|0;g=(r+(I<<2)|0)-16|0;c=x[R+1100>>2];while(1){if(g>>>0>=r>>>0){k=(z[c>>1]<<2)+j|0;B[h+12>>2]=B[k>>2];B[h+8>>2]=B[k+4>>2];B[g+12>>2]=B[k+8>>2];B[g+8>>2]=B[k+12>>2];k=(z[c+2>>1]<<2)+j|0;B[h+4>>2]=B[k>>2];B[h>>2]=B[k+4>>2];B[g+4>>2]=B[k+8>>2];B[g>>2]=B[k+12>>2];c=c+4|0;h=h-16|0;g=g-16|0;continue}break}c=x[R+1084>>2];g=r;h=g+(S<<2)|0;k=h;while(1){i=k-16|0;if(i>>>0>g>>>0){l=B[g+4>>2];o=k-4|0;s=B[o>>2];t=E(l-s);H=B[c+4>>2];l=E(l+s);s=B[g>>2];n=k-8|0;L=B[n>>2];V=E(s-L);W=B[c>>2];ba=E(E(H*l)-E(V*W));B[g+4>>2]=t+ba;s=E(s+L);l=E(E(H*V)+E(l*W));B[g>>2]=s+l;B[o>>2]=ba-t;B[n>>2]=s-l;l=B[g+8>>2];s=B[i>>2];t=E(l+s);H=B[c+12>>2];l=E(l-s);s=B[g+12>>2];k=k-12|0;L=B[k>>2];V=E(s+L);W=B[c+8>>2];ba=E(E(H*l)+E(V*W));B[g+8>>2]=t+ba;s=E(s-L);l=E(E(H*V)-E(l*W));B[g+12>>2]=s+l;B[i>>2]=t-ba;B[k>>2]=l-s;g=g+16|0;c=c+16|0;k=i;continue}break}g=x[R+1076>>2]+(S<<2)|0;c=(q<<2)+j|0;k=((T<<2)+j|0)-16|0;while(1){i=h-32|0;if(i>>>0>=r>>>0){l=B[h-8>>2];s=B[g-4>>2];t=B[g-8>>2];H=B[h-4>>2];L=E(E(l*s)-E(t*H));B[j>>2]=L;B[c+12>>2]=-L;l=E(E(t*E(-l))-E(s*H));B[u>>2]=l;B[k+12>>2]=l;l=B[h-16>>2];s=B[g-12>>2];t=B[g-16>>2];H=B[h-12>>2];L=E(E(l*s)-E(t*H));B[j+4>>2]=L;B[c+8>>2]=-L;l=E(E(t*E(-l))-E(s*H));B[u+4>>2]=l;B[k+8>>2]=l;l=B[h-24>>2];s=B[g-20>>2];t=B[g-24>>2];H=B[h-20>>2];L=E(E(l*s)-E(t*H));B[j+8>>2]=L;B[c+4>>2]=-L;l=E(E(t*E(-l))-E(s*H));B[u+8>>2]=l;B[k+4>>2]=l;l=B[i>>2];s=B[g-28>>2];g=g-32|0;t=B[g>>2];H=B[h-28>>2];L=E(E(l*s)-E(t*H));B[j+12>>2]=L;B[c>>2]=-L;l=E(E(t*E(-l))-E(s*H));B[u+12>>2]=l;B[k>>2]=l;k=k-16|0;c=c-16|0;u=u+16|0;j=j+16|0;h=i;continue}break}if(!x[a+80>>2]){Hb(r)}x[a+92>>2]=ka;break B}i=i+1|0;continue}}c=c+1|0;continue}break}m=m+1|0;j=x[a+4>>2];continue}break}}else{j=c<<2;h=j+a|0;g=x[h+800>>2];F:{if(x[j+(Q+320|0)>>2]){Zb(g,0,O);break F}G=x[h+996>>2];G:{j=y[(y[(x[S+4>>2]+D(c,3)|0)+2|0]+S|0)+9|0];if(!z[((j<<1)+a|0)+132>>1]){gc(a,21);break G}q=T>>1;n=x[a+260>>2]+D(j,1596)|0;j=D(y[n+1588|0],w[G>>1]);i=1;h=0;while(1){if(x[n+1592>>2]>(i|0)){k=y[(i+n|0)+838|0]<<1;r=w[k+G>>1];if((r|0)>=0){r=D(y[n+1588|0],r&65535);k=z[(k+n|0)+338>>1];if((k|0)!=(h|0)){o=r-j|0;C=k-h|0;u=(o|0)/(C|0)|0;H:{I=(k|0)<(q|0)?k:q;if((I|0)<=(h|0)){break H}F=o;o=o>>31;R=u>>31;R=((F^o)-o|0)-D(C,(R^u)-R|0)|0;P=o|1;o=g+(h<<2)|0;B[o>>2]=B[((j&255)<<2)+72080>>2]*B[o>>2];I=I-1|0;o=0;while(1){if((h|0)==(I|0)){break H}h=h+1|0;U=g+(h<<2)|0;o=o+R|0;K=(o|0)<(C|0);j=(j+u|0)+(K?0:P)|0;B[U>>2]=B[((j&255)<<2)+72080>>2]*B[U>>2];o=o-(K?0:C)|0;continue}}h=k}j=r}i=i+1|0;continue}break}if((h|0)>=(q|0)){break G}j=(j<<2)+72080|0;while(1){if((h|0)==(q|0)){break G}k=g+(h<<2)|0;B[k>>2]=B[j>>2]*B[k>>2];h=h+1|0;continue}}}c=c+1|0;continue}break}LH(a);I:{if(y[a+1377|0]){x[a+1060>>2]=sa;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=T-ja;break I}c=x[a+1412>>2];if(!c){break I}j=ma-ca|0;if((j|0)<=(c|0)){x[a+1412>>2]=c-j;x[ia>>2]=ma;ca=ma;break I}ca=c+ca|0;x[ia>>2]=ca;x[a+1412>>2]=0}c=x[a+1064>>2];J:{K:{L:{M:{if(x[a+1388>>2]==x[a+1404>>2]){N:{if(!c|!(y[a+1375|0]&4)){break N}c=x[a+1408>>2];j=x[a+1060>>2];if(c>>>0>=j+(ja-ca|0)>>>0){break N}j=c-j|0;c=(c>>>0>=j>>>0?j:0)+ca|0;c=(c|0)<(ja|0)?c:ja;x[Y+12>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break K}x[a+1064>>2]=1;c=x[a+1408>>2]+(ca-da|0)|0;break M}if(!c){break L}c=x[a+1060>>2]}x[a+1060>>2]=c+(ma-ca|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break J}x[Y+12>>2]=ja}c=1;break o}aa(6286,13065,3451,5595);p()}h=h-1|0;c=x[S+4>>2]+D(h,3)|0;k=x[((y[c+1|0]<<2)+a|0)+800>>2];r=x[((y[c|0]<<2)+a|0)+800>>2];c=0;while(1){if((c|0)==(j|0)){continue z}g=c<<2;i=g+k|0;t=B[i>>2];g=g+r|0;l=B[g>>2];O:{if(l>E(0)){if(t>E(0)){s=E(l-t);break O}s=l;l=E(l+t);break O}if(t>E(0)){s=E(l+t);break O}s=l;l=E(l-t)}B[g>>2]=l;B[i>>2]=s;c=c+1|0;continue}}}aa(6286,13065,3335,5595);p()}R=Q+256|0;g=0;C=hb-16|0;hb=C;u=x[a+4>>2];n=x[a+396>>2];i=y[(Z+(j+K|0)|0)+24|0];q=n+D(i,24)|0;h=x[q+4>>2];la=z[((i<<1)+a|0)+268>>1];c=da<<((la|0)==2);k=c>>>0>h>>>0?h:c;h=x[q>>2];O=(k-(c>>>0>h>>>0?h:c)>>>0)/A[q+8>>2]|0;h=O<<2;c=D(u,h+4|0);ka=x[x[a+124>>2]+D(y[q+13|0],2096)>>2];ta=x[a+92>>2];P:{if(x[a+80>>2]){k=qn(a,c);u=x[a+4>>2];break P}k=Ld(c)}r=(m|0)>0?m:0;G=da<<2;c=0;I=(u|0)>0?u:0;o=(u<<2)+k|0;while(1){if((c|0)!=(I|0)){x[(c<<2)+k>>2]=o;c=c+1|0;o=h+o|0;continue}break}h=k;c=0;while(1){if((c|0)!=(r|0)){if(!y[c+Q|0]){Zb(x[R+(c<<2)>>2],0,G)}c=c+1|0;continue}break}Q:{if(!((m|0)==1|(la|0)!=2)){c=0;while(1){R:{if((c|0)!=(r|0)){if(y[c+Q|0]){break R}}else{c=r}if((c|0)==(m|0)){break Q}r=n+D(i,24)|0;G=(m|0)!=2;I=(m|0)<3;while(1){if((g|0)==8){break Q}S:{if(!G){o=0;k=0;while(1){if((k|0)>=(O|0)){break S}c=x[q>>2]+D(x[q+8>>2],k)|0;x[C+12>>2]=c&1;x[C+8>>2]=c>>1;c=0;if(!g){i=D(y[q+13|0],2096);u=x[a+124>>2];if(x[a+1396>>2]<=9){Bk(a)}n=i+u|0;P=x[a+1392>>2];i=w[(i+(u+((P&1023)<<1)|0)|0)+36>>1];T:{if((i|0)>=0){u=i&65535;i=y[u+x[n+8>>2]|0];x[a+1392>>2]=P>>>i;i=x[a+1396>>2]-i|0;x[a+1396>>2]=(i|0)>0?i:0;i=(i|0)<0?-1:u;break T}i=Jl(a,n)}i=y[n+23|0]?x[x[n+2088>>2]+(i<<2)>>2]:i;if((i|0)==-1){break Q}x[x[h>>2]+(o<<2)>>2]=x[x[r+16>>2]+(i<<2)>>2]}while(1){if(!((c|0)>=(ka|0)|(k|0)>=(O|0))){i=x[q+8>>2];n=w[(x[r+20>>2]+(y[x[x[h>>2]+(o<<2)>>2]+c|0]<<4)|0)+(g<<1)>>1];U:{if((n|0)>=0){if(!KH(a,x[a+124>>2]+D(n&65535,2096)|0,R,2,C+12|0,C+8|0,da,i)){break Q}k=k+1|0;break U}k=k+1|0;i=x[q>>2]+D(i,k)|0;x[C+8>>2]=i>>1;x[C+12>>2]=i&1}c=c+1|0;continue}break}o=o+1|0;continue}}if(I){break S}o=0;k=0;while(1){if((k|0)>=(O|0)){break S}i=x[q>>2]+D(x[q+8>>2],k)|0;c=(i|0)/(m|0)|0;x[C+12>>2]=i-D(c,m);x[C+8>>2]=c;c=0;if(!g){i=D(y[q+13|0],2096);u=x[a+124>>2];if(x[a+1396>>2]<=9){Bk(a)}n=i+u|0;P=x[a+1392>>2];i=w[(i+(u+((P&1023)<<1)|0)|0)+36>>1];V:{if((i|0)>=0){u=i&65535;i=y[u+x[n+8>>2]|0];x[a+1392>>2]=P>>>i;i=x[a+1396>>2]-i|0;x[a+1396>>2]=(i|0)>0?i:0;i=(i|0)<0?-1:u;break V}i=Jl(a,n)}i=y[n+23|0]?x[x[n+2088>>2]+(i<<2)>>2]:i;if((i|0)==-1){break Q}x[x[h>>2]+(o<<2)>>2]=x[x[r+16>>2]+(i<<2)>>2]}while(1){if(!((c|0)>=(ka|0)|(k|0)>=(O|0))){i=x[q+8>>2];n=w[(x[r+20>>2]+(y[x[x[h>>2]+(o<<2)>>2]+c|0]<<4)|0)+(g<<1)>>1];W:{if((n|0)>=0){if(!KH(a,x[a+124>>2]+D(n&65535,2096)|0,R,m,C+12|0,C+8|0,da,i)){break Q}k=k+1|0;break W}k=k+1|0;i=x[q>>2]+D(i,k)|0;n=(i|0)/(m|0)|0;x[C+8>>2]=n;x[C+12>>2]=i-D(m,n)}c=c+1|0;continue}break}o=o+1|0;continue}}g=g+1|0;continue}}c=c+1|0;continue}}na=n+D(i,24)|0;m=0;while(1){if((m|0)==8){break Q}o=0;P=0;X:while(1){if((o|0)<(O|0)){k=0;c=0;Y:{if(m){break Y}while(1){if((c|0)==(r|0)){break Y}if(!y[c+Q|0]){g=D(y[q+13|0],2096);n=x[a+124>>2];if(x[a+1396>>2]<=9){Bk(a)}i=g+n|0;u=x[a+1392>>2];g=w[(g+(n+((u&1023)<<1)|0)|0)+36>>1];Z:{if((g|0)>=0){n=g&65535;g=y[n+x[i+8>>2]|0];x[a+1392>>2]=u>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:n;break Z}g=Jl(a,i)}g=y[i+23|0]?x[x[i+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[h+(c<<2)>>2]+(P<<2)>>2]=x[x[na+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((k|0)>=(ka|0)){break $}c=0;if((o|0)>=(O|0)){break $}while(1){if((c|0)==(r|0)){break _}aa:{if(y[c+Q|0]){break aa}g=c<<2;i=w[(x[na+20>>2]+(y[x[x[g+h>>2]+(P<<2)>>2]+k|0]<<4)|0)+(m<<1)>>1];if((i|0)<0){break aa}u=x[a+124>>2]+D(i&65535,2096)|0;X=x[g+R>>2];U=x[q+8>>2];I=x[q>>2]+D(U,o)|0;ba:{ca:{if(la){G=0;while(1){g=1;if((G|0)>=(U|0)){break ba}ea=X+(I<<2)|0;g=U-G|0;i=0;l=E(0);da:{n=HH(a,u);if((n|0)<0){break da}i=x[u>>2];g=(g|0)>(i|0)?i:g;F=D(i,n);if(y[u+22|0]){n=0;g=(g|0)>0?g:0;i=1;while(1){if((g|0)==(n|0)){break da}ha=ea+(n<<2)|0;l=E(l+B[x[u+28>>2]+(n+F<<2)>>2]);B[ha>>2]=B[ha>>2]+l;n=n+1|0;l=E(l+B[u+12>>2]);continue}}n=0;g=(g|0)>0?g:0;i=1;while(1){if((g|0)==(n|0)){break da}ha=ea+(n<<2)|0;B[ha>>2]=B[ha>>2]+E(B[x[u+28>>2]+(n+F<<2)>>2]+E(0));n=n+1|0;continue}}if(!i){break ca}g=x[u>>2];I=g+I|0;G=g+G|0;continue}}G=0;ea=(U|0)/x[u>>2]|0;F=(ea|0)>0?ea:0;ha=X+(I<<2)|0;g=1;while(1){if((G|0)==(F|0)){break ba}i=G+I|0;n=G<<2;G=G+1|0;ua=n+ha|0;X=U-i|0;n=0;l=E(0);ea:{oa=HH(a,u);if((oa|0)<0){break ea}i=0;n=x[u>>2];X=(n|0)<(X|0)?n:X;X=(X|0)>0?X:0;oa=D(n,oa);n=1;while(1){if((i|0)==(X|0)){break ea}ra=ua+(D(i,ea)<<2)|0;s=E(l+B[x[u+28>>2]+(i+oa<<2)>>2]);B[ra>>2]=B[ra>>2]+s;l=y[u+22|0]?s:l;i=i+1|0;continue}}if(n){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}}P=P+1|0;continue X}o=o+1|0;k=k+1|0;continue}}break}m=m+1|0;continue}}if(!x[a+80>>2]){Hb(h)}x[a+92>>2]=ta;hb=C+16|0;j=j+1|0;continue}}aa(6286,13065,3302,5595);p()}hb=Q+2368|0}else{c=0}hb=fa+16|0;if(!c){fa:{ga:{ha:{c=x[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}x[a+100>>2]=0;while(1){if((gh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break fa}x[a+100>>2]=0;while(1){if((gh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;c=1;break a}c=0;r=x[Y+12>>2];i=x[Y+4>>2];k=x[Y+8>>2];ia:{ja:{g=x[a+992>>2];if(g){h=g<<1;ka:{if((h|0)==x[a+112>>2]){h=a+1092|0}else{j=0;if((h|0)!=x[a+116>>2]){break ka}h=a+1096|0}j=x[h>>2]}if(!j){break ja}q=(g|0)>0?g:0;while(1){if(x[a+4>>2]>(N|0)){m=(N<<2)+a|0;h=0;while(1){if((h|0)!=(q|0)){o=x[m+800>>2]+(h+i<<2)|0;F=o;l=B[o>>2];o=h<<2;B[F>>2]=E(l*B[o+j>>2])+E(B[o+x[m+928>>2]>>2]*B[j+(g+(h^-1)<<2)>>2]);h=h+1|0;continue}break}N=N+1|0;continue}break}N=x[a+992>>2]}x[a+992>>2]=r-k;g=(k|0)>(r|0);m=(g?k:r)-k|0;while(1){if(x[a+4>>2]>(qa|0)){j=(qa<<2)+a|0;h=0;while(1){if((h|0)!=(m|0)){B[x[j+928>>2]+(h<<2)>>2]=B[x[j+800>>2]+(h+k<<2)>>2];h=h+1|0;continue}break}qa=qa+1|0;continue}break}if(!N){break ja}j=(g?r:k)-i|0;x[a+1416>>2]=j+x[a+1416>>2];break ia}j=0}while(1){h=x[a+4>>2];if((h|0)>(c|0)){h=(c<<2)+a|0;x[h+864>>2]=x[h+800>>2]+(i<<2);c=c+1|0;continue}break}if(d){x[d>>2]=h}x[f>>2]=j;x[e>>2]=a+864;c=x[a+32>>2]-b|0}hb=Y+16|0;return c}function hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=hb-1760|0;hb=d;xc(b);f=hb-16|0;hb=f;h=d+1632|0;pR(f+8|0,h);g=x[f+12>>2];l=b;mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){bc(l,x[f+12>>2])}hb=f+16|0;b=(b|0)==(g|0);if(!b){oR(h)}a:{if(!b){break a}if(!qR(d+1632|0)){break a}if(!Qb(x[l>>2],x[l+8>>2],Uc(256,0))){break a}b:{if(!c){break b}Cd(a,1048576);Ag(a);b=hb-16|0;hb=b;e=Xb(b,4191);dd(d+1376|0,e);xb(e);hb=b+16|0;b=z[d+1640>>1];x[d+160>>2]=b>>>8;x[23604]=0;x[d+16>>2]=b&255;R(378,d+88|0,d+16|0);b=x[23604];x[23604]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){x[23604]=0;X(364,d+272|0,d+1376|0,d+160|0,d+88|0);b=x[23604];x[23604]=0;if((b|0)==1){break m}b=d+272|0;Ab(a+1298344|0,b);xb(b);e=d+88|0;xb(e);f=d+1376|0;Db(f);g=Xb(b,14991);Ab(a+1298356|0,g);xb(g);We(e,2,d+1642|0);Dc(f,e);x[23604]=0;U(11,b|0,8,f|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}b=d+272|0;Ab(a+1298368|0,b);xb(b);e=d+1376|0;xb(e);x[a+1298404>>2]=8;Sz(e,2,d+1674|0);Dc(b,e);Ab(a+1298308|0,b);xb(b);w[a+480188>>1]=z[d+1744>>1];f=y[d+1748|0];x[a+480204>>2]=125e4;x[a+480208>>2]=32792;H=a,I=Td(f,1,31),x[H+480196>>2]=I;w[a+480192>>1]=z[d+1754>>1];w[a+480190>>1]=z[d+1756>>1];f=Td(y[d+1749|0],1,32);x[a+480216>>2]=f;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=f<<2;Gu(l,e);f=a+484360|0;g=a+484376|0;Bq(_b(x[f>>2],y[g|0]),e,z[d+1738>>1],65535,65535);Xe(_b(x[f>>2],y[g|0]),z[d+1740>>1]);r=Cg(l);Ud(b,l,r?274:0);B=kc(d+1352|0,b);yb(b);x[23604]=0;b=S(143,l|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break k}x[23604]=0;U(176,d+272|0,l|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break k}b=d+272|0;t=kc(d+1328|0,b);yb(b);b=a+480188|0;q=z[b>>1];if(r){w[b>>1]=q+8}u=c&1;if(!u){break j}x[23604]=0;R(211,a+484344|0,z[d+1742>>1]);b=x[23604];x[23604]=0;if((b|0)!=1){break j}g=P()|0;break e}g=P()|0;break l}g=P()|0;xb(d+88|0)}Db(d+1376|0);break c}g=P()|0;break d}o=a+484344|0;C=a+480188|0;g=0;while(1){n:{o:{p:{q:{r:{s:{if(z[d+1742>>1]<=s>>>0){b=z[d+1746>>1];if((b-2&65535)>>>0>=4998){break q}if(!(g&1)){break s}h=0;b=Ec(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}x[23604]=0;b=S(180,l|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break f}x[d+160>>2]=b;x[23604]=0;b=S(143,l|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break g}x[23604]=0;U(176,d+88|0,l|0,b+1&-2);b=x[23604];x[23604]=0;if((b|0)==1){break g}b=d+88|0;j=kc(d+272|0,b);yb(b);wc(d+160|0,1024);if(!u){break o}n=x[d+160>>2];if(!n){break o}x[23604]=0;b=W(212,o|0,s&65535,n|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){if(!b){break o}k=0;e=0;if(v[d+1750|0]&1){break p}t:while(1){if((k|0)==(n|0)){break o}e=0;b=ac(x[o>>2],s);b=of(x[b>>2],x[x[b+48>>2]+12>>2],k);while(1){if((e|0)==(q|0)){k=k+1|0;continue t}x[23604]=0;R(552,j|0,d+88|0);f=x[23604];x[23604]=0;if((f|0)!=1){g=nR(b+D(e,6)|0,d+88|0)|g;e=e+1|0;continue}break}break}break h}break h}h=2;b=Ge(2646e3/+(D(b,D(x[a+480216>>2],x[a+480196>>2]))>>>0)*1e4)}v[a+480224|0]=h;x[a+480204>>2]=b}h=a+480188|0;b=z[h>>1];x[23604]=0;v[d+272|0]=0;s=W(553,d+1312|0,b|0,d+272|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){k=a+1298320|0;n=a+1298332|0;m=a+484348|0;j=0;u:{v:{w:{x:{y:{z:{while(1){b=x[t+8>>2];e=x[t>>2];x[23604]=0;b=W(142,e|0,b|0,8)|0;e=x[23604];x[23604]=0;A:{if((e|0)!=1){if(b){break A}f=x[s>>2];h=0;g=a+480188|0;while(1){e=z[g>>1];if(e>>>0<=h>>>0){x[d+264>>2]=0;x[d+268>>2]=0;x[d+256>>2]=0;x[d+260>>2]=0;x[d+248>>2]=0;x[d+252>>2]=0;x[d+240>>2]=0;x[d+244>>2]=0;B:{C:{if(!r){break C}e=0;x[23604]=0;R(554,B|0,d+272|0);b=x[23604];x[23604]=0;if((b|0)==1){break B}while(1){if((e|0)==8){e=0;x[23604]=0;k=Q(204,d+224|0,z[d+272>>1])|0;b=x[23604];x[23604]=0;if((b|0)!=1){D:{E:{F:{G:{while(1){if(z[d+272>>1]<=e>>>0){x[23604]=0;n=W(555,d+208|0,z[d+1742>>1],27292)|0;b=x[23604];x[23604]=0;if((b|0)==1){break E}i=a+484376|0;u=a+484348|0;C=a+480188|0;f=0;break F}x[23604]=0;b=S(180,l|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){x[23604]=0;U(176,d+160|0,l|0,b<<5);b=x[23604];x[23604]=0;if((b|0)==1){break G}f=d+160|0;b=kc(d+88|0,f);$c(zg(x[k>>2],e),b);yb(b);e=e+1|0;yb(f);continue}break}g=P()|0;break D}g=P()|0;break D}while(1){if(z[d+1738>>1]<=f>>>0){nd(n);jd(k);break C}H:{g=d+f|0;e=y[g+290|0];if(e>>>0>=z[d+272>>1]){break H}b=z[cc(x[_b(x[a+484360>>2],y[i|0])>>2],f)>>1];if(b>>>0>=z[d+1742>>1]){break H}I:{h=cc(x[n>>2],b);m=z[h>>1];J:{if((m|0)==65535){w[h>>1]=e;break J}if((e|0)==(m|0)){break J}x[23604]=0;e=Q(556,o|0,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break I}if((e|0)==65535){break J}H=cc(x[_b(x[a+484360>>2],y[i|0])>>2],f),I=e,w[H>>1]=I;b=e}if(!pe(x[a+484344>>2],x[u>>2],b)){break H}r=zg(x[k>>2],y[g+290|0]);xc(r);e=x[r>>2];x[23604]=0;e=S(146,e|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break I}E=e>>>5|0;h=0;K:while(1){e=ac(x[o>>2],b);if(A[e+12>>2]<=h>>>0){break H}g=0;e=cd(x[e>>2],x[x[e+48>>2]+12>>2],h,z[C>>1]-8&65535);while(1){if((g|0)==8){h=h+1|0;continue K}sh(d+88|0);m=z[d+92>>1];v[e+4|0]=m;v[e+5|0]=m>>>8;m=x[d+88>>2];v[e|0]=m;v[e+1|0]=m>>>8;v[e+2|0]=m>>>16;v[e+3|0]=m>>>24;L:{if(h>>>0>=E>>>0){break L}x[23604]=0;Q(557,r|0,d+88|0)|0;m=x[23604];x[23604]=0;if((m|0)==1){break I}if(v[d+88|0]>=0){break L}v[e|0]=61;v[e+1|0]=y[(d+256|0)+(g<<1)|0];m=y[d+88|0]&31;v[d+160|0]=m;if(m){mf(d+160|0,15);v[e+3|0]=20;v[e+5|0]=y[d+160|0]|208}v[e+2|0]=1;v[e+4|0]=y[d+89|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=P()|0;nd(n);break D}f=f+1|0;continue}}g=P()|0}jd(k);break u}g=P()|0;break u}f=e<<1;g=f+(d+256|0)|0;b=z[a+480192>>1]+1&65535;h=z[x[a+8>>2]+58>>1];while(1){M:{N:{k=b&65535;if(k>>>0<=h>>>0){if(x[((k<<2)+a|0)+900380>>2]){break N}}else{b=65535}b=b&65535;break M}b=b+1|0;continue}break}w[g>>1]=b;h=f+(d+240|0)|0;f=z[(d+f|0)+274>>1];w[h>>1]=f;O:{if((b|0)!=65535){x[23604]=0;b=W(237,a|0,b|0,f+1&65535)|0;f=x[23604];x[23604]=0;P:{Q:{if((f|0)!=1){if(!b){break O}x[23604]=0;R(271,d+160|0,4436);f=x[23604];x[23604]=0;if((f|0)==1){break Q}x[23604]=0;x[d+16>>2]=e+1;U(558,d+88|0,d+160|0,d+16|0);f=x[23604];x[23604]=0;if((f|0)==1){break P}f=b+492|0;b=d+88|0;Bc(f,b);xb(b);Db(d+160|0);break O}g=P()|0;break u}g=P()|0;break u}g=P()|0;Db(d+160|0);break u}w[g>>1]=0}e=e+1|0;continue}}R:{S:{b=z[d+1750>>1]|z[d+1752>>1]<<16;if(!(b&2)){break S}b=(((b&8?z[a+480188>>1]:q)&65535)+(z[d+1640>>1]>591?j:0)|0)+(b>>>4&1)|0;f=0;T:while(1){e=0;if(z[d+1742>>1]<=f>>>0){break S}while(1){U:{if((b|0)!=(e|0)){g=x[l+8>>2];h=x[l>>2];x[23604]=0;g=W(142,h|0,g|0,4)|0;h=x[23604];x[23604]=0;if((h|0)==1){break R}if(g){break U}}f=f+1|0;continue T}x[23604]=0;R(559,z[d+1640>>1],l|0);g=x[23604];x[23604]=0;if((g|0)==1){break R}e=e+1|0;continue}}}x[23604]=0;k=Q(204,d+192|0,255)|0;b=x[23604];x[23604]=0;if((b|0)!=1){m=a+480208|0;f=0;while(1){V:{b=f;W:{if((b|0)==255){o=Qz(d+88|0);n=Qz(d+160|0);g=0;while(1){X:{Y:{Z:{if((g|0)==256){h=0;break Z}x[23604]=0;R(560,l|0,d+272|0);b=x[23604];x[23604]=0;if((b|0)==1){break Y}x[23604]=0;b=S(143,l|0)|0;e=x[23604];x[23604]=0;_:{$:{aa:{if((e|0)!=1){x[23604]=0;U(176,d+16|0,l|0,b|0);e=x[23604];x[23604]=0;if((e|0)==1){break aa}e=d+16|0;j=kc(d- -64|0,e);yb(e);if(z[d+1756>>1]>g>>>0){e=d+48|0;We(e,2,d+272|0);x[23604]=0;R(208,d+16|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break _}e=d+16|0;Bc(((g<<5)+a|0)+946336|0,e);xb(e)}if(!b){break X}if(z[d+1756>>1]>g>>>0){break $}break X}g=P()|0;break W}g=P()|0;break W}x[23604]=0;b=D(g,104)+a|0;e=b+484484|0;R(262,e|0,32);f=x[23604];x[23604]=0;ba:{ca:{da:{if((f|0)!=1){uo(e);x[23604]=0;R(561,j|0,d+16|0);e=x[23604];x[23604]=0;if((e|0)==1){break _}b=b+104|0;e=b+484380|0;h=x[d+16>>2];x[e>>2]=h;x[b+484404>>2]=x[d+20>>2];if(y[d+24|0]>=2){h=h>>>1|0;x[e>>2]=h;f=b+484414|0;w[f>>1]=z[f>>1]|1}if(y[d+25|0]>=2){x[e>>2]=h>>>1;e=b+484414|0;w[e>>1]=z[e>>1]|64}h=2;switch(y[d+27|0]-1|0){case 0:break ca;case 1:break da;default:break ba}}break _}h=6}e=b+484414|0;w[e>>1]=z[e>>1]|h}x[b+484384>>2]=x[d+28>>2];x[b+484388>>2]=x[d+32>>2];w[b+484410>>1]=z[d+36>>1]>>>7;e=y[d+38|0];ea:{if((e|0)==128){e=b+484414|0;f=z[e>>1]|256;w[e>>1]=f;break ea}w[b+484408>>1]=(e<<24>>24)+128;f=z[b+484414>>1]}h=b+484414|0;w[h>>1]=f|32;v[b+484416|0]=y[d+39|0];e=y[d+26|0];if(e&2){b=d+48|0;Jb(b,n,g);km(b);e=y[d+26|0]}if(e&5){w[h>>1]=z[h>>1]|16384}if(!(e&8)){break X}b=d+48|0;Jb(b,o,g);km(b);e=0;while(1){if((e|0)==8){break X}b=e<<1;fa:{if(z[b+(d+240|0)>>1]!=(g|0)){break fa}b=x[((z[b+(d+256|0)>>1]<<2)+a|0)+900380>>2];if(!b){break fa}v[b+14|0]=0}e=e+1|0;continue}}g=P()|0;yb(j);break W}while(1){ga:{ha:{if(z[d+1754>>1]<=h>>>0){if(!(c&2)){break ha}e=a+1298404|0;f=a+1298464|0;g=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{while(1){if(z[a+480190>>1]<=g>>>0){break ha}g=g+1|0;c=D(g,104)+a|0;h=c+484380|0;b=c+484416|0;bq(h,(+(v[b|0]-49|0)+ +v[c+484417|0]*-.0078125)/-12);w[b>>1]=0;b=z[c+484414>>1];if(!(b&16384)){b=Xc(d+272|0,b&1?16:8,b&64?3:1,0,11);x[23604]=0;W(205,b|0,h|0,l|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}g=P()|0;break W}x[23604]=0;h=S(143,l|0)|0;b=x[23604];x[23604]=0;qa:{if((b|0)==1){break qa}x[23604]=0;Q(174,l|0,12)|0;b=x[23604];x[23604]=0;if((b|0)==1){break qa}b=Kb(d+272|0);x[23604]=0;U(253,l|0,b|0,h|0);h=x[23604];x[23604]=0;if((h|0)==1){break pa}ze(c+484423|0,b);x[23604]=0;R(363,d- -64|0,16265);c=x[23604];x[23604]=0;if((c|0)==1){break oa}x[d+12>>2]=g;c=x[e>>2];x[23604]=0;U(11,d+48|0,c|0,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break na}x[23604]=0;X(364,d+16|0,d- -64|0,d+12|0,d+48|0);c=x[23604];x[23604]=0;if((c|0)==1){break ma}c=x[f>>2];x[23604]=0;U(351,c|0,2,d+16|0);c=x[23604];x[23604]=0;if((c|0)==1){break la}xb(d+16|0);xb(d+48|0);Db(d- -64|0);xb(b);continue}break}g=P()|0;break W}g=P()|0;break ia}g=P()|0;break ia}g=P()|0;break ja}g=P()|0;break ka}g=P()|0;xb(d+16|0)}xb(d+48|0)}Db(d- -64|0)}xb(b);break W}b=x[zg(x[k>>2],h)>>2];x[23604]=0;b=S(146,b|0)|0;e=x[23604];x[23604]=0;ra:{sa:{if((e|0)!=1){if(!b){h=h+1|0;continue}b=zg(x[k>>2],h);xc(b);x[23604]=0;R(562,b|0,d+272|0);b=x[23604];x[23604]=0;if((b|0)==1){break sa}j=Sb(d+16|0);x[23604]=0;U(563,l|0,j|0,z[d+272>>1]);b=x[23604];x[23604]=0;if((b|0)==1){break ra}h=h+1|0;b=x[((h<<2)+a|0)+900380>>2];if(!b|y[b+34|0]){break ga}x[b+4>>2]=32;e=0;Jt(b,0);m=b+108|0;i=b+236|0;while(1){if((e|0)==96){break ga}f=y[(d+e|0)+274|0];ta:{if(f>>>0>=z[d+272>>1]){break ta}q=Ne(x[j>>2],f);f=y[q|0];g=f+1|0;r=e+12|0;H=cc(i,r),I=g,w[H>>1]=I;if(f>>>0>=z[a+480190>>1]){break ta}f=D(g,104)+a|0;v[f+484418|0]=y[d+370|0]&3;v[f+484419|0]=y[d+371|0];v[f+484420|0]=y[d+372|0];v[f+484421|0]=y[d+373|0];w[f+484412>>1]=y[q+1|0]<<1;v[f+484417|0]=y[q+2|0];f=g-1|0;Jb(d- -64|0,o,f);if(Mb(x[x[d+64>>2]>>2],x[d+68>>2])){v[b+14|0]=0}Jb(d- -64|0,n,f);if(!Mb(x[x[d+64>>2]>>2],x[d+68>>2])){break ta}H=Gb(m,r),I=61,v[H|0]=I}e=e+1|0;continue}}g=P()|0;break W}g=P()|0;break W}g=P()|0;je(j);break W}jd(k);fc(s);yb(t);yb(B);break b}je(j);continue}}g=P()|0;break W}yb(j);g=g+1|0;continue}}x[23604]=0;R(560,l|0,d+160|0);e=x[23604];x[23604]=0;ua:{va:{wa:{xa:{if((e|0)!=1){x[23604]=0;e=S(143,l|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break xa}x[23604]=0;e=(e|0)==32?428:e;j=e?z[d+1640>>1]>513?e+4|0:e:e;U(176,d+88|0,l|0,j|0);e=x[23604];x[23604]=0;if((e|0)==1){break wa}g=d+88|0;e=kc(d+272|0,g);h=ge(d+16|0,$c(zg(x[k>>2],b),e));yb(e);f=b+1|0;yb(g);if(b>>>0>=z[d+1754>>1]){break V}x[23604]=0;b=f&65535;g=W(237,a|0,b|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break va}break ua}g=P()|0;break W}g=P()|0;break W}g=P()|0;break W}if(!g){break V}b=d+88|0;We(b,2,d+160|0);x[23604]=0;R(208,d+272|0,b|0);b=x[23604];x[23604]=0;ya:{if((b|0)!=1){b=d+272|0;Bc(g+492|0,b);xb(b);if(!j){break V}x[23604]=0;R(562,h|0,d+272|0);b=x[23604];x[23604]=0;if((b|0)!=1){j=3;o=0;if(z[d+1640>>1]<513){n=0;break ya}x[23604]=0;n=S(180,h|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break ua}if(z[d+1640>>1]<514){break ya}x[23604]=0;j=S(143,h|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break ya}break ua}break ua}break ua}x[g>>2]=z[d+374>>1];v[g+16|0]=y[(z[d+376>>1]&3)+27294|0];v[g+17|0]=y[(y[d+377|0]&3)+27294|0];v[g+18|0]=y[(z[d+376>>1]>>>12&3)+27298|0];while(1){za:{Aa:{if((o|0)==4){if(!(v[g+60|0]&1|y[g+16|0]==3)){x[g>>2]=32767}Bm(g,127,1);Am(g,0,1);if(!n){break V}x[23604]=0;R(564,h|0,d+88|0);b=x[23604];x[23604]=0;if((b|0)==1){break ua}if(n&2){Bm(g,kR(x[m>>2],+z[d+90>>1]),1);Am(g,y[d+92|0],1)}v[g+25|0]=y[d+89|0]==1;if(!(n&4)){break V}v[g+31|0]=y[d+95|0]+1;b=v[d+96|0];v[g+34|0]=b+1;if((b|0)<0){v[g+30|0]=y[d+103|0]+1}if(!y[d+100|0]){break Aa}j=g+108|0;e=0;while(1){if((e|0)==128){break Aa}b=e+1|0;x[d+64>>2]=b+v[d+100|0];jR(d- -64|0);o=x[d+64>>2];H=Gb(j,e),I=o,v[H|0]=I;e=b;continue}}if(!(j&1)){break za}x[23604]=0;R(565,h|0,d+88|0);b=x[23604];x[23604]=0;Ba:{if((b|0)!=1){b=xi(g,y[o+27302|0]);Ca:{if((o|0)!=3){e=y[d+88|0];q=y[b+12|0]&-17;break Ca}e=y[d+88|0];q=e<<4&16|y[b+12|0]&-17}v[b+12|0]=e>>>1&2|(e<<1&4|(q&248|e&1));v[d+64|0]=y[d+89|0];v[d+48|0]=16;e=y[Wb(d- -64|0,d+48|0)|0];x[23604]=0;R(276,b|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break Ba}e=y[d+90|0];v[b+15|0]=e;v[b+16|0]=e;v[b+13|0]=y[d+91|0];v[b+14|0]=y[d+92|0];e=0;q=x[b>>2];i=ie(q,x[b+4>>2]);while(1){if((e|0)==(i|0)){break za}r=zb(q,e);b=(d+88|0)+(e<<2)|0;w[r>>1]=y[b+8|0]|y[b+9|0]<<8;H=r,I=Td(y[b+10|0]|y[b+11|0]<<8,0,64),v[H+2|0]=I;e=e+1|0;continue}}break ua}break ua}Jt(g,0);break V}o=o+1|0;j=j>>>1|0;continue}}g=P()|0;yb(h)}jd(k);break u}yb(h);continue}}g=P()|0;break u}g=P()|0;break u}g=P()|0;break u}else{b=v[Gb(f,h)|0];Da:{if((b|0)<=(h|0)|(b|0)>=(e|0)){break Da}b=y[((b<<5)+a|0)+480288|0];if(!b){break Da}e=((h<<5)+a|0)+480288|0;k=y[e|0];if(!k){v[e|0]=b;break Da}e=k-1|0;while(1){k=D(e&255,160)+a|0;e=Em(x[k+906328>>2]);if((e|0)!=255){continue}break}b=b-1&255;x[(k+906300|0)+28>>2]=b>>>0<250?b+128|0:0}h=h+1|0;continue}}}g=P()|0;break u}x[23604]=0;f=S(143,t|0)|0;b=x[23604];x[23604]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((b|0)!=1){x[23604]=0;b=S(143,t|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ma}x[23604]=0;U(176,d+272|0,t|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break Ma}e=d+272|0;b=kc(d+88|0,e);yb(e);if((f|0)==4674381){break Ia}if((f|0)==5068115){break Ha}if((f|0)==726487106){break La}if((f|0)==844387158){break Ga}e=0;if((f|0)==1280004692){break Ka}if((f|0)==1314144592){break Ja}if((f|0)!=1397445204){break Fa}x[23604]=0;e=S(180,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break w}e=e>>>0<256?48:e>>>8|0;x[a+480228>>2]=e;x[a+480232>>2]=e>>>1;e=0;while(1){if(z[h>>1]<=e>>>0){break Fa}x[23604]=0;f=Q(566,b|0,d+272|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break z}if(f){w[((e<<5)+a|0)+480286>>1]=z[d+272>>1]>>>10;H=Gb(x[s>>2],e),I=y[d+275|0],v[H|0]=I}e=e+1|0;continue}}g=P()|0;break u}g=P()|0;break u}if(g&1){break Fa}v[a+480224|0]=2;x[23604]=0;F=+na(567,b|0);e=x[23604];x[23604]=0;if((e|0)==1){break Ea}if(!(F>1e-8)){break Fa}H=a,I=Ge(2646e3/(F*+(D(x[a+480216>>2],x[a+480196>>2])>>>0))*1e4),x[H+480204>>2]=I;break Fa}while(1){Na:{if(z[h>>1]<=e>>>0){break Fa}f=x[b>>2];x[23604]=0;f=W(142,f|0,x[d+96>>2],1)|0;i=x[23604];x[23604]=0;if((i|0)==1){break y}if(!f){break Fa}f=Kb(d+272|0);x[23604]=0;U(334,b|0,f|0,-1);i=x[23604];x[23604]=0;if((i|0)!=1){i=d+16|0;Kf(i,3,Pb(f),Qc(x[d+276>>2],y[d+283|0]));x[23604]=0;R(208,d+160|0,i|0);i=x[23604];x[23604]=0;if((i|0)==1){break Na}i=d+160|0;vm(((e<<5)+a|0)+480289|0,i);xb(i);xb(f);e=e+1|0;continue}}break}g=P()|0;xb(f);break v}while(1){if(z[d+1742>>1]<=e>>>0){break Fa}f=x[b>>2];x[23604]=0;f=W(142,f|0,x[d+96>>2],1)|0;i=x[23604];x[23604]=0;if((i|0)==1){break x}if(!f){break Fa}if(!wm(x[a+484344>>2],x[m>>2],e&65535)){break Fa}f=Kb(d+272|0);x[23604]=0;U(334,b|0,f|0,-1);i=x[23604];x[23604]=0;Oa:{if((i|0)==1){break Oa}i=x[o>>2];x[23604]=0;R(266,ac(i,e)|0,f|0);i=x[23604];x[23604]=0;if((i|0)==1){break Oa}xb(f);e=e+1|0;continue}break}g=P()|0;xb(f);break v}x[23604]=0;Q(174,b|0,1)|0;e=x[23604];x[23604]=0;if((e|0)==1){break w}x[23604]=0;e=S(188,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break w}x[23604]=0;X(315,n|0,b|0,e|0,2);e=x[23604];x[23604]=0;if((e|0)!=1){break Fa}break w}x[23604]=0;Q(568,b|0,d+16|0)|0;e=x[23604];x[23604]=0;Pa:{if((e|0)!=1){e=Kb(d+272|0);x[23604]=0;U(334,b|0,e|0,-1);f=x[23604];x[23604]=0;if((f|0)==1){break Pa}if($p(e,12489)){x[23604]=0;U(11,d+160|0,8,e|0);f=x[23604];x[23604]=0;if((f|0)==1){break Pa}f=d+160|0;Ab(k,f);xb(f)}xb(e);break Fa}g=P()|0;break v}g=P()|0;xb(e);break v}x[23604]=0;j=S(143,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break w}}yb(b);continue}break}g=P()|0;break v}g=P()|0;break v}g=P()|0;break v}g=P()|0;break v}g=P()|0}yb(b)}fc(s);break e}g=P()|0;break e}while(1){b=x[j>>2];x[23604]=0;b=W(142,b|0,x[d+280>>2],1)|0;f=x[23604];x[23604]=0;Qa:{if((f|0)!=1){if(!b){break o}x[23604]=0;h=S(192,j|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break h}m=0;if((h|0)!=255){break Qa}x[23604]=0;m=S(192,j|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){x[23604]=0;h=S(192,j|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break Qa}}break h}break h}if(h&127){b=ac(x[o>>2],s);f=cd(x[b>>2],x[x[b+48>>2]+12>>2],e,k&65535);ru(d+88|0);if(h&1){x[23604]=0;b=S(192,j|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break n}v[d+88|0]=b}if(h&2){x[23604]=0;b=S(192,j|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break n}v[d+89|0]=b}if(h&4){x[23604]=0;b=S(192,j|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break n}v[d+90|0]=b}if(h&8){x[23604]=0;b=S(192,j|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break n}v[d+91|0]=b}if(h&16){x[23604]=0;b=S(192,j|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break n}v[d+92|0]=b}if(h&32){x[23604]=0;b=S(192,j|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break n}v[d+93|0]=b}if(h&64){x[23604]=0;b=S(192,j|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break n}v[d+94|0]=b}E=nR(f,d+88|0);x[d+16>>2]=m;x[d+64>>2]=n+(e^-1);G=x[Fb(d+16|0,d- -64|0)>>2];h=0;b=f;while(1){if((h|0)!=(G|0)){b=D(z[C>>1],6)+b|0;i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=i;v[b+1|0]=i>>>8;v[b+2|0]=i>>>16;v[b+3|0]=i>>>24;i=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=i;v[b+5|0]=i>>>8;h=h+1|0;continue}break}g=g|E}e=(e+m|0)+1|0;while(1){if(e>>>0>=n>>>0){k=k+1|0;e=e-n|0;continue}break}if(q>>>0>(k&65535)>>>0){continue}break}}yb(j);s=s+1|0;continue}break}break h}g=P()|0;xb(d+1376|0);break c}g=P()|0;yb(j);break e}g=P()|0;break e}g=P()|0}yb(t)}yb(B)}T(g|0);p()}e=1}hb=d+1760|0;return e|0}function Y8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,S=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0;m=hb-1168|0;hb=m;xc(b);a:{if(!$q(b,m+1144|0)){break a}if(!uL(m+1144|0)){break a}if(x[m+1152>>2]!=(Fg(x[b>>2])|0)){break a}if(x[m+1160>>2]!=(cf(b)|0)){break a}if(!c){h=1;break a}d=m+1088|0;Zb(d,0,56);o=-2;b:{if(!d){break b}x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+8>>2]=0;o=x[d+32>>2];if(!o){x[d+32>>2]=1036;o=1036}if(!x[d+36>>2]){x[d+36>>2]=1037}e=mb[o|0](x[d+40>>2],1,43784)|0;o=-4;if(!e){break b}x[d+28>>2]=e;x[e+43780>>2]=1;x[e+10992>>2]=0;x[e+10996>>2]=0;x[e>>2]=0;x[e+11008>>2]=15;x[e+11e3>>2]=1;x[e+11004>>2]=0;o=0}if(o){break a}h=x[m+1160>>2];x[m+1084>>2]=h;H=x[m+1164>>2];O=VA(m+1072|0,H);c:{d:{while(1){if(!(!h|!H|(g|0)==1)){x[m+32>>2]=1024;g=m+32|0;R=x[Fb(g,m+1084|0)>>2];d=ec(m+40|0,m+48|0,R);h=x[d>>2];d=x[d+4>>2];x[23604]=0;Wm(151,g,b,h,d);g=x[23604];x[23604]=0;if((g|0)==1){break d}d=m+48|0;g=d;h=R;e=Z^-1;while(1){if(h>>>0<4){while(1){if(h){e=x[(((y[g|0]^e)&255)<<2)+62496>>2]^e>>>8;h=h-1|0;g=g+1|0;continue}break}Z=e^-1}else{e=x[(((y[g|0]^e)&255)<<2)+62496>>2]^e>>>8;e=e>>>8^x[(((e^y[g+1|0])&255)<<2)+62496>>2];e=e>>>8^x[(((e^y[g+2|0])&255)<<2)+62496>>2];e=e>>>8^x[(((e^y[g+3|0])&255)<<2)+62496>>2];h=h-4|0;g=g+4|0;continue}break}x[m+1092>>2]=R;x[m+1088>>2]=d;x[m+1104>>2]=H;x[m+1100>>2]=x[O>>2]+_;E=hb-16|0;hb=E;g=-2;q=m+1088|0;e:{if(!q){break e}i=x[q+28>>2];if(!i){break e}$=x[q+4>>2];x[i+11e3>>2]=0;f:{if(x[i+43780>>2]<0){break f}if(x[i+11004>>2]){break e}h=x[i+11008>>2];g=0;x[i+11004>>2]=0;d=x[i+10996>>2];if(!d){U=(h|0)>0?11:10;G=i+11012|0;e=x[q+4>>2];k=x[i+10992>>2];while(1){x[E+12>>2]=e;x[E+8>>2]=32768-k;C=x[q>>2];d=0;e=0;o=0;I=0;S=0;Q=0;V=0;X=hb-144|0;hb=X;g:{h:{J=k+G|0;if(J>>>0>=G>>>0){F=x[E+8>>2]+J|0;s=F-G|0;Y=(G^-1)+F|0;if(!(s&Y)){break h}}x[E+8>>2]=0;x[E+12>>2]=0;n=-3;break g}r=x[E+12>>2];B=r+C|0;K=x[i+60>>2];t=x[i+40>>2];g=x[i+36>>2];u=x[i+32>>2];h=x[i+56>>2];f=x[i+4>>2];n=-1;j=C;l=J;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{k=x[i>>2];switch(k|0){case 36:break k;case 39:break n;case 10:break o;case 35:break p;case 17:break q;case 21:break r;case 34:break s;case 42:break w;case 41:break x;case 53:break y;case 52:break z;case 51:break A;case 38:break B;case 27:break C;case 26:break D;case 25:break E;case 24:break F;case 23:break G;case 18:break H;case 16:break I;case 14:break J;case 11:break K;case 9:break L;case 7:break M;case 6:break N;case 3:break O;case 37:break P;case 32:break Q;case 5:break R;case 2:break S;case 1:break T;case 0:break U;default:break j}}x[i+28>>2]=1;h=0;x[i+8>>2]=0;x[i+12>>2]=0;x[i+16>>2]=1;t=0;g=0;u=0;f=0;if(U&1){break T}break v}if((r|0)<=0){x[i>>2]=1;break m}x[i+8>>2]=y[C|0];j=C+1|0}if(j>>>0>=B>>>0){x[i>>2]=2;n=1;break i}g=y[j|0];x[i+12>>2]=g;r=1;e=x[i+8>>2];if(!(((g|e<<8)>>>0)%31|g&32)){r=(e&15)!=8}j=j+1|0;k=36;g=256<<(e>>>4);if(g>>>0>32768|g>>>0>s>>>0){break l}g=0;if(r){break l}break v}if((r|0)<=0){x[i>>2]=5;break m}S=f+8|0;j=C+1|0;h=y[C|0]<<f|h;d=2;break v}if((r|0)<=0){x[i>>2]=32;break m}f=f+8|0;j=C+1|0;break u}k=37;break k}d=1;break v}d=4;break v}d=3;break v}d=7;break v}d=9;break v}d=10;break v}d=11;break v}d=12;break v}d=13;break v}d=14;break v}d=15;break v}d=16;break v}d=17;break v}d=8;break v}d=5;break v}d=6;break v}d=18;break v}k=2;break t}k=1;break t}V:while(1){W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{switch(d|0){case 0:if(f>>>0>2){break Ba}d=1;continue;case 3:break za;case 2:break Aa;case 1:break Ca;case 9:break fa;case 10:break ga;case 11:break ha;case 12:break ia;case 13:break ja;case 14:break ka;case 15:break la;case 16:break ma;case 17:break na;case 8:break ta;case 7:break ua;case 6:break va;case 5:break wa;case 4:break ya;default:break oa}}while(1){if(j>>>0>=B>>>0){x[i>>2]=3;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}}d=h&7;x[i+20>>2]=d;k=d>>>1|0;x[i+24>>2]=k;f=f-3|0;h=h>>>3|0;if(d>>>0>=2){break sa}S=f;break pa}f=S&-8;h=h>>>(S&7)|0;g=0;d=0;break ra}if(j>>>0<B>>>0){break xa}x[i>>2]=7;n=1;break i}while(1){if(j>>>0>=B>>>0){x[i>>2]=6;n=1;break i}h=y[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}d=1;break ra}v[(g+i|0)+10528|0]=y[j|0];j=j+1|0;d=2;break ra}while(1){if(j>>>0>=B>>>0){x[i>>2]=51;n=1;break i}h=y[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}break Z}if(l>>>0<F>>>0){v[l|0]=u;g=g-1|0;l=l+1|0;break _}n=2;k=52;break k}if(l>>>0<F>>>0){break qa}n=2;k=9;break k}if(j>>>0<B>>>0){d=F-l|0;e=B-j|0;d=d>>>0<e>>>0?d:e;d=d>>>0<g>>>0?d:g;g=g-d|0;l=vc(l,j,d)+d|0;j=d+j|0;break Y}x[i>>2]=38;n=1;break i}e=0;Da:{switch(k-1|0){case 0:x[i+44>>2]=288;x[i+48>>2]=32;d=i+3552|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3560|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3568|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3576|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i- -64|0;k=0;while(1){e=144;if((k|0)==144){while(1){k=256;if((e|0)==256){while(1){e=280;if((k|0)==280){while(1){if((e|0)==288){break ca}v[d|0]=8;e=e+1|0;d=d+1|0;continue}}else{v[d|0]=7;k=k+1|0;d=d+1|0;continue}}}else{v[d|0]=9;e=e+1|0;d=d+1|0;continue}}}else{v[d|0]=8;k=k+1|0;d=d+1|0;continue}};case 2:break o;default:break Da}}d=0;break ea}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{switch(d|0){case 0:if(g>>>0>3){break Ha}if(!f){f=0;d=3;continue V}if(f>>>0>7){break Fa}d=4;continue V;case 1:v[(g+i|0)+10528|0]=h;f=f-8|0;h=h>>>8|0;break Ea;default:break Ia}}g=g+1|0;break Ga}g=z[i+10528>>1];if((g|0)==(z[i+10530>>1]^65535)){break _}break n}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(l>>>0>=F>>>0){n=2;k=53;break k}v[l|0]=y[(K-u&Y)+G|0];l=l+1|0;K=K+1|0;d=7;break $}while(1){if(j>>>0>=B>>>0){x[i>>2]=27;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(t>>>0>f>>>0){continue}break}d=6;break $}if(j>>>0>=B>>>0){x[i>>2]=26;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=4;if(f>>>0<15){break $}d=5;break $}while(1){if(j>>>0>=B>>>0){x[i>>2]=25;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(t>>>0>f>>>0){continue}break}d=3;break $}if(l>>>0>=F>>>0){n=2;k=24;break k}v[l|0]=g;l=l+1|0;break aa}if(j>>>0>=B>>>0){x[i>>2]=23;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=0;if(f>>>0<15){break $}d=1;break $}while(1){if(j>>>0>=B>>>0){x[i>>2]=18;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(t>>>0>f>>>0){continue}break}V=u-16|0;d=3;break ba}if(j>>>0>=B>>>0){x[i>>2]=16;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=1;if(f>>>0<15){break ba}d=2;break ba}while(1){if(j>>>0>=B>>>0){x[i>>2]=14;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}d=1;break da}d=g+21483|0;while(1){if(j>>>0>=B>>>0){x[i>>2]=11;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;I=v[d|0];if(f>>>0<I>>>0){continue}break}e=g;d=1}while(1){Ja:{Ka:{La:{if(!d){if(e>>>0>2){break La}g=e;I=v[e+21483|0];if(I>>>0<=f>>>0){break Ja}d=9;continue V}g=e<<2;x[(g+i|0)+44>>2]=x[g+64032>>2]+((-1<<I^-1)&h);e=e+1|0;f=f-I|0;h=h>>>I|0;break Ka}g=0;Zb(i+7040|0,0,288);d=0;break da}d=0;continue}d=1;continue}}while(1){Ma:{Na:{Oa:{if(!d){if(A[i+52>>2]<=g>>>0){break Oa}if(f>>>0>2){break Ma}d=10;continue V}v[(y[g+64048|0]+i|0)+7040|0]=h&7;g=g+1|0;f=f-3|0;h=h>>>3|0;break Na}x[i+52>>2]=19;break ca}d=0;continue}d=1;continue}}Q=x[i+24>>2];d=0}while(1){Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{switch(d|0){case 0:d=0;if((Q|0)<0){break aa}L=Zb(X,0,64);e=D(Q,3488)+i|0;Zb(e+352|0,0,3200);M=e- -64|0;s=x[i+24>>2];e=x[((s<<2)+i|0)+44>>2];while(1){if((d|0)!=(e|0)){k=(y[d+M|0]<<2)+L|0;x[k>>2]=x[k>>2]+1;d=d+1|0;continue}break};x[L+64>>2]=0;x[L+68>>2]=0;k=0;d=1;e=0;while(1){if((d|0)!=16){r=d<<2;d=d+1|0;r=x[r+L>>2];e=r+e<<1;x[(L- -64|0)+(d<<2)>>2]=e;k=k+r|0;continue}break};N=0;r=-1;if((e|0)!=65536&k>>>0>=2){break p}while(1){if(A[((s<<2)+i|0)+44>>2]>N>>>0){s=y[M+N|0];Ya:{if(!s){break Ya}d=(L- -64|0)+(s<<2)|0;k=x[d>>2];x[d>>2]=k+1;d=0;e=s;while(1){if(e){d=k&1|d<<1;k=k>>>1|0;e=e-1|0;continue}break}if(s>>>0<=10){e=1<<s;k=s<<9|N;while(1){if(d>>>0>1023){break Ya}w[((d<<1)+M|0)+288>>1]=k;d=d+e|0;continue}}k=((d&1023)<<1)+M|0;e=w[k+288>>1];Za:{if(e){k=r;r=e;break Za}w[k+288>>1]=r;k=r-2|0}d=d>>>9|0;while(1){d=d>>>1|0;e=d&1;if(s>>>0>=12){e=((e+(r^-1)<<1)+M|0)+2336|0;r=w[e>>1];if(!r){w[e>>1]=k;r=k;k=k-2|0}s=s-1|0;continue}break}w[((e+(r^-1)<<1)+M|0)+2336>>1]=N;r=k}N=N+1|0;s=x[i+24>>2];continue}break};d=0;if((s|0)!=2){break Qa}break Ua;case 1:d=w[(((h&1023)<<1)+i|0)+7328>>1];_a:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>f>>>0){break _a}break Ta}if(f>>>0<11){break _a}e=10;while(1){d=w[(((h>>>e&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break Ta}}d=11;continue V;case 2:e=w[(((h&1023)<<1)+i|0)+7328>>1];if((e|0)>=0){break Wa}d=10;while(1){k=h>>>d|0;d=d+1|0;e=w[(((k&1)+(e^-1)<<1)+i|0)+9376>>1];if((e|0)<0){continue}break};u=e&65535;break Va;default:break Xa}}d=v[V+17692|0]+((-1<<t^-1)&h)|0;f=f-t|0;h=h>>>t|0;e=g+i|0;Zb(e+10532|0,(u|0)==16?y[e+10531|0]:0,d);d=d+g|0;break Ua}d=e>>>9|0;u=e&511}f=f-d|0;h=h>>>d|0;if(u>>>0>15){break Sa}v[(g+i|0)+10532|0]=u;d=g+1|0}e=x[i+48>>2];g=x[i+44>>2];k=e+g|0;if(k>>>0<=d>>>0){break Ra}if(f>>>0<=14){if((B-j|0)<=1){g=d;d=1;continue}h=y[j|0]<<f|y[j+1|0]<<f+8|h;j=j+2|0;f=f+16|0}g=d}d=2;continue}if(!((u|0)!=16|g)){g=0;u=16;break q}V=u-16|0;t=v[u+21458|0];if(t>>>0<=f>>>0){break Pa}d=12;continue V}if((d|0)!=(k|0)){g=d;break r}k=i+10532|0;vc(i- -64|0,k,g);vc(i+3552|0,g+k|0,e);s=x[i+24>>2];g=d}Q=s-1|0;x[i+24>>2]=Q;d=0;continue}d=3;continue}}o=h;d=2}$a:while(1){ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{switch(d|0){case 0:d=w[(((h&1023)<<1)+i|0)+352>>1];pb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>f>>>0){break pb}break ab}if(f>>>0<11){break pb}e=10;while(1){d=w[(((h>>>e&1)+(d^-1)<<1)+i|0)+2400>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break ab}}d=13;continue V;case 1:e=w[(((h&1023)<<1)+i|0)+352>>1];if((e|0)>=0){break nb}d=10;while(1){g=h>>>d|0;d=d+1|0;e=w[(((g&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break};g=e&65535;break mb;case 3:break db;case 4:break eb;case 5:break ib;case 6:break jb;case 2:break ob;default:break kb}}while(1){d=B-j|0;if(!((F-l|0)>1&(d|0)>=4)){if(f>>>0>14){h=o;break ab}if((d|0)<=1){h=o;d=0;continue $a}h=y[j|0]<<f|y[j+1|0]<<f+8|o;f=f+16|0;j=j+2|0;break ab}if(f>>>0>14){k=j}else{o=(y[j|0]|y[j+1|0]<<8)<<f|o;f=f+16|0;k=j+2|0}g=w[(((o&1023)<<1)+i|0)+352>>1];qb:{if((g|0)<0){d=10;while(1){h=o>>>d|0;d=d+1|0;g=w[(((h&1)+(g^-1)<<1)+i|0)+2400>>1];if((g|0)<0){continue}break}g=g&65535;break qb}d=g>>>9|0}f=f-d|0;h=o>>>d|0;if(g&256){j=k;break lb}if(!(f>>>0>14)){h=(y[k|0]|y[k+1|0]<<8)<<f|h;k=k+2|0;f=f+16|0}s=f;j=k;e=w[(((h&1023)<<1)+i|0)+352>>1];rb:{if((e|0)<0){d=10;while(1){o=h>>>d|0;d=d+1|0;e=w[(((o&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break}e=e&65535;break rb}d=e>>>9|0}v[l|0]=g;f=s-d|0;o=h>>>d|0;if(!(e&256)){v[l+1|0]=e;l=l+2|0;continue}break}l=l+1|0;h=o;g=e;break lb}d=e>>>9|0;g=e&511}f=f-d|0;h=h>>>d|0;if(g>>>0>255){break lb}d=14;continue V}e=g&511;g=256;if((e|0)==256){break X}d=e-257<<2;g=x[d+63520>>2];t=0;if(e-285>>>0<4294967276){break cb}t=x[d+63648>>2];if(t>>>0>f>>>0){d=15;continue V}d=3;continue}if(!g){o=h;g=-1;break gb}g=g-1|0;d=18;continue V}f=f-t|0;o=h>>>t|0;u=((-1<<t^-1)&h)+u|0;break hb}e=w[(((h&1023)<<1)+i|0)+3840>>1];sb:{if((e|0)<0){d=10;while(1){k=h>>>d|0;d=d+1|0;e=w[(((k&1)+(e^-1)<<1)+i|0)+5888>>1];if((e|0)<0){continue}break}e=e&65535;break sb}d=e>>>9|0;e=e&511}f=f-d|0;h=h>>>d|0;d=e<<2;u=x[d+63776>>2];t=0;if(e-30>>>0<4294967270){o=h;break hb}t=x[d+63904>>2];if(t>>>0<=f>>>0){break fb}d=17;continue V}K=l-G|0;d=(K-u&Y)+G|0;if((d>>>0<l>>>0?l:d)+g>>>0>F>>>0){h=o;d=7;continue}while(1){if(g>>>0>=3){v[l|0]=y[d|0];v[l+1|0]=y[d+1|0];v[l+2|0]=y[d+2|0];g=g-3|0;d=d+3|0;l=l+3|0;continue}break}if(!g){g=0;break gb}v[l|0]=y[d|0];if((g|0)!=1){v[l+1|0]=y[d+1|0]}l=g+l|0}d=2;continue}d=6;continue}d=w[(((h&1023)<<1)+i|0)+3840>>1];tb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>f>>>0){break tb}break bb}if(f>>>0<11){break tb}e=10;while(1){d=w[(((h>>>e&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break bb}}d=16;continue V}f=f-t|0;g=((-1<<t^-1)&h)+g|0;h=h>>>t|0}if(f>>>0>14){break bb}if((B-j|0)<=1){d=4;continue}h=y[j|0]<<f|y[j+1|0]<<f+8|h;f=f+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!g|!f){break Y}if(f>>>0>7){break Z}d=5;continue}f=f-8|0;u=h&255;h=h>>>8|0;d=6;continue}if(g){break W}g=0}if(v[i+20|0]&1){break u}d=0;continue}d=7;continue}}h=0;d=f>>>3|0;e=j-C|0;e=e>>>0<=j>>>0?e:0;d=d>>>0<e>>>0?d:e;if((f&-8)==d<<3){j=j-d|0;e=0;d=0;f=0;if(!(U&1)){break s}k=0;break t}aa(6800,13043,2797,6810);p()}while(1){ub:{vb:{wb:{xb:{yb:{zb:{switch(k|0){case 0:if(e>>>0>3){g=e;f=d;break s}f=0;if(d){break yb}g=e;k=1;continue;case 1:break zb;default:break xb}}if(j>>>0<B>>>0){break vb}x[i>>2]=42;n=1;break i}g=e;f=d;if(d>>>0>7){break wb}k=2;continue}while(1){if(j>>>0>=B>>>0){x[i>>2]=41;n=1;break i}h=y[j|0]<<f|h;e=f>>>0>4294967287;j=j+1|0;d=f+8|0;f=d;if(e){continue}break}e=g}k=h&255;h=h>>>8|0;d=d-8|0;break ub}k=y[j|0];j=j+1|0;e=g;d=f}x[i+16>>2]=x[i+16>>2]<<8|k;e=e+1|0;k=0;continue}}n=0;k=34;break k}k=21;break k}k=17;break k}k=35;break k}k=10;break k}k=39;break k}n=1;break i}g=1}x[i>>2]=k}d=f>>>3|0;e=j-C|0;e=e>>>0<=j>>>0?e:0;d=d>>>0<e>>>0?d:e;j=j-d|0;f=f-(d<<3)|0}x[i+4>>2]=f;x[i+60>>2]=K;x[i+40>>2]=t;x[i+36>>2]=g;x[i+32>>2]=u;x[i+56>>2]=(((f&63)>>>0<32?-1<<f:0)^-1)&h;x[E+12>>2]=j-C;h=l-J|0;x[E+8>>2]=h;if((n|0)<0){break g}f=(h>>>0)%5552|0;g=x[i+28>>2];e=g>>>16|0;k=g&65535;while(1){j=0;if(h){d=J;while(1){if((j|7)>>>0<f>>>0){g=y[d|0]+k|0;o=g+y[d+1|0]|0;r=o+y[d+2|0]|0;s=r+y[d+3|0]|0;l=s+y[d+4|0]|0;u=l+y[d+5|0]|0;C=u+y[d+6|0]|0;k=C+y[d+7|0]|0;e=k+(C+(u+(l+(s+(r+(o+(e+g|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;j=j+8|0;continue}break}j=f&8184;while(1){if((f|0)!=(j|0)){j=j+1|0;k=y[d|0]+k|0;e=k+e|0;d=d+1|0;continue}break}h=h-f|0;e=(e>>>0)%65521|0;k=(k>>>0)%65521|0;J=f+J|0;f=5552;continue}break}g=e<<16|k;x[i+28>>2]=g;if(n){break g}n=0;if(!(U&1)){break g}n=(g|0)!=x[i+16>>2]?-2:0}hb=X+144|0;x[i+43780>>2]=n;g=x[E+12>>2];x[q>>2]=g+x[q>>2];x[q+4>>2]=x[q+4>>2]-g;x[q+8>>2]=g+x[q+8>>2];x[q+48>>2]=x[i+28>>2];g=x[E+8>>2];x[i+10996>>2]=g;d=x[q+16>>2];d=d>>>0>g>>>0?g:d;vc(x[q+12>>2],x[i+10992>>2]+G|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];h=x[i+10996>>2];x[i+10996>>2]=h-d;k=d+x[i+10992>>2]&32767;x[i+10992>>2]=k;if((n|0)<0){break f}if(!((n|0)!=1|$)){g=-5;break e}if(n){g=0;e=x[q+4>>2];if(!e|!x[q+16>>2]){break e}if((d|0)==(h|0)){continue}break e}break}g=(d|0)==(h|0);break e}h=x[q+16>>2];d=d>>>0<h>>>0?d:h;vc(x[q+12>>2],(x[i+10992>>2]+i|0)+11012|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];h=x[i+10996>>2];x[i+10996>>2]=h-d;x[i+10992>>2]=d+x[i+10992>>2]&32767;if(x[i+43780>>2]){break e}g=(d|0)==(h|0);break e}g=-3}hb=E+16|0;h=x[m+1084>>2]-R|0;x[m+1084>>2]=h;d=H+_|0;H=x[m+1104>>2];_=d-H|0;continue}break}b=m+1088|0;Ab:{if(!b){break Ab}d=x[b+28>>2];if(!d){break Ab}mb[x[b+36>>2]](x[b+40>>2],d);x[b+28>>2]=0}h=0;Bb:{Cb:{if(!(x[m+1156>>2]!=(Z|0)|H|(g|0)!=1)){ke(m+24|0,x[O>>2],x[O+4>>2]);b=Yd(m+16|0);x[23604]=0;g=x[b+4>>2];x[m+8>>2]=x[b>>2];x[m+12>>2]=g;b=rg(489,m+48|0,x[m+24>>2],x[m+28>>2],m+8|0);g=x[23604];x[23604]=0;if((g|0)==1){break Cb}x[23604]=0;h=W(823,a|0,b|0,c|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break Bb}yb(b)}fc(O);break a}a=P()|0;break c}a=P()|0;yb(b);break c}a=P()|0}fc(O);T(a|0);p()}hb=m+1168|0;return h|0}function Dfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=E(0),C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=E(0),M=0,N=0,O=E(0),Q=0,R=E(0),U=0,X=0,Y=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=E(0);n=hb-96|0;hb=n;xc(c);a:{while(1){b:{if(!Qb(x[c>>2],x[c+8>>2],4)){break b}d=n+72|0;g=hb-16|0;hb=g;c:{if(!Qb(x[c>>2],x[c+8>>2],3)){F=0;while(1){if((F|0)!=3){qg(d+F|0);F=F+1|0;continue}break}break c}_u(g+8|0,d);qd(g,c,x[g+8>>2],x[g+12>>2])}hb=g+16|0;d:{e:{if(!Rb(d,14888,3)){d=n+24|0;g=hb-16|0;hb=g;f:{if(!Qb(x[c>>2],x[c+8>>2],7)){F=0;while(1){if((F|0)!=7){qg(d+F|0);F=F+1|0;continue}break}break f}po(g+8|0,d);qd(g,c,x[g+8>>2],x[g+12>>2])}hb=g+16|0;F=0;g=3;while(1){if((g|0)==7){break d}d=v[(n+24|0)+g|0];if((d|0)<0){break e}g=g+1|0;F=d&255|F<<7;continue}}g:{if(Rb(n+72|0,14058,3)){break g}if(!CR(c,13429)){break g}bc(c,kg(c)+16|0);continue}if(!Rb(n+72|0,30590,3)){continue}if(!Rb(n+72|0,30594,3)){continue}if(!y[n+72|0]){hg(c,2);continue}if(jP(n+72|0)){break b}}g=0;break a}bc(c,F);continue}break}xc(c);g=n+72|0;AA(g,c);U=x[n+72>>2];fa=xe(g);M=Sb(n+56|0);x[23604]=0;aa=S(523,n+48|0)|0;c=x[23604];x[23604]=0;h:{i:{j:{if((c|0)!=1){Qy(Zb(x[aa>>2],0,6668));x[n+40>>2]=0;x[n+44>>2]=0;x[n+32>>2]=0;x[n+36>>2]=0;x[n+24>>2]=0;x[n+28>>2]=0;x[23604]=0;ba=S(524,n+8|0)|0;c=x[23604];x[23604]=0;k:{if((c|0)!=1){F=0;c=0;while(1){G=x[aa>>2];j=fa;e=Ec(U,$);X=x[ba>>2];d=0;m=0;r=hb-17168|0;hb=r;x[r+17164>>2]=0;l:{m:{n:{if(y[G+6152|0]!=255|(e|0)<5){break n}if(!Zo(G+6152|0,j)){break n}g=Rw(y[j+1|0],y[j+2|0],x[G+6148>>2])+Yo(j)|0;x[r+17164>>2]=g;if((e|0)==(g|0)){g=e;break m}o:{if((e|0)>=(g+4|0)){if(Zo(j,g+j|0)){break o}}x[r+17164>>2]=0;break n}if(g){break m}}h=j;C=Zb(G,0,6668)+6148|0;I=r+17164|0;s=e-4|0;k=(s|0)>0?s:0;while(1){p:{q:{r:{s:{if((k|0)==(m|0)){m=e;break s}if(!TH(h)){break q}i=Rw(y[h+1|0],y[h+2|0],x[C>>2]);g=i+Yo(h)|0;f=4;o=m+4|0;t:{while(1){if(!(f>>>0>2303|i)){if((s|0)<=((f<<1)+m|0)){break t}i=0;q=f+h|0;u:{if(!Zo(h,q)){break u}l=f-Yo(h)|0;u=Yo(q)+l|0;if((e|0)<(u+(f+o|0)|0)){break u}if(!Zo(h,q+u|0)){break u}x[C>>2]=l;i=l;g=f}f=f+1|0;continue}break}if(!i|(e|0)<(g+m|0)){break t}q=e-m|0;f=0;o=0;while(1){v:{w:{if((o|0)!=10){l=(o|0)!=0;K=f;f=f+h|0;f=(K+Rw(y[f+1|0],y[f+2|0],i)|0)+Yo(f)|0;if((q|0)<(f+4|0)){break v}if(Zo(h,f+h|0)){break w}l=0}else{l=1}break v}o=o+1|0;continue}break}if(!l){break t}d=g;break s}if((e|0)!=(g|0)|m){break r}m=0;d=e}x[I>>2]=d;d=m;break p}x[C>>2]=0}h=h+1|0;m=m+1|0;continue}break}g=x[r+17164>>2];if((e|0)>=(d+g|0)?g:0){break m}x[n+24>>2]=d;o=0;break l}u=d+j|0;x[G+6152>>2]=y[u|0]|y[u+1|0]<<8|(y[u+2|0]<<16|y[u+3|0]<<24);x[n+28>>2]=d;x[n+24>>2]=d+g;x[n+32>>2]=y[u+3|0]>191?1:2;ra=n,sa=WH(y[u+1|0],y[u+2|0]),x[ra+36>>2]=sa;x[n+40>>2]=4-(y[u+1|0]>>>1&3);ra=n,sa=Qw(y[u+1|0],y[u+2|0]),x[ra+44>>2]=sa;if(!X){o=Pw(y[u+1|0]);break l}VH(r+17152|0,u+4|0,g-4|0);if(!(v[u+1|0]&1)){ae(r+17152|0,16)}x:{if(x[n+40>>2]==3){o=0;d=r+17152|0;ja=r+3740|0;g=ja;h=0;e=y[u+1|0];f=D((e>>>3&1)+(e>>>4&1)|0,3)+(y[u+2|0]>>>2&3)|0;f=f-((f|0)!=0)|0;m=y[u+3|0]>191?1:2;y:{if(e&8){i=ae(d,9);m=m<<1;h=ae(d,m+7|0);break y}i=ae(d,m|8)>>>m|0}e=D(f,40);C=e+64368|0;s=e+64688|0;q=D(f,23)+64176|0;j=-1;l=0;z:{while(1){e=y[u+3|0];I=ae(d,12);w[g+4>>1]=I;f=ae(d,9);w[g+6>>1]=f;if((f&65535)>>>0>288){break z}f=e>>>0>191?h<<4:h;ra=g,sa=ae(d,8),v[ra+10|0]=sa;e=ae(d,y[u+1|0]&8?4:9);v[g+13|0]=22;v[g+14|0]=0;x[g>>2]=q;w[g+8>>1]=e;A:{if(ae(d,1)){e=ae(d,2);v[g+11|0]=e;if(!(e&255)){break z}e=ae(d,1);w[g+18>>1]=65287;v[g+12|0]=e;if(y[g+11|0]==2){B:{if(!(e&255)){x[g>>2]=C;v[g+18|0]=8;h=0;e=39;break B}x[g>>2]=s;h=y[u+1|0]&8?8:6;e=30}v[g+14|0]=e;v[g+13|0]=h;f=f&3855}e=ae(d,10);ra=g,sa=ae(d,3),v[ra+21|0]=sa;ra=g,sa=ae(d,3),v[ra+22|0]=sa;ra=g,sa=ae(d,3),v[ra+23|0]=sa;h=e<<5;break A}v[g+11|0]=0;v[g+12|0]=0;h=ae(d,15);ra=g,sa=ae(d,4),v[ra+18|0]=sa;e=ae(d,3);v[g+20|0]=255;v[g+19|0]=e}v[g+17|0]=h&31;v[g+15|0]=h>>>10;v[g+16|0]=h>>>5&31;l=(I&65535)+l|0;C:{if(y[u+1|0]&8){e=ae(d,1);break C}e=z[g+8>>1]>499}v[g+24|0]=e;ra=g,sa=ae(d,1),v[ra+25|0]=sa;e=ae(d,1);v[g+27|0]=f>>>12&15;v[g+26|0]=e;g=g+28|0;h=f<<4;m=m-1|0;if(m){continue}break}j=(x[d+4>>2]+l|0)>(x[d+8>>2]+(i<<3)|0)?-1:i}if(!((j|0)<0|x[r+17156>>2]>x[r+17160>>2])){g=r+17152|0;f=x[g+4>>2];m=x[g+8>>2];h=r+912|0;d=x[G+6144>>2];e=d-j|0;d=(d|0)<(j|0)?d:j;e=vc(h+12|0,(((e|0)>0?e:0)+G|0)+6156|0,d);i=x[g>>2]+(x[g+4>>2]/8|0)|0;g=(m-f|0)/8|0;vc(d+e|0,i,g);VH(h,e,d+g|0);D:{g=x[G+6144>>2]>=(j|0);if(!g){break D}ma=G+2304|0;na=r+8620|0;oa=r+3852|0;while(1){if((y[u+1|0]&8?2:1)>>>0<=o>>>0){break D}pa=Zb(oa,0,4608);e=x[n+32>>2];m=D(D(e,o),28)+ja|0;d=0;ka=(e|0)>0?e:0;C=r+912|0;I=C+7548|0;Y=G+6152|0;while(1){if((d|0)!=(ka|0)){j=D(d,28)+m|0;K=z[j+4>>1];Q=x[C+4>>2];t=(C+D(d,39)|0)+16156|0;e=I;s=d;f=hb-48|0;hb=f;d=j;J=y[d+25|0];H=D(!y[d+13|0]+(y[d+14|0]!=0)|0,28)+65008|0;E:{if(y[Y+1|0]&8){i=y[d+27|0];j=y[z[d+8>>1]+65104|0];h=j&3;v[f+47|0]=h;v[f+46|0]=h;j=j>>>2|0;v[f+45|0]=j;v[f+44|0]=j;break E}j=(y[Y+3|0]&16)>>>4&(s|0)!=0;k=j?12:0;h=z[d+8>>1]>>>j|0;while(1){if((h|0)>=0){i=3;j=1;while(1){if((i|0)>=0){l=y[(i+k|0)+65120|0];v[(f+44|0)+i|0]=((h|0)/(j|0)|0)%(l|0);i=i-1|0;j=D(j,l);continue}break}k=k+4|0;h=h-j|0;continue}break}H=k+H|0;i=-16}j=f;ca=f+44|0;h=0;while(1){F:{G:{H:{if((h|0)==4){break H}q=y[h+H|0];if(!q){break H}if(i&8){vc(j,t,q);break G}k=y[h+ca|0];if(!k){Zb(j,0,q);Zb(t,0,q);break G}ea=(i|0)>=0?-1:-1<<k^-1;l=0;while(1){if((l|0)==(q|0)){break G}N=ae(C,k);v[l+t|0]=(N|0)==(ea|0)?-1:N;v[j+l|0]=N;l=l+1|0;continue}}v[j+2|0]=0;v[j|0]=0;v[j+1|0]=0;break F}i=i<<1;h=h+1|0;j=j+q|0;t=q+t|0;continue}break}I:{j=y[d+14|0];if(j){h=2-J|0;l=y[d+23|0]<<h;q=y[d+22|0]<<h;k=y[d+21|0]<<h;t=y[d+13|0];i=0;while(1){if(i>>>0>=j>>>0){break I}h=f+(i+t|0)|0;v[h|0]=k+y[h|0];v[h+1|0]=q+y[h+1|0];v[h+2|0]=l+y[h+2|0];i=i+3|0;continue}}if(!y[d+24|0]){break I}i=0;while(1){if((i|0)==10){break I}h=f+i|0;v[h+11|0]=y[h+11|0]+y[i+65144|0];i=i+1|0;continue}}h=J+1|0;i=0;A=Ow(E(2048),((((y[Y+3|0]&224)==96)<<1)-y[d+10|0]|0)+258|0);while(1){if(y[d+13|0]+(j&255)>>>0>i>>>0){ra=e+(i<<2)|0,ta=Ow(A,y[f+i|0]<<h),B[ra>>2]=ta;i=i+1|0;j=y[d+14|0];continue}break}hb=f+48|0;l=(C+D(s,2304)|0)+2940|0;i=e;ca=K+Q|0;A=E(0);j=x[C+4>>2];e=x[C>>2]+((j|0)/8|0)|0;f=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);f=(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))<<(j&7);k=j|-8;t=e+4|0;q=d;H=x[d>>2];J=z[d+6>>1];e=0;while(1){J:{K:{if((J|0)>0){j=e+1|0;e=e+q|0;d=y[e+15|0];ea=(w[(d<<1)+69568>>1]<<1)+65184|0;N=y[e+18|0];if(d>>>0>=16){ga=y[d+69632|0];qa=32-ga|0;while(1){ha=y[H|0]>>>1|0;ia=(J|0)<(ha|0)?J:ha;A=B[i>>2];while(1){e=f>>>27|0;d=5;while(1){e=w[ea+(e<<1)>>1];if((e|0)<0){f=f<<d;h=e&7;e=(f>>>32-h|0)-(e>>3)|0;k=d+k|0;d=h;continue}break}h=e&65535;d=h>>>8|0;k=d+k|0;f=f<<d;d=0;while(1){if((d|0)!=2){K=h&15;L:{if((K|0)==15){k=k+ga|0;e=f<<ga;while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}L=A;K=(f>>>qa|0)+15|0;f=K;M:{if((f|0)<=128){R=B[(f<<2)+69728>>2];break M}la=f>>>0<1024;f=la?f<<3:f;Q=f<<1&64;O=E(E((f&63)-Q|0)/E(Q+(f&-64)|0));R=E((la?E(16):E(256))*E(E(E(O*E(E(O*E(.2222222238779068))+E(1.3333333730697632)))+E(1))*B[(f+Q>>6<<2)+69728>>2]))}L=E(E(L*R)*E(e>>31|1));break L}e=f;L=E(A*B[(((e>>>27&16|K)^16)<<2)+69664>>2])}B[l>>2]=L;h=h>>>4|0;l=l+4|0;d=d+1|0;f=(K|0)!=0;k=f+k|0;f=e<<f;continue}break}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}ia=ia-1|0;if(ia){continue}break}i=i+4|0;H=H+1|0;J=J-ha|0;if((J|0)<=0){break K}d=(N|0)>0;N=N-1|0;if(d){continue}break}break K}while(1){Q=y[H|0]>>>1|0;K=(J|0)<(Q|0)?J:Q;A=B[i>>2];while(1){e=f>>>27|0;d=5;while(1){e=w[ea+(e<<1)>>1];if((e|0)<0){f=f<<d;h=e&7;e=(f>>>32-h|0)-(e>>3)|0;k=d+k|0;d=h;continue}break}d=e&65535;e=d>>>8|0;k=e+k|0;f=f<<e;e=0;while(1){if((e|0)!=2){h=d&15;B[l>>2]=A*B[(((h|f>>>27&16)^16)<<2)+69664>>2];d=d>>>4|0;l=l+4|0;e=e+1|0;h=(h|0)!=0;k=h+k|0;f=f<<h;continue}break}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}K=K-1|0;if(K){continue}break}i=i+4|0;H=H+1|0;J=J-Q|0;if((J|0)<=0){break K}d=(N|0)>0;N=N-1|0;if(d){continue}break}break K}d=1-J|0;while(1){N:{j=y[q+26|0]?69552:69520;e=y[j+(f>>>28|0)|0];if(!(e&8)){e=y[j+((f<<4>>>32-(e&3))+(e>>>3)|0)|0]}j=e&7;k=j+k|0;if((ca|0)<((k+(t-x[C>>2]<<3)|0)-24|0)){break N}d=d-1|0;if(!d){d=y[H|0];if(d>>>0<2){break N}H=H+1|0;A=B[i>>2];i=i+4|0;d=d>>>1|0}f=f<<j;if(e>>>0>=128){B[l>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}if(e&64){B[l+4>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}d=d-1|0;if(!d){d=y[H|0];if(d>>>0<2){break N}H=H+1|0;A=B[i>>2];i=i+4|0;d=d>>>1|0}if(e&32){B[l+8>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}if(e&16){B[l+12>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}l=l+16|0;continue}break}x[C+4>>2]=ca;break J}e=j;continue}break}d=s+1|0;continue}break}d=y[G+6155|0];O:{if(d&16){s=C+16195|0;d=0;l=hb-16|0;hb=l;j=C+2940|0;i=j+2304|0;I=x[m>>2];k=y[m+14|0];t=y[m+13|0];q=k+t|0;e=l+4|0;x[e+8>>2]=-1;x[e>>2]=-1;x[e+4>>2]=-1;while(1){if((d|0)!=(q|0)){H=d+I|0;h=y[H|0];f=0;P:{while(1){if(f>>>0>=h>>>0){break P}J=f<<2;if(B[J+i>>2]==E(0)){f=f+2|0;if(B[(J|4)+i>>2]==E(0)){continue}}break}x[e+((d>>>0)%3<<2)>>2]=d;h=y[H|0]}d=d+1|0;i=(h<<2)+i|0;continue}break}if(t){d=x[l+4>>2];e=x[l+8>>2];d=(d|0)>(e|0)?d:e;e=x[l+12>>2];d=(d|0)>(e|0)?d:e;x[l+12>>2]=d;x[l+8>>2]=d;x[l+4>>2]=d}e=k?3:1;h=q-e|0;d=0;while(1){if((d|0)!=(e|0)){i=d+h|0;f=i-e|0;if((f|0)<=x[(l+4|0)+(d<<2)>>2]){f=y[Y+1|0]<<28>>31&3}else{f=y[f+s|0]}v[i+s|0]=f;d=d+1|0;continue}break}h=x[m>>2];q=l+4|0;I=w[m+36>>1]&1;i=0;k=y[Y+1|0]&8?7:64;while(1){t=h+i|0;e=y[t|0];if(e){f=y[Y+3|0]&32;Q:{R:{if(x[q+((i>>>0)%3<<2)>>2]>=(i|0)){break R}d=y[i+s|0];if(d>>>0>=k>>>0){break R}L=f?E(1.4142135381698608):E(1);S:{if(y[Y+1|0]&8){d=d<<3;A=B[d+70260>>2];R=B[d+70256>>2];break S}O=Ow(E(1),d+1>>>1<<I);d=d&1;A=d?E(1):O;R=d?O:E(1)}O=E(L*R);L=E(L*A);d=0;while(1){if((d|0)!=(e|0)){f=(d<<2)+j|0;A=B[f>>2];B[f+2304>>2]=A*L;B[f>>2]=A*O;d=d+1|0;continue}break}break Q}if(!f){break Q}SH(j,e)}i=i+1|0;j=(y[t|0]<<2)+j|0;continue}break}hb=l+16|0;break O}if((d&224)!=96){break O}SH(C+2940|0,576)}j=C+7708|0;d=0;while(1){if((d|0)!=(ka|0)){e=y[G+6153|0];s=(y[m+12|0]!=0)<<1<<((D((e>>>3&1)+(e>>>4&1)|0,3)+(y[G+6154|0]>>>2&3)|0)==2);l=(C+D(d,2304)|0)+2940|0;i=l;if(y[m+14|0]){h=x[m>>2]+y[m+13|0]|0;t=((C+D(d,2304)|0)+D(s,72)|0)+2940|0;e=t;f=j;while(1){q=y[h|0];if(q){k=q<<1;I=0;while(1){if((q|0)!=(I|0)){B[f>>2]=B[e>>2];B[f+4>>2]=B[(q<<2)+e>>2];B[f+8>>2]=B[(k<<2)+e>>2];e=e+4|0;I=I+1|0;f=f+12|0;continue}break}h=h+3|0;e=(k<<2)+e|0;continue}break}vc(t,j,f-j|0);f=s-1|0}else{f=31}while(1){e=0;if((f|0)>0){while(1){if((e|0)!=8){h=e<<2;q=h+i|0;A=B[q+72>>2];O=B[h+70320>>2];L=B[h+70352>>2];h=(17-e<<2)+i|0;R=B[h>>2];B[q+72>>2]=E(A*O)-E(L*R);B[h>>2]=E(A*L)+E(R*O);e=e+1|0;continue}break}i=i+72|0;f=f-1|0;continue}break}e=l;f=D(d,1152)+G|0;h=y[m+11|0];if(s){RH(e,f,70384,s);f=D(s,36)+f|0;e=D(s,72)+e|0}T:{if((h|0)==2){i=32-s|0;h=hb-80|0;hb=h;q=h|8;I=h|4;while(1){if((i|0)>0){s=vc(h,e,72);k=x[f+20>>2];x[e+16>>2]=x[f+16>>2];x[e+20>>2]=k;k=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=k;k=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=k;K=s;s=f+24|0;Nw(K,e+24|0,s);Nw(I,e+48|0,s);Nw(q,f,s);e=e+72|0;f=f+36|0;i=i-1|0;continue}break}hb=h+80|0;break T}RH(e,f,D((h|0)==3,72)+70384|0,32-s|0)}h=0;i=l+72|0;while(1){e=1;if(h>>>0<=31){while(1){if(e>>>0<=17){f=(e<<2)+i|0;B[f>>2]=-B[f>>2];e=e+2|0;continue}break}i=i+144|0;h=h+2|0;continue}break}m=m+28|0;d=d+1|0;continue}break}UH(ma,pa,18,x[n+32>>2],X,na);o=o+1|0;X=D(x[n+32>>2],1152)+X|0;continue}}e=r+912|0;m=x[e+8>>2]>>>3|0;j=x[e+4>>2]+7>>>3|0;d=m-j|0;f=(d|0)>=511?511:d;if((d|0)>0){ah(G+6156|0,(e+(d>>>0>511?m-511|0:j)|0)+12|0,f)}x[G+6144>>2]=f;break x}Qy(G);break l}j=r+17152|0;o=0;m=0;i=0;e=r;d=0;U:{V:{W:{g=y[u+3|0];h=g>>>6|0;switch(h-1|0){case 2:break U;case 0:break W;default:break V}}d=(g>>>2&12)+4|0;break U}d=32}g=y[u+1|0];X:{if((g&6)==6){g=32;f=71788;break X}if(!(g&8)){g=30;f=71791;break X}l=y[u+2|0];f=l>>>2&3;g=Qw(g,l)>>>((h|0)!=3)|0;g=g?g:192;if(g>>>0<=55){g=(f|0)==2?12:8;f=71812;break X}g=g>>>0<=95?27:(f|0)!=1?30:27;f=71800}v[e+768|0]=g;v[e+769|0]=(d|0)<(g|0)?d:g;g=f;f=71696;while(1){d=y[e+768|0];if(o>>>0>=d>>>0){o=0;while(1){f=d<<1&510;if(f>>>0>o>>>0){f=e+o|0;Y:{if(!y[f+770|0]){g=6;break Y}g=2;if((y[u+1|0]&6)==6){break Y}g=ae(j,2);d=y[e+768|0]}v[f+834|0]=g;o=o+1|0;continue}break}m=e+770|0;h=e+834|0;g=0;i=f;while(1){if((g|0)!=(i|0)){l=y[m|0];f=l?19>>>y[g+h|0]&3|4:0;m=m+1|0;l=D(l,3)-6|0;A=E(0);d=4;while(1){if(d){if(d&f){C=ae(j,6);s=(C|0)/3|0;A=E(B[(l+(D(s,-3)+C|0)<<2)+71824>>2]*E(2097152>>>s|0))}B[e>>2]=A;d=d>>>1|0;e=e+4|0;continue}break}g=g+1|0;continue}break}o=y[r+769|0];g=y[r+768|0];g=g>>>0<o>>>0?o:g;while(1){if((g|0)!=(o|0)){v[((o<<1)+r|0)+771|0]=0;o=o+1|0;continue}break}}else{if((i|0)==(o|0)){f=y[g|0]+71696|0;i=y[g+2|0]+o|0;m=y[g+1|0];g=g+3|0}h=o<<1;d=y[ae(j,m)+f|0];v[(h+e|0)+770|0]=d;l=y[e+769|0];if(l>>>0>o>>>0){d=y[ae(j,m)+f|0];l=y[e+769|0]}v[((h|1)+e|0)+770|0]=l?d:0;o=o+1|0;continue}break}g=0;e=Zb(r+3852|0,0,4608);I=G+2304|0;k=r+8620|0;o=0;Z:{while(1){if((o|0)==3){break Z}u=e+(g<<2)|0;C=r+17152|0;h=0;l=x[n+40>>2]|1;s=(l|0)>0?l:0;j=576;while(1){if((h|0)!=4){m=u+(D(h,l)<<2)|0;f=0;while(1){if(y[r+768|0]<<1>>>0>f>>>0){_:{i=y[(f+r|0)+770|0];if(!i){break _}if(i>>>0<=16){q=(-1<<i-1)+1|0;d=0;while(1){if((d|0)==(s|0)){break _}ra=(d<<2)+m|0,ta=E(ae(C,i)+q|0),B[ra>>2]=ta;d=d+1|0;continue}}d=2<<i-17;i=ae(C,(d-(d>>>3|0)|0)+3|0);t=d>>>1|0;q=d|1;d=0;while(1){if((d|0)==(s|0)){break _}K=i;i=(i>>>0)/(q>>>0)|0;B[(d<<2)+m>>2]=K-(t+D(q,i)|0)|0;d=d+1|0;continue}}f=f+1|0;m=(j<<2)+m|0;j=18-j|0;continue}break}h=h+1|0;continue}break}g=(l<<2)+g|0;if((g|0)==12){d=(o<<2)+r|0;g=e;f=y[r+769|0];m=e+D(f,72)|0;vc(m+2304|0,m,D(y[r+768|0]-f|0,72));m=0;while(1){if(y[r+768|0]>m>>>0){h=0;while(1){if((h|0)!=12){f=(h<<2)+g|0;B[f>>2]=B[d>>2]*B[f>>2];f=f+2304|0;B[f>>2]=B[d+12>>2]*B[f>>2];h=h+1|0;continue}break}d=d+24|0;g=g+72|0;m=m+1|0;continue}break}UH(I,e,12,x[n+32>>2],X,k);Zb(e,0,4608);X=D(x[n+32>>2],768)+X|0;g=0}o=o+1|0;if(x[r+17156>>2]<=x[r+17160>>2]){continue}break}Qy(G);o=0;break l}g=1}o=D(Pw(y[G+6153|0]),g)}hb=r+17168|0;g=x[n+24>>2];if((g|0)<0|!g&(o|0)!=0|!(g|o)){break h}if(g){d=x[n+36>>2];if((d|0)!=(F|0)?F:0){break h}g=x[n+32>>2];if((g|0)!=(c|0)?c:0){break h}if(g-3>>>0<4294967294|(d|0)<=0){break i}x[n+4>>2]=0;ra=n,sa=Ec(U,$),x[ra>>2]=sa;c=x[nj(n+24|0,n+4|0,n)>>2];x[n+4>>2]=0;ra=n,sa=Ec(U,$),x[ra>>2]=sa;fa=c+fa|0;e=x[nj(n+24|0,n+4|0,n)>>2];c=U-e|0;$=$-((e>>31)+(e>>>0>U>>>0)|0)|0;U=c;$:{if(!o){break $}c=x[ba>>2];x[23604]=0;W(525,M|0,c|0,c+(D(g,o)<<1)|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break $}F=V(92520)|0;if((ib|0)==(da(92520)|0)){_(F|0)|0;x[23604]=0;Z(17);e=x[23604];x[23604]=0;c=g;F=d;if((e|0)!=1){break h}F=P()|0}nd(ba);break k}F=d;c=g}if((Kc(x[M>>2],x[M+4>>2])>>>0)/(c>>>0)>>>0>268435456){break h}if(!!U&($|0)>=0|($|0)>0){continue}break}break h}F=P()|0}PN(aa);break j}F=P()|0}nd(M);Lc(n+72|0);T(F|0);p()}c=g;F=d}g=0;aa:{if(!F|!c){break aa}d=x[M>>2];e=x[M+4>>2];if(tc(d,e)){break aa}if((Kc(d,e)>>>0)/(c>>>0)>>>0>268435456){break aa}Ss(a,b);b=D(b,104)+a|0;a=b+484380|0;ra=a,sa=(Kc(x[M>>2],x[M+4>>2])>>>0)/(c>>>0)|0,x[ra>>2]=sa;d=b+484414|0;g=z[d>>1];w[d>>1]=(c|0)==2?g|65:g&65470|1;yg(a);b=b+484400|0;g=Qd(x[a>>2],x[b>>2]);if(!g){break aa}g=Bb(x[M>>2]);d=Bb(x[M+4>>2]);c=hb-16|0;hb=c;VO(c+8|0,g,d,x[b>>2]);hb=c+16|0;g=Qd(x[a>>2],x[b>>2])}nd(ba);PN(aa);nd(M);Lc(n+72|0)}hb=n+96|0;return g|0}function eA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=E(0),u=0,C=0,G=0,H=0,I=E(0),K=0,L=0,M=0,N=0,O=E(0);r=hb-1520|0;hb=r;e=r+8|0;M=Zb(e,0,1512),N=-1,x[M+1420>>2]=N;v[r+56|0]=1;x[r+48>>2]=a+b;x[r+40>>2]=a;n=hb-1024|0;hb=n;v[e+1377|0]=1;a:{if(!Tr(e)){break a}b=y[e+1375|0];if(!(b&2)){gc(e,34);break a}if(b&4){gc(e,34);break a}if(b&1){gc(e,34);break a}if(x[e+1116>>2]!=1){gc(e,34);break a}b=y[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!Kw(e,n+1018|0,6)|y[n+1018|0]!=102|(y[n+1019|0]!=105|y[n+1020|0]!=115)){break b}if(y[n+1021|0]!=104|y[n+1022|0]!=101|y[n+1023|0]!=97){break b}if((Ke(e)|0)!=100){break b}if(Ke(e)){break b}gc(e,38);break a}gc(e,34);break a}if((Ke(e)|0)!=1){gc(e,34);break a}if(!Kw(e,n+1018|0,6)){gc(e,10);break a}if(!Hw(n+1018|0)){gc(e,34);break a}if(Qi(e)){gc(e,34);break a}b=Ke(e);x[e+4>>2]=b;if(!b){gc(e,34);break a}if(b>>>0>=17){gc(e,5);break a}b=Qi(e);x[e>>2]=b;if(!b){gc(e,34);break a}Qi(e);Qi(e);Qi(e);b=Ke(e);g=b>>>4|0;x[e+116>>2]=1<<g;h=b&15;x[e+112>>2]=1<<h;if(h-14>>>0<=4294967287){gc(e,20);break a}if(b+32<<24>>24>=0){gc(e,20);break a}c:{if(g>>>0<h>>>0){gc(e,20);break c}if(!(Ke(e)&1)){gc(e,34);break c}if(!Tr(e)){break a}if(!Iw(e)){break a}if(!Lw(e)){break a}if((gh(e)|0)==3){while(1){if((f|0)!=6){M=(n+1018|0)+f|0,N=gh(e),v[M|0]=N;f=f+1|0;continue}break}if(!Hw(n+1018|0)){gc(e,20);break c}b=Gw(e);h=$d(e,b+1|0);x[e+20>>2]=h;if(h){f=0;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){g=gh(e);v[x[e+20>>2]+f|0]=g;f=f+1|0;continue}break}v[b+x[e+20>>2]|0]=0;b=Gw(e);x[e+28>>2]=0;x[e+24>>2]=b;d:{if((b|0)<=0){break d}b=$d(e,b<<2);x[e+28>>2]=b;if(b){break d}gc(e,3);break c}while(1){e:{f:{if(x[e+24>>2]>(k|0)){b=Gw(e);f=$d(e,b+1|0);h=k<<2;x[h+x[e+28>>2]>>2]=f;if(!x[h+x[e+28>>2]>>2]){break f}f=0;g=(b|0)>0?b:0;while(1){if((f|0)==(g|0)){break e}i=gh(e);v[x[h+x[e+28>>2]>>2]+f|0]=i;f=f+1|0;continue}}if(!(gh(e)&1)){gc(e,20);break c}GH(e,y[e+1376|0]);v[e+1376|0]=0;while(1){b=Lw(e);GH(e,b);v[e+1376|0]=0;if(b){continue}break}f=0;if(!Iw(e)){break a}if(!NH(e)){if(x[e+100>>2]!=21){break a}x[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){h=b<<24;i=0;while(1){if((i|0)!=8){h=h>>31&79764919^h<<1;i=i+1|0;continue}break}x[(b<<2)+463296>>2]=h;b=b+1|0;continue}break}if((gh(e)|0)==5){while(1){if((f|0)!=6){M=(n+1018|0)+f|0,N=gh(e),v[M|0]=N;f=f+1|0;continue}break}if(!Hw(n+1018|0)){gc(e,20);break c}b=nc(e,8)+1|0;x[e+120>>2]=b;b=$d(e,D(b,2096));x[e+124>>2]=b;if(!b){gc(e,3);break c}Zb(b,0,D(x[e+120>>2],2096));g:{h:{while(1){i:{if(x[e+120>>2]>(j|0)){b=x[e+124>>2];if((nc(e,8)&255)!=66){gc(e,20);break c}if((nc(e,8)&255)!=67){gc(e,20);break c}if((nc(e,8)&255)!=86){gc(e,20);break c}g=b+D(j,2096)|0;M=g,N=nc(e,8)&255|nc(e,8)<<8,x[M>>2]=N;M=g,N=nc(e,8)&255|(nc(e,8)<<8&65280|nc(e,8)<<16),x[M+4>>2]=N;m=g+4|0;f=0;k=nc(e,1);if(!k){f=nc(e,1)}v[g+23|0]=f;h=x[m>>2];if(x[g>>2]){b=h;break i}b=0;if(!h){break i}gc(e,20);break c}b=nc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!nc(e,16)){continue}break}gc(e,20);break c}b=nc(e,6)+1|0;x[e+128>>2]=b;b=$d(e,D(b,1596));x[e+260>>2]=b;k:{l:{if(b){l=0;h=0;m:while(1){if(x[e+128>>2]<=(h|0)){break l}b=nc(e,16);w[((h<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){gc(e,20);break c}if(!b){b=x[e+260>>2]+D(h,1596)|0;M=b,N=nc(e,8),v[M|0]=N;M=b,N=nc(e,16),w[M+2>>1]=N;M=b,N=nc(e,16),w[M+4>>1]=N;M=b,N=nc(e,6),v[M+6|0]=N;M=b,N=nc(e,8),v[M+7|0]=N;j=nc(e,4)+1|0;v[b+8|0]=j;f=0;while(1){if((j&255)>>>0>f>>>0){M=b+f|0,N=nc(e,8),v[M+9|0]=N;f=f+1|0;j=y[b+8|0];continue}break}gc(e,4);break c}f=x[e+260>>2]+D(h,1596)|0;b=nc(e,5);v[f|0]=b;i=0;j=-1;while(1)if((b&255)>>>0<=i>>>0){k=j+1|0;b=0;while(1){if((b|0)!=(k|0)){g=b+f|0;M=g,N=nc(e,3)+1|0,v[M+33|0]=N;j=nc(e,2);v[g+49|0]=j;i=0;if(j&255){j=nc(e,8);v[g+65|0]=j;if(x[e+120>>2]<=(j&255)){break k}}while(1){if(1<<y[g+49|0]>(i|0)){j=nc(e,8)-1|0;w[((f+(b<<4)|0)+(i<<1)|0)+82>>1]=j;i=i+1|0;if(x[e+120>>2]>j<<16>>16){continue}break k}break}b=b+1|0;continue}break}j=2;M=f,N=nc(e,2)+1|0,v[M+1588|0]=N;b=nc(e,4);x[f+1592>>2]=2;k=0;w[f+338>>1]=0;v[f+1589|0]=b;w[f+340>>1]=1<<b;g=f+338|0;b=0;while(1){if(y[f|0]>b>>>0){m=f+y[(b+f|0)+1|0]|0;i=0;while(1){if(y[m+33|0]>i>>>0){j=nc(e,y[f+1589|0]);w[(f+(x[f+1592>>2]<<1)|0)+338>>1]=j;j=x[f+1592>>2]+1|0;x[f+1592>>2]=j;i=i+1|0;continue}break}b=b+1|0;continue}break}while(1){if((k|0)<(j|0)){b=z[(f+(k<<1)|0)+338>>1];i=(n+16|0)+(k<<2)|0;w[i+2>>1]=k;w[i>>1]=b;k=k+1|0;j=x[f+1592>>2];continue}break}FH(n+16|0,j,1038);j=x[f+1592>>2];k=((j|0)<=1?1:j)-1|0;i=0;b=0;while(1){if((b|0)!=(k|0)){m=n+16|0;o=z[m+(b<<2)>>1];b=b+1|0;if((o|0)!=z[m+(b<<2)>>1]){continue}break k}break}while(1){if((i|0)<(j|0)){v[(f+i|0)+838|0]=y[((n+16|0)+(i<<2)|0)+2|0];i=i+1|0;j=x[f+1592>>2];continue}break}i=2;while(1){if((i|0)<(j|0)){x[n+12>>2]=0;x[n+8>>2]=0;b=0;s=(i|0)>0?i:0;j=g+(i<<1)|0;m=65536;o=-1;while(1){if((b|0)!=(s|0)){q=g+(b<<1)|0;k=z[q>>1];if(!((o|0)>=(k|0)|z[j>>1]<=k>>>0)){x[n+12>>2]=b;k=z[q>>1];o=k}if(!((k|0)>=(m|0)|z[j>>1]>=k>>>0)){x[n+8>>2]=b;m=z[q>>1]}b=b+1|0;continue}break}b=f+(i<<1)|0;v[b+1088|0]=x[n+12>>2];v[b+1089|0]=x[n+8>>2];i=i+1|0;j=x[f+1592>>2];continue}break}l=(j|0)>(l|0)?j:l;h=h+1|0;continue m}else{b=nc(e,4);v[(f+i|0)+1|0]=b;b=b&255;j=(b|0)>(j|0)?b:j;i=i+1|0;b=y[f|0];continue}}}gc(e,3);break c}b=nc(e,6)+1|0;x[e+264>>2]=b;b=$d(e,D(b,24));x[e+396>>2]=b;if(!b){gc(e,3);break c}k=0;Zb(b,0,D(x[e+264>>2],24));n:{o:{while(1){if(x[e+264>>2]>(k|0)){b=x[e+396>>2];h=nc(e,16);w[((k<<1)+e|0)+268>>1]=h;j=20;if((h&65535)>>>0>2){break n}g=b+D(k,24)|0;M=g,N=nc(e,24),x[M>>2]=N;b=nc(e,24);x[g+4>>2]=b;if(b>>>0<A[g>>2]){break n}M=g,N=nc(e,24)+1|0,x[M+8>>2]=N;M=g,N=nc(e,6)+1|0,v[M+12|0]=N;b=nc(e,8);v[g+13|0]=b;if(x[e+120>>2]<=(b&255)){break n}f=0;while(1){b=y[g+12|0];if(b>>>0>f>>>0){h=(n+16|0)+f|0;i=nc(e,3);if(nc(e,1)){b=nc(e,5)}else{b=0}v[h|0]=i+(b<<3);f=f+1|0;continue}break}b=$d(e,b<<4);x[g+20>>2]=b;if(!b){break o}h=0;while(1){if(y[g+12|0]>h>>>0){b=y[(n+16|0)+h|0];f=0;while(1){if((f|0)!=8){p:{if(b>>>f&1){i=nc(e,8);o=f<<1;m=h<<4;w[o+(m+x[g+20>>2]|0)>>1]=i;if(x[e+120>>2]<=w[o+(m+x[g+20>>2]|0)>>1]){break n}break p}w[(x[g+20>>2]+(h<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}h=h+1|0;continue}break}h=$d(e,x[(x[e+124>>2]+D(y[g+13|0],2096)|0)+4>>2]<<2);x[g+16>>2]=h;if(!h){break o}b=0;Zb(h,0,x[(x[e+124>>2]+D(y[g+13|0],2096)|0)+4>>2]<<2);while(1){h=x[e+124>>2]+D(y[g+13|0],2096)|0;if(x[h+4>>2]>(b|0)){f=x[h>>2];i=$d(e,f);h=b<<2;x[h+x[g+16>>2]>>2]=i;i=b;if(!x[h+x[g+16>>2]>>2]){break o}while(1){if((f|0)>0){f=f-1|0;v[f+x[h+x[g+16>>2]>>2]|0]=(i|0)%y[g+12|0];i=(i|0)/y[g+12|0]|0;continue}break}b=b+1|0;continue}break}k=k+1|0;continue}break}b=nc(e,6)+1|0;x[e+400>>2]=b;b=$d(e,D(b,40));x[e+404>>2]=b;if(!b){gc(e,3);break c}Zb(b,0,D(x[e+400>>2],40));h=0;while(1){if(x[e+400>>2]>(h|0)){i=x[e+404>>2];if(nc(e,16)){gc(e,20);break c}k=D(h,40);g=k+i|0;b=$d(e,D(x[e+4>>2],3));x[g+4>>2]=b;if(!b){gc(e,3);break c}if(nc(e,1)){b=nc(e,4)+1|0}else{b=1}v[g+8|0]=b;q:{if(nc(e,1)){b=nc(e,8)+1|0;w[g>>1]=b;f=0;j=x[e+4>>2];if((j|0)<(b&65535)){gc(e,20);break c}while(1){if(z[g>>1]<=f>>>0){break q}j=nc(e,Kl(j-1|0));b=D(f,3);v[b+x[g+4>>2]|0]=j;j=nc(e,Kl(x[e+4>>2]-1|0));v[(b+x[g+4>>2]|0)+1|0]=j;j=x[e+4>>2];b=b+x[g+4>>2]|0;m=y[b|0];if((j|0)<=(m|0)){gc(e,20);break c}b=y[b+1|0];if((b|0)>=(j|0)){gc(e,20);break c}f=f+1|0;if((b|0)!=(m|0)){continue}break}gc(e,20);break c}w[g>>1]=0}if(nc(e,2)){gc(e,20);break c}j=0;b=0;f=0;r:{if(y[g+8|0]>=2){while(1){if(x[e+4>>2]<=(b|0)){break r}f=nc(e,4);m=D(b,3);v[(m+x[g+4>>2]|0)+2|0]=f;b=b+1|0;if(y[(m+x[g+4>>2]|0)+2|0]<y[g+8|0]){continue}break}gc(e,20);break c}while(1){if(x[e+4>>2]<=(f|0)){break r}v[(x[g+4>>2]+D(f,3)|0)+2|0]=0;f=f+1|0;continue}}s:{while(1){if(y[g+8|0]<=j>>>0){break s}nc(e,8);b=k+(i+j|0)|0;M=b,N=nc(e,8),v[M+9|0]=N;f=nc(e,8);v[b+24|0]=f;if(x[e+128>>2]<=y[b+9|0]){gc(e,20);break c}j=j+1|0;if(x[e+264>>2]>(f&255)){continue}break}gc(e,20);break c}h=h+1|0;continue}break}M=e,N=nc(e,6)+1|0,x[M+408>>2]=N;f=0;t:{while(1){if(x[e+408>>2]<=(f|0)){break t}b=D(f,6)+e|0;M=b,N=nc(e,1),v[M+412|0]=N;M=b,N=nc(e,16),w[M+414>>1]=N;M=b,N=nc(e,16),w[M+416>>1]=N;h=nc(e,8);v[b+413|0]=h;if(z[b+414>>1]){gc(e,20);break c}if(z[b+416>>1]){gc(e,20);break c}f=f+1|0;if(x[e+400>>2]>(h&255)){continue}break}gc(e,20);break c}LH(e);x[e+992>>2]=0;h=l<<1;f=0;while(1){if(x[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=$d(e,x[e+116>>2]<<2),x[M+800>>2]=N;M=b,N=$d(e,x[e+116>>2]<<1&2147483646),x[M+928>>2]=N;g=$d(e,h);x[b+996>>2]=g;i=x[b+800>>2];if(g?!i|!x[b+928>>2]:1){gc(e,3);break c}Zb(i,0,x[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!EH(e,0,x[e+112>>2])){break a}if(!EH(e,1,x[e+116>>2])){break a}x[e+104>>2]=x[e+112>>2];h=x[e+116>>2];x[e+108>>2]=h;b=x[e+264>>2];i=(b|0)>0?b:0;b=(h|0)/2|0;j=0;while(1){if((f|0)!=(i|0)){g=x[e+396>>2]+D(f,24)|0;k=x[g+4>>2];l=b>>>0>k>>>0?k:b;k=x[g>>2];g=(l-(b>>>0>k>>>0?k:b)>>>0)/A[g+8>>2]|0;j=(g|0)>(j|0)?g:j;f=f+1|0;continue}break}b=h<<1&2147483646;h=D(x[e+4>>2],(j<<2)+4|0);b=b>>>0>h>>>0?b:h;x[e+12>>2]=b;u:{v:{if(!x[e+80>>2]){break v}h=x[e+92>>2];if((h|0)!=x[e+84>>2]){break u}if(h>>>0>=(b+x[e+88>>2]|0)+1512>>>0){break v}gc(e,3);break c}w:{if(x[e+1380>>2]==-1){x[e+52>>2]=y[e+48|0]?0:x[e+32>>2]-x[e+36>>2]|0;break w}x[e+52>>2]=0}f=1;break a}aa(7262,13065,4196,8731);p()}j=3}gc(e,j);break c}gc(e,20);break c}x:{if(f&255){i=qn(e,b);break x}i=$d(e,b);x[g+8>>2]=i}if(!i){gc(e,3);break c}h=0;y:{if(!k){f=0;while(1){b=x[m>>2];if((f|0)>=(b|0)){break y}z:{A:{if(y[g+23|0]){if(!nc(e,1)){break A}}b=nc(e,5)+1|0;v[f+i|0]=b;if((b&255)!=32){h=h+1|0;break z}gc(e,20);break c}v[f+i|0]=255}f=f+1|0;continue}}k=nc(e,5);f=0;while(1){b=x[m>>2];if((f|0)>=(b|0)){break y}l=nc(e,Kl(b-f|0));k=k+1|0;if((k|0)>=32){gc(e,20);break c}b=f+l|0;if((b|0)>x[m>>2]){gc(e,20);break c}else{Zb(f+i|0,k,l);f=b;continue}}}B:{C:{D:{if(y[g+23|0]){if(b>>2>(h|0)){break D}if(x[e+16>>2]<(b|0)){x[e+16>>2]=b;b=x[m>>2]}b=$d(e,b);x[g+8>>2]=b;if(!b){gc(e,3);break c}vc(b,i,x[m>>2]);Pi(e,i,x[m>>2]);i=x[g+8>>2];v[g+23|0]=0;b=x[m>>2]}k=0;h=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(h|0)){k=((y[f+i|0]-11&255)>>>0<244)+k|0;f=f+1|0;continue}break}x[g+2092>>2]=k;b=$d(e,b<<2);x[g+32>>2]=b;if(b){k=g+2092|0;f=0;break C}gc(e,3);break c}x[g+2092>>2]=h;k=g+2092|0;E:{if(!h){f=0;h=0;break E}b=$d(e,h);x[g+8>>2]=b;if(!b){gc(e,3);break c}b=qn(e,x[k>>2]<<2);x[g+32>>2]=b;if(!b){gc(e,3);break c}f=qn(e,x[k>>2]<<2);if(!f){break B}b=x[m>>2];h=x[k>>2]}b=(h<<3)+b|0;if(b>>>0<=A[e+16>>2]){break C}x[e+16>>2]=b}o=x[m>>2];b=0;h=hb-128|0;hb=h;q=Zb(h,0,128);h=(o|0)>0?o:0;while(1){F:{G:{if((b|0)!=(h|0)){if(y[b+i|0]==255){break G}h=b}if((h|0)==(o|0)){b=1;if(!x[g+2092>>2]){break F}aa(15581,13065,1103,7506);p()}b=h+i|0;l=y[b|0];if(l>>>0<32){CH(g,0,h,0,l,f);s=1;l=y[b|0]+1|0;b=1;H:{while(1){if((b|0)==(l|0)){I:while(1){J:{b=1;h=h+1|0;if((o|0)<=(h|0)){break F}C=h+i|0;l=y[C|0];if((l|0)==255){continue}b=l;if(b>>>0>=32){break J}while(1){if((b|0)<=0){b=0;break F}G=q+(b<<2)|0;H=x[G>>2];if(!H){b=b-1|0;continue}break}x[G>>2]=0;CH(g,Il(H),h,s,l,f);s=s+1|0;l=y[C|0];if((l|0)==(b|0)){continue}while(1){if((b|0)>=(l|0)){continue I}C=q+(l<<2)|0;if(x[C>>2]){break H}x[C>>2]=H+(1<<32-l);l=l-1|0;continue}}break}}else{x[q+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}aa(15036,13065,1118,7506);p()}aa(15625,13065,1133,7506);p()}aa(15043,13065,1104,7506);p()}b=b+1|0;continue}break}hb=q+128|0;if(!b){if(y[g+23|0]){Pi(e,f,0)}gc(e,20);break c}b=x[k>>2];if(b){b=$d(e,(b<<2)+4|0);x[g+2084>>2]=b;if(!b){gc(e,3);break c}b=$d(e,(x[k>>2]<<2)+4|0);x[g+2088>>2]=b;if(!b){gc(e,3);break c}x[g+2088>>2]=b+4;x[b>>2]=-1;b=0;l=0;K:{L:{M:{if(y[g+23|0]){while(1){l=x[g+2092>>2];if((l|0)<=(b|0)){break M}h=b<<2;M=h+x[g+2084>>2]|0,N=Il(x[h+x[g+32>>2]>>2]),x[M>>2]=N;b=b+1|0;continue}}while(1){if(x[g+4>>2]>(b|0)){if(BH(y[g+23|0],y[b+i|0])){M=x[g+2084>>2]+(l<<2)|0,N=Il(x[x[g+32>>2]+(b<<2)>>2]),x[M>>2]=N;l=l+1|0}b=b+1|0;continue}break}if(x[g+2092>>2]!=(l|0)){break L}}FH(x[g+2084>>2],l,1039);x[x[g+2084>>2]+(x[g+2092>>2]<<2)>>2]=-1;h=0;b=x[g+(y[g+23|0]?2092:4)>>2];H=(b|0)>0?b:0;N:{while(1){if((h|0)!=(H|0)){b=h;l=y[g+23|0];b=l?x[(b<<2)+f>>2]:b;C=y[b+i|0];O:{if(!BH(l,C)){break O}G=h<<2;o=Il(x[G+x[g+32>>2]>>2]);b=x[g+2092>>2];l=0;while(1){if((b|0)>=2){q=b>>>1|0;K=q+l|0;s=o>>>0<A[x[g+2084>>2]+(K<<2)>>2];b=s?q:b-q|0;l=s?l:K;continue}break}b=l<<2;if((o|0)!=x[b+x[g+2084>>2]>>2]){break N}if(y[g+23|0]){x[b+x[g+2088>>2]>>2]=x[f+G>>2];v[x[g+8>>2]+l|0]=C;break O}x[b+x[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break K}aa(12106,13065,1230,9874);p()}aa(7447,13065,1200,9874);p()}}if(y[g+23|0]){Pi(e,f,x[k>>2]<<2);Pi(e,x[g+32>>2],x[k>>2]<<2);Pi(e,i,x[m>>2]);x[g+32>>2]=0}b=0;f=0;while(1){if((b|0)!=1024){w[(g+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=x[g+(y[g+23|0]?2092:4)>>2];b=(b|0)>=32767?32767:b;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){P:{if(y[x[g+8>>2]+f|0]>10){break P}Q:{if(y[g+23|0]){b=Il(x[x[g+2084>>2]+(f<<2)>>2]);break Q}b=x[x[g+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break P}w[(g+(b<<1)|0)+36>>1]=f;b=(1<<y[x[g+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=nc(e,4);v[g+21|0]=b;b=b&255;if(b>>>0>=3){gc(e,20);break c}if(b){M=g,O=DH(nc(e,32)),B[M+12>>2]=O;M=g,O=DH(nc(e,32)),B[M+16>>2]=O;M=g,N=nc(e,4)+1|0,v[M+20|0]=N;M=g,N=nc(e,1),v[M+22|0]=N;f=x[g>>2];h=x[m>>2];R:{if(y[g+21|0]==1){u=J(pr(+E(E(Po(+E(h|0)))/E(f|0))));S:{if(F(u)<2147483648){b=~~u;break S}b=-2147483648}u=+(f|0);L=J(xj(+E(E(b|0)+E(1)),u));T:{if(F(L)<2147483648){f=~~L;break T}f=-2147483648}b=((f|0)<=(h|0))+b|0;t=E(b|0);if(xj(+E(t+E(1)),u)<=+(h|0)){f=-1}else{u=J(xj(+t,u));U:{if(F(u)<2147483648){f=~~u;break U}f=-2147483648}f=(f|0)>(h|0)?-1:b}if((f|0)>=0){break R}gc(e,20);break c}f=D(f,h)}x[g+24>>2]=f;if(!f){gc(e,20);break c}l=qn(e,f<<1);if(!l){break h}f=0;while(1){i=x[g+24>>2];if((i|0)>(f|0)){b=nc(e,y[g+20|0]);if((b|0)==-1){Pi(e,l,x[g+24>>2]<<1);gc(e,20);break c}else{w[l+(f<<1)>>1]=b;f=f+1|0;continue}}break}V:{W:{if(y[g+21|0]==1){o=y[g+23|0];X:{if(o){f=x[k>>2];if(f){break X}break V}f=x[m>>2]}b=$d(e,D(x[g>>2],f)<<2);x[g+28>>2]=b;if(!b){Pi(e,l,x[g+24>>2]<<1);gc(e,3);break c}h=0;b=x[(o?k:m)>>2];q=(b|0)>0?b:0;s=g+2088|0;t=E(0);while(1){if((h|0)==(q|0)){break W}k=o?x[x[s>>2]+(h<<2)>>2]:h;i=x[g>>2];f=0;b=1;while(1){if((f|0)<(i|0)){I=E(t+E(E(E(z[l+(((k>>>0)/(b>>>0)>>>0)%A[g+24>>2]<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(D(h,i)+f<<2)>>2]=I;t=y[g+22|0]?I:t;f=f+1|0;i=x[g>>2];if((f|0)>=(i|0)){continue}m=x[g+24>>2];Jia(m,0,b,0);if(lb){Pi(e,l,m<<1);gc(e,20);break c}else{b=D(b,m);continue}}break}h=h+1|0;continue}}b=$d(e,i<<2);x[g+28>>2]=b;if(!b){break g}f=0;t=E(0);while(1){i=x[g+24>>2];if((i|0)<=(f|0)){break V}I=E(t+E(E(E(z[l+(f<<1)>>1])*B[g+16>>2])+B[g+12>>2]));B[x[g+28>>2]+(f<<2)>>2]=I;t=y[g+22|0]?I:t;f=f+1|0;continue}}v[g+21|0]=2;i=x[g+24>>2]}Pi(e,l,i<<1)}j=j+1|0;continue}break}gc(e,3);break c}gc(e,3);break c}Pi(e,l,x[g+24>>2]<<1);gc(e,3);break c}gc(e,20);break c}gc(e,3);break c}v[b+x[x[e+28>>2]+(k<<2)>>2]|0]=0;k=k+1|0;continue}}gc(e,3);break c}gc(e,20)}f=0}hb=n+1024|0;Y:{Z:{if(!f){x[d>>2]=x[r+104>>2]?1:x[r+108>>2];break Z}b=$d(r+8|0,1512);if(b){M=c,N=x[vc(b,r+8|0,1512)+32>>2]-a|0,x[M>>2]=N;x[d>>2]=0;break Y}}OH(r+8|0);b=0}hb=r+1520|0;return b}function BG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;r=hb-48|0;hb=r;a:{if(c>>>0<=2){c=c<<2;I=x[c+78684>>2];J=x[c+78672>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=md(b)}if(vk(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=md(b)}e:{f:{while(1){if(v[g+4913|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=md(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=hb-16|0;hb=l;h=(q(E(E(o|0)*E(O))),j(2));b=h&2147483647;h:{if(b-8388608>>>0<=2130706431){d=(b>>>7|0)+1065353216|0;c=b<<25;break h}d=h>>>7|2147418112;c=h<<25;if(b>>>0>=2139095040){break h}d=0;c=0;if(!b){break h}c=b;b=G(b);vf(l,c,0,0,0,b+81|0);k=x[l>>2];i=x[l+4>>2];d=x[l+12>>2]^65536|16265-b<<16;c=x[l+8>>2]}x[r>>2]=k;x[r+4>>2]=i;x[r+8>>2]=c;x[r+12>>2]=h&-2147483648|d;hb=l+16|0;k=x[r+8>>2];i=x[r+12>>2];h=x[r>>2];m=x[r+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+9870|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=md(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=md(b)}if((g&-33)==88){g=d;c=0;f=hb-432|0;hb=f;p:{q:{d=x[b+4>>2];if((d|0)!=x[b+104>>2]){x[b+4>>2]=d+1;c=y[d|0];break q}d=0;break p}d=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!d){c=md(b);break y}if((c|0)!=48){m=1073676288;if((c|0)==46){break w}break v}d=x[b+4>>2];if((d|0)==x[b+104>>2]){break x}n=1;x[b+4>>2]=d+1;c=y[d|0]}d=1;continue}n=1;break s}c=x[b+4>>2];z:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break z}c=md(b)}if((c|0)==48){break u}e=1}break t}while(1){c=s;s=c-1|0;t=t-!c|0;e=1;c=x[b+4>>2];A:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break A}c=md(b)}if((c|0)==48){continue}break}n=1}while(1){K=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|K-97>>>0<6)){d=c;break r}d=46;if((c|0)!=46){break C}if(e){break r}e=1;s=k;t=i;break B}c=(c|0)>57?K-87|0:M;D:{if((i|0)<=0&k>>>0<=7|(i|0)<0){w=c+(w<<4)|0;break D}if(!i&k>>>0<=28){Gg(f+48|0,c);Ed(f+32|0,F,H,h,m,0,0,0,1073414144);F=x[f+32>>2];H=x[f+36>>2];h=x[f+40>>2];m=x[f+44>>2];Ed(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],F,H,h,m);tg(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],l,p,B,C);B=x[f+8>>2];C=x[f+12>>2];l=x[f>>2];p=x[f+4>>2];break D}if(!c|u){break D}Ed(f+80|0,F,H,h,m,0,0,0,1073610752);tg(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],l,p,B,C);B=x[f+72>>2];C=x[f+76>>2];u=1;l=x[f+64>>2];p=x[f+68>>2]}k=k+1|0;i=k?i:i+1|0;n=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0]}else{c=md(b)}continue}}d=0;continue}break}E:{if(!n){c=x[b+116>>2];F:{G:{if((c|0)>0|(c|0)>=0){c=x[b+4>>2];x[b+4>>2]=c-1;if(!g){break G}x[b+4>>2]=c-2;if(!e){break F}x[b+4>>2]=c-3;break F}if(g){break F}}Zh(b,0,0)}Ai(f+96|0,+(o|0)*0);l=x[f+96>>2];p=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break E}if((i|0)<=0&k>>>0<=7|(i|0)<0){h=k;m=i;while(1){w=w<<4;h=h+1|0;m=h?m:m+1|0;if((h|0)!=8|m){continue}break}}H:{I:{J:{if((d&-33)==80){h=AG(b,g);c=lb;m=c;if(h|(c|0)!=-2147483648){break H}if(g){c=x[b+116>>2];if((c|0)>0|(c|0)>=0){break J}break I}l=0;p=0;Zh(b,0,0);c=0;b=0;break E}h=0;m=0;if(x[b+116>>2]<0){break H}}x[b+4>>2]=x[b+4>>2]-1}h=0;m=0}if(!w){Ai(f+112|0,+(o|0)*0);l=x[f+112>>2];p=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break E}b=e?s:k;i=(e?t:i)<<2|b>>>30;b=h+(b<<2)|0;d=i+m|0;k=b-32|0;i=(b>>>0<h>>>0?d+1|0:d)-(b>>>0<32)|0;b=i;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){x[116080]=68;Gg(f+160|0,o);Ed(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);Ed(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);l=x[f+128>>2];p=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break E}b=I-226|0;c=b>>31;if((i|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(i|0)){if((w|0)>=0){while(1){tg(f+416|0,l,p,B,C,0,0,0,-1073807360);c=zN(l,p,B,C,1073610752);b=(c|0)<0;tg(f+400|0,l,p,B,C,b?l:x[f+416>>2],b?p:x[f+420>>2],b?B:x[f+424>>2],b?C:x[f+428>>2]);b=k;k=b-1|0;i=i-!b|0;B=x[f+408>>2];C=x[f+412>>2];l=x[f+400>>2];p=x[f+404>>2];w=w<<1|(c|0)>=0;if((w|0)>=0){continue}break}}d=i-((I>>31)+(k>>>0<I>>>0)|0)|0;b=(k-I|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<J>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:J;K:{if((c|0)>=113){Gg(f+384|0,o);s=x[f+392>>2];t=x[f+396>>2];F=x[f+384>>2];H=x[f+388>>2];h=0;b=0;break K}Ai(f+352|0,uj(1,144-c|0));Gg(f+336|0,o);F=x[f+336>>2];H=x[f+340>>2];s=x[f+344>>2];t=x[f+348>>2];DG(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],F,H,s,t);z=x[f+376>>2];L=x[f+380>>2];h=x[f+372>>2];b=x[f+368>>2]}d=!(w&1)&((bm(l,p,B,C,0,0,0,0)|0)!=0&(c|0)<32);Qm(f+320|0,d+w|0);Ed(f+304|0,F,H,s,t,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);c=b;tg(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,h,z,L);b=d;Ed(f+288|0,F,H,s,t,b?0:l,b?0:p,b?0:B,b?0:C);tg(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);Zv(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],c,h,z,L);b=x[f+240>>2];d=x[f+244>>2];c=x[f+248>>2];h=x[f+252>>2];if(!bm(b,d,c,h,0,0,0,0)){x[116080]=68}CG(f+224|0,b,d,c,h,k);l=x[f+224>>2];p=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break E}x[116080]=68;Gg(f+208|0,o);Ed(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);Ed(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);l=x[f+176>>2];p=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[r+16>>2]=l;x[r+20>>2]=p;x[r+24>>2]=b;x[r+28>>2]=c;hb=f+432|0;k=x[r+24>>2];i=x[r+28>>2];h=x[r+16>>2];m=x[r+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;z=o;f=d;d=0;o=0;e=hb-8976|0;hb=e;L=0-I|0;K=L-J|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}b=x[g+4>>2];if((b|0)==x[g+104>>2]){break N}x[g+4>>2]=b+1;c=y[b|0];break M}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){d=1;x[g+4>>2]=b+1;c=y[b|0]}else{d=1;c=md(g)}continue}break}c=md(g)}n=1;if((c|0)!=48){break L}while(1){b=k;k=b-1|0;i=i-!b|0;b=x[g+4>>2];O:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break O}c=md(g)}if((c|0)==48){continue}break}d=1}x[e+784>>2]=0;P:{Q:{b=(c|0)==46;l=c-48|0;R:{S:{T:{U:{if(b|l>>>0<=9){while(1){V:{if(b&1){if(!n){k=h;i=m;n=1;break V}b=!d;break U}h=h+1|0;m=h?m:m+1|0;if((o|0)<=2044){w=(c|0)==48?w:h;b=(e+784|0)+(o<<2)|0;if(u){l=(D(x[b>>2],10)+c|0)-48|0}x[b>>2]=l;d=1;c=u+1|0;b=(c|0)==9;u=b?0:c;o=b+o|0;break V}if((c|0)==48){break V}x[e+8960>>2]=x[e+8960>>2]|1;w=18396}b=x[g+4>>2];W:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break W}c=md(g)}b=(c|0)==46;l=c-48|0;if(b|l>>>0<10){continue}break}}k=n?k:h;i=n?i:m;if(!(!d|(c&-33)!=69)){l=AG(g,f);b=lb;p=b;X:{if(l|(b|0)!=-2147483648){break X}if(!f){break R}l=0;p=0;if(x[g+116>>2]<0){break X}x[g+4>>2]=x[g+4>>2]-1}if(!d){break S}i=i+p|0;k=k+l|0;i=k>>>0<l>>>0?i+1|0:i;break Q}b=!d;if((c|0)<0){break T}}if(x[g+116>>2]<0){break T}x[g+4>>2]=x[g+4>>2]-1}if(!b){break Q}}x[116080]=28}h=0;m=0;Zh(g,0,0);c=0;b=0;break P}b=x[e+784>>2];if(!b){Ai(e,+(z|0)*0);h=x[e>>2];m=x[e+4>>2];c=x[e+12>>2];b=x[e+8>>2];break P}if(!((h|0)!=(k|0)|(i|0)!=(m|0)|(h>>>0>9&(m|0)>=0|(m|0)>0)|(b>>>J|0?(J|0)<=30:0))){Gg(e+48|0,z);Qm(e+32|0,b);Ed(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);h=x[e+16>>2];m=x[e+20>>2];c=x[e+28>>2];b=x[e+24>>2];break P}if(k>>>0>L>>>1>>>0&(i|0)>=0|(i|0)>0){x[116080]=68;Gg(e+96|0,z);Ed(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);Ed(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);h=x[e+64>>2];m=x[e+68>>2];c=x[e+76>>2];b=x[e+72>>2];break P}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(i|0)<=(b|0)|(b|0)>(i|0)){x[116080]=68;Gg(e+144|0,z);Ed(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);Ed(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);h=x[e+112>>2];m=x[e+116>>2];c=x[e+124>>2];b=x[e+120>>2];break P}if(u){if((u|0)<=8){b=(e+784|0)+(o<<2)|0;g=x[b>>2];while(1){g=D(g,10);u=u+1|0;if((u|0)!=9){continue}break}x[b>>2]=g}o=o+1|0}n=k;Y:{if((k|0)<(w|0)|(w|0)>8|(k|0)>17){break Y}if((n|0)==9){Gg(e+192|0,z);Qm(e+176|0,x[e+784>>2]);Ed(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);h=x[e+160>>2];m=x[e+164>>2];c=x[e+172>>2];b=x[e+168>>2];break P}if((n|0)<=8){Gg(e+272|0,z);Qm(e+256|0,x[e+784>>2]);Ed(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);Gg(e+224|0,x[(0-n<<2)+78672>>2]);gK(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);h=x[e+208>>2];m=x[e+212>>2];c=x[e+220>>2];b=x[e+216>>2];break P}b=(J+D(n,-3)|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}Gg(e+352|0,z);Qm(e+336|0,c);Ed(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);Gg(e+304|0,x[(n<<2)+78600>>2]);Ed(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);h=x[e+288>>2];m=x[e+292>>2];c=x[e+300>>2];b=x[e+296>>2];break P}while(1){c=o;o=c-1|0;if(!x[(e+784|0)+(o<<2)>>2]){continue}break}b=(n|0)%9|0;Z:{if(!b){u=0;b=0;break Z}u=0;d=(n|0)<0?b+9|0:b;_:{if(!c){b=0;c=0;break _}k=x[(0-d<<2)+78672>>2];i=1e9/(k|0)|0;l=0;g=0;b=0;while(1){h=l;l=(e+784|0)+(g<<2)|0;m=x[l>>2];o=(m>>>0)/(k>>>0)|0;h=h+o|0;x[l>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;n=h?n-9|0:n;l=D(i,m-D(k,o)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!l){break _}x[(e+784|0)+(c<<2)>>2]=l;c=c+1|0}n=(n-d|0)+9|0}while(1){o=(e+784|0)+(b<<2)|0;g=(n|0)<36;$:{while(1){aa:{if(g){break aa}if((n|0)!=36){break $}if(A[o>>2]<=10384592){break aa}n=36;break $}d=c+2047|0;l=0;while(1){h=d&2047;f=(e+784|0)+(h<<2)|0;d=x[f>>2];m=d>>>3|0;k=l;l=d<<29;k=k+l|0;d=m;i=k>>>0<l>>>0?d+1|0:d;if(!i&k>>>0<1000000001){l=0}else{l=Mia(k,i,1e9,0);d=Jia(l,lb,-1e9,-1);k=d+k|0}x[f>>2]=k;c=(h|0)!=(c-1&2047)?c:(b|0)==(h|0)?c:k?c:h;d=h-1|0;if((b|0)!=(h|0)){continue}break}u=u-29|0;if(!l){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;k=d+((c+2046&2047)<<2)|0;c=c-1&2047;x[k>>2]=x[k>>2]|x[d+(c<<2)>>2]}n=n+9|0;x[(e+784|0)+(b<<2)>>2]=l;continue}break}ba:{ca:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;da:{while(1){d=b;g=0;ea:{while(1){fa:{b=d+g&2047;if((b|0)==(c|0)){break fa}b=x[(e+784|0)+(b<<2)>>2];i=x[(g<<2)+78624>>2];if(b>>>0<i>>>0){break fa}if(b>>>0>i>>>0){break ea}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break ea}k=0;i=0;g=0;h=0;m=0;while(1){b=d+g&2047;if((b|0)==(c|0)){c=c+1&2047;x[((c<<2)+e|0)+780>>2]=0}Qm(e+768|0,x[(e+784|0)+(b<<2)>>2]);Ed(e+752|0,k,i,h,m,0,0,1342177280,1075633366);tg(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);h=x[e+744>>2];m=x[e+748>>2];k=x[e+736>>2];i=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}Gg(e+720|0,z);Ed(e+704|0,k,i,h,m,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);h=x[e+712>>2];m=x[e+716>>2];k=0;i=0;l=x[e+704>>2];p=x[e+708>>2];f=u+113|0;o=f-I|0;n=(o|0)<(J|0);b=n?(o|0)>0?o:0:J;if((b|0)<=112){break da}break ba}u=h+u|0;b=c;if((d|0)==(b|0)){continue}break}m=1e9>>>h|0;o=-1<<h^-1;g=0;b=d;while(1){i=g;g=(e+784|0)+(d<<2)|0;f=x[g>>2];i=i+(f>>>h|0)|0;x[g>>2]=i;i=!i&(b|0)==(d|0);b=i?b+1&2047:b;n=i?n-9|0:n;g=D(m,f&o);d=d+1&2047;if((d|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(k|0)){x[(e+784|0)+(c<<2)>>2]=g;c=k;continue ca}x[l>>2]=x[l>>2]|1;continue}break}break}Ai(e+656|0,uj(1,225-b|0));DG(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],l,p,h,m);F=x[e+696>>2];H=x[e+700>>2];B=x[e+688>>2];C=x[e+692>>2];Ai(e+640|0,uj(1,113-b|0));HJ(e+672|0,l,p,h,m,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);k=x[e+672>>2];i=x[e+676>>2];s=x[e+680>>2];t=x[e+684>>2];Zv(e+624|0,l,p,h,m,k,i,s,t);tg(e+608|0,B,C,F,H,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);h=x[e+616>>2];m=x[e+620>>2];l=x[e+608>>2];p=x[e+612>>2]}g=d+4&2047;ga:{if((g|0)==(c|0)){break ga}g=x[(e+784|0)+(g<<2)>>2];ha:{if(g>>>0<=499999999){if(!g&(d+5&2047)==(c|0)){break ha}Ai(e+496|0,+(z|0)*.25);tg(e+480|0,k,i,s,t,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);s=x[e+488>>2];t=x[e+492>>2];k=x[e+480>>2];i=x[e+484>>2];break ha}if((g|0)!=5e8){Ai(e+592|0,+(z|0)*.75);tg(e+576|0,k,i,s,t,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);s=x[e+584>>2];t=x[e+588>>2];k=x[e+576>>2];i=x[e+580>>2];break ha}N=+(z|0);if((d+5&2047)==(c|0)){Ai(e+528|0,N*.5);tg(e+512|0,k,i,s,t,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);s=x[e+520>>2];t=x[e+524>>2];k=x[e+512>>2];i=x[e+516>>2];break ha}Ai(e+560|0,N*.75);tg(e+544|0,k,i,s,t,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);s=x[e+552>>2];t=x[e+556>>2];k=x[e+544>>2];i=x[e+548>>2]}if((b|0)>111){break ga}HJ(e+464|0,k,i,s,t,0,0,0,1073676288);if(bm(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break ga}tg(e+448|0,k,i,s,t,0,0,0,1073676288);s=x[e+456>>2];t=x[e+460>>2];k=x[e+448>>2];i=x[e+452>>2]}tg(e+432|0,l,p,h,m,k,i,s,t);Zv(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],B,C,F,H);h=x[e+424>>2];m=x[e+428>>2];l=x[e+416>>2];p=x[e+420>>2];ia:{if((K-2|0)>=(f&2147483647)){break ia}x[e+408>>2]=h;x[e+412>>2]=m&2147483647;x[e+400>>2]=l;x[e+404>>2]=p;Ed(e+384|0,l,p,h,m,0,0,0,1073610752);d=zN(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);c=(d|0)<0;h=c?h:x[e+392>>2];m=c?m:x[e+396>>2];l=c?l:x[e+384>>2];p=c?p:x[e+388>>2];u=((d|0)>=0)+u|0;if(!((bm(k,i,s,t,0,0,0,0)|0)!=0&(c?n:n&(b|0)!=(o|0)))&(u+110|0)<=(K|0)){break ia}x[116080]=68}CG(e+368|0,l,p,h,m,u);h=x[e+368>>2];m=x[e+372>>2];c=x[e+380>>2];b=x[e+376>>2]}x[r+40>>2]=b;x[r+44>>2]=c;x[r+32>>2]=h;x[r+36>>2]=m;hb=e+8976|0;k=x[r+40>>2];i=x[r+44>>2];h=x[r+32>>2];m=x[r+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}break i}ja:{c=x[b+4>>2];ka:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ka}c=md(b)}if((c|0)==40){g=1;break ja}i=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];la:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break la}c=md(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}i=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}ma:{if(d){if(g){break ma}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(g){continue}break}break a}x[116080]=28;Zh(b,0,0)}i=0}x[a>>2]=h;x[a+4>>2]=m;x[a+8>>2]=k;x[a+12>>2]=i;hb=r+48|0}function zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;d=hb-384|0;hb=d;xc(b);a:{if(!ho(b,d+368|0)){break a}if(!UQ(d+368|0)){break a}r=ge(d+344|0,b);o=Sb(d+328|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!c){x[23604]=0;R(588,d+40|0,r|0);b=x[23604];x[23604]=0;if((b|0)==1){break z}break B}x[23604]=0;R(589,d+40|0,r|0);b=x[23604];x[23604]=0;if((b|0)==1){break A}}b=d+40|0;st(o,b);Xd(b);x[23604]=0;U(590,b|0,o|0,1413891155);b=x[23604];x[23604]=0;C:{D:{if((b|0)!=1){x[23604]=0;e=Q(591,d+40|0,13987)|0;b=x[23604];x[23604]=0;if((b|0)==1){break D}yb(d+40|0);if(!c){break b}if(!(e^1)){break C}break b}b=P()|0;break c}b=P()|0;yb(d+40|0);break c}x[23604]=0;R(232,a|0,4194304);b=x[23604];x[23604]=0;if((b|0)==1){break d}x[a+480208>>2]=12;x[23604]=0;U(590,d+304|0,o|0,1280592212);b=x[23604];x[23604]=0;if((b|0)==1){break e}x[23604]=0;b=S(146,x[d+304>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break g}x[23604]=0;U(389,d+304|0,a+1298308|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break g}i=a+484360|0;j=a+484376|0;Fc(_b(x[i>>2],y[j|0]));k=Sb(d+288|0);v[d+287|0]=0;x[23604]=0;U(592,d+272|0,o|0,1196314451);b=x[23604];x[23604]=0;if((b|0)==1){break i}B=d,C=Bb(x[d+272>>2]),x[B+264>>2]=C;q=d+252|0;s=Bb(x[d+276>>2]);E:{F:{while(1){b=x[d+264>>2];if(!Ob(b,s)){break F}l=ge(d+40|0,b);x[23604]=0;e=Q(593,l|0,d+24|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break E}b=1;if(!(!e|y[d+33|0]!=1)){B=a,C=Td(y[d+34|0],z[a+480188>>1],127),w[B+480188>>1]=C;x[23604]=0;h=S(594,d+208|0)|0;b=x[23604];x[23604]=0;G:{H:{I:{J:{K:{if((b|0)!=1){b=d+192|0;df(b,d+24|0,9,1);x[23604]=0;R(208,d+160|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break K}b=d+8|0;ec(b,q,10);e=b;b=d+160|0;ol(e,b);xb(b);b=_b(x[a+484360>>2],y[j|0]);if(tc(x[b>>2],x[b+4>>2])){break H}x[23604]=0;b=S(257,i|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break J}if((b|0)!=255){break I}b=2;break G}b=P()|0;break k}b=P()|0;break l}b=P()|0;break l}b=_b(x[a+484360>>2],y[j|0])}x[23604]=0;U(5,d+160|0,5,q|0);e=x[23604];x[23604]=0;if((e|0)==1){break n}x[23604]=0;R(258,b|0,d+160|0);b=x[23604];x[23604]=0;if((b|0)==1){break o}xb(d+160|0);x[23604]=0;R(589,d+192|0,l|0);b=x[23604];x[23604]=0;if((b|0)==1){break p}B=d,C=Bb(x[d+192>>2]),x[B+184>>2]=C;n=Bb(x[d+196>>2]);L:{M:{while(1){b=x[d+184>>2];if(!Ob(b,n)){b=0;if(z[d+244>>1]==65535|z[d+246>>1]==65535){break L}b=y[j|0];e=x[a+484360>>2];x[23604]=0;Y(595,_b(e,b)|0);b=x[23604];x[23604]=0;if((b|0)!=1){x[23604]=0;R(596,k|0,h|0);e=x[23604];x[23604]=0;b=0;if((e|0)!=1){break L}}b=P()|0;break m}qm(d+160|0,b);ti(d+8|0,x[b>>2],x[b+4>>2]);e=1;N:{g=x[d+8>>2];O:{if((g|0)!=1212960847){b=0;if((g|0)!=1312903248){break O}while(1){if(z[a+480188>>1]<=b>>>0){break O}x[23604]=0;g=W(142,x[d+160>>2],x[d+168>>2],2)|0;f=x[23604];x[23604]=0;if((f|0)!=1){if(!g){break O}x[23604]=0;R(245,d+136|0,d+160|0);g=x[23604];x[23604]=0;P:{Q:{R:{S:{if((g|0)!=1){switch(y[d+136|0]){case 4:break Q;case 2:break R;case 0:break S;default:break P}}break q}g=hd(d+136|0);B=Gb(x[h>>2],b),C=y[g|0]^128,v[B|0]=C;g=d+144|0;Jb(g,x[d+232>>2],b);sg(g,0);break P}B=Gb(x[h>>2],b),C=128,v[B|0]=C;g=d+144|0;Jb(g,x[d+232>>2],b);sg(g,1);break P}B=Gb(x[h>>2],b),C=128,v[B|0]=C;g=d+144|0;Jb(g,x[d+232>>2],b);sg(g,0)}b=b+1|0;continue}break}break q}if(A[d+12>>2]<9){break O}b=0;x[23604]=0;Q(174,d+160|0,2)|0;e=x[23604];x[23604]=0;g=65535;if((e|0)==1){break N}while(1){T:{x[23604]=0;e=W(142,x[d+160>>2],x[d+168>>2],1)|0;f=x[23604];x[23604]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{if((f|0)!=1){if(!e){break T}x[23604]=0;f=S(192,d+160|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break q}e=0;switch(f|0){case 0:break T;case 14:break V;case 13:break W;case 12:break X;case 8:break Y;case 7:break Z;case 4:break _;case 1:break $;default:break O}}break q}e=_b(x[a+484360>>2],y[j|0]);if(z[d+244>>1]==65535){B=d,C=il(x[e>>2],x[e+4>>2]),w[B+244>>1]=C}e=il(x[e>>2],x[e+4>>2]);x[23604]=0;w[d+246>>1]=e;e=Q(597,d+160|0,d+287|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break q}aa:{ba:{switch(e-254|0){case 1:e=65535;break aa;case 0:break ba;default:break aa}}e=65534}f=y[j|0];m=x[a+484360>>2];x[23604]=0;R(470,_b(m,f)|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break q}g=(g&65535)==65535?b:g;break U}x[23604]=0;e=S(180,d+160|0)|0;f=x[23604];x[23604]=0;ca:{da:{if((f|0)!=1){if(e>>>0>=(g&65535)>>>0){break da}e=z[d+248>>1];break ca}break q}e=e-g|0;w[d+248>>1]=e}Xe(_b(x[a+484360>>2],y[j|0]),e&65535);break U}x[23604]=0;e=S(192,d+160|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break q}v[d+251|0]=e;break U}x[23604]=0;e=S(192,d+160|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break q}v[d+250|0]=e;break U}x[23604]=0;f=Q(568,d+160|0,d+144|0)|0;m=x[23604];x[23604]=0;if((m|0)!=1){if(y[d+144|0]|!f|(y[d+146|0]|y[d+145|0]!=255)){break O}if(y[d+147|0]|y[d+148|0]!=1){break O}if(!y[d+149|0]){break U}break O}break q}x[23604]=0;R(482,d+152|0,d+160|0);e=x[23604];x[23604]=0;ea:{fa:{ga:{ha:{if((e|0)!=1){m=hd(d+152|0);e=x[h>>2];u=Rc(e,x[d+212>>2]);f=y[d+152|0];if(u>>>0<=f>>>0){break U}switch(y[Re(d+152|0)|0]){case 4:break fa;case 2:break ga;case 0:break ha;default:break ea}}break q}B=Gb(e,f),C=y[m|0]^128,v[B|0]=C;e=d+144|0;Jb(e,x[d+232>>2],y[d+152|0]);sg(e,0);break ea}B=Gb(e,f),C=128,v[B|0]=C;e=d+144|0;Jb(e,x[d+232>>2],y[d+152|0]);sg(e,1);break ea}B=Gb(e,f),C=128,v[B|0]=C;e=d+144|0;Jb(e,x[d+232>>2],y[d+152|0]);sg(e,0)}ia:{if(t){break ia}t=0;e=x[k+4>>2];if(!Gp(x[k>>2],e)){break U}f=Mz(e);e=y[d+152|0];if(y[Gb(x[f>>2],e)|0]!=y[Gb(x[h>>2],e)|0]){break ia}Jb(d+144|0,x[f+24>>2],e);e=Mb(x[x[d+144>>2]>>2],x[d+148>>2]);Jb(d+136|0,x[d+232>>2],y[d+152|0]);if((Mb(x[x[d+136>>2]>>2],x[d+140>>2])|0)==(e|0)){break U}}t=1;break U}x[23604]=0;R(245,d+144|0,d+160|0);e=x[23604];x[23604]=0;if((e|0)==1){break q}e=x[d+220>>2];m=Rc(e,x[d+224>>2]);f=y[d+144|0];if(m>>>0<=f>>>0){break U}m=hd(d+144|0);B=Gb(e,f),C=(y[m|0]>>>2|0)+1|0,v[B|0]=C}b=b+1|0;continue}break}e=1}yb(d+160|0);if(!e){break M}pm(d+184|0);continue}break}break q}b=1}Xd(d+192|0)}rt(h)}yb(l);if(!b){rh(d+264|0);continue}break}e=0;if((b|0)!=2){break w}}e=0;ui(i,0);b=x[k>>2];if(tc(b,x[k+4>>2])){break w}if(!(c&2)){break x}x[23604]=0;U(592,d+160|0,o|0,1347244868);b=x[23604];x[23604]=0;if((b|0)!=1){B=d,C=Bb(x[d+160>>2]),x[B+8>>2]=C;e=a+480190|0;g=d+53|0;h=d+57|0;j=Bb(x[d+164>>2]);l=y[d+287|0];while(1){b=x[d+8>>2];if(!Ob(b,j)){jd(d+160|0);b=x[k>>2];break x}ja:{ka:{la:{if(!l){x[23604]=0;f=Q(598,b|0,d+40|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break ja}if(!f){break ka}f=z[d+92>>1];i=f+1|0;w[d+144>>1]=i;if(f>>>0>3998){break la}B=a,C=z[Se(e,d+144|0)>>1],w[B+480190>>1]=C;x[23604]=0;R(599,d+40|0,(D(i&65535,104)+a|0)+484380|0);f=x[23604];x[23604]=0;if((f|0)==1){break ja}f=d+24|0;TQ(f,g);x[23604]=0;R(208,d+192|0,f|0);f=x[23604];x[23604]=0;if((f|0)==1){break y}f=d+192|0;Bc(((z[d+144>>1]<<5)+a|0)+946304|0,f);xb(f);break la}x[23604]=0;f=Q(600,b|0,d+40|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break y}if(!f){break ka}f=z[d+96>>1];i=f+1|0;w[d+144>>1]=i;if(f>>>0>3998){break la}B=a,C=z[Se(e,d+144|0)>>1],w[B+480190>>1]=C;x[23604]=0;R(601,d+40|0,(D(i&65535,104)+a|0)+484380|0);f=x[23604];x[23604]=0;if((f|0)==1){break y}f=d+24|0;TQ(f,h);x[23604]=0;R(208,d+192|0,f|0);f=x[23604];x[23604]=0;if((f|0)==1){break y}f=d+192|0;Bc(((z[d+144>>1]<<5)+a|0)+946304|0,f);xb(f)}f=z[d+144>>1];if((f-1&65535)>>>0>3998){break ka}i=Xc(d+40|0,8,1,0,2);x[23604]=0;W(205,i|0,(D(f,104)+a|0)+484380|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break ka}break y}rh(d+8|0);continue}break}break y}b=P()|0;break j}b=P()|0;break k}b=P()|0;break c}b=P()|0;break c}b=P()|0;jd(d+160|0);break j}b=Lz(b,0);x[a+480196>>2]=y[b+43|0];x[a+480204>>2]=D(y[b+42|0],1e4);Xe(_b(x[a+484360>>2],y[a+484376|0]),z[b+40>>1]);b=0;while(1){if(z[a+480188>>1]>b>>>0){e=(b<<5)+a|0;g=e+480280|0;Qe(g);h=Lz(x[k>>2],0);B=e+480286|0,C=y[Gb(x[h+12>>2],b)|0],w[B>>1]=C;B=e+480284|0,C=y[Gb(x[h>>2],b)|0],w[B>>1]=C;Jb(d+40|0,x[h+24>>2],b);B=g,C=x[g>>2]&-257|(Mb(x[x[d+40>>2]>>2],x[d+44>>2])?256:0),x[B>>2]=C;b=b+1|0;continue}break}x[23604]=0;b=Q(1,d+192|0,(y[d+287|0]?16979:16852)|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break r}Ab(a+1298344|0,b);xb(b);x[23604]=0;b=Q(1,d+24|0,10029)|0;e=x[23604];x[23604]=0;if((e|0)==1){break s}Ab(a+1298356|0,b);xb(b);x[a+1298404>>2]=5;e=1;if(!(c&1)|!z[a+480188>>1]){break w}x[23604]=0;U(592,d+8|0,o|0,1146045008);b=x[23604];x[23604]=0;if((b|0)==1){break t}b=x[d+12>>2];c=x[d+8>>2];x[23604]=0;l=a+484344|0;R(211,l|0,Bf(c,b)&65535);b=x[23604];x[23604]=0;if((b|0)==1){break v}B=d,C=Bb(x[d+8>>2]),x[B+144>>2]=C;s=Bb(x[d+12>>2]);while(1){j=x[d+144>>2];if(!Ob(j,s)){ma:{na:{b=x[k>>2];e=x[k+4>>2];if(Gp(b,e)>>>0<2){break na}j=a+484348|0;g=0;while(1){if(Gp(b,e)>>>0<=g>>>0){break na}i=x[a+484344>>2];n=x[j>>2];h=fj(x[a+484360>>2],g&255);m=x[h>>2];c=Lz(b,g);f=z[c+36>>1];if(pe(i,n,z[cc(m,f)>>1])){x[23604]=0;e=Q(344,h|0,f|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break ma}oa:{if(!t){break oa}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break oa}f=SQ(x[c+24>>2],b);h=ac(x[l>>2],e);pa:{if(f){he(h,vh(jo(Ce(ye(d+40|0,20,145),0),b&65535)));break pa}he(h,vh(jo(Ce(ye(d+40|0,9,y[Gb(x[c>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;he(ac(x[l>>2],e),vh(Ce(ye(b,16,y[c+43|0]),0)));he(ac(x[l>>2],e),vh(Ce(ye(b,17,y[c+42|0]),0)));e=x[k+4>>2];b=x[k>>2]}g=g+1|0;continue}}jd(d+8|0);e=1;break w}b=P()|0;break u}b=x[j>>2];x[23604]=0;b=S(146,b|0)|0;c=x[23604];x[23604]=0;qa:{ra:{sa:{ta:{ua:{va:{wa:{if((c|0)==1){break wa}x[23604]=0;c=S(143,j|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break wa}if((b|0)!=(c|0)){break qa}b=x[j>>2];x[23604]=0;b=Q(602,b|0,8)|0;c=x[23604];x[23604]=0;if((c|0)==1){break wa}if(!b){break qa}x[23604]=0;i=Q(597,j|0,d+287|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break ra}x[23604]=0;q=S(180,j|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break sa}x[23604]=0;b=W(212,l|0,i|0,q|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break sa}if(!b){break qa}f=0;while(1){if((f|0)==(q|0)){break qa}b=ac(x[l>>2],i);c=of(x[b>>2],x[x[b+48>>2]+12>>2],f);x[23604]=0;b=S(180,j|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break va}xa:{if(b>>>0>=3){x[23604]=0;U(176,d+160|0,j|0,b-2|0);b=x[23604];x[23604]=0;if((b|0)==1){break ta}b=d+160|0;h=kc(d+40|0,b);yb(b);while(1){b=x[h>>2];x[23604]=0;b=W(142,b|0,x[d+48>>2],3)|0;e=x[23604];x[23604]=0;if((e|0)==1){break xa}if(b){x[23604]=0;R(245,d+160|0,h|0);b=x[23604];x[23604]=0;ya:{za:{Aa:{Ba:{if((b|0)!=1){w[d+136>>1]=z[a+480188>>1]-1;B=d,C=y[hd(d+160|0)|0],w[B+264>>1]=C;e=z[Wc(d+136|0,d+264|0)>>1];g=c+D(e,6)|0;b=v[d+160|0];if((b|0)>=0){break ya}x[23604]=0;b=S(192,h|0)|0;n=x[23604];x[23604]=0;if((n|0)==1){break ua}if(y[d+287|0]){break Aa}if((b|0)!=255){break Ba}b=254;break za}break ua}if(b>>>0>128){break za}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break za}b=b>>>0<85?b+36|0:b}v[g|0]=b;b=y[d+160|0]}if(b&64){x[23604]=0;b=S(192,h|0)|0;n=x[23604];x[23604]=0;if((n|0)==1){break ua}v[g+1|0]=b+1;b=y[d+160|0]}if(b&32){x[23604]=0;b=S(192,h|0)|0;n=x[23604];x[23604]=0;if((n|0)==1){break ua}v[d+136|0]=b;v[g+2|0]=1;v[d+264|0]=127;B=g,C=y[Wb(d+136|0,d+264|0)|0]+1>>>1|0,v[B+4|0]=C;b=y[d+160|0]}if(!(b&16)){continue}x[23604]=0;R(245,d+136|0,h|0);b=x[23604];x[23604]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((b|0)!=1){b=y[hd(d+136|0)|0];v[g+5|0]=b;switch(y[d+136|0]-1|0){case 72:break Da;case 71:break Ea;case 70:break Fa;case 61:break Ga;case 60:break Ha;case 53:break Ia;case 52:break Ja;case 51:break Ka;case 50:break Ma;case 43:break Na;case 42:break Oa;case 41:break Pa;case 40:break Qa;case 31:break Ra;case 30:break Sa;case 23:break Ta;case 22:break Ua;case 21:break Va;case 20:break Wa;case 18:break Xa;case 17:break Ya;case 15:break Za;case 16:break _a;case 14:break $a;case 13:break ab;case 12:break bb;case 11:break cb;case 10:break db;case 3:break eb;case 2:break fb;case 1:break gb;case 0:break hb;default:break Ca}}break ua}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b<<4|15;continue}v[g+5|0]=b<<3|15;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b<<4;continue}v[g+5|0]=b<<3&240;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b|240;continue}v[g+5|0]=b>>>1|240;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b&15;continue}if(b>>>0<=1){v[g+5|0]=b|240;continue}v[g+5|0]=b>>>1&15;continue}v[(c+D(e,6)|0)+3|0]=2;B=g,C=qt(b,y[d+287|0])|240,v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=2;B=g,C=qt(b,y[d+287|0]),v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=3;B=g,C=qt(b,y[d+287|0])|240,v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=3;B=g,C=qt(b,y[d+287|0]),v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=4;if(y[d+287|0]){continue}v[g+5|0]=(b&252)>>>2;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&1|16;continue}v[(c+D(e,6)|0)+3|0]=6;v[g+5|0]=b&240;continue}v[(c+D(e,6)|0)+3|0]=6;v[g+5|0]=(b&240)>>>4;continue}v[(c+D(e,6)|0)+3|0]=20;continue}v[(c+D(e,6)|0)+3|0]=5;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|48;continue}v[(c+D(e,6)|0)+3|0]=7;v[g+5|0]=b|240;continue}v[(c+D(e,6)|0)+3|0]=7;continue}v[(c+D(e,6)|0)+3|0]=8;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|64;continue}v[(c+D(e,6)|0)+3|0]=10;x[23604]=0;b=S(192,h|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break La}break ua}v[(c+D(e,6)|0)+3|0]=15;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|192;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|208;continue}v[(c+D(e,6)|0)+3|0]=12;b=(b&254)>>>1|0}v[g+5|0]=b;x[23604]=0;Q(174,h|0,1)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}break ua}v[(c+D(e,6)|0)+3|0]=14;v[g+5|0]=0;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|176;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|224;continue}v[(c+D(e,6)|0)+3|0]=16;continue}v[(c+D(e,6)|0)+3|0]=17;continue}v[(c+D(e,6)|0)+3|0]=1;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|32;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|128;continue}v[(c+D(e,6)|0)+3|0]=0;continue}break}yb(h)}f=f+1|0;continue}break}break ua}b=P()|0;break u}b=P()|0;break u}b=P()|0;yb(h);break u}b=P()|0;break u}b=P()|0;break u}b=P()|0;break u}rh(d+144|0);continue}}jd(d+272|0);RQ(k);yb(d+304|0);break b}b=P()|0}jd(d+8|0);break j}b=P()|0;break j}b=P()|0;break j}b=P()|0;break j}b=P()|0;yb(d+160|0);break m}b=P()|0;break l}b=P()|0;xb(d+160|0);break l}b=P()|0;break l}Xd(d+192|0)}rt(h)}yb(l)}jd(d+272|0);break h}b=P()|0}RQ(k);break f}b=P()|0}yb(d+304|0);break c}b=P()|0;break c}b=P()|0}Xd(o);yb(r);T(b|0);p()}Xd(o);yb(r)}hb=d+384|0;return e|0}function zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;d=hb-480|0;hb=d;xc(b);f=d+472|0;e=ou(b,f);if(!e){sS(f)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!e){break k}if(!tS(d+472|0)){break k}if(!c){G=1;break k}H=ge(d+448|0,b);x[23604]=0;R(438,d+432|0,H|0);b=x[23604];x[23604]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((b|0)!=1){x[23604]=0;U(439,d+408|0,d+432|0,20041);b=x[23604];x[23604]=0;if((b|0)==1){break u}x[23604]=0;e=S(164,x[d+408>>2])|0;b=x[23604];x[23604]=0;if((b|0)==1){break m}if(!e){break l}x[23604]=0;e=Q(440,d+408|0,d+312|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break m}if(!e){break l}x[23604]=0;R(232,a|0,16384);b=x[23604];x[23604]=0;if((b|0)==1){break m}x[a+480208>>2]=8;x[23604]=0;e=W(249,a+1074312|0,9,1)|0;b=x[23604];x[23604]=0;if((b|0)==1){break m}x[23604]=0;e=W(249,e|0,114,1)|0;b=x[23604];x[23604]=0;if((b|0)==1){break m}x[23604]=0;e=Q(250,e|0,21)|0;b=x[23604];x[23604]=0;if((b|0)==1){break m}x[23604]=0;Q(250,e|0,30)|0;b=x[23604];x[23604]=0;if((b|0)==1){break m}x[23604]=0;e=Q(1,d+296|0,8198)|0;b=x[23604];x[23604]=0;if((b|0)==1){break r}Ab(a+1298344|0,e);xb(e);x[23604]=0;e=Q(1,d+280|0,10614)|0;b=x[23604];x[23604]=0;if((b|0)==1){break q}Ab(a+1298356|0,e);xb(e);x[23604]=0;j=Q(1,d+264|0,17349)|0;b=x[23604];x[23604]=0;if((b|0)==1){break p}e=14917;b=y[d+476|0];switch(b-16|0){case 1:break n;case 0:break t;default:break s}}h=P()|0;break a}h=P()|0;break b}e=14898;break n}if(!b){break o}e=21502;break n}h=P()|0;break c}h=P()|0;break c}h=P()|0;break c}e=13129}x[23604]=0;f=Q(1,d+248|0,e|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}x[23604]=0;U(2,d+208|0,j|0,f|0);b=x[23604];x[23604]=0;if((b|0)==1){break f}e=d+208|0;Ab(a+1298368|0,e);xb(e);xb(f);xb(j);x[a+1298404>>2]=5;b=d+96|0;We(b,3,d+312|0);x[23604]=0;R(208,e|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break g}b=d+208|0;Ab(a+1298308|0,b);xb(b);b=d+232|0;jj(b,3,d+344|0);x[23604]=0;R(208,d+96|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break h}x[23604]=0;U(11,d+208|0,5,d+96|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}b=d+208|0;Ab(a+1298320|0,b);xb(b);xb(d+96|0);x[a+480200>>2]=y[d+368|0]+1;I=a,J=Td(y[d+369|0],1,255),x[I+480196>>2]=J;I=a,J=D(Td(y[d+370|0],4,255),1e4),x[I+480204>>2]=J;f=x[a+484360>>2];e=a+484376|0;b=y[e|0];x[23604]=0;ea(324,_b(f,b)|0,d+408|0,z[d+364>>1],65535,65535);b=x[23604];x[23604]=0;if((b|0)==1){break m}Xe(_b(x[a+484360>>2],y[e|0]),z[d+366>>1]);w[a+480188>>1]=0;b=0;while(1){if((b|0)==32){x[23604]=0;U(439,d+208|0,d+432|0,17741);b=x[23604];x[23604]=0;if((b|0)!=1){b=d+208|0;f=$c(d+408|0,b);yb(b);b=x[f>>2];x[23604]=0;e=S(146,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break m}x[23604]=0;X(315,a+1298332|0,f|0,e|0,0);b=x[23604];x[23604]=0;if((b|0)==1){break m}x[23604]=0;U(439,d+208|0,d+432|0,21321);b=x[23604];x[23604]=0;if((b|0)!=1){b=d+208|0;k=$c(f,b);yb(b);b=x[k>>2];x[23604]=0;e=S(164,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break m}v:{w:{if(e){x[23604]=0;U(439,d+208|0,d+432|0,16723);b=x[23604];x[23604]=0;if((b|0)==1){break v}x[23604]=0;j=S(192,k|0)|0;b=x[23604];x[23604]=0;x:{if((b|0)!=1){f=c&2;F=a+480190|0;while(1){if(j>>>0<=(m&255)>>>0){break x}x[23604]=0;i=S(192,k|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break w}if(!i){break x}e=x[k+8>>2];b=x[k>>2];x[23604]=0;e=W(142,b|0,e|0,56)|0;b=x[23604];x[23604]=0;if((b|0)==1){break w}if(!e){break x}if(i>>>0>z[F>>1]){w[F>>1]=i}x[23604]=0;o=D(i,104)+a|0;r=o+484380|0;R(262,r|0,0);b=x[23604];x[23604]=0;if((b|0)==1){break w}YA(r);x[23604]=0;U(298,k|0,((i<<5)+a|0)+946304|0,32);b=x[23604];x[23604]=0;if((b|0)==1){break w}x[23604]=0;R(301,k|0,o+484423|0);b=x[23604];x[23604]=0;if((b|0)==1){break w}y:{if(y[d+476|0]<=15){x[23604]=0;h=S(180,k|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break y}break w}x[23604]=0;h=S(143,k|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break w}}x[o+484404>>2]=h<<1;x[23604]=0;e=S(143,k|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break w}x[r>>2]=e;x[23604]=0;e=S(143,k|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break w}g=o+484384|0;x[g>>2]=e;x[23604]=0;e=S(143,k|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break w}B=o+484388|0;x[B>>2]=e;if(e){b=o+484414|0;w[b>>1]=z[b>>1]|2;x[B>>2]=e+x[g>>2]}x[23604]=0;e=S(192,k|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break w}if(y[d+476|0]<=15){w[o+484410>>1]=e}x[23604]=0;E=S(192,k|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break w}i=o+484414|0;e=z[i>>1];b=8;if(E&1){e=e|1;w[i>>1]=e;x[r>>2]=x[r>>2]>>>1;x[g>>2]=x[g>>2]>>>1;x[B>>2]=x[B>>2]>>>1;b=16}w[i>>1]=e&65531|E<<1&4;b=Xc(d+96|0,b,1,0,((E&12)!=0)<<3);z:{if(!f){break z}x[23604]=0;W(205,b|0,r|0,d+208|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break z}break w}m=m+1|0;continue}}break w}yb(d+208|0)}x[23604]=0;U(439,d+208|0,d+432|0,18761);b=x[23604];x[23604]=0;A:{if((b|0)!=1){b=d+208|0;l=$c(k,b);yb(b);b=x[l>>2];x[23604]=0;e=S(164,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break m}if(!e){break A}s=Sb(d+96|0);u=Sb(d+232|0);t=Sb(d+192|0);x[23604]=0;U(439,d+168|0,d+432|0,17750);b=x[23604];x[23604]=0;B:{if((b|0)==1){break B}b=x[d+180>>2];e=d- -64|0;x[e>>2]=x[d+176>>2];x[e+4>>2]=b;x[d+72>>2]=x[d+184>>2];x[23604]=0;b=x[d+172>>2];x[d+56>>2]=x[d+168>>2];x[d+60>>2]=b;R(441,d+56|0,s|0);b=x[23604];x[23604]=0;if((b|0)==1){break B}x[23604]=0;U(439,d+144|0,d+432|0,17744);b=x[23604];x[23604]=0;if((b|0)==1){break B}b=x[d+156>>2];x[d+40>>2]=x[d+152>>2];x[d+44>>2]=b;x[d+48>>2]=x[d+160>>2];x[23604]=0;b=x[d+148>>2];x[d+32>>2]=x[d+144>>2];x[d+36>>2]=b;R(441,d+32|0,u|0);b=x[23604];x[23604]=0;if((b|0)==1){break B}x[23604]=0;U(439,d+120|0,d+432|0,17734);b=x[23604];x[23604]=0;if((b|0)==1){break B}b=x[d+132>>2];x[d+16>>2]=x[d+128>>2];x[d+20>>2]=b;x[d+24>>2]=x[d+136>>2];x[23604]=0;b=x[d+124>>2];x[d+8>>2]=x[d+120>>2];x[d+12>>2]=b;R(441,d+8|0,t|0);b=x[23604];x[23604]=0;if((b|0)==1){break B}x[23604]=0;r=S(192,l|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break B}o=d+208|1;g=a+480190|0;while(1){if(r>>>0<=(G&255)>>>0){co(t);co(u);co(s);break A}x[23604]=0;R(245,d+80|0,l|0);b=x[23604];x[23604]=0;C:{if((b|0)!=1){C=hd(d+80|0);D:{E:{if(!y[d+80|0]){break E}f=x[l+8>>2];e=x[l>>2];b=y[C|0];x[23604]=0;e=W(142,e|0,f|0,D(b,14)+32|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break B}if(!e){break E}x[23604]=0;q=W(237,a|0,y[d+80|0],0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break B}if(q){break D}}b=y[C|0];x[23604]=0;Q(174,l|0,D(b,14)+32|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break C}break B}x[23604]=0;U(298,l|0,q+492|0,32);b=x[23604];x[23604]=0;if((b|0)==1){break B}B=q+88|0;E=q+68|0;F=q+48|0;i=q+236|0;b=0;m=0;while(1){if(y[C|0]<=(m&255)>>>0){break C}x[23604]=0;R(442,l|0,d+208|0);e=x[23604];x[23604]=0;if((e|0)==1){break B}e=y[d+208|0];F:{if(!e|e>>>0>z[g>>1]){break F}if(y[o|0]>=129){v[o|0]=128}while(1){f=b&255;j=y[d+209|0];if(f>>>0>j>>>0){e=x[s+4>>2];b=x[s>>2];x[23604]=0;X(443,F|0,y[d+211|0],b|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break B}e=x[u+4>>2];b=x[u>>2];x[23604]=0;X(443,E|0,y[d+213|0],b|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break B}e=x[t+4>>2];b=x[t>>2];x[23604]=0;X(443,B|0,y[d+221|0],b|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break B}x[q>>2]=z[d+214>>1]+1>>>1;n=D(y[d+208|0],104)+a|0;G:{if(y[d+211|0]&64){w[n+484410>>1]=y[d+210|0];break G}b=n+484414|0;w[b>>1]=z[b>>1]|32768}w[d+118>>1]=y[d+212|0]<<1;w[d+116>>1]=254;I=n+484408|0,J=z[Wc(d+118|0,d+116|0)>>1],w[I>>1]=J;v[n+484418|0]=y[(y[d+219|0]&3)+27028|0];e=n+484419|0;k=y[d+218|0];v[e|0]=k;f=y[d+217|0]+3>>>2|0;v[n+484420|0]=f;v[n+484421|0]=y[d+216|0];b=j+1|0;if(k){f=zm(Uc(((f<<8|k>>>1)>>>0)/(k>>>0)|0,0))}else{f=255}v[e|0]=f;if(!(y[d+213|0]&64)){break F}e=n+484414|0;w[e>>1]=z[e>>1]|32}else{e=y[d+208|0];I=cc(i,f),J=e,w[I>>1]=J;b=b+1|0;continue}break}}m=m+1|0;continue}}break B}G=G+1|0;continue}}h=P()|0;co(t);co(u);co(s);break c}h=P()|0;break c}G=1;q=Sb(d+232|0);H:{if(!(c&1)){break H}x[23604]=0;U(439,d+208|0,d+432|0,21076);b=x[23604];x[23604]=0;I:{J:{K:{L:{M:{N:{if((b|0)!=1){j=$c(l,d+208|0);b=x[j>>2];x[23604]=0;c=S(164,b|0)|0;b=x[23604];x[23604]=0;O:{P:{Q:{if((b|0)!=1){yb(d+208|0);if(!c){break O}x[23604]=0;e=S(180,j|0)|0;c=x[23604];x[23604]=0;b=1;if((c|0)==1){break Q}x[23604]=0;f=e+1|0;R(444,q|0,f|0);c=x[23604];x[23604]=0;if((c|0)==1){break Q}while(1){if((b|0)==(f|0)){break O}x[23604]=0;e=S(180,j|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break P}x[23604]=0;U(176,d+96|0,j|0,e|0);c=x[23604];x[23604]=0;if((c|0)==1){break P}c=d+96|0;e=kc(d+208|0,c);$c(zg(x[q>>2],b),e);yb(e);b=b+1|0;yb(c);continue}}h=P()|0;yb(d+208|0);break I}h=P()|0;break I}h=P()|0;break I}x[23604]=0;U(439,d+208|0,d+432|0,16720);b=x[23604];x[23604]=0;if((b|0)==1){break K}l=$c(j,d+208|0);b=x[l>>2];x[23604]=0;c=S(164,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break L}yb(d+208|0);if(!c){break N}x[23604]=0;k=S(192,l|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break J}c=0;R:{S:{T:while(1){U:{if(k>>>0<=(c&65535)>>>0){x[23604]=0;Q(141,l|0,1)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break U}break J}m=32;V:{if(y[d+476|0]<16){break V}x[23604]=0;R(445,l|0,d+208|0);b=x[23604];x[23604]=0;if((b|0)==1){break R}m=y[d+208|0];if(m>>>0<=z[a+480188>>1]|m>>>0>32){break V}w[a+480188>>1]=m}b=0;while(1){j=b&65535;if(j>>>0>=m>>>0){c=c+1|0;continue T}x[23604]=0;f=S(180,l|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break S}if(!(!f|j>>>0>31|j>>>0<z[a+480188>>1])){w[a+480188>>1]=b+1}b=b+1|0;continue}}break}x[23604]=0;s=a+484344|0;R(211,s|0,k|0);b=x[23604];x[23604]=0;if((b|0)==1){break J}E=d+208|2;n=0;while(1){if((k|0)==(n|0)){break N}u=Kb(d+96|0);W:{if(y[d+476|0]<16){o=32;j=64;break W}x[23604]=0;R(445,l|0,d+208|0);b=x[23604];x[23604]=0;if((b|0)==1){break M}c=y[d+209|0];o=y[d+208|0];b=d+80|0;df(b,E,16,3);x[23604]=0;R(208,d+192|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break M}b=d+192|0;Ab(u,b);xb(b);j=c+1|0}x[23604]=0;c=W(212,s|0,n&65535,j|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break M}X:{if(!c){x[23604]=0;Q(174,l|0,o<<1)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break X}break M}b=x[s>>2];x[23604]=0;R(266,ac(b,n)|0,u|0);b=x[23604];x[23604]=0;if((b|0)==1){break M}F=j-1|0;r=0;while(1){t=r&65535;if(t>>>0>=o>>>0){break X}x[23604]=0;c=S(180,l|0)|0;b=x[23604];x[23604]=0;Y:{if((b|0)!=1){if(!c){break Y}b=x[q>>2];if(Bf(b,x[q+4>>2])>>>0<=c>>>0|t>>>0>=z[a+480188>>1]){break Y}A=zg(b,c);xc(A);c=0;Z:while(1){e=c;if(j>>>0<=e>>>0){break Y}c=x[A+8>>2];b=x[A>>2];x[23604]=0;c=W(142,b|0,c|0,1)|0;b=x[23604];x[23604]=0;_:{$:{aa:{ba:{ca:{if((b|0)!=1){if(!c){break Y}b=ac(x[s>>2],n);b=cd(x[b>>2],x[x[b+48>>2]+12>>2],e,t);x[23604]=0;f=S(192,A|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break M}g=f<<24>>24;h=(g&252)>>>2|0;switch((g&3)-1|0){case 2:break $;case 1:break aa;case 0:break ba;default:break ca}}break M}c=(e+h|0)+1|0;continue}c=0;if(!e){continue}c=ac(x[s>>2],n);i=cd(x[c>>2],x[x[c+48>>2]+12>>2],e-1|0,t);while(1){c=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[i+4|0]|y[i+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;c=e+1|0;if((e|0)==(F|0)){continue Z}b=D(z[a+480188>>1],6)+b|0;f=h&255;e=c;h=h-1|0;if(f){continue}break}continue}if(e>>>0<=h>>>0){break _}c=ac(x[s>>2],n);f=cd(x[c>>2],x[x[c+48>>2]+12>>2],h,t);c=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;break _}if(h&1){x[23604]=0;f=S(192,A|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break M}v[b|0]=f>>>0>120?-1:f}if(h&2){x[23604]=0;f=S(192,A|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break M}v[b+1|0]=f}c=0;m=0;da:{if(h&4){x[23604]=0;m=S(192,A|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break da}}C=0;if(h&8){x[23604]=0;f=S(192,A|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break da}C=f>>>4|0;c=f&15}B=0;i=0;if(h&16){x[23604]=0;i=S(192,A|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break da}}if((g|0)<0){x[23604]=0;B=S(192,A|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break da}}g=hb-16|0;hb=g;v[g+14|0]=C;v[g+15|0]=c;v[g+13|0]=i;v[g+12|0]=B;if((C-1&255)>>>0<=5){v[g+14|0]=C+15}pS(g+15|0,g+13|0);pS(g+14|0,g+12|0);ea:{fa:{c=y[g+15|0];ga:{if((c|0)==10){i=y[g+12|0];f=y[g+13|0]&15;v[g+13|0]=f?-1:i;c=y[g+14|0];c=(c|0)!=10?c:0;v[g+14|0]=c;f=i|f<<8;break ga}if(y[g+14|0]!=10){break fa}f=y[g+12|0]&15;v[g+12|0]=f?-1:0;f=f<<8}if(f-256>>>0>4294967038){break fa}if(vi(c)>>>0>=vi(10)>>>0){break fa}v[b+5|0]=f;v[b+2|0]=15;v[b+3|0]=10;v[b+4|0]=f>>>8;break ea}if(m){v[b+2|0]=1;v[b+4|0]=m+2>>>2}uu(g+15|0,g+13|0,g+14|0,g+12|0);f=y[g+15|0];ha:{if(!f){break ha}c=y[g+14|0];if(!c){v[g+14|0]=f;v[g+12|0]=y[g+13|0];break ha}if((c|0)==(f|0)&(f|0)!=20){break ha}if(!m){oo(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);v[b+2|0]=y[g+15|0];v[b+4|0]=y[g+13|0];break ha}if(vi(f)>>>0<=vi(c)>>>0){break ha}Xg(g+15|0,g+14|0);Xg(g+13|0,g+12|0)}v[b+3|0]=y[g+14|0];v[b+5|0]=y[g+12|0]}hb=g+16|0;break _}break M}c=e+1|0;continue}}break M}r=r+1|0;continue}}xb(u);n=n+1|0;continue}}h=P()|0;break I}h=P()|0;break I}h=P()|0;break I}x[23604]=0;U(439,d+208|0,d+432|0,20048);b=x[23604];x[23604]=0;ia:{ja:{if((b|0)!=1){f=$c(l,d+208|0);b=x[f>>2];x[23604]=0;c=S(164,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break ja}yb(d+208|0);if(!c){break H}e=a+484348|0;while(1){if(!nf(x[a+484344>>2],x[e>>2])){break H}c=x[f+8>>2];b=x[f>>2];x[23604]=0;c=W(142,b|0,c|0,16)|0;b=x[23604];x[23604]=0;if((b|0)==1){break ia}if(!c){break H}x[23604]=0;R(446,f|0,d+208|0);b=x[23604];x[23604]=0;if((b|0)!=1){b=x[a+484344>>2];x[23604]=0;R(447,ac(b,0)|0,d+208|0);b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}h=P()|0;break I}h=P()|0;break I}h=P()|0;yb(d+208|0);break I}h=P()|0;break I}h=P()|0;xb(u);break I}h=P()|0;yb(d+208|0);break I}h=P()|0;break I}h=P()|0}jd(q);break c}jd(q);break l}h=P()|0;yb(d+208|0);break c}h=P()|0;break c}h=P()|0;break c}h=P()|0;break c}i=(b<<5)+a|0;j=i+480280|0;Qe(j);f=v[(b+d|0)+371|0];e=f<<1&254;w[i+480284>>1]=(e|0)==254?256:e;ka:{if((f|0)<0){x[j>>2]=x[j>>2]|1024;break ka}w[a+480188>>1]=b+1}x[23604]=0;R(448,d+408|0,i+480289|0);e=x[23604];x[23604]=0;if((e|0)==1){break j}b=b+1|0;continue}}h=P()|0;break c}yb(d+408|0);Xd(d+432|0);yb(H)}hb=d+480|0;return G|0}h=P()|0;break c}h=P()|0;xb(d+96|0);break c}h=P()|0;break c}h=P()|0;break c}h=P()|0;xb(f);break d}h=P()|0}xb(j)}yb(d+408|0)}Xd(d+432|0)}yb(H);T(h|0);p()}function VU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=hb-448|0;hb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!Th(b,d+440|0)){break F}if(!uB(d+440|0)){break F}if(!c){o=1;break F}q=ge(d+416|0,b);x[23604]=0;R(246,d+400|0,q|0);b=x[23604];x[23604]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){x[23604]=0;U(247,d+224|0,d+400|0,1229866575);b=x[23604];x[23604]=0;if((b|0)==1){break da}x[23604]=0;o=Q(248,d+224|0,d+384|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break fa}yb(d+224|0);if(!o){break G}x[23604]=0;R(232,a|0,524288);b=x[23604];x[23604]=0;ga:{if((b|0)==1){break ga}Ag(a);x[a+480208>>2]=12;H=a+480188|0,I=Td(Lb(z[d+392>>1]),1,127),w[H>>1]=I;H=d,I=Lb(z[d+384>>1]),w[H+224>>1]=I;w[d+328>>1]=255;H=a+480192|0,I=z[Wc(d+224|0,d+328|0)>>1],w[H>>1]=I;H=d,I=Lb(z[d+386>>1]),w[H+224>>1]=I;w[d+328>>1]=3999;H=a+480190|0,I=z[Wc(d+224|0,d+328|0)>>1],w[H>>1]=I;x[23604]=0;b=W(249,a+1074312|0,6,1)|0;e=x[23604];x[23604]=0;if((e|0)==1){break ga}x[23604]=0;b=Q(250,b|0,21)|0;e=x[23604];x[23604]=0;if((e|0)==1){break ga}x[23604]=0;Q(250,b|0,13)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break ea}}b=P()|0;break b}b=P()|0;break a}b=P()|0;yb(d+224|0);break b}x[23604]=0;b=Q(1,d+368|0,9184)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}Ab(a+1298344|0,b);xb(b);x[23604]=0;b=Q(1,d+352|0,10209)|0;e=x[23604];x[23604]=0;if((e|0)==1){break d}Ab(a+1298356|0,b);xb(b);x[23604]=0;R(251,d+328|0,4297);b=x[23604];x[23604]=0;if((b|0)==1){break e}x[23604]=0;R(252,d+304|0,d+440|4);b=x[23604];x[23604]=0;if((b|0)==1){break g}x[23604]=0;R(252,d+280|0,d+440|5);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;X(97,d+224|0,d+328|0,d+304|0,d+280|0);b=x[23604];x[23604]=0;if((b|0)==1){break j}b=d+224|0;Ab(a+1298368|0,b);xb(b);xb(d+280|0);xb(d+304|0);b=d+328|0;Db(b);x[a+1298404>>2]=13;x[23604]=0;U(247,b|0,d+400|0,1312902469);b=x[23604];x[23604]=0;if((b|0)==1){break k}x[23604]=0;b=S(146,x[d+328>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break m}x[23604]=0;j=a+1298308|0;U(253,d+328|0,j|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break m}x[23604]=0;U(247,d+304|0,d+400|0,1397706311);b=x[23604];x[23604]=0;if((b|0)==1){break n}g=a+484360|0;e=a+484376|0;Fc(_b(x[g>>2],y[e|0]));h=Lb(z[d+388>>1]);k=a+1298319|0;m=a+1298312|0;ha:{ia:{while(1){if(h>>>0<=(f&65535)>>>0){break ha}x[23604]=0;b=W(142,x[d+304>>2],x[d+312>>2],46)|0;n=x[23604];x[23604]=0;ja:{if((n|0)!=1){if(!b){break ha}x[23604]=0;R(254,d+304|0,d+224|0);b=x[23604];x[23604]=0;if((b|0)!=1){if(!wd(x[m>>2],y[k|0])){break ja}x[23604]=0;R(255,j|0,d+224|0);b=x[23604];x[23604]=0;if((b|0)!=1){break ja}}b=P()|0;break o}b=P()|0;break o}x[23604]=0;n=S(256,d+304|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break ca}b=_b(x[a+484360>>2],y[e|0]);if(!tc(x[b>>2],x[b+4>>2])){x[23604]=0;b=S(257,g|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break ca}if((b|0)==255){break ha}b=_b(x[a+484360>>2],y[e|0])}x[23604]=0;U(5,d+280|0,13,d+224|0);i=x[23604];x[23604]=0;if((i|0)!=1){x[23604]=0;R(258,b|0,d+280|0);b=x[23604];x[23604]=0;if((b|0)==1){break ia}xb(d+280|0);b=y[e|0];i=x[a+484360>>2];x[23604]=0;U(259,_b(i,b)|0,d+304|0,n|0);b=x[23604];x[23604]=0;if((b|0)==1){break ca}f=f+1|0;continue}break}b=P()|0;break o}b=P()|0;xb(d+280|0);break o}ui(g,0);x[23604]=0;U(247,d+280|0,d+400|0,1229869908);b=x[23604];x[23604]=0;if((b|0)==1){break ba}x[23604]=0;b=S(260,x[d+280>>2])|0;f=x[23604];x[23604]=0;if((f|0)==1){break p}ka:{if(!b){break ka}g=a+480192|0;f=1;la:{while(1){b=f&65535;if(b>>>0>z[g>>1]){x[23604]=0;U(247,d+200|0,d+400|0,1447382614);b=x[23604];x[23604]=0;if((b|0)!=1){break la}break p}x[23604]=0;R(261,d+280|0,d+224|0);e=x[23604];x[23604]=0;if((e|0)==1){break p}e=z[d+254>>1];x[23604]=0;b=W(237,a|0,b|0,Lb(e)|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break p}ma:{na:{if(!b){break na}if(Lb(z[d+254>>1])>>>0>3999){break na}e=d+112|0;ju(e,2,d+224|0);x[23604]=0;R(208,d+136|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break ma}e=d+136|0;Bc(b+492|0,e);xb(e);j=d+112|0;ju(j,2,d+224|0);x[23604]=0;R(208,e|0,j|0);e=x[23604];x[23604]=0;if((e|0)==1){break p}e=d+136|0;Bc(((Lb(z[d+254>>1])<<5)+a|0)+946304|0,e);xb(e);x[b>>2]=0;H=b,I=Lb(z[d+270>>1])+128&65535,x[H+8>>2]=I;wc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=z[d+254>>1];x[23604]=0;b=D(Lb(b),104)+a|0;R(262,b+484380|0,0);e=x[23604];x[23604]=0;if((e|0)==1){break p}H=d,I=Lb(z[d+256>>1]),w[H+136>>1]=I;w[d+112>>1]=64;H=b+484410|0,I=z[Wc(d+136|0,d+112|0)>>1]<<2,w[H>>1]=I;j=b+484404|0;e=dc(z[d+258>>1]|z[d+260>>1]<<16);h=Jia(e,e>>31,8303,0);e=lb;h=h+4181|0;e=h>>>0<4181?e+1|0:e;H=j,I=Ec(Kia(h,e,8363,0),lb),x[H>>2]=I;e=dc(z[d+266>>1]|z[d+268>>1]<<16);if(!e){break na}j=Lb(z[d+272>>1]);if(!(j&3)){break na}h=dc(z[d+262>>1]|z[d+264>>1]<<16);x[b+484384>>2]=h;x[b+484388>>2]=e+h;b=b+484414|0;e=z[b>>1];w[b>>1]=e|2;if(!(j&2)){break na}w[b>>1]=e|6}f=f+1|0;continue}break}break p}b=x[d+212>>2];x[d+32>>2]=x[d+208>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+216>>2];x[23604]=0;b=x[d+204>>2];x[d+24>>2]=x[d+200>>2];x[d+28>>2]=b;X(263,d+24|0,0,a|0,0);b=x[23604];x[23604]=0;if((b|0)==1){break p}x[23604]=0;U(247,d+176|0,d+400|0,1346719318);b=x[23604];x[23604]=0;if((b|0)==1){break p}b=x[d+188>>2];x[d+8>>2]=x[d+184>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+192>>2];x[23604]=0;b=x[d+180>>2];x[d>>2]=x[d+176>>2];x[d+4>>2]=b;X(263,d|0,1,a|0,y[d+444|0]>2|0);b=x[23604];x[23604]=0;if((b|0)==1){break p}e=z[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break ka}f=x[((b<<2)+a|0)+900380>>2];if(!(!f|v[f+60|0]&1)){x[f>>2]=32767}b=b+1|0;continue}}yb(d+280|0);x[23604]=0;U(247,d+224|0,d+400|0,1346458708);b=x[23604];x[23604]=0;if((b|0)==1){break q}x[23604]=0;b=S(164,x[d+224>>2])|0;f=x[23604];x[23604]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){x[23604]=0;U(247,d+280|0,d+400|0,1347305805);b=x[23604];x[23604]=0;if((b|0)==1){break t}x[23604]=0;Q(174,d+280|0,1)|0;b=x[23604];x[23604]=0;if((b|0)==1){break v}b=z[d+390>>1];x[23604]=0;m=a+484344|0;R(211,m|0,Lb(b)|0);b=x[23604];x[23604]=0;if((b|0)==1){break v}b=d+112|0;s=b|5;t=b|3;u=b|4;A=b|2;B=b|1;j=Sb(d+160|0);C=a+480188|0;f=0;while(1){if(Lb(z[d+390>>1])>>>0<=f>>>0){nd(j);yb(d+280|0);if(!(c&4)){break $}f=0;if(!E){break aa}e=z[a+480188>>1];b=0;f=1;while(1){if((b|0)==(e|0)){break aa}g=(b<<5)+a|0;v[g+480288|0]=1;g=g+480280|0;x[g>>2]=x[g>>2]|67108864;b=b+1|0;continue}}x[23604]=0;b=S(256,d+224|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break x}x[23604]=0;e=S(264,d+224|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break y}x[23604]=0;U(176,d+112|0,d+224|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break z}e=d+112|0;g=kc(d+136|0,e);yb(e);x[23604]=0;e=W(212,m|0,f&65535,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break B}oa:{if(e){n=Kb(d+96|0);x[23604]=0;R(265,d+280|0,n|0);e=x[23604];x[23604]=0;if((e|0)==1){break oa}e=x[m>>2];x[23604]=0;R(266,ac(e,f)|0,n|0);e=x[23604];x[23604]=0;if((e|0)==1){break oa}e=0;h=ac(x[m>>2],f);r=of(x[h>>2],x[x[h+48>>2]+12>>2],0);Fc(j);F=(b>>>0<=1?1:b)-1|0;pa:while(1){b=x[g>>2];x[23604]=0;b=W(142,b|0,x[d+144>>2],1)|0;h=x[23604];x[23604]=0;if((h|0)==1){break C}qa:{if(!b){break qa}x[23604]=0;k=S(192,g|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break C}if(!k){H=d,I=Bb(x[j>>2]),x[H+88>>2]=I;h=Bb(x[j+4>>2]);while(1){b=x[d+88>>2];if(Ob(b,h)){he(ac(x[m>>2],f),Ce(ye(d+112|0,y[b|0],y[b+1|0]),e));Pe(d+88|0);continue}else{Fc(j);if((e|0)==(F|0)){break qa}b=ac(x[m>>2],f);e=e+1|0;r=of(x[b>>2],x[x[b+48>>2]+12>>2],e);continue pa}}}sh(d+112|0);h=z[C>>1];x[23604]=0;b=S(192,g|0)|0;i=x[23604];x[23604]=0;ra:{sa:{if((i|0)!=1){h=h>>>0<k>>>0;k=D(k-1|0,6)+r|0;ta:{if(!(b&1)){break ta}x[23604]=0;i=S(192,g|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break C}l=h?d+112|0:k;if((i|0)!=31){if((i-1&255)>>>0>252){break ta}i=(D(i>>>4|0,12)+(i&15)|0)+13|0}else{i=255}v[l|0]=i}if(!(b&2)){break ra}x[23604]=0;i=S(192,g|0)|0;l=x[23604];x[23604]=0;if((l|0)!=1){break sa}}break C}v[(h?B:k+1|0)|0]=i}if(!(b&60)){continue}v[d+87|0]=0;v[d+86|0]=0;v[d+85|0]=0;v[d+84|0]=0;if(b&4){x[23604]=0;i=S(192,g|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break C}v[d+86|0]=i}if(b&8){x[23604]=0;i=S(192,g|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break C}v[d+84|0]=i}if(b&16){x[23604]=0;i=S(192,g|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break C}v[d+87|0]=i}if(b&32){x[23604]=0;b=S(192,g|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break C}v[d+85|0]=b}rB(d+87|0,d+85|0);rB(d+86|0,d+84|0);b=y[d+86|0];if(!(y[d+87|0]==13|b?(b|0)!=13:0)){Xg(d+87|0,d+86|0);Xg(d+85|0,d+84|0)}oo(d+88|0,d+87|0,d+85|0,d+86|0,d+84|0);if(qB(y[d+88|0],y[d+89|0])){b=x[Ib(d+80|0,Bb(x[j>>2]))>>2];x[23604]=0;U(267,j|0,b|0,d+88|0);b=x[23604];x[23604]=0;if((b|0)==1){break C}}v[(h?A:k+2|0)|0]=y[d+87|0];v[(h?u:k+4|0)|0]=y[d+85|0];b=y[d+86|0];v[(h?t:k+3|0)|0]=b;v[(h?s:k+5|0)|0]=y[d+84|0];if((b|0)==43){E=1;continue}if((b|0)!=31){continue}G=1;continue}break}xb(n)}yb(g);f=f+1|0;continue}break}break C}f=0;if(c&4){break aa}break H}b=P()|0;break b}b=P()|0;break o}b=P()|0;break o}x[d+160>>2]=-1778364416;x[d+164>>2]=-16756736;x[23604]=0;U(247,d+280|0,d+400|0,1146310725);b=x[23604];x[23604]=0;if((b|0)==1){break E}x[23604]=0;b=S(260,x[d+280>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break D}if(b){x[23604]=0;j=S(256,d+280|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break D}h=a+480188|0;b=0;e=f;while(1){ua:{if((b|0)==(j|0)){x[23604]=0;R(268,d+280|0,d+160|0);b=x[23604];x[23604]=0;if((b|0)!=1){break ua}break D}x[23604]=0;g=S(192,d+280|0)|0;k=x[23604];x[23604]=0;va:{wa:{if((k|0)!=1){if(z[h>>1]<=b>>>0){break va}if(!f){break wa}k=((b<<5)+a|0)+480280|0;x[k>>2]=x[k>>2]&-67108865|((g|0)!=0)<<26;break va}break D}if(g){break va}e=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}f=e&1}yb(d+280|0);if(!f){break $}x[23604]=0;Y(269,a+906300|0);b=x[23604];x[23604]=0;if((b|0)==1){break _}b=a+906324|0;x[b>>2]=655376;x[b+4>>2]=0;b=a+906316|0;x[b>>2]=810369604;x[b+4>>2]=1869112133;x[d+280>>2]=0;f=a+906348|0;nB(a+906332|0,f,d+280|0);x[23604]=0;b=Q(54,d+136|0,9458)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Z}iu(f,b);xb(b);x[23604]=0;b=Q(54,d+112|0,9422)|0;f=x[23604];x[23604]=0;if((f|0)==1){break Y}oq(a+906380|0,b);xb(b);x[23604]=0;b=a+906304|0;R(270,b|0,8);f=x[23604];x[23604]=0;if((f|0)==1){break _}mB(d+280|0,y[d+161|0],y[d+163|0],y[d+165|0],y[d+167|0]);f=x[d+284>>2];b=x[b>>2];e=x[d+280>>2];v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=f;v[b+5|0]=f>>>8;v[b+6|0]=f>>>16;v[b+7|0]=f>>>24}if(!G){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}x[d+88>>2]=D(b,127)>>>5;x[23604]=0;R(271,d+160|0,4054);e=x[23604];x[23604]=0;if((e|0)==1){break X}x[23604]=0;R(272,d+96|0,d+88|0);e=x[23604];x[23604]=0;if((e|0)==1){break W}x[23604]=0;U(273,d+280|0,d+160|0,d+96|0);e=x[23604];x[23604]=0;if((e|0)==1){break V}e=d+280|0;ve(d+72|0,e);Oe(qe(f,b),x[d+72>>2],x[d+76>>2]);xb(e);xb(d+96|0);e=d+160|0;Db(e);x[23604]=0;R(271,e|0,4036);e=x[23604];x[23604]=0;if((e|0)==1){break T}x[23604]=0;R(272,d+96|0,d+88|0);e=x[23604];x[23604]=0;if((e|0)==1){break S}x[23604]=0;U(273,d+280|0,d+160|0,d+96|0);e=x[23604];x[23604]=0;if((e|0)==1){break R}e=d+280|0;ve(d- -64|0,e);Oe(qe(f,b+32|0),x[d+64>>2],x[d+68>>2]);xb(e);xb(d+96|0);e=d+160|0;Db(e);x[23604]=0;R(271,e|0,4027);e=x[23604];x[23604]=0;if((e|0)==1){break P}x[23604]=0;R(272,d+96|0,d+88|0);e=x[23604];x[23604]=0;if((e|0)==1){break O}x[23604]=0;U(273,d+280|0,d+160|0,d+96|0);e=x[23604];x[23604]=0;if((e|0)==1){break N}e=d+280|0;ve(d+56|0,e);Oe(qe(f,b- -64|0),x[d+56>>2],x[d+60>>2]);xb(e);xb(d+96|0);e=d+160|0;Db(e);x[23604]=0;R(271,e|0,4e3);e=x[23604];x[23604]=0;if((e|0)==1){break L}x[23604]=0;R(272,d+96|0,d+88|0);e=x[23604];x[23604]=0;if((e|0)==1){break K}x[23604]=0;U(273,d+280|0,d+160|0,d+96|0);e=x[23604];x[23604]=0;if((e|0)==1){break J}e=d+280|0;ve(d+48|0,e);Oe(qe(f,b+96|0),x[d+48>>2],x[d+52>>2]);b=b+1|0;xb(e);xb(d+96|0);Db(d+160|0);continue}}b=P()|0;break r}b=P()|0;break r}b=P()|0;break r}b=P()|0;break r}b=P()|0;break U}b=P()|0;xb(d+96|0)}Db(d+160|0);break r}b=P()|0;break r}b=P()|0;break Q}b=P()|0;xb(d+96|0)}Db(d+160|0);break r}b=P()|0;break r}b=P()|0;break M}b=P()|0;xb(d+96|0)}Db(d+160|0);break r}b=P()|0;break r}b=P()|0;break I}b=P()|0;xb(d+96|0)}Db(d+160|0);break r}x[23604]=0;U(247,d+280|0,d+400|0,1397575756);b=x[23604];x[23604]=0;xa:{if((b|0)!=1){x[23604]=0;b=S(164,x[d+280>>2])|0;f=x[23604];x[23604]=0;if((f|0)!=1){ya:{f=1;if(!(c&2)|b^1){break xa}c=a+480190|0;while(1){e=f&65535;if(e>>>0>z[c>>1]){break xa}x[23604]=0;b=S(264,d+280|0)|0;g=x[23604];x[23604]=0;za:{if((g|0)!=1){x[23604]=0;g=S(264,d+280|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break ya}if(!(b&7)){break za}e=(D(e,104)+a|0)+484380|0;x[e>>2]=g;b=Xc(d+160|0,b&4?32:b&2?16:8,1,1,0);x[23604]=0;W(205,b|0,e|0,d+280|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break za}break ya}break ya}f=f+1|0;continue}}}b=P()|0;yb(d+280|0);break r}b=P()|0;break r}yb(d+280|0);yb(d+224|0);yb(d+304|0);yb(d+328|0)}Xd(d+400|0);yb(q)}hb=d+448|0;return o|0}b=P()|0;break r}b=P()|0;yb(d+280|0);break r}b=P()|0;xb(n);break A}b=P()|0}yb(g);break w}b=P()|0;break w}b=P()|0;break w}b=P()|0}nd(j);break u}b=P()|0}yb(d+280|0);break r}b=P()|0;break r}b=P()|0}yb(d+224|0);break o}b=P()|0;break o}b=P()|0;yb(d+280|0)}yb(d+304|0);break l}b=P()|0;break l}b=P()|0}yb(d+328|0);break b}b=P()|0;break b}b=P()|0;xb(d+280|0);break h}b=P()|0}xb(d+304|0);break f}b=P()|0}Db(d+328|0);break b}b=P()|0;break b}b=P()|0;break b}b=P()|0}Xd(d+400|0)}yb(q);T(b|0);p()}function $ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=hb-240|0;hb=d;xc(b);e=hb-16|0;hb=e;h=d+216|0;Ut(e+8|0,h);g=x[e+12>>2];mc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(g|0)){bc(b,x[e+12>>2])}hb=e+16|0;e=(g|0)==(j|0);if(!e){FT(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!GT(d+216|0)){break n}if(!c){f=1;break n}Cd(a,1024);Ag(a);x[a+480208>>2]=x[a+480208>>2]|12;zf(a+1074312|0,21);e=Lb(z[d+232>>1]);if(e){x[a+480204>>2]=D(e,1e4)}e=Lb(z[d+230>>1]);if(e){x[a+480196>>2]=e}if(!y[d+226|0]){uh(a,1)}ku(b,a+1298308|0,dc(x[d+220>>2])-14|0);b=ge(d+112|0,b);x[23604]=0;R(322,d+200|0,b|0);e=x[23604];x[23604]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){yb(b);x[23604]=0;U(323,d+112|0,d+200|0,1395544366);b=x[23604];x[23604]=0;if((b|0)==1){break s}x[23604]=0;b=S(260,x[d+112>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break y}if(!b){break r}x[23604]=0;b=S(256,d+112|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break y}x[23604]=0;e=S(256,d+112|0)|0;f=x[23604];x[23604]=0;A:{if((f|0)==1){break A}x[23604]=0;Q(174,d+112|0,4)|0;f=x[23604];x[23604]=0;if((f|0)==1){break A}f=a+484376|0;g=y[f|0];h=x[a+484360>>2];x[23604]=0;ea(324,_b(h,g)|0,d+112|0,b|0,65535,65535);b=x[23604];x[23604]=0;if((b|0)!=1){break z}}break y}a=P()|0;yb(b);break a}Xe(_b(x[a+484360>>2],y[f|0]),e);b=d+112|0;yb(b);x[23604]=0;U(323,b|0,d+200|0,1346458708);b=x[23604];x[23604]=0;if((b|0)==1){break x}x[23604]=0;e=S(260,x[d+112>>2])|0;b=x[23604];x[23604]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}x[23604]=0;e=S(256,d+112|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break w}w[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}x[23604]=0;b=S(256,d+112|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break w}x[23604]=0;R(211,a+484344|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break w}b=0;x[23604]=0;m=S(264,d+112|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break w}switch(m-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}a=P()|0;yb(d+112|0);break b}a=P()|0;break b}a=P()|0;yb(d+112|0);break b}if(m){break t}}b=1}yb(d+112|0);if(!b){break o}x[23604]=0;U(323,d+176|0,d+200|0,1398157625);b=x[23604];x[23604]=0;if((b|0)==1){break d}x[23604]=0;b=S(260,x[d+176>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}if(!b){break q}x[23604]=0;Q(174,d+176|0,2)|0;b=x[23604];x[23604]=0;if((b|0)==1){break c}x[23604]=0;b=S(264,d+176|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}H=a,I=Ge((+(b>>>0)*2.3283064365386963e-10+ +(A[a+480204>>2]/1e4>>>0))*1e4),x[H+480204>>2]=I;b=0;x[23604]=0;Q(325,d+176|0,d+112|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}f=z[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){H=d,I=Lb(z[(d+112|0)+(b<<1)>>1]),x[H+48>>2]=I;x[d+32>>2]=180;e=x[rd(d+48|0,d+32|0)>>2]-90|0;h=e>>31<<7|e>>>25;H=((b<<5)+a|0)+480284|0,I=Ec(Kia(e<<7|45,h,90,0),lb)+128|0,w[H>>1]=I;b=b+1|0;continue}else{B:{x[23604]=0;Q(174,d+176|0,16)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break B}break c}}break}x[23604]=0;b=W(142,x[d+176>>2],x[d+184>>2],2)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}C:{if(b){x[23604]=0;b=S(256,d+176|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break C}w[d+48>>1]=b;w[d+32>>1]=256;H=a,I=z[Wc(d+48|0,d+32|0)>>1],x[H+480200>>2]=I}x[23604]=0;Q(174,d+176|0,128)|0;b=x[23604];x[23604]=0;if((b|0)==1){break c}x[23604]=0;b=Q(325,d+176|0,d+48|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){if(!b){break q}e=z[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){H=d,I=Lb(z[(d+48|0)+(b<<1)>>1]),x[H+32>>2]=I;x[d+16>>2]=128;H=((b<<5)+a|0)+480286|0,I=x[rd(d+32|0,d+16|0)>>2]/2&255,w[H>>1]=I;b=b+1|0;continue}else{x[a+480228>>2]=x[a+480228>>2]<<1;break q}}break c}break c}a=P()|0;break b}yb(d+112|0);break p}yb(d+176|0);x[23604]=0;U(323,d+112|0,d+200|0,1413830740);b=x[23604];x[23604]=0;D:{E:{if((b|0)!=1){x[23604]=0;b=S(260,x[d+112>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break e}if(!b){break D}x[23604]=0;R(326,d+112|0,d+48|0);b=x[23604];x[23604]=0;if((b|0)==1){break e}if((Lb(z[d+58>>1])|0)!=65535){break E}x[23604]=0;Q(174,d+112|0,1)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break E}break e}a=P()|0;break b}x[23604]=0;b=S(188,d+112|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break e}x[23604]=0;X(315,a+1298332|0,d+112|0,b|0,2);b=x[23604];x[23604]=0;if((b|0)==1){break e}}yb(d+112|0);x[23604]=0;U(323,d+48|0,d+200|0,1229869908);b=x[23604];x[23604]=0;if((b|0)==1){break h}x[23604]=0;b=S(260,x[d+48>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}F:{if(!b){break F}x[23604]=0;b=S(256,d+48|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}x[23604]=0;e=W(142,x[d+48>>2],x[d+56>>2],D(f,(b>>>14&2)+50|0)|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break g}if(!e){break H}w[a+480190>>1]=f;g=a+480190|0;h=d+130|0;j=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){x[23604]=0;b=S(256,d+48|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break I}break g}M:{if(j){o=b}else{x[23604]=0;e=S(256,d+48|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break M}o=e+1|0}w[d+16>>1]=o;x[23604]=0;R(327,d+48|0,d+112|0);e=x[23604];x[23604]=0;if((e|0)==1){break L}e=z[d+16>>1];if((e-4e3&65535)>>>0>=61537){H=a,I=z[Se(g,d+16|0)>>1],w[H+480190>>1]=I;l=z[d+234>>1]|z[d+236>>1]<<16;x[23604]=0;X(328,d+112|0,(D(e,104)+a|0)+484380|0,dc(l)|0,m|0);e=x[23604];x[23604]=0;if((e|0)==1){break K}e=d+32|0;ml(e,2,h);x[23604]=0;R(208,d+176|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break J}e=d+176|0;Bc(((z[d+16>>1]<<5)+a|0)+946304|0,e);xb(e)}b=b+1|0;continue}break}a=P()|0;break f}a=P()|0;break f}a=P()|0;break f}a=P()|0;break f}if((b|0)!=4){break F}w[d+112>>1]=z[a+480190>>1];w[d+176>>1]=255;h=a+480192|0;b=d+176|0;H=h,I=z[Wc(d+112|0,b)>>1],w[H>>1]=I;x[23604]=0;U(323,b|0,d+200|0,1229278806);b=x[23604];x[23604]=0;if((b|0)==1){break j}N:while(1){O:{x[23604]=0;b=W(142,x[d+48>>2],x[d+56>>2],15)|0;e=x[23604];x[23604]=0;if((e|0)==1){break O}if(!b){break G}x[23604]=0;R(329,d+48|0,d+32|0);b=x[23604];x[23604]=0;if((b|0)==1){break k}b=Lb(z[d+32>>1]);if(b>>>0>=z[h>>1]){continue}e=D(b,104)+a|0;v[e+484524|0]=y[d+40|0];f=y[d+39|0];v[e+484523|0]=255;v[e+484525|0]=f;x[23604]=0;b=b+1&65535;e=W(237,a|0,b|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break k}if(!e){continue}H=d,I=Lb(y[d+37|0]|y[d+38|0]<<8),w[H+112>>1]=I;w[d+16>>1]=4095;H=e,I=z[Wc(d+112|0,d+16|0)>>1],x[H>>2]=I;b=y[d+35|0];if((b|0)==255){continue}x[23604]=0;b=Q(141,d+176|0,D(b,34)+2|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break k}if(!b){continue}x[23604]=0;R(330,d+176|0,d+112|0);b=x[23604];x[23604]=0;if((b|0)==1){break k}v[e+60|0]=y[e+60|0]|1;b=z[d+112>>1];x[d+20>>2]=16;x[d+24>>2]=240;H=d,I=Lb(b),x[H+16>>2]=I;b=jB(d+16|0);x[23604]=0;R(276,e+48|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break k}g=x[e+52>>2];f=x[e+48>>2];b=0;while(1){j=ie(f,g);if(j>>>0<=b>>>0){b=y[d+36|0];if((b|0)!=255){v[e- -64|0]=b;v[e+63|0]=b;v[e+60|0]=y[e+60|0]|4}if(tc(f,g)){continue N}b=j-1|0;v[e+62|0]=b;v[e+61|0]=b;v[e+60|0]=y[e+60|0]|2;continue N}else{v[d+16|0]=64;j=(d+112|0)+(b<<1)|0;v[d+12|0]=y[j+2|0];l=Wb(d+16|0,d+12|0);i=zb(f,b);v[i+2|0]=y[l|0];w[i>>1]=y[j+3|0];b=b+1|0;continue}}}break}break k}yb(d+48|0);break p}yb(d+176|0)}yb(d+48|0);x[23604]=0;U(331,d+176|0,d+200|0,1145131092);b=x[23604];x[23604]=0;if((b|0)==1){break m}H=d,I=Bb(x[d+176>>2]),x[H+16>>2]=I;l=a+484344|0;C=c&1;s=d+48|4;E=Bb(x[d+180>>2]);t=(m|0)!=841887798;u=a+480188|0;F=(m|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{g=x[d+16>>2];if(!Ob(g,E)){jd(d+176|0);x[23604]=0;U(323,d+112|0,d+200|0,1346458702);b=x[23604];x[23604]=0;if((b|0)!=1){break ba}a=P()|0;break b}x[23604]=0;Q(174,g|0,4)|0;b=x[23604];x[23604]=0;if((b|0)!=1){x[23604]=0;f=S(256,g|0)|0;b=x[23604];x[23604]=0;ca:{if((b|0)!=1){x[23604]=0;j=S(256,g|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break R}j=t?j:(j>>>0)/A[a+480196>>2]|0;if(!C|f>>>0>255){break P}x[23604]=0;b=W(212,l|0,f|0,j|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break R}if(b){break ca}break P}a=P()|0;break Q}if(!t){h=0;x[23604]=0;Q(174,g|0,4)|0;b=x[23604];x[23604]=0;if((b|0)==1){break R}while(1){B=h&65535;if(B>>>0>=z[u>>1]){break P}x[23604]=0;b=S(256,g|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break aa}x[23604]=0;U(176,d+48|0,g|0,b+(b&1)&65535);b=x[23604];x[23604]=0;if((b|0)==1){break S}b=d+48|0;e=kc(d+112|0,b);yb(b);x[d+48>>2]=0;x[d+52>>2]=0;n=0;da:{while(1){b=x[e>>2];x[23604]=0;b=W(142,b|0,x[d+120>>2],6)|0;i=x[23604];x[23604]=0;if((i|0)==1){break da}i=x[d+48>>2];if(b&i>>>0<j>>>0){b=ac(x[l>>2],f);b=cd(x[b>>2],x[x[b+48>>2]+12>>2],i,B);x[23604]=0;R(332,d+32|0,e|0);i=x[23604];x[23604]=0;ea:{fa:{if((i|0)!=1){i=d+32|0;k=hd(i);G=Re(i);o=wi(i);q=jc(i);r=v[d+32|0];if((r-1&255)>>>0>95){break fa}v[b|0]=r+13;if(!x[d+52>>2]){break ea}v[b+3|0]=19;x[d+12>>2]=15;H=b,I=y[rd(s,d+12|0)|0]|208,v[H+5|0]=I;break ea}break T}if((r|0)>=0){break ea}if(x[d+52>>2]){v[b+3|0]=19;x[d+12>>2]=15;H=b,I=y[rd(s,d+12|0)|0]|192,v[H+5|0]=I;break ea}v[b|0]=254}if(y[k|0]){v[b+2|0]=1;v[d+12|0]=64;H=b,I=y[Wb(k,d+12|0)|0],v[H+4|0]=I}k=y[G|0];if(k){v[b+1|0]=k}k=y[o|0];if(k|y[q|0]){v[b+3|0]=k;v[b+5|0]=y[q|0];Hf(b)}i=v[i+5|0];b=i&255;k=d+48|0;if((i|0)<0){x[23604]=0;i=S(192,e|0)|0;q=x[23604];x[23604]=0;if((q|0)==1){break T}b=i|b<<8&32512}n=b+n|0;bB(k,n,x[a+480196>>2]);continue}break}yb(e);h=h+1|0;continue}break}break T}h=0;b=ac(x[l>>2],f);b=cd(x[b>>2],x[x[b+48>>2]+12>>2],0,0);ga:while(1){f=0;if((h|0)==(j|0)){break P}while(1){if(z[u>>1]<=(f&65535)>>>0){h=h+1|0;continue ga}x[23604]=0;R(333,d+112|0,g|0);e=x[23604];x[23604]=0;if((e|0)==1){break $}ha:{if(!F){e=x[d+112>>2];x[d+48>>2]=e;i=d+48|0;n=hd(i);k=Re(i);i=wi(i);if(e<<24>>24>0){v[b|0]=(D((e&240)>>>4|0,12)+(e&15)|0)+12}e=y[n|0];if(e>>>0>=4){v[b+2|0]=1;v[b+4|0]=(e>>>2|0)-1;e=y[n|0]}v[b+1|0]=e<<4&48|y[k|0]>>>4;v[b+3|0]=y[k|0]&15;v[b+5|0]=y[i|0];break ha}e=x[d+112>>2];x[d+8>>2]=e;x[d+4>>2]=e;Tt(d+4|0,b);e=Gb(d+112|0,0);v[b+1|0]=y[b+1|0]|y[e|0]&48}Hf(b);e=y[b+3|0];ia:{if(e>>>0>11){break ia}e=1<<e;ja:{if(!(e&2240)){if(!(e&12)){break ia}if(!y[b+5|0]){break ja}break ia}e=y[b+5|0];i=e&240;if(i){v[b+5|0]=i;break ia}if(e){break ia}}v[b+3|0]=0}b=b+6|0;f=f+1|0;continue}}}a=P()|0;break Q}x[23604]=0;b=S(260,x[d+112>>2])|0;e=x[23604];x[23604]=0;ka:{la:{ma:{na:{oa:{if((e|0)!=1){if(b){e=Kb(d+48|0);f=a+484348|0;b=0;pa:{while(1){qa:{x[23604]=0;g=W(142,x[d+112>>2],x[d+120>>2],1)|0;h=x[23604];x[23604]=0;if((h|0)==1){break qa}if(!g){break pa}if(nf(x[a+484344>>2],x[f>>2])>>>0<=b>>>0){break pa}x[23604]=0;U(334,d+112|0,e|0,32);g=x[23604];x[23604]=0;if((g|0)==1){break qa}g=x[l>>2];x[23604]=0;R(266,ac(g,b)|0,e|0);g=x[23604];x[23604]=0;if((g|0)==1){break qa}b=b+1|0;continue}break}a=P()|0;xb(e);break oa}xb(e)}b=d+112|0;yb(b);x[23604]=0;U(323,b|0,d+200|0,1414679374);b=x[23604];x[23604]=0;if((b|0)==1){break na}x[23604]=0;b=S(260,x[d+112>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break V}if(!b){break ka}e=Kb(d+48|0);f=a+480188|0;b=0;while(1){x[23604]=0;g=W(142,x[d+112>>2],x[d+120>>2],1)|0;h=x[23604];x[23604]=0;if((h|0)==1){break ma}if(!(g&z[f>>1]>b>>>0)){break la}x[23604]=0;U(334,d+112|0,e|0,32);g=x[23604];x[23604]=0;if((g|0)==1){break ma}vm(((b<<5)+a|0)+480289|0,e);b=b+1|0;continue}}a=P()|0}yb(d+112|0);break b}a=P()|0;break b}a=P()|0;xb(e);break U}xb(e)}b=d+112|0;yb(b);x[23604]=0;U(331,b|0,d+200|0,1145129300);b=x[23604];x[23604]=0;if((b|0)==1){break W}H=d,I=Bb(x[d+112>>2]),x[H+48>>2]=I;e=c&2;f=Bb(x[d+116>>2]);g=a+480190|0;ra:{sa:{ta:{ua:{va:{wa:{while(1){b=x[d+48>>2];if(!Ob(b,f)){jd(d+112|0);b=Kb(d+48|0);if((m|0)!=841887798){break va}x[23604]=0;c=Q(1,d+112|0,9392)|0;e=x[23604];x[23604]=0;if((e|0)==1){break wa}Ab(b,c);xb(c);break ua}x[23604]=0;c=S(256,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break X}xa:{if(!(!e|c>>>0>=z[g>>1])){c=D(c,104)+a|0;h=z[c+484518>>1];h=Xc(d+176|0,h&1?16:8,h&64?2:1,1,0);x[23604]=0;W(205,h|0,c+484484|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break xa}}rh(d+48|0);continue}break}break X}a=P()|0;break Y}x[23604]=0;U(323,d+112|0,d+200|0,1447383635);c=x[23604];x[23604]=0;ya:{za:{Aa:{Ba:{Ca:{if((c|0)!=1){x[23604]=0;c=S(260,x[d+112>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break ta}if(!c){break za}x[23604]=0;c=S(264,d+112|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ca}x[23604]=0;R(251,d+32|0,4253);e=x[23604];x[23604]=0;if((e|0)==1){break Ba}x[d+16>>2]=c>>>4;x[23604]=0;x[d+12>>2]=c&15;X(335,d+176|0,d+32|0,d+16|0,d+12|0);c=x[23604];x[23604]=0;if((c|0)==1){break Aa}c=d+176|0;Ab(b,c);xb(c);Db(d+32|0);break ya}a=P()|0;break Y}a=P()|0;break Z}a=P()|0;break Z}a=P()|0;Db(d+32|0);break Z}x[23604]=0;c=Q(1,d+176|0,8427)|0;e=x[23604];x[23604]=0;if((e|0)==1){break _}Ab(b,c);xb(c)}yb(d+112|0)}x[23604]=0;c=Q(1,d+32|0,8427)|0;e=x[23604];x[23604]=0;if((e|0)==1){break sa}Ab(a+1298344|0,c);xb(c);x[23604]=0;c=Q(1,d+16|0,10025)|0;e=x[23604];x[23604]=0;if((e|0)==1){break ra}Ab(a+1298356|0,c);xb(c);Ab(a+1298368|0,b);x[a+1298404>>2]=13;xb(b);f=1;break o}a=P()|0;break Z}a=P()|0;break Y}a=P()|0;break Y}a=P()|0;break Q}a=P()|0;break Q}a=P()|0}yb(d+112|0)}xb(b);break b}a=P()|0;jd(d+112|0);break b}a=P()|0;break b}a=P()|0}yb(d+112|0);break b}a=P()|0;yb(e);break Q}a=P()|0;break Q}a=P()|0}jd(d+176|0);break b}rh(d+16|0);continue}}f=0}Xd(d+200|0)}hb=d+240|0;return f|0}a=P()|0;break b}a=P()|0;break f}a=P()|0;yb(d+176|0);break f}a=P()|0;break f}a=P()|0;break f}a=P()|0;break b}a=P()|0}yb(d+48|0);break b}a=P()|0;yb(d+112|0);break b}a=P()|0;break b}a=P()|0;yb(d+176|0)}Xd(d+200|0)}T(a|0);p()}function Uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,V=0;e=hb-496|0;hb=e;xc(b);j=hb-16|0;hb=j;m=e+288|0;gQ(j+8|0,m);f=x[j+12>>2];o=b;mc(j,x[b>>2],x[b+8>>2],x[j+8>>2],x[j+12>>2]);b=x[j+4>>2];if((b|0)==(f|0)){bc(o,x[j+12>>2])}hb=j+16|0;b=(b|0)==(f|0);if(!b){fQ(m)}a:{if(!b){break a}if(!hQ(e+288|0)){break a}if(!c){d=1;break a}Cd(a,134217728);b=e+8|0;ef(b,3936);x[23604]=0;U(625,e+120|0,b|0,z[e+292>>1]);b=x[23604];x[23604]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=e+120|0;Ab(a+1298344|0,b);xb(b);Db(e+8|0);b=Xb(b,8876);Ab(a+1298356|0,b);xb(b);x[a+480188>>2]=4;x[a+1298404>>2]=13;O=a,V=Lb(z[e+424>>1]),x[O+480196>>2]=V;b=z[e+428>>1];x[a+480260>>2]=56;x[a+480264>>2]=13696;O=a,V=eQ(Lb(b)),x[O+480204>>2]=V;mq(_b(x[a+484360>>2],y[a+484376|0]),e+296|0,y[e+294|0]);r=a+480190|0;i=a+480188|0;q=Sb(e+272|0);u=Sb(e+256|0);h:{i:{j:{k:{l:{while(1){if(Lb(z[e+488>>1])>>>0<=(l&65535)>>>0){break k}x[23604]=0;b=S(256,o|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break g}w[e+232>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}d=Lb(z[e+490>>1]);if((Lb(z[e+292>>1])|0)==2){x[23604]=0;b=S(264,o|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break h}d=b-2|0}x[23604]=0;U(176,e+8|0,o|0,d|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}b=e+8|0;j=kc(e+120|0,b);yb(b);C=z[Se(r,e+232|0)>>1];w[r>>1]=C;x[23604]=0;m=D(z[e+232>>1],104)+a|0;f=m+484380|0;R(262,f|0,1);b=x[23604];x[23604]=0;m:{n:{o:{if((b|0)==1){break o}if(Lb(z[e+292>>1])>>>0>1){break n}x[23604]=0;R(626,j|0,m+484423|0);b=x[23604];x[23604]=0;if((b|0)==1){break o}x[23604]=0;Q(174,j|0,1)|0;b=x[23604];x[23604]=0;if((b|0)==1){break o}x[23604]=0;U(309,j|0,((z[e+232>>1]<<5)+a|0)+946304|0,30);b=x[23604];x[23604]=0;if((b|0)!=1){break m}}f=P()|0;break f}b=Kb(e+8|0);x[23604]=0;U(334,j|0,b|0,257);d=x[23604];x[23604]=0;p:{q:{if((d|0)==1){break q}ze(m+484423|0,b);x[23604]=0;Q(174,j|0,1)|0;d=x[23604];x[23604]=0;if((d|0)==1){break q}x[23604]=0;U(334,j|0,b|0,31);d=x[23604];x[23604]=0;if((d|0)==1){break q}Bc(((z[e+232>>1]<<5)+a|0)+946304|0,b);if(!(v[e+128|0]&1)){break p}x[23604]=0;Q(174,j|0,1)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break p}}f=P()|0;xb(b);break f}xb(b)}x[23604]=0;R(627,j|0,e+8|0);b=x[23604];x[23604]=0;if((b|0)==1){break l}h=hb-16|0;hb=h;d=dc(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24));x[f>>2]=d;v[h+15|0]=y[e+12|0];v[h+14|0]=64;O=f,V=y[Wb(h+15|0,h+14|0)|0]<<2,w[O+30>>1]=V;g=dc(y[e+14|0]|y[e+15|0]<<8|(y[e+16|0]<<16|y[e+17|0]<<24));x[f+4>>2]=g;b=dc(y[e+14|0]|y[e+15|0]<<8|(y[e+16|0]<<16|y[e+17|0]<<24))+dc(y[e+18|0]|y[e+19|0]<<8|(y[e+20|0]<<16|y[e+21|0]<<24))|0;x[f+8>>2]=b;if(d>>>0<=g>>>0){g=d-1|0;x[f+4>>2]=g}if(b>>>0>d>>>0){x[f+8>>2]=d;b=d}r:{if(b>>>0<g>>>0){x[f+4>>2]=0;x[f+8>>2]=0;break r}if(b>>>0<=g>>>0){break r}w[f+34>>1]=z[f+34>>1]|2;O=zb(f+68|0,0),V=g,x[O>>2]=V}hb=h+16|0;s:{t:{u:{switch(Lb(z[e+292>>1])|0){case 2:v[m+484417|0]=y[e+26|0]<<3;break;case 0:break t;default:break u}}x[23604]=0;R(200,u|0,C|0);b=x[23604];x[23604]=0;if((b|0)==1){break l}x[23604]=0;R(628,q|0,C|0);b=x[23604];x[23604]=0;if((b|0)==1){break l}f=Zd(x[q>>2],z[e+232>>1]-1|0);Fc(f);x[23604]=0;b=S(256,o|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break j}d=x[o+8>>2];h=x[o>>2];x[23604]=0;d=W(142,h|0,d|0,b<<3)|0;h=x[23604];x[23604]=0;if((h|0)==1){break j}if(!d){break s}x[23604]=0;R(629,f|0,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break j}d=0;x[e+248>>2]=0;if(!(!(y[m+484414|0]&2)|b)){b=x[m+484384>>2];x[e+240>>2]=b;d=x[m+484388>>2];x[23604]=0;x[e+244>>2]=d-b;R(630,f|0,e+240|0);b=x[23604];x[23604]=0;if((b|0)!=1){break t}f=P()|0;break f}while(1){if(b>>>0<=(d&65535)>>>0){break t}x[23604]=0;m=S(264,o|0)|0;h=x[23604];x[23604]=0;v:{if((h|0)==1){break v}x[23604]=0;x[e+240>>2]=m;m=S(264,o|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break v}x[23604]=0;x[e+244>>2]=m;R(630,f|0,e+240|0);m=x[23604];x[23604]=0;if((m|0)==1){break v}d=d+1|0;continue}break}f=P()|0;break f}yb(j);l=l+1|0;continue}break}yb(j);break c}f=P()|0;break f}w:{x:{y:{z:{if(Lb(z[e+292>>1])){B=y[e+295|0];w[e+238>>1]=4;E=128;break z}x[23604]=0;E=S(256,o|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){f=P()|0;break e}b=z[e+292>>1];B=y[e+295|0];w[e+238>>1]=4;if(!Lb(b)){break y}}d=x[o+8>>2];f=0;while(1){A:{if((f&65535)>>>0>=E>>>0){break A}x[23604]=0;b=S(256,o|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break x}if((b|0)==65535){break A}x[23604]=0;B=S(256,o|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break x}x[23604]=0;b=S(256,o|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break x}w[e+238>>1]=b;if(b>>>0>127){break c}O=i,V=z[Se(i,e+238|0)>>1],w[O>>1]=V;x[23604]=0;Q(174,o|0,D(b,B)<<2)|0;b=x[23604];x[23604]=0;if((b|0)==1){break x}f=f+1|0;continue}break}x[23604]=0;Q(141,o|0,d|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break w}}b=z[i>>1];x[23604]=0;F=Q(631,e+240|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){K=a+484344|0;N=c&1;G=Lb(z[e+426>>1]);b=0;j=0;while(1){B:{C:{D:{E:{if((b&65535)>>>0>=E>>>0){break E}F:{if(!Lb(z[e+292>>1])){d=z[e+238>>1];f=b;break F}x[23604]=0;f=S(256,o|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}if((f|0)==65535){break E}x[23604]=0;B=S(256,o|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}x[23604]=0;d=S(256,o|0)|0;m=x[23604];x[23604]=0;if((m|0)==1){break B}w[e+238>>1]=d}m=x[o+8>>2];h=x[o>>2];x[23604]=0;g=d&65535;H=B&65535;d=H<<2;m=W(142,h|0,m|0,D(g,d)|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break B}if(!m){break E}if(!N){break D}x[23604]=0;L=f&65535;f=W(212,K|0,L|0,H|0)|0;m=x[23604];x[23604]=0;if((m|0)==1){break B}if(!f){break D}t=0;G:while(1){if((t|0)==(H|0)){break C}f=0;d=ac(x[K>>2],L);i=of(x[d>>2],x[x[d+48>>2]+12>>2],t);I=0;m=0;H:{I:{J:{switch((G&3)-1|0){case 0:m=!(t&3);break I;case 1:m=!(t&1);break I;case 2:break J;default:break H}}m=(t&3)!=3}}while(1){if(z[e+238>>1]<=f>>>0){t=t+1|0;continue G}d=x[F>>2];x[23604]=0;R(333,e+232|0,o|0);h=x[23604];x[23604]=0;if((h|0)==1){break B}h=D(f,9)+d|0;d=e+232|0;g=hd(d);s=Re(d);l=i+D(f,6)|0;v[l+1|0]=y[e+232|0];k=y[g|0];v[l|0]=k;g=y[wi(d)|0];v[l+5|0]=g;n=l+5|0;if(k){v[l|0]=k+25;v[h+8|0]=0;v[h|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[h+3|0]=0;v[h+4|0]=0;v[h+5|0]=0;v[h+6|0]=0;v[h+7|0]=0;g=y[n|0]}k=g&255;s=y[s|0];K:{if(s>>>0>=240){d=k|(s&15)<<8;if(d){O=n,V=ao(+(eQ(d)>>>0)/1e4),v[O|0]=V;v[l+3|0]=17;break K}v[l+3|0]=0;break K}J=k>>>4|0;M=k<<4;d=J|M;L:{switch(s|0){case 0:d=i+D(f,6)|0;if(g&255){v[d+3|0]=1;break K}v[d+3|0]=0;break K;case 1:v[(i+D(f,6)|0)+3|0]=2;break K;case 2:v[(i+D(f,6)|0)+3|0]=3;break K;case 3:v[e+228|0]=15;O=h,V=y[Wb(n,e+228|0)|0]|16,v[O|0]=V;v[h+7|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 4:v[e+228|0]=15;O=h,V=y[Wb(n,e+228|0)|0]|32,v[O|0]=V;v[h+7|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 5:v[h+7|0]=0;v[h+2|0]=0;v[h+1|0]=g;v[h|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 6:v[h+7|0]=0;v[h+2|0]=g;v[h|0]=0;v[h+1|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 7:v[(i+D(f,6)|0)+3|0]=23;j=0;break K;case 8:v[(i+D(f,6)|0)+3|0]=0;j=d;break K;case 9:v[(i+D(f,6)|0)+3|0]=19;v[e+228|0]=15;O=n,V=y[Wb(n,e+228|0)|0]|16,v[O|0]=V;break K;case 10:v[(i+D(f,6)|0)+3|0]=19;v[e+228|0]=15;O=n,V=y[Wb(n,e+228|0)|0]|32,v[O|0]=V;break K;case 11:v[h+3|0]=d;v[(i+D(f,6)|0)+3|0]=0;break K;case 12:d=i+D(f,6)|0;v[d+4|0]=g;v[d+2|0]=1;v[h+3|0]=0;v[d+3|0]=0;break K;case 13:M:{N:{if((g&255)>>>0>=16){v[(i+D(f,6)|0)+2|0]=4;g=(g&240)>>>4|0;break N}if(!(k&15)){break M}v[(i+D(f,6)|0)+2|0]=3}v[(i+D(f,6)|0)+4|0]=g}v[h+3|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 14:v[(i+D(f,6)|0)+3|0]=19;v[n|0]=!(g&255);break K;case 15:v[(i+D(f,6)|0)+3|0]=16;v[n|0]=(g&240)>>>4;G=g&15;break K;case 16:v[h+5|0]=0;v[h+4|0]=g;v[(i+D(f,6)|0)+3|0]=0;break K;case 17:v[h+6|0]=k&15?g:0;v[(i+D(f,6)|0)+3|0]=0;break K;case 18:v[(i+D(f,6)|0)+3|0]=14;break K;case 19:v[h+8|0]=0;v[h+7|0]=g;v[h+2|0]=0;v[h|0]=0;v[h+1|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 20:v[(i+D(f,6)|0)+3|0]=12;break K;case 22:d=y[l+1|0];O:{if(!d){break O}k=x[q>>2];if(Dd(k,x[q+4>>2])>>>0<d>>>0){break O}g=g-1|0;v[n|0]=g;x[23604]=0;S(632,e+120|0)|0;s=x[23604];x[23604]=0;if((s|0)==1){break B}x[e+228>>2]=9;d=Zd(k,d-1|0);O=e,V=Dd(x[d>>2],x[d+4>>2]),x[O+116>>2]=V;if(A[Fb(e+228|0,e+116|0)>>2]<=(g&255)>>>0){break O}d=i+D(f,6)|0;v[d+2|0]=15;v[d+4|0]=y[n|0]}v[(i+D(f,6)|0)+3|0]=0;break K;case 23:d=y[l+1|0];P:{if(!d){break P}k=x[q>>2];if(Dd(k,x[q+4>>2])>>>0<d>>>0){break P}g=g-1|0;v[n|0]=g;d=Zd(k,d-1|0);k=x[d>>2];s=Dd(k,x[d+4>>2]);d=g&255;if(s>>>0<=d>>>0){break P}d=Zd(k,d);g=z[d+8>>1];Q:{if(g){break Q}g=0;k=z[r>>1];if(!Nh(k)){break Q}g=k+1|0;w[r>>1]=g;w[d+8>>1]=g}v[l+1|0]=g}v[(i+D(f,6)|0)+3|0]=0;break K;case 24:d=y[l+1|0];R:{if(!d){break R}k=x[q>>2];if(Dd(k,x[q+4>>2])>>>0<d>>>0){break R}g=g-1|0;v[n|0]=g;x[23604]=0;S(632,e+8|0)|0;s=x[23604];x[23604]=0;if((s|0)==1){break B}x[e+228>>2]=9;d=Zd(k,d-1|0);O=e,V=Dd(x[d>>2],x[d+4>>2]),x[O+116>>2]=V;if(A[Fb(e+228|0,e+116|0)>>2]>(g&255)>>>0){d=i+D(f,6)|0;v[d+2|0]=15;v[d+4|0]=y[n|0]}d=cc(x[u>>2],y[l+1|0]-1|0);g=z[d>>1];S:{if(g){break S}g=0;k=z[r>>1];if(!Nh(k)){break S}g=k+1|0;w[r>>1]=g;w[d>>1]=g}v[l+1|0]=g}v[(i+D(f,6)|0)+3|0]=0;break K;case 25:d=y[l+1|0];T:{if(!d){break T}k=x[q>>2];if(Dd(k,x[q+4>>2])>>>0<d>>>0){break T}g=g-1|0;v[n|0]=g;d=Zd(k,d-1|0);k=x[d>>2];s=Dd(k,x[d+4>>2]);d=g&255;if(s>>>0<=d>>>0){break T}d=Zd(k,d);g=z[d+10>>1];U:{if(g){break U}g=0;k=z[r>>1];if(!Nh(k)){break U}g=k+1|0;w[r>>1]=g;w[d+10>>1]=g}v[l+1|0]=g}v[(i+D(f,6)|0)+3|0]=0;break K;case 29:v[(i+D(f,6)|0)+3|0]=11;v[n|0]=d;if(k&15){v[n|0]=M|15;break K}if((g&255)>>>0<16){break K}v[n|0]=J|240;break K;case 32:if((g&255)>>>0>=16){v[h+3|0]=J;v[(i+D(f,6)|0)+3|0]=0;break K}v[(i+D(f,6)|0)+3|0]=19;v[n|0]=g|192;break K;case 33:v[(i+D(f,6)|0)+3|0]=19;v[e+228|0]=15;O=n,V=y[Wb(n,e+228|0)|0]|208,v[O|0]=V;break K;case 34:v[(i+D(f,6)|0)+3|0]=19;v[e+228|0]=15;O=n,V=y[Wb(n,e+228|0)|0]|144,v[O|0]=V;break K;case 73:v[(i+D(f,6)|0)+3|0]=10;break K;case 78:if((g&112|128)==224){v[(i+D(f,6)|0)+3|0]=19;break K}v[(i+D(f,6)|0)+3|0]=0;break K;case 79:d=i+D(f,6)|0;if((g&255)>>>0<=31){v[d+3|0]=16;G=0;break K}v[d+3|0]=17;break K;default:break L}}v[(i+D(f,6)|0)+3|0]=0}k=0;g=y[h+3|0];if(!(y[l+2|0]|!g)){V:{if(g>>>0>=16){v[l+2|0]=5;g=g>>>4|0;break V}v[l+2|0]=6}v[l+4|0]=g;k=1}W:{if(y[l+3|0]){break W}d=y[h+1|0];X:{if(d){v[l+3|0]=2;break X}d=y[h+2|0];if(d){v[l+3|0]=3;break X}d=y[h|0];if(d){v[l+3|0]=19;break X}d=y[h+7|0];if(d){v[l+3|0]=4;v[h+8|0]=d;break X}d=y[h+4|0];if(d){v[l+3|0]=5;v[h+5|0]=d;break X}d=y[h+3|0];if(!(!d|k)){v[l+3|0]=11;v[n|0]=d;if(d&15){d=d|-16;break X}if(d>>>0<16){break W}d=d|15;break X}d=y[h+6|0];if(d){v[l+3|0]=8;break X}if(m){v[l+3|0]=20;m=0;d=97;break X}m=0;if(I){break W}d=j&255;if(!d){break W}v[l+3|0]=24;v[n|0]=j;if(j&15){d=j|-16}else{I=1;if(d>>>0<16){break W}d=j|15}I=1}v[n|0]=d}f=f+1|0;continue}}}x[a+480228>>2]=256/z[a+480188>>1];k=1;uh(a,1);if(Lb(z[e+292>>1])){Y:{while(1){b=x[o+8>>2];d=x[o>>2];x[23604]=0;b=W(142,d|0,b|0,2)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}if(!b){break Y}x[23604]=0;b=S(256,o|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break B}if((b|0)==65535){break Y}x[23604]=0;Q(174,o|0,2)|0;b=x[23604];x[23604]=0;if((b|0)==1){break B}x[23604]=0;b=S(264,o|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){x[23604]=0;Q(174,o|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}break B}x[23604]=0;Q(174,o|0,34)|0;b=x[23604];x[23604]=0;if((b|0)==1){break B}}Z:{if(!(c&2)){break Z}while(1){b=k&65535;if(b>>>0>C>>>0){break Z}_:{d=(D(b,104)+a|0)+484380|0;if(!x[d>>2]){break _}c=Xc(e+232|0,8,1,0,0);x[23604]=0;W(205,c|0,d|0,o|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break B}c=x[q>>2];if(Dd(c,x[q+4>>2])>>>0<b>>>0){break _}g=b-1|0;m=Zd(c,g);c=0;b=0;i=hb-112|0;hb=i;$:{h=x[d>>2];if(!Qd(h,x[d+20>>2])){break $}n=x[m>>2];j=Dd(n,x[m+4>>2]);if(j>>>0<2){break $}f=_n(i+8|0,d);x[f+20>>2]=0;x[f>>2]=0;aa:{while(1){if((c|0)==(j|0)){break aa}ba:{l=Zd(n,c);r=x[l>>2];if(r>>>0>=h>>>0){break ba}l=x[l+4>>2];if(l>>>0>h-r>>>0|268435456-l>>>0<b>>>0){break ba}b=b+l|0;x[f>>2]=b;c=c+1|0;continue}break}j=c}if(!yg(f)){break $}l=f+68|0;b=0;c=0;while(1){if((c|0)==(j|0)){im(d);b=_n(d,f);x[b+4>>2]=0;x[b+8>>2]=x[b>>2];w[b+34>>1]=z[b+34>>1]|2;break $}n=x[f+20>>2]+b|0;r=x[d+20>>2];h=Zd(x[m>>2],c);vc(n,r+x[h>>2]|0,x[h+4>>2]);x[h>>2]=b;if(c-10>>>0>=4294967287){O=zb(l,c-1|0),V=b,x[O>>2]=V}c=c+1|0;b=x[h+4>>2]+b|0;continue}}hb=i+112|0;b=z[cc(x[u>>2],g)>>1];if(b){Ez(d,(D(b,104)+a|0)+484380|0,0,x[d>>2],0)}b=Zd(x[q>>2],g);O=e,V=Bb(x[b>>2]),x[O+232>>2]=V;c=Bb(x[b+4>>2]);while(1){b=x[e+232>>2];if(!Ob(b,c)){break _}j=z[b+8>>1];if(j){Ez(d,(D(j,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],1)}j=z[b+10>>1];if(j){Ez(d,(D(j,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],0)}Wp(e+232|0);continue}}k=k+1|0;continue}}pt(F);d=1;break b}x[23604]=0;Q(174,o|0,D(d,z[e+238>>1])|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break C}break B}b=b+1|0;continue}break}f=P()|0;pt(F);break e}f=P()|0;break e}f=P()|0;break e}f=P()|0;break e}f=P()|0;break f}f=P()|0;break e}f=P()|0;break e}f=P()|0;Db(e+8|0);break d}f=P()|0;break e}yb(j)}nd(u);bQ(q)}T(f|0);p()}d=0}nd(u);bQ(q)}hb=e+496|0;return d|0}function cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-592|0;hb=d;xc(b);a:{if(!GA(b,d+512|0)){break a}if(!sP(d+512|0)){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(rP(d+512|0),lb))){break a}b:{if(!c){break b}Cd(a,4);Ag(a);v[a+1074368|0]=4;k=Kb(d+496|0);c:{d:{e:{f:{l=d+550|0;g:{if(!(Rb(l,17645,20)|x[d+572>>2]!=276)){if(z[d+570>>1]<260){break g}e=IA(d+529|0,0,20)?1154:34;break e}if(!Rb(l,17624,20)){e=1;break e}g=d- -64|0;jj(g,3,l);x[23604]=0;R(208,d+104|0,g|0);g=x[23604];x[23604]=0;h:{i:{if((g|0)!=1){x[23604]=0;U(11,d+208|0,5,d+104|0);g=x[23604];x[23604]=0;if((g|0)==1){break i}g=d+208|0;Ab(k,g);xb(g);xb(d+104|0);if(Rb(l,17462,8)){break h}e=1048;break e}f=P()|0;break c}f=P()|0;xb(d+104|0);break c}if(!Rb(l,17362,12)){e=16;if(!Rb(d+562|0,17666,8)){break e}v[a+1074368|0]=5;break e}if(Rb(l,11532,20)){break f}}e=48;break e}if(!Rb(l,27456,15)){x[23604]=0;g=Q(250,a+1074312|0,54)|0;e=x[23604];x[23604]=0;C=1;if((e|0)==1){break d}x[23604]=0;Q(250,g|0,51)|0;g=x[23604];x[23604]=0;e=16;if((g|0)==1){break d}break e}j:{if(Rb(l,27472,14)){if(Rb(l,27487,14)){break j}}x[23604]=0;g=Q(250,a+1074312|0,57)|0;e=x[23604];x[23604]=0;if((e|0)==1){break d}x[23604]=0;Q(250,g|0,51)|0;g=x[23604];x[23604]=0;e=16;if((g|0)!=1){break e}break d}e=Rb(l,17450,11)?16:256}g=d+104|0;t=d+529|0;jj(g,3,t);x[23604]=0;R(208,d+208|0,g|0);g=x[23604];x[23604]=0;k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){g=d+208|0;Ab(a+1298308|0,g);xb(g);x[a+480260>>2]=1;x[a+480264>>2]=31999;Xe(_b(x[a+484360>>2],y[a+484376|0]),z[d+578>>1]);w[a+480188>>1]=z[d+580>>1];w[d+208>>1]=z[d+584>>1];w[d+104>>1]=255;G=a+480192|0,H=z[Wc(g,d+104|0)>>1],w[G>>1]=H;g=z[d+588>>1];if(g){x[a+480196>>2]=g}g=z[d+590>>1];if(g){g=D(g,1e4);g=g>>>0>=1e7?1e7:g;x[a+480204>>2]=g>>>0<=32e4?32e4:g}g=z[d+586>>1];x[a+480208>>2]=g<<4&16|g<<3&32768;f=y[a+484376|0];m=x[a+484360>>2];x[23604]=0;ea(324,_b(m,f)|0,b|0,z[d+576>>1],65535,65535);f=x[23604];x[23604]=0;if((f|0)==1){break d}f=g>>>12&1?(e|0)==34?146:e:e;if(!(z[d+576>>1]|f>>>0>1023)){g=y[a+484376|0];e=x[a+484360>>2];x[23604]=0;Y(682,_b(e,g)|0);g=x[23604];x[23604]=0;if((g|0)==1){break d}}x[23604]=0;Q(141,b|0,x[d+572>>2]+60|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(z[d+570>>1]>=260){x[23604]=0;U(683,b|0,d+512|0,a|0);g=x[23604];x[23604]=0;if((g|0)==1){break d}}v[d+495|0]=0;u=c&2;E=d+122|0;n=d+241|0;m=Sb(d+480|0);F=a+480192|0;q=1;g=-1;while(1){e=q&65535;if(e>>>0>z[F>>1]){if(!(!(f&2)|r&255)){f=IA(t,0,20)?f|16:f}if(z[d+570>>1]>259){break o}if(c&3){x[23604]=0;U(683,b|0,d+512|0,a|0);c=x[23604];x[23604]=0;if((c|0)==1){break n}}if(!u){break o}n=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>z[n>>1]){break o}i=x[m>>2];x[23604]=0;W(205,zb(i,c-1|0)|0,(D(c,104)+a|0)+484380|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){e=e+1|0;continue}break}f=P()|0;break k}x[23604]=0;i=S(143,b|0)|0;h=x[23604];x[23604]=0;r:{s:{if((h|0)!=1){hg(b,4);x[23604]=0;U(684,b|0,d+208|0,(i?i:263)|0);i=x[23604];x[23604]=0;if((i|0)==1){break p}t:{if((f|0)==1){i=x[d+208>>2];if((i|0)!=263){f=16;if((i|0)!=245){break t}x[a+1074308>>2]=16777381;x[23604]=0;f=Q(1,d+192|0,13225)|0;i=x[23604];x[23604]=0;if((i|0)!=1){Ab(k,f);xb(f);f=17;break t}f=P()|0;break k}x[a+1074308>>2]=16777395;x[23604]=0;f=Q(1,d+176|0,13140)|0;i=x[23604];x[23604]=0;if((i|0)!=1){Ab(k,f);xb(f);f=17;break t}f=P()|0;break k}if(y[d+235|0]|y[d+236|0]<<8){break t}i=x[d+208>>2];if(!(!(f&2)|(y[d+237|0]|y[d+238|0]<<8|(y[d+239|0]<<16|y[d+240|0]<<24))|(i|0)!=263)){f=f|16;break t}if(!(!(f&256)|(i|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(i|0)==33?f:0}x[23604]=0;i=W(237,a|0,e|0,0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break p}if(!i){break r}i=((e<<2)+a|0)+900380|0;e=x[i>>2];x[23604]=0;R(685,d+208|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break p}e=y[d+234|0];u:{if((g|0)==-1){g=e;break u}if(!(f&32)|(e|0)==(g|0)){break u}f=f&-161|128}e=y[d+235|0]|y[d+236|0]<<8;if(!e){break r}x[23604]=0;h=y[d+455|0];j=y[d+451|0]|y[d+452|0]<<8;o=y[d+450|0];s=y[d+449|0];U(686,d+160|0,a|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break q}f=h|(j|(o|s))?f&-4:f;i=x[i>>2]+236|0;e=12;h=x[d+160>>2];j=Kc(h,x[d+164>>2]);v:{while(1){w:{if((e|0)==108){if(z[d+570>>1]>259){Fc(m)}e=0;x[23604]=0;i=Q(687,d+144|0,y[d+235|0]|y[d+236|0]<<8)|0;h=x[23604];x[23604]=0;if((h|0)!=1){break w}f=P()|0;break v}if(j>>>0>z[cc(i,e)>>1]){o=z[cc(h,z[cc(i,e)>>1])>>1];G=cc(i,e),H=o,w[G>>1]=H}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){h=y[d+235|0]|y[d+236|0]<<8;if(e>>>0>=h>>>0){e=0;if(z[d+570>>1]<=259){break s}B:{while(1){if(e>>>0>=h>>>0){break s}j=y[zb(x[m>>2],e)+3|0];h=x[zb(x[i>>2],e)>>2];x[23604]=0;U(176,d- -64|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=x[23604];x[23604]=0;if((h|0)!=1){j=d- -64|0;h=kc(d+104|0,j);yb(j);j=x[d+160>>2];if(!(!u|Kc(j,x[d+164>>2])>>>0<=e>>>0)){o=z[cc(j,e)>>1];j=zb(x[m>>2],e);j=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);x[23604]=0;x[d+56>>2]=j;x[d>>2]=j;j=fa(688,(D(o,104)+a|0)+484380|0,d|0,h|0,d+495|0)|0;o=x[23604];x[23604]=0;if((o|0)==1){break B}B=j^1|B}yb(h);e=e+1|0;h=y[d+235|0]|y[d+236|0]<<8;continue}break}f=P()|0;break x}f=P()|0;yb(h);break x}x[23604]=0;R(689,b|0,d+104|0);h=x[23604];x[23604]=0;if((h|0)==1){break y}h=d- -64|0;j=y[d+118|0];C:{if(!(j&48|y[d+121|0]!=173)){Xc(h,8,1,0,10);break C}Xc(h,j&16?16:8,j&32?3:1,0,2)}x[23604]=0;R(690,m|0,h|0);h=x[23604];x[23604]=0;if((h|0)!=1){G=zb(x[i>>2],e),H=x[d+104>>2],x[G>>2]=H;o=y[d+121|0];h=x[d+160>>2];if(Kc(h,x[d+164>>2])>>>0>e>>>0){j=z[cc(h,e)>>1];x[23604]=0;h=(D(j,104)+a|0)+484380|0;R(691,d+104|0,h|0);s=x[23604];x[23604]=0;if((s|0)==1){break A}v[h+38|0]=y[n+202|0];v[h+39|0]=y[n+203|0];v[h+40|0]=y[n+204|0];v[h+41|0]=y[n+205|0];h=d+88|0;ml(h,3,E);x[23604]=0;R(208,d- -64|0,h|0);h=x[23604];x[23604]=0;if((h|0)==1){break z}h=d- -64|0;Bc(((j<<5)+a|0)+946304|0,h);xb(h);f=(y[d+118|0]&3)==3?(f&2)>>>1|0?f|4:f:f}r=o|r;e=e+1|0;continue}break}f=P()|0;break x}f=P()|0;break x}f=P()|0;break x}f=P()|0}sc(i)}nd(d+160|0);break k}f=P()|0;break k}sc(i);nd(d+160|0)}q=q+1|0;continue}}f=P()|0;break c}f=P()|0;break k}f=P()|0;break k}D:{if(!(B&1)){break D}x[23604]=0;c=Q(1,d+104|0,16477)|0;e=x[23604];x[23604]=0;E:{if((e|0)!=1){e=x[a+1298464>>2];x[23604]=0;U(351,e|0,2,c|0);e=x[23604];x[23604]=0;if((e|0)==1){break E}xb(c);break D}f=P()|0;break k}f=P()|0;xb(c);break k}x[23604]=0;c=Q(346,b|0,5519)|0;e=x[23604];x[23604]=0;if((e|0)==1){break n}if(c){x[23604]=0;c=S(143,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break n}x[23604]=0;X(315,a+1298332|0,b|0,c|0,0);c=x[23604];x[23604]=0;if((c|0)==1){break n}f=f|16}x[23604]=0;n=Q(346,b|0,13949)|0;c=x[23604];x[23604]=0;if((c|0)==1){break l}if(n){x[23604]=0;c=S(143,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}x[23604]=0;e=a+901404|0;U(692,b|0,e|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break l}HA(e);f=f|16}x[23604]=0;c=Q(346,b|0,13715)|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}if(!c){break m}x[23604]=0;c=S(143,b|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){w[d+208>>1]=c>>>5;G=d,H=nf(x[a+484344>>2],x[a+484348>>2]),w[G+64>>1]=H;c=z[Wc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break m}x[23604]=0;R(516,b|0,d+208|0);i=x[23604];x[23604]=0;F:{if((i|0)==1){break F}i=x[a+484344>>2];x[23604]=0;R(517,ac(i,e)|0,d+208|0);i=x[23604];x[23604]=0;if((i|0)==1){break F}e=e+1|0;continue}break}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}x[23604]=0;c=Q(346,b|0,13720)|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}G:{if(!c){break G}x[23604]=0;c=S(143,b|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){w[d+208>>1]=(c>>>0)/20;w[d+64>>1]=z[a+480188>>1];c=z[Wc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}x[23604]=0;U(357,b|0,((e<<5)+a|0)+480289|0,20);i=x[23604];x[23604]=0;if((i|0)!=1){e=e+1|0;continue}break}f=P()|0;break k}f=P()|0;break k}c=x[b+8>>2];e=x[b>>2];x[23604]=0;c=W(142,e|0,c|0,8)|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=x[b+8>>2];x[23604]=0;Q(358,a|0,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break K}f=(c|0)==x[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){x[a+1074308>>2]=17367040;x[23604]=0;c=Q(1,d+208|0,14556)|0;e=x[23604];x[23604]=0;if((e|0)!=1){Ab(k,c);xb(c);break L}f=P()|0;break k}if(!(f&2)){break L}x[a+1074308>>2]=18219008;x[23604]=0;c=Q(1,d+208|0,14722)|0;e=x[23604];x[23604]=0;if((e|0)==1){break J}Ab(k,c);xb(c)}M:{N:{O:{P:{Q:{R:{S:{if(!Rb(l,17462,8)){x[23604]=0;c=Q(693,d- -64|0,d+558|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break S}x[23604]=0;U(11,d+160|0,1,c|0);e=x[23604];x[23604]=0;if((e|0)==1){break R}x[23604]=0;e=S(694,d+160|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break Q}x[a+1074308>>2]=e;xb(d+160|0);v[a+1074368|0]=A[a+1074308>>2]<19007257?4:5;xb(c);f=24}if(!(!x[a+1074308>>2]|f&8)){v[a+1074368|0]=0;Qt(a+1074312|0)}c=f&32;T:{if(!c){break T}v[a+1074368|0]=5;if(!n){Zp(a+901404|0)}if(z[d+570>>1]<260){break T}x[23604]=0;W(249,a+1074312|0,4,1)|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}}if(!wd(x[k+4>>2],y[k+11|0])){break M}if(!(f&256)|r&255|g+1>>>0>1){break N}x[23604]=0;c=Q(1,d+160|0,8210)|0;g=x[23604];x[23604]=0;if((g|0)==1){break O}Ab(k,c);xb(c);break M}f=P()|0;break k}f=P()|0;break P}f=P()|0;xb(d+160|0)}xb(c);break k}f=P()|0;break k}if(c){x[23604]=0;c=Q(1,d+160|0,11944)|0;g=x[23604];x[23604]=0;if((g|0)!=1){Ab(k,c);xb(c);break M}f=P()|0;break k}x[23604]=0;c=Q(1,d+160|0,9642)|0;g=x[23604];x[23604]=0;if((g|0)==1){break I}Ab(k,c);xb(c)}v[d+55|0]=0;U:{if(z[a+480192>>1]){x[23604]=0;c=Q(367,a|0,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break U}v[d+55|0]=c}x[23604]=0;X(368,a|0,b|0,1,d+55|0);b=x[23604];x[23604]=0;if((b|0)==1){break U}e=x[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(y[d+55|0]){if(e>>>0>18284543){break ha}x[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}x[23604]=0;b=Q(1,d+40|0,17462)|0;c=x[23604];x[23604]=0;if((c|0)==1){break fa}c=x[a+1074308>>2];x[23604]=0;R(695,d+24|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break ea}x[23604]=0;U(2,d+88|0,b|0,d+24|0);c=x[23604];x[23604]=0;if((c|0)==1){break da}c=d+88|0;Ab(k,c);xb(c);xb(d+24|0);xb(b);e=x[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=x[a+484344>>2];f=x[a+484348>>2];if(!pe(b,f,254)){b=y[a+484376|0];c=x[a+484360>>2];x[23604]=0;Y(696,_b(c,b)|0);b=x[23604];x[23604]=0;if((b|0)==1){break U}f=x[a+484348>>2];b=x[a+484344>>2]}if(pe(b,f,255)){break ia}Zz(_b(x[a+484360>>2],y[a+484376|0]),255,65535)}x[23604]=0;R(697,d+24|0,4063);b=x[23604];x[23604]=0;if((b|0)==1){break ba}b=z[d+570>>1];x[d+20>>2]=b>>>8;x[23604]=0;x[d+4>>2]=b&255;R(378,d+8|0,d+4|0);b=x[23604];x[23604]=0;if((b|0)==1){break aa}x[23604]=0;X(364,d+88|0,d+24|0,d+20|0,d+8|0);b=x[23604];x[23604]=0;if((b|0)==1){break $}c=d+88|0;b=Ab(a+1298344|0,c);xb(c);xb(d+8|0);Db(d+24|0);Ab(a+1298368|0,k);x[a+1298404>>2]=C?8:x[a+1074308>>2]?8:5;if(!y[d+495|0]){break W}Ab(a+1298380|0,b);x[23604]=0;c=Q(1,d+88|0,15084)|0;g=x[23604];x[23604]=0;if((g|0)==1){break Z}Ab(b,c);xb(c);x[23604]=0;b=Q(1,d+24|0,9993)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Y}Ab(a+1298356|0,b);xb(b);x[23604]=0;b=Q(1,d+8|0,9994)|0;c=x[23604];x[23604]=0;if((c|0)==1){break X}Ab(a+1298392|0,b);break V}f=P()|0;break k}f=P()|0;break ca}f=P()|0;xb(d+24|0)}xb(b);break k}f=P()|0;break k}f=P()|0;break _}f=P()|0;xb(d+8|0)}Db(d+24|0);break k}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}x[23604]=0;b=Q(1,d+88|0,9994)|0;c=x[23604];x[23604]=0;if((c|0)==1){break H}Ab(a+1298356|0,b)}xb(b);sc(m);xb(k);break b}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}f=P()|0}sc(m);break c}f=P()|0}xb(k);T(f|0);p()}e=1}hb=d+592|0;return e|0}function dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;e=hb-336|0;hb=e;xc(b);a:{b:{c:{if(!tt(b,e+240|0)){break c}if(!BQ(e+240|0)){break c}if(!Qb(x[b>>2],x[b+8>>2],Uc(AQ(e+240|0),lb))){break c}if(!c){l=1;break c}Cd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;j=Kb(e+224|0);d=z[e+280>>1];i=(d|0)==20479?z[e+294>>1]:d-16464|0;d:{e:{f:{g:{h:{i:{switch(d>>>12|0){case 0:if((d|0)!=520){break d}x[23604]=0;d=Q(1,e+208|0,12184)|0;h=x[23604];x[23604]=0;if((h|0)!=1){Ab(j,d);break e}b=P()|0;break a;case 1:j:{if((d|0)!=4896){break j}d=z[e+302>>1];if(d){break j}if(!(z[e+278>>1]&65455|(y[e+292|0]|y[e+272|0]&15))){k:{if(v[e+291|0]<0){x[a+1074308>>2]=18219008;x[23604]=0;d=Q(1,e+208|0,14635)|0;f=x[23604];x[23604]=0;if((f|0)!=1){break k}b=P()|0;break a}x[a+1074308>>2]=16777216;x[23604]=0;d=Q(1,e+208|0,13225)|0;f=x[23604];x[23604]=0;if((f|0)==1){break h}}Ab(j,d);xb(d);x[23604]=0;f=1;W(249,a+1074312|0,81,1)|0;d=x[23604];x[23604]=0;g=1;if((d|0)!=1){break d}break b}if(y[e+292|0]|d|(z[e+278>>1]|y[e+293|0])){break j}x[23604]=0;d=Q(1,e+208|0,9378)|0;h=x[23604];x[23604]=0;if((h|0)!=1){Ab(j,d);break e}b=P()|0;break a}x[23604]=0;d=Q(1,e+208|0,8412)|0;f=x[23604];x[23604]=0;k=1;if((f|0)!=1){Ab(j,d);xb(d);break f}b=P()|0;break a;case 2:x[23604]=0;d=Q(1,e+208|0,6734)|0;f=x[23604];x[23604]=0;g=1;if((f|0)!=1){Ab(j,d);xb(d);break f}b=P()|0;break a;case 3:l:{m:{n:{o:{if(d>>>0<=12820){x[23604]=0;f=Q(1,e+208|0,8459)|0;h=x[23604];x[23604]=0;if((h|0)!=1){Ab(j,f);xb(f);break o}b=P()|0;break a}x[23604]=0;R(376,e+208|0,3976);f=x[23604];x[23604]=0;if((f|0)==1){break n}x[23604]=0;x[e+192>>2]=z[e+280>>1]-12820;U(377,e+48|0,e+208|0,e+192|0);f=x[23604];x[23604]=0;if((f|0)==1){break m}f=e+48|0;Ab(j,f);xb(f);Db(e+208|0)}f=z[e+280>>1];if(f>>>0<12807){break g}h=x[e+296>>2];if(h){break l}break g}b=P()|0;break a}b=P()|0;Db(e+208|0);break a}f=EC(f,h);h=kq(e+48|0);x[h+44>>2]=f;x[23604]=0;R(379,a+1298408|0,h|0);f=x[23604];x[23604]=0;if((f|0)!=1){break g}b=P()|0;break a;case 4:p:{q:{if((d|0)==16640){x[23604]=0;f=Q(1,e+208|0,8258)|0;h=x[23604];x[23604]=0;if((h|0)!=1){Ab(j,f);xb(f);f=81;break q}b=P()|0;break a}x[23604]=0;U(380,e+48|0,d|0,z[e+294>>1]);f=x[23604];x[23604]=0;r:{if((f|0)!=1){f=e+48|0;Ab(j,f);xb(f);x[a+480260>>2]=1;if((i|0)<4201){break r}x[23604]=0;W(249,a+1074312|0,7,1)|0;h=x[23604];x[23604]=0;f=38;if((h|0)==1){break b}break q}b=P()|0;break a}f=38;if((i|0)<2386){break p}}x[23604]=0;W(249,a+1074312|0,f|0,1)|0;f=x[23604];x[23604]=0;if((f|0)==1){break b}}h=(d|0)!=16640;g=1;f=0;break d;case 5:d=d&4095;x[a+1074308>>2]=d<<16|(d>>>0>296?z[e+294>>1]:0)&65535;x[23604]=0;d=Q(1,e+208|0,17462)|0;f=x[23604];x[23604]=0;s:{t:{u:{if((f|0)!=1){f=x[a+1074308>>2];x[23604]=0;R(126,e+192|0,f|0);f=x[23604];x[23604]=0;if((f|0)==1){break u}f=0;x[23604]=0;U(2,e+48|0,d|0,e+192|0);h=x[23604];x[23604]=0;if((h|0)==1){break t}h=e+48|0;Ab(j,h);xb(h);xb(e+192|0);break e}b=P()|0;break a}b=P()|0;break s}b=P()|0;xb(e+192|0)}xb(d);break a;case 6:x[23604]=0;d=Q(1,e+208|0,8258)|0;h=x[23604];x[23604]=0;if((h|0)!=1){Ab(j,d);xb(d);x[23604]=0;W(249,a+1074312|0,81,1)|0;d=x[23604];x[23604]=0;h=0;if((d|0)==1){break b}break d}b=P()|0;break a;case 7:x[23604]=0;d=Q(1,e+208|0,8270)|0;h=x[23604];x[23604]=0;if((h|0)!=1){Ab(j,d);break e}b=P()|0;break a;default:break i}}if((d|0)!=51712){break d}x[23604]=0;d=Q(1,e+208|0,9177)|0;h=x[23604];x[23604]=0;if((h|0)!=1){Ab(j,d);break e}b=P()|0;break a}b=P()|0;break a}x[23604]=0;f=W(249,a+1074312|0,7,1)|0;h=x[23604];x[23604]=0;if((h|0)==1){break b}x[23604]=0;f=W(249,f|0,23,1)|0;h=x[23604];x[23604]=0;if((h|0)==1){break b}x[23604]=0;f=W(249,f|0,38,1)|0;h=x[23604];x[23604]=0;if((h|0)==1){break b}x[23604]=0;W(249,f|0,107,1)|0;f=x[23604];x[23604]=0;if((f|0)==1){break b}g=1;x[a+480260>>2]=1;f=0;h=0;if(d>>>0>12820){break d}}x[23604]=0;Y(617,e+192|0);d=x[23604];x[23604]=0;v:{w:{x:{if((d|0)!=1){d=z[e+280>>1];x[e+160>>2]=d>>>8&15;x[23604]=0;x[e+136>>2]=d&255;R(378,e+176|0,e+136|0);d=x[23604];x[23604]=0;if((d|0)==1){break x}f=0;x[23604]=0;ea(618,e+48|0,e+192|0,j|0,e+160|0,e+176|0);d=x[23604];x[23604]=0;if((d|0)==1){break w}d=e+48|0;Ab(j,d);xb(d);xb(e+176|0);Db(e+192|0);break d}b=P()|0;break a}b=P()|0;break v}b=P()|0;xb(e+176|0)}Db(e+192|0);break a}xb(d);h=0}x[23604]=0;d=Q(1,e+192|0,14902)|0;n=x[23604];x[23604]=0;y:{z:{A:{B:{C:{D:{E:{F:{if((n|0)!=1){Ab(a+1298344|0,d);xb(d);x[23604]=0;d=Q(1,e+176|0,10366)|0;n=x[23604];x[23604]=0;if((n|0)==1){break F}Ab(a+1298356|0,d);xb(d);r=Ab(a+1298368|0,j);x[a+1298404>>2]=x[a+1074308>>2]?8:5;if(g){x[23604]=0;d=Q(250,a+1074312|0,77)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}x[23604]=0;d=Q(250,d|0,78)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}x[23604]=0;d=Q(250,d|0,79)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}x[23604]=0;d=Q(250,d|0,80)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}x[23604]=0;d=Q(250,d|0,82)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}x[23604]=0;d=Q(250,d|0,96)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}x[23604]=0;Q(250,d|0,113)|0;d=x[23604];x[23604]=0;if((d|0)==1){break b}}d=z[e+280>>1];g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|d>>>0>12819|f}x[23604]=0;d=a+901404|0;Y(619,d|0);g=x[23604];x[23604]=0;if((g|0)==1){break b}if(!f){Zp(d)}d=e+160|0;hl(d,1,e+240|0);x[23604]=0;R(208,e+48|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break C}d=e+48|0;Ab(a+1298308|0,d);xb(d);d=z[e+278>>1];if(d&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(d&1){x[a+480208>>2]=x[a+480208>>2]|131072}f=z[e+280>>1];if(!(!(d&64)&(f|0)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}d=y[e+289|0];x[a+480196>>2]=d;if(!(!k|(d|0)!=255?d:0)){x[a+480196>>2]=6}d=y[e+290|0];x[a+480204>>2]=d>>>0<33?k?125e4:32e4:D(d,1e4);v[e+48|0]=y[e+288|0];v[e+160|0]=64;d=y[Wb(e+48|0,e+160|0)|0];x[a+480200>>2]=d<<2;if(!(d|f>>>0>4895)){x[a+480200>>2]=256}g=y[e+291|0];if(z[e+282>>1]!=1|g>>>0>7){break E}x[e+48>>2]=(g<<4)+16;x[e+160>>2]=127;f=x[rd(e+48|0,e+160|0)>>2];break D}b=P()|0;break a}b=P()|0;break a}f=32;if((g|16)==18){break D}d=g&127;f=48;if(!d){break D}x[e+48>>2]=d;x[e+160>>2]=16;f=x[Je(e+48|0,e+160|0)>>2]}x[a+480228>>2]=f;d=0;n=x[a+1074308>>2]!=0|g<<24>>24<0;if(!n){I=a,J=Uc(Mia(f<<3|5,f>>>29|0,11,0),lb),x[I+480228>>2]=J}s=a+480188|0;w[s>>1]=4;x[a+480232>>2]=h?(i|0)<3299?64:36:36;f=zc(e+152|0);while(1){if((d|0)==32){d=a+480188|0;if(!z[d>>1]){w[d>>1]=1}d=y[a+484376|0];h=x[a+484360>>2];x[23604]=0;ea(324,_b(h,d)|0,b|0,z[e+272>>1],255,254);d=x[23604];x[23604]=0;if((d|0)!=1){n=Sb(e+160|0);x[23604]=0;W(203,b|0,n|0,z[e+274>>1])|0;d=x[23604];x[23604]=0;if((d|0)!=1){s=Sb(e+136|0);x[23604]=0;W(203,b|0,s|0,z[e+276>>1])|0;d=x[23604];x[23604]=0;G:{if((d|0)!=1){if(y[e+293|0]!=252){break B}d=0;x[23604]=0;R(620,b|0,e+48|0);h=x[23604];x[23604]=0;if((h|0)==1){break G}while(1){if((d|0)==32){break B}h=y[(e+48|0)+d|0];H:{if(!(h&32)){break H}if(k){zl(e+32|0,f,d);if(Mb(x[x[e+32>>2]>>2],x[e+36>>2])){break H}}w[((d<<5)+a|0)+480284>>1]=(((h&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break A}break A}b=P()|0;break z}b=P()|0;break a}h=(d<<5)+a|0;i=h+480280|0;Qe(i);g=y[(d+e|0)+304|0];o=g&126;I:{if((g|0)!=255){g=g<<24>>24;w[s>>1]=d+1;if(n){w[h+480284>>1]=g&8?204:51}if((g|0)>=0){break I}}x[i>>2]=1024}if((o-16&255)>>>0<=13){w[h+480284>>1]=128;h=e+48|0;zl(h,f,d);km(h)}d=d+1|0;continue}}b=P()|0;break a}w[e+48>>1]=z[e+274>>1];w[e+32>>1]=3999;f=z[Wc(e+48|0,e+32|0)>>1];w[a+480190>>1]=f;i=c&2;o=e+96|0;d=0;g=0;h=0;J:{K:{L:{while(1){if((f&65535)>>>0<=d>>>0){if(!k){break K}if(!(!(g&1)|h&65535)&z[e+280>>1]!=4864){break L}x[23604]=0;d=h&65535;f=W(249,a+1074312|0,79,d>>>0>1|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break A}x[23604]=0;d=d>>>0<2;f=W(249,f|0,107,d|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break A}x[23604]=0;W(249,f|0,38,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break A}x[23604]=0;d=h&65535;Q(119,r|0,(d>>>0>1?17023:17030)|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break A}if(d>>>0<2){break K}x[a+480228>>2]=48;break K}f=cc(x[n>>2],d);f=y[f|0]|y[f+1|0]<<8;x[23604]=0;f=Q(141,b|0,f<<4)|0;m=x[23604];x[23604]=0;if((m|0)==1){break J}M:{N:{if(!f){break N}x[23604]=0;f=Q(621,b|0,e+48|0)|0;m=x[23604];x[23604]=0;if((m|0)==1){break J}if(!f){break N}x[23604]=0;f=d+1|0;m=(D(f,104)+a|0)+484380|0;U(622,e+48|0,m|0,k|0);l=x[23604];x[23604]=0;if((l|0)==1){break J}l=e+16|0;hl(l,1,o);x[23604]=0;R(208,e+32|0,l|0);l=x[23604];x[23604]=0;if((l|0)==1){break M}l=((f<<5)+a|0)+946304|0;f=e+32|0;Bc(l,f);xb(f);if(y[e+48|0]>1){break N}O:{if(!i|!x[e+64>>2]){break O}f=yQ(e+48|0);x[23604]=0;f=Q(141,b|0,f|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break A}if(!f){break O}f=e+32|0;xQ(f,y[e+78|0],y[e+79|0],z[e+282>>1]==1);x[23604]=0;W(205,f|0,m|0,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break A}g=1}h=z[e+88>>1]|h}d=d+1|0;f=z[a+480190>>1];continue}break}break A}x[23604]=0;d=Q(1,e+48|0,9642)|0;f=x[23604];x[23604]=0;if((f|0)==1){break A}Ab(r,d);xb(d)}l=1;if(!(c&1)){break y}c=z[e+280>>1];w[e+32>>1]=z[e+276>>1];w[e+16>>1]=255;t=z[Wc(e+32|0,e+16|0)>>1];x[23604]=0;k=a+484344|0;R(211,k|0,t|0);d=x[23604];x[23604]=0;if((d|0)==1){break J}u=c>>>0<4896;c=e+32|0;C=c|5;E=c|3;A=c|4;F=c|2;G=c|1;H=a+480188|0;h=0;r=0;o=0;while(1){if((h|0)==(t|0)){if(!u){break y}a=z[a+480188>>1];if((a|0)>(o+r|0)|(a|0)<=(r-o|0)){break y}d=nf(x[k>>2],x[k+4>>2])-1&65535;b=0;P:{if(nf(x[k>>2],x[k+4>>2])>>>0<=d>>>0){break P}while(1){c=b&65535;if(c>>>0>d>>>0){break P}a=Jf(x[k>>2],c);f=x[a>>2];if(Ob(f,x[a+4>>2])){a=Bb(f);f=Bb(x[Jf(x[k>>2],c)+4>>2]);c=hb-16|0;hb=c;x[c+8>>2]=a;while(1){if(Ob(a,f)){if(y[a+3|0]==31){v[a+3|0]=20;v[a+5|0]=y[a+5|0]|128}a=x[dk(c+8|0)>>2];continue}break}hb=c+16|0}b=b+1|0;continue}}break y}x[23604]=0;c=W(212,k|0,h&65535,64)|0;d=x[23604];x[23604]=0;if((d|0)==1){break J}Q:{if(!c){break Q}c=cc(x[s>>2],h);c=y[c|0]|y[c+1|0]<<8;if(!c){break Q}x[23604]=0;c=Q(141,b|0,c<<4)|0;d=x[23604];x[23604]=0;if((d|0)==1){break J}if(!c){break Q}x[23604]=0;Q(174,b|0,2)|0;c=x[23604];x[23604]=0;if((c|0)==1){break J}d=0;c=ac(x[k>>2],h);c=of(x[c>>2],x[x[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break Q}f=d;x[23604]=0;d=S(192,b|0)|0;g=x[23604];x[23604]=0;R:{if((g|0)!=1){m=d<<24>>24;if(m){break R}d=64;if(f>>>0>62){continue}c=ac(x[k>>2],h);d=f+1|0;c=of(x[c>>2],x[x[c+48>>2]+12>>2],d);continue}break A}g=m&31;d=D(g,6)+c|0;q=Oh(e+32|0);i=g>>>0<z[H>>1];B=i?d:q;if(m&32){x[23604]=0;R(245,e+16|0,b|0);g=x[23604];x[23604]=0;S:{T:{U:{if((g|0)!=1){q=hd(e+16|0);g=y[e+16|0];if(g>>>0>239){break U}g=wQ((D(g>>>4|0,12)+(g&15)|0)+13|0);break T}break A}V:{switch(g-254|0){case 0:break T;case 1:break V;default:break S}}g=0}v[B|0]=g}v[(i?d+1|0:G)|0]=y[q|0]}W:{if(!(m&64)){break W}x[23604]=0;q=S(192,b|0)|0;g=x[23604];x[23604]=0;X:{if((g|0)!=1){g=i?d+2|0:F;q=q<<24>>24;v[e+16|0]=q;if((q|0)>-64){break X}v[g|0]=2;v[(i?d+4|0:A)|0]=y[e+16|0]^128;break W}break A}v[g|0]=1;v[e+15|0]=64;I=i?d+4|0:A,J=y[Wb(e+16|0,e+15|0)|0],v[I|0]=J}Y:{if((m|0)>=0){break Y}x[23604]=0;R(245,e+16|0,b|0);g=x[23604];x[23604]=0;Z:{_:{if((g|0)!=1){g=i?d+3|0:E;v[g|0]=y[e+16|0];d=i?d+5|0:C;I=d,J=y[hd(e+16|0)|0],v[I|0]=J;FA(B,0);i=y[g|0];if((i|0)==10){break Z}if((i|0)==31){break _}if((i|0)!=20){break Y}g=y[d|0];if((g&240)!=160|z[e+280>>1]>4895){break Y}v[d|0]=g&15^136;break Y}break A}d=y[d|0];if(d>>>0>15){u=0;break Y}if(d>>>0<=7){o=o+1|0;break Y}r=((d|0)!=8)+r|0;break Y}if(y[d|0]|z[e+280>>1]>4865){break Y}v[g|0]=37}d=f;continue}}h=h+1|0;continue}}}b=P()|0;nd(s)}nd(n);break a}nd(s);nd(n);xb(j)}hb=e+336|0;return l|0}b=P()|0}xb(j);T(b|0);p()}function K9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=0,H=0,I=0,J=0,K=E(0),L=E(0),M=0,N=0;f=hb-48|0;hb=f;c=x[a+1074308>>2];if(!(c>>>0>18285125|(c|0)==18284544)){zf(a+1074312|0,0)}k=a+1074308|0;c=f+32|0;h=a+1074312|0;Jb(c,h,0);e=Mb(x[x[f+32>>2]>>2],x[f+36>>2]);b=a+480180|0;d=x[b>>2];Jb(c,h,0);s=e&(d&16777248)!=0;H=Mb(x[x[f+32>>2]>>2],x[f+36>>2]);I=x[b>>2];a:{c=x[a+1074308>>2];if(c>>>0>18874367){break a}d=!s;g=a+480192|0;e=1;while(1){b:{c=e&65535;if(c>>>0<=z[g>>1]){c=x[((c<<2)+a|0)+900380>>2];if(!c){break b}x[f+32>>2]=D(y[c+20|0],100)>>>6;x[f+16>>2]=100;M=c,N=x[Fb(f+32|0,f+16|0)>>2],v[M+20|0]=N;if(!(d|A[k>>2]<18350080)){break b}i=v[c+26|0];v[c+26|0]=((i>>31|1)+i|0)/2;if(!(d|A[k>>2]<18285314)){break b}JA(xi(c,2),x[b>>2]);i=x[a+1074308>>2];c:{if(i>>>0<18284544){break c}if(i>>>0>18285135){break b}if(!y[c+34|0]){break c}if(!bj(y[c+31|0])){break c}Nb(h,2,1);if(A[k>>2]>18285135){break b}}if(!(y[c+24|0]|(y[c+23|0]|(y[c+19|0]|y[c+20|0])))){break b}Nb(h,1,1)}d:{if(!(x[a+480180>>2]&16777248)|A[k>>2]>18285313&s){break d}e=z[a+480190>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break d}c=D(b,104)+a|0;d=c+484419|0;if(!(y[d|0]|!(y[c+484421|0]|y[c+484420|0]))){v[d|0]=255}b=b+1|0;continue}}e=a+901404|0;g=oz(e);while(1){if((e|0)!=(g|0)){c=e;i=Vn(c);while(1){if((c|0)!=(i|0)){b=y[c|0];e:{f:{if((b-97&255)>>>0<=5){d=b-32|0;break f}if(!(b-88>>>0<2|b-120>>>0<2)){d=99;if((b|0)==75|(b|0)==107){break f}break e}d=122}v[c|0]=d}c=c+1|0;continue}break}e=e+32|0;continue}break}c=x[a+1074308>>2];break a}e=e+1|0;continue}}g:{if(!(x[a+480180>>2]&16777252)|((c|0)==18874368|c>>>0>18874895)){break g}g=z[a+480192>>1]+1&65535;e=0;b=1;while(1){if((b|0)==(g|0)){if(!e){break g}Nb(h,3,1);c=x[k>>2]}else{d=x[((b<<2)+a|0)+900380>>2];if(!(!d|!y[d+31|0])){v[d+33|0]=13;e=1}b=b+1|0;continue}break}}h:{if(!(x[a+480180>>2]&16777248)|((c|0)==19005440|c>>>0>19006225)){break h}Jb(f+32|0,h,0);if(!Mb(x[x[f+32>>2]>>2],x[f+36>>2])){Jb(f+16|0,h,1);if(!Mb(x[x[f+16>>2]>>2],x[f+20>>2])){break h}}e=z[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break h}c=x[((b<<2)+a|0)+900380>>2];if(!(!c|!y[c+19|0]|!(v[c+80|0]&1))){v[c+19|0]=0}b=b+1|0;continue}}i:{if(A[k>>2]>19007232){break i}c=a+946300|0;b=a+906300|0;while(1){if((b|0)==(c|0)){break i}e=f+16|0;d=b+80|0;dM(e,d);x[23604]=0;X(221,f+32|0,0,8,e|0);e=x[23604];x[23604]=0;if((e|0)!=1){xb(f+16|0);e=f+32|0;oq(d,e);b=b+160|0;xb(e);continue}break}a=P()|0;xb(f+16|0);T(a|0);p()}j:{k:{l:{m:{n:{o:{if(x[a+480180>>2]!=4){break o}e=x[k>>2];if(e>>>0<19007257){break m}if(e>>>0>19071235){break n}if(y[a+1074368|0]!=4){break o}fy(a,5)}e=x[k>>2]}if(e>>>0>19202054){break l}c=19202048;if((e|0)==19202048){break k}}g=z[a+480192>>1]+1&65535;c=1;while(1){if((c|0)==(g|0)){break l}d=x[((c<<2)+a|0)+900380>>2];p:{if(!d|!y[d+20|0]|!y[d+31|0]){break p}b=d+236|0;i=aq(b);while(1){if((b|0)!=(i|0)){m=z[b>>1];b=b+2|0;if(!m){continue}break p}break}v[d+20|0]=0}c=c+1|0;continue}}c=e;if(c>>>0>19267583){break j}}d=!s;g=z[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(g|0)){break j}e=x[((b<<2)+a|0)+900380>>2];q:{if(!e){break q}c=v[e+26|0];v[e+26|0]=((c>>31|1)+c|0)/2;c=x[k>>2];if(!(d|c>>>0<18350080)){break q}v[e+19|0]=y[e+19|0]+3>>>2}b=b+1|0;continue}}r:{if(c>>>0>19398673){break r}e=z[a+480192>>1];b=1;while(1){d=b&65535;if(d>>>0>e>>>0){break r}d=x[((d<<2)+a|0)+900380>>2];if(!d|y[d+65|0]==255){b=b+1|0;continue}else{Nb(h,94,1);c=x[k>>2]}break}}s:{if(c>>>0>19399427){break s}e=z[a+480192>>1];b=1;while(1){d=b&65535;if(d>>>0>e>>>0){break s}d=x[((d<<2)+a|0)+900380>>2];if(!d|y[d+36|0]>1){b=b+1|0;continue}else{Nb(h,101,1);c=x[k>>2]}break}}t:{if(c>>>0>19923027){break t}e=z[a+480190>>1];b=1;while(1){c=b&65535;if(c>>>0>e>>>0){break t}c=D(c,104)+a|0;if(!Qd(x[c+484380>>2],x[c+484400>>2])|!(y[c+484414|0]&20)){b=b+1|0;continue}else{Nb(h,116,1)}break}}c=hb-16|0;hb=c;w[f+12>>1]=0;x[f+8>>2]=a;Jb(c+8|0,a+1074312|0,0);M=f,N=Mb(x[x[c+8>>2]>>2],x[c+12>>2]),v[M+14|0]=N;hb=c+16|0;e=x[f+8>>2];u=x[f+12>>2];c=a+484344|0;C=c;F=nf(x[c>>2],x[c+4>>2])-1&65535;m=hb-32|0;hb=m;u:{if(nf(x[c>>2],x[c+4>>2])>>>0<=F>>>0){break u}while(1){c=G&65535;if(c>>>0>F>>>0){break u}b=Jf(x[C>>2],c);d=x[b>>2];if(Ob(d,x[b+4>>2])){b=Bb(d);J=Bb(x[Jf(x[C>>2],c)+4>>2]);x[m+24>>2]=e;x[m+28>>2]=u;x[m+8>>2]=e;x[m+12>>2]=u;i=m+8|0;t=hb-16|0;hb=t;x[t+8>>2]=b;while(1){if(Ob(b,J)){B=z[i+4>>1];c=B+1|0;w[i+4>>1]=c;d=x[i>>2];w[i+4>>1]=z[d+480188>>1]>(c&65535)>>>0?c:0;v:{if(Pg(y[b|0])){break v}g=x[d+1074308>>2];w:{n=x[d+480180>>2];x:{y:{if((n|0)==2){if(g>>>0>18415615){break y}if(y[b+3|0]!=23){break x}mf(b+5|0,64);break x}z:{if(n&16777248){A:{B:{if(g>>>0>=18285314){if(y[i+6|0]){break B}c=0;d=0;if(g>>>0>18874367){break A}}C:{switch(y[b+3|0]-20|0){case 3:mf(b+5|0,128);break B;case 0:break C;default:break B}}c=y[b+5|0];if((c|0)!=208){if((c|0)!=192){break B}v[b|0]=254;v[b+3|0]=0;break B}v[b+3|0]=0}D:{E:{if(g>>>0>=18350080){if(y[i+6|0]){break E}c=0;d=0;if(g>>>0>18874367){break A}}d=y[b+3|0];c=0;if(d>>>0>29){break D}c=536873152>>>d&1;break D}c=0;d=0;if(g>>>0>18874367){break A}d=y[b+3|0];c=0}d=(d|0)==24|(d|0)==22}F:{if(!(c|d)){break F}d=y[b+5|0];c=d&15;if(!c|(c|0)==15){break F}d=d&240;if(!d|(d|0)==240){break F}v[b+5|0]=y[b+3|0]==24?d:c}G:{if((g|0)==19005440|g>>>0>19005699){break G}c=z[x[i>>2]+480192>>1];if(y[i+6|0]|(!c|c>>>0>=y[b+1|0])){break G}v[b+4|0]=0;v[b+2|0]=1}if(y[b+3|0]!=18|y[b+5|0]!=17){break y}if(g>>>0>19468801){break w}if(!Tb(x[i>>2]+1074312|0,22)|y[x[i>>2]+480208|0]&4){break y}c=b+5|0;break z}if((n|0)!=4){break y}H:{if((!y[i+6|0]|g>>>0<18285314)&g>>>0<18874368){break H}if(g>>>0>19137025){break w}if(y[b+3|0]!=23|y[b+5|0]<65){break H}v[b+3|0]=0}I:{J:{K:{if(!(y[i+6|0]|g>>>0>18874367?g>>>0>=18415616:0)){c=y[b+3|0];d=y[b+2|0];if((c|0)!=10|(d|0)!=11){break K}c=0;v[b+3|0]=0;break I}if(g>>>0>18874639){break J}c=y[b+3|0];d=y[b+2|0]}if((d|0)!=11|(c&255)!=4){break I}d=y[b+4|0];if(!(d|y[i+6|0])){c=4;break I}c=4;o=y[b+5|0];if(!o){break I}v[b+2|0]=0;M=b,N=Yt((d<<4)+o|0),v[M+5|0]=N;break I}if(g>>>0>19007240){break w}c=y[b+3|0]}if(y[b+5|0]|(c&255)!=16){break y}c=b+3|0}v[c|0]=0}if(g>>>0>18874367){break w}}c=y[b+3|0];o=y[b+5|0]&240;L:{M:{if((c|0)!=28|(o|0)!=96){d=0}else{if(!y[i+6|0]|(n|0)!=4){break M}d=g>>>0<18350080}if(!(d|(c|0)==20&(o|0)==96)){break L}}d=D(B,-6)+b|0;while(1){if(b>>>0>d>>>0){if(!((y[d+3|0]|8)!=28|(y[d+5|0]&240)!=96)){v[d+3|0]=0}d=d+6|0;continue}break}c=y[b+3|0]}if((c&255)!=20|(y[b+5|0]&240)!=224){break w}d=D(B,-6)+b|0;while(1){if(b>>>0<=d>>>0){break w}if(!(y[d+3|0]!=20|(y[d+5|0]&240)!=224)){v[d+3|0]=0}d=d+6|0;continue}}d=b+2|0;c=y[b+2|0];N:{if((c|0)==8){if((g|0)==19333120|g>>>0>19333174){break v}g=y[b+4|0];c=y[b+3|0];if(!(!g|(c|0)!=7)){v[b+3|0]=11;break v}O:{switch(c-5|0){default:if((c|0)!=26){break v}break;case 1:break v;case 2:break N;case 0:break O}}n=y[b+5|0];if(!(n&15)){v[b+3|0]=5;v[b+5|0]=n|g&15;break N}P:{switch(c-5|0){case 1:break v;case 0:case 2:break N;default:break P}}if((c|0)==26){break N}break v}Q:{if(!((n|0)==16777216|(c|0)!=15)){c=y[b+3|0];if(c){break Q}v[b+3|0]=10;v[b+5|0]=y[b+4|0]<<3;break N}if((c|0)!=15){break v}c=y[b+3|0]}if((c|0)!=10|g>>>0>19922963){break v}d=y[b+5|0]?d:y[b+4|0]?b+3|0:d}v[d|0]=0}b=x[dk(t+8|0)>>2];continue}break}c=x[i+4>>2];x[m+16>>2]=x[i>>2];x[m+20>>2]=c;hb=t+16|0}G=G+1|0;continue}}x[f+32>>2]=e;x[f+36>>2]=u;hb=m+32|0;R:{c=A[a+1074308>>2]<19267584;if(c&s){b=42400;while(1){if((b|0)==42744){break R}c=x[k>>2];e=x[b+4>>2];Nb(h,x[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;continue}}if(!(c&((I|0)==4&H))){break R}b=42752;while(1){if((b|0)==42992){break R}Nb(h,x[b>>2],A[k>>2]>=A[b+4>>2]);b=b+8|0;continue}}S:{T:{c=x[a+480180>>2];if(c&16777248){b=42992;while(1){if((b|0)==43048){break T}c=x[k>>2];e=x[b+4>>2];d=e&-65536;if(!(c>>>0>=d>>>0&(c>>>0<=d>>>0|c>>>0>=e>>>0))){zf(h,x[b>>2])}b=b+8|0;continue}}b=43120;e=43056;U:{switch(c-2|0){case 2:while(1){if((e|0)==43120){break T}if(A[k>>2]<A[e+4>>2]){zf(h,x[e>>2])}e=e+8|0;continue};case 0:break U;default:break S}}while(1){if((b|0)==43208){break T}if(A[k>>2]<A[b+4>>2]){zf(h,x[b>>2])}b=b+8|0;continue}}c=x[a+480180>>2]}V:{if((c|0)==4){b=x[k>>2];if(b>>>0>18415615){break V}Nb(h,98,1)}b=x[k>>2]}e=8;if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){c=b+77|0;Jb(f+32|0,h,c);zf(Nb(h,b+86|0,Mb(x[x[f+32>>2]>>2],x[f+36>>2])),c);b=b+1|0;continue}break}b=x[k>>2]}W:{if(b>>>0>=18284544){if(b>>>0>18874627){break W}e=6;if((b|0)==18874368){break W}}Nb(h,e,1)}c=x[a+1074308>>2];X:{if(y[a+480208|0]&16){if(c>>>0<=19136511){zf(h,7);break X}if(!(x[a+480180>>2]&16777248)|c>>>0>19267583){break X}Nb(h,7,1);break X}if((c|0)==19922944|c>>>0>19922997){break X}zf(h,7)}Jb(f+32|0,h,31);Y:{if(!Mb(x[x[f+32>>2]>>2],x[f+36>>2])){break Y}c=x[k>>2];if(c>>>0<19071234|c>>>0>19398722){break Y}e=z[a+480192>>1];b=1;while(1){c=b&65535;if(c>>>0>e>>>0){break Y}Z:{c=x[((c<<2)+a|0)+900380>>2];if(!c){break Z}d=y[c+65|0];if(!(y[c+60|0]&4)|(d|0)==255|d>>>0<=y[c- -64|0]){break Z}Nb(h,97,1);break Y}b=b+1|0;continue}}c=x[a+480180>>2];_:{if(!(c&16777218)){break _}e=z[a+480190>>1];b=1;while(1){d=b&65535;if(d>>>0>e>>>0){break _}b=b+1|0;if(!(y[(D(d,104)+a|0)+484415|0]&2)){continue}break}$:{aa:{ba:{if(!(!z[a+480192>>1]|(c|0)!=16777216)){b=x[k>>2];if(b>>>0<19398688){break aa}if(b>>>0>19464277){break ba}Nb(h,109,1)}b=x[k>>2]}if((b|0)==19922944|b>>>0>19922996){break $}}zf(h,111);b=x[k>>2]}c=x[a+480180>>2];if(!((c|0)!=2|b>>>0>19464191)){Nb(h,108,1);break _}if((c|0)==2){break _}zf(h,108)}ca:{b=x[k>>2];da:{ea:{if(b>>>0>=19333186){if(b>>>0>19923013){break ea}if(!(x[a+480180>>2]&16777252)){break da}c=a+946300|0;b=a+906300|0;while(1){if((b|0)!=(c|0)){fa:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-271958638){break fa}if((Rc(x[b+4>>2],x[b+8>>2])|0)!=32){break fa}e=Xb(f+32|0,16700);oq(b+80|0,e);xb(e)}b=b+160|0;continue}break}b=x[k>>2]}if(b>>>0<19333120){break ca}}if(b>>>0>19924479){break ca}}if(!(x[a+480180>>2]&16777252)){break ca}e=a+946300|0;b=a+906300|0;while(1){if((b|0)==(e|0)){break ca}ga:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-281111764){break ga}a=x[b+4>>2];if((Rc(a,x[b+8>>2])|0)!=24){break ga}K=Fd(E(E(E((l(2,y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));L=Fd(E(E(E((l(2,y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));c=(q(K),j(2));v[a+12|0]=c;v[a+13|0]=c>>>8;v[a+14|0]=c>>>16;v[a+15|0]=c>>>24;a=x[b+4>>2];c=(q(L),j(2));v[a+16|0]=c;v[a+17|0]=c>>>8;v[a+18|0]=c>>>16;v[a+19|0]=c>>>24}b=b+160|0;continue}}hb=f+48|0}function L5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;a:{b:{c:{d:{e:{f:{if(ne(b,21502)){Kb(a);break f}if(ne(b,9785)){b=hb-128|0;hb=b;e=Kb(a);x[23604]=0;Y(120,b+96|0);a=x[23604];x[23604]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23604]=0;x[b+64>>2]=0;R(1001,b+80|0,b- -64|0);a=x[23604];x[23604]=0;if((a|0)==1){break q}x[23604]=0;a=Q(753,e|0,b+80|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break p}xb(b+80|0);x[23604]=0;a=Q(889,a|0,16619)|0;c=x[23604];x[23604]=0;r:{if((c|0)==1){break r}x[23604]=0;x[b+64>>2]=6;R(1001,b+80|0,b- -64|0);c=x[23604];x[23604]=0;if((c|0)==1){break o}x[23604]=0;a=Q(753,a|0,b+80|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break n}xb(b+80|0);x[23604]=0;a=Q(889,a|0,16619)|0;c=x[23604];x[23604]=0;if((c|0)==1){break r}x[23604]=0;x[b+64>>2]=7;R(1001,b+80|0,b- -64|0);c=x[23604];x[23604]=0;if((c|0)==1){break m}x[23604]=0;g=Q(753,a|0,b+80|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break l}a=b+80|0;xb(a);x[23604]=0;a=Q(54,a|0,15493)|0;c=x[23604];x[23604]=0;if((c|0)==1){break k}c=Qc(x[a+4>>2],y[a+11|0]);xb(a);if(!c){break j}x[23604]=0;Q(889,g|0,15493)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break j}}a=P()|0;break i}a=P()|0;break h}a=P()|0;break i}a=P()|0;xb(b+80|0);break i}a=P()|0;break i}a=P()|0;xb(b+80|0);break i}a=P()|0;break i}a=P()|0;xb(b+80|0);break i}a=P()|0;break i}c=Sb(b- -64|0);s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{a=x[b+108>>2];if(a){x[23604]=0;x[b+16>>2]=a;R(1001,b+32|0,b+16|0);a=x[23604];x[23604]=0;if((a|0)==1){break E}x[23604]=0;U(915,b+48|0,8866,b+32|0);a=x[23604];x[23604]=0;if((a|0)==1){break D}x[23604]=0;R(169,c|0,b+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break C}xb(b+48|0);xb(b+32|0)}if(!ud(y[b+112|0])){break y}x[23604]=0;d=Q(54,b+48|0,12645)|0;a=x[23604];x[23604]=0;if((a|0)==1){break A}x[23604]=0;R(169,c|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break z}xb(d);break x}a=P()|0;break s}a=P()|0;break B}a=P()|0;xb(b+48|0)}xb(b+32|0);break s}a=P()|0;break s}a=P()|0;xb(d);break s}if(!ud(y[b+113|0])){break x}x[23604]=0;d=Q(54,b+48|0,12416)|0;a=x[23604];x[23604]=0;if((a|0)==1){break w}x[23604]=0;R(169,c|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break v}xb(d)}if(ud(y[b+114|0])){break u}break t}a=P()|0;break s}a=P()|0;xb(d);break s}x[23604]=0;d=Q(54,b+32|0,10992)|0;a=x[23604];x[23604]=0;F:{if((a|0)!=1){x[23604]=0;R(169,c|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break F}xb(d);break t}a=P()|0;break s}a=P()|0;xb(d);break s}if(tc(x[c>>2],x[c+4>>2])){break g}x[23604]=0;a=Q(889,g|0,16649)|0;d=x[23604];x[23604]=0;if((d|0)!=1){x[23604]=0;d=Q(54,b|0,16619)|0;g=x[23604];x[23604]=0;G:{H:{I:{if((g|0)!=1){x[23604]=0;U(1002,b+16|0,c|0,d|0);g=x[23604];x[23604]=0;if((g|0)==1){break I}x[23604]=0;Q(753,a|0,b+16|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break H}xb(b+16|0);xb(d);break g}a=P()|0;break s}a=P()|0;break G}a=P()|0;xb(b+16|0)}xb(d);break s}a=P()|0}Vd(c)}qf(b+96|0)}xb(e);break b}Vd(c);qf(b+96|0);hb=b+128|0;break f}if(ne(b,8050)){x[f>>2]=0;bp(a,f);break f}if(ne(b,8028)){x[f>>2]=6;bp(a,f);break f}if(ne(b,10712)){x[f>>2]=7;bp(a,f);break f}if(ne(b,10488)){Xb(a,15493);break f}if(ne(b,11278)){b=Xb(f,15493);c=y[b+11|0];d=x[b+4>>2];x[23604]=0;Q(54,a|0,(Qc(d,c)?15654:15256)|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break e}xb(b);break f}if(ne(b,7330)){b=hb-48|0;hb=b;JD(b+16|0);x[23604]=0;Y(137,b|0);c=x[23604];x[23604]=0;J:{K:{L:{M:{if((c|0)!=1){x[23604]=0;U(138,b+32|0,b+16|0,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break M}x[23604]=0;R(962,a|0,b+32|0);a=x[23604];x[23604]=0;if((a|0)==1){break L}xb(b+32|0);xb(b);xb(b+16|0);hb=b+48|0;break f}a=P()|0;break J}a=P()|0;break K}a=P()|0;xb(b+32|0)}xb(b)}xb(b+16|0);break b}if(ne(b,9801)){b=hb-16|0;hb=b;g=hb-16|0;hb=g;x[g+8>>2]=101;c=hb-112|0;hb=c;e=Sb(c+96|0);N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{d=x[g+8>>2];if(d&1){x[23604]=0;R(126,c- -64|0,19924993);d=x[23604];x[23604]=0;if((d|0)==1){break aa}x[23604]=0;R(110,e|0,c- -64|0);d=x[23604];x[23604]=0;if((d|0)==1){break $}xb(c- -64|0);d=x[g+8>>2]}if(!(d&4)){break Z}x[23604]=0;d=ga(127)|0;h=x[23604];x[23604]=0;if((h|0)==1){break Y}if(!d){break _}break Z}d=P()|0;break O}d=P()|0;xb(c- -64|0);break O}x[23604]=0;Y(128,c- -64|0);d=x[23604];x[23604]=0;ba:{if((d|0)!=1){x[23604]=0;R(110,e|0,c- -64|0);d=x[23604];x[23604]=0;if((d|0)==1){break ba}xb(c- -64|0);break Z}d=P()|0;break O}d=P()|0;xb(c- -64|0);break O}ca:{d=x[g+8>>2];if(!(d&32)){break ca}x[23604]=0;Y(120,c- -64|0);d=x[23604];x[23604]=0;da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{if((d|0)!=1){x[23604]=0;R(129,c+48|0,c- -64|0);d=x[23604];x[23604]=0;if((d|0)==1){break ea}d=wd(x[c+52>>2],y[c+59|0]);xb(c+48|0);if(!d){x[23604]=0;Y(130,c+32|0);d=x[23604];x[23604]=0;if((d|0)==1){break va}x[23604]=0;R(129,c+16|0,c- -64|0);d=x[23604];x[23604]=0;if((d|0)==1){break ua}x[23604]=0;U(131,c+48|0,c+32|0,c+16|0);d=x[23604];x[23604]=0;if((d|0)==1){break ta}x[23604]=0;R(110,e|0,c+48|0);d=x[23604];x[23604]=0;if((d|0)==1){break sa}xb(c+48|0);xb(c+16|0);Db(c+32|0)}d=Go(c- -64|0);if(!wd(x[d+4>>2],y[d+11|0])){x[23604]=0;Y(132,c+32|0);h=x[23604];x[23604]=0;if((h|0)==1){break pa}x[23604]=0;U(133,c+48|0,c+32|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break oa}x[23604]=0;R(110,e|0,c+48|0);d=x[23604];x[23604]=0;if((d|0)==1){break na}xb(c+48|0);Db(c+32|0)}x[23604]=0;R(134,c+48|0,c- -64|0);d=x[23604];x[23604]=0;if((d|0)==1){break la}d=wd(x[c+52>>2],y[c+59|0]);xb(c+48|0);if(!d){x[23604]=0;Y(130,c+32|0);d=x[23604];x[23604]=0;if((d|0)==1){break ka}x[23604]=0;R(134,c+16|0,c- -64|0);d=x[23604];x[23604]=0;if((d|0)==1){break ja}x[23604]=0;U(131,c+48|0,c+32|0,c+16|0);d=x[23604];x[23604]=0;if((d|0)==1){break ia}x[23604]=0;R(110,e|0,c+48|0);d=x[23604];x[23604]=0;if((d|0)==1){break ha}xb(c+48|0);xb(c+16|0);Db(c+32|0)}qf(c- -64|0);d=x[g+8>>2];break ca}d=P()|0;break O}d=P()|0;break da}d=P()|0;break qa}d=P()|0;break ra}d=P()|0;xb(c+48|0)}xb(c+16|0)}Db(c+32|0);break da}d=P()|0;break da}d=P()|0;break ma}d=P()|0;xb(c+48|0)}Db(c+32|0);break da}d=P()|0;break da}d=P()|0;break da}d=P()|0;break fa}d=P()|0;break ga}d=P()|0;xb(c+48|0)}xb(c+16|0)}Db(c+32|0);break da}d=P()|0}qf(c- -64|0);break O}wa:{if(!(d&64)){break wa}x[23604]=0;d=ga(127)|0;h=x[23604];x[23604]=0;if((h|0)==1){break Y}if(d){break wa}d=c- -64|0;Kb(d);x[23604]=0;R(110,e|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break P}xb(c- -64|0)}if(y[g+8|0]&128){x[23604]=0;Y(135,c- -64|0);d=x[23604];x[23604]=0;if((d|0)==1){break X}x[23604]=0;R(110,e|0,c- -64|0);d=x[23604];x[23604]=0;if((d|0)==1){break W}xb(c- -64|0)}x[23604]=0;h=Q(1,c- -64|0,21502)|0;d=x[23604];x[23604]=0;if((d|0)==1){break V}x[23604]=0;U(136,c|0,e|0,h|0);d=x[23604];x[23604]=0;if((d|0)==1){break U}x[23604]=0;Y(137,c+48|0);d=x[23604];x[23604]=0;if((d|0)==1){break T}x[23604]=0;U(138,b|0,c|0,c+48|0);d=x[23604];x[23604]=0;if((d|0)==1){break S}xb(c+48|0);xb(c);xb(h);Vd(e);hb=c+112|0;break N}d=P()|0;break O}d=P()|0;break O}d=P()|0;xb(c- -64|0);break O}d=P()|0;break O}d=P()|0;break Q}d=P()|0;break R}d=P()|0;xb(c+48|0)}xb(c)}xb(h);break O}d=P()|0;xb(c- -64|0)}Vd(e);T(d|0);p()}hb=g+16|0;x[23604]=0;R(962,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break c}if(ne(b,10417)){b=hb-48|0;hb=b;er(b);x[23604]=0;R(129,b+32|0,b|0);c=x[23604];x[23604]=0;xa:{ya:{if((c|0)!=1){x[23604]=0;R(962,a|0,b+32|0);a=x[23604];x[23604]=0;if((a|0)==1){break ya}xb(b+32|0);qf(b);hb=b+48|0;break f}a=P()|0;break xa}a=P()|0;xb(b+32|0)}qf(b);break b}if(ne(b,11241)){b=hb-32|0;hb=b;er(b);x[23604]=0;R(962,a|0,Go(b)|0);a=x[23604];x[23604]=0;if((a|0)!=1){qf(b);hb=b+32|0;break f}a=P()|0;qf(b);break b}if(ne(b,9814)){b=hb-48|0;hb=b;er(b+16|0);c=x[b+28>>2];za:{if(c){x[23604]=0;x[b+12>>2]=c;R(1001,a|0,b+12|0);a=x[23604];x[23604]=0;if((a|0)!=1){break za}a=P()|0;qf(b+16|0);break b}Kb(a)}qf(b+16|0);hb=b+48|0;break f}if(ne(b,12635)){er(f);b=y[f+16|0];x[23604]=0;Q(54,a|0,(ud(b)?15256:15654)|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){qf(f);break f}a=P()|0;qf(f);break b}if(ne(b,9830)){er(f);b=y[f+17|0];x[23604]=0;Q(54,a|0,(ud(b)?15256:15654)|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){qf(f);break f}a=P()|0;qf(f);break b}if(ne(b,12088)){er(f);b=y[f+18|0];x[23604]=0;Q(54,a|0,(ud(b)?15256:15654)|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){qf(f);break f}a=P()|0;qf(f);break b}if(ne(b,12390)){b=hb-16|0;hb=b;c=hb-32|0;hb=c;d=Kb(b);x[23604]=0;Y(120,c|0);e=x[23604];x[23604]=0;Aa:{Ba:{if((e|0)!=1){x[23604]=0;R(121,d|0,Go(c)|0);e=x[23604];x[23604]=0;if((e|0)==1){break Ba}qf(c);hb=c+32|0;break Aa}a=P()|0;break a}a=P()|0;qf(c);break a}x[23604]=0;R(962,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break c}if(ne(b,8171)){b=hb-16|0;hb=b;c=hb-48|0;hb=c;d=Kb(b);x[23604]=0;R(123,c+16|0,4096);e=x[23604];x[23604]=0;Ca:{Da:{Ea:{Fa:{if((e|0)!=1){x[c+12>>2]=16;x[c+8>>2]=0;x[23604]=0;x[c+4>>2]=0;ea(124,c+32|0,c+16|0,c+12|0,c+8|0,c+4|0);e=x[23604];x[23604]=0;if((e|0)==1){break Fa}x[23604]=0;Q(87,d|0,c+32|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Ea}xb(c+32|0);Db(c+16|0);hb=c+48|0;break Ca}a=P()|0;break a}a=P()|0;break Da}a=P()|0;xb(c+32|0)}Db(c+16|0);break a}x[23604]=0;R(962,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break c}if(ne(b,6783)){b=hb-16|0;hb=b;Jm(b,0,19448);x[23604]=0;R(962,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break c}if(ne(b,6416)){b=hb-48|0;hb=b;c=Xb(b+16|0,17509);x[23604]=0;R(1003,b|0,2);d=x[23604];x[23604]=0;Ga:{Ha:{Ia:{Ja:{if((d|0)!=1){x[23604]=0;U(2,b+32|0,c|0,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break Ja}x[23604]=0;R(962,a|0,b+32|0);a=x[23604];x[23604]=0;if((a|0)==1){break Ia}xb(b+32|0);xb(b);xb(c);hb=b+48|0;break f}a=P()|0;break Ga}a=P()|0;break Ha}a=P()|0;xb(b+32|0)}xb(b)}xb(c);break b}if(ne(b,11264)){b=hb-16|0;hb=b;Jm(b,0,17848);x[23604]=0;R(962,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break c}if(ne(b,10424)){b=hb-16|0;hb=b;ar(b,0);x[23604]=0;R(962,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break c}if(ne(b,10399)){b=hb-16|0;hb=b;ar(b,2);x[23604]=0;R(962,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break c}if(ne(b,10384)){b=hb-16|0;hb=b;ar(b,3);x[23604]=0;R(962,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break c}Kb(a)}hb=f+32|0;break d}a=P()|0;xb(b);break b}return}a=P()|0;xb(b)}T(a|0);p()}xb(d);T(a|0);p()}function KV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a:{n=wh(b,13689);if(!n){break a}o=a+480192|0;b:while(1){if(!Qb(x[b>>2],x[b+8>>2],6)){break a}c:{f=kg(b);d:{if((f|0)==(ym(13508)|0)){break d}c=y[21478]|y[21479]<<8|(y[21480]<<16|y[21481]<<24);if(!(f&1616928864)|f&-2139062144){break d}if((c|0)!=(f|0)){break c}}hg(b,4);break a}l=1;c=Cg(b);while(1){d=l&65535;if(d>>>0>z[o>>1]){continue b}d=x[((d<<2)+a|0)+900380>>2];if(d){e:{g=0;if((ym(16603)|0)==(f|0)){bc(b,c);break e}e=hb-48|0;hb=e;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{switch(f-1349079874|0){default:if((f|0)==1095062094){break v}if((f|0)==1095126087){break s}if((f|0)==1129524782){break B}if((f|0)==1145263150){break Y}if((f|0)==1145979182){break X}if((f|0)==1179463214){break z}if((f|0)==1851469358){break F}if((f|0)==1179931728){break n}$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((f|0)!=1196830254){if((f|0)==1229341486){break U}if((f|0)==1229345326){break T}if((f|0)==1264266798){break G}if((f|0)==1296182830){break S}if((f|0)==1296248366){break Q}if((f|0)==1297100334){break R}if((f|0)==1297110852){break q}if((f|0)==1298747438){break D}if((f|0)==1313692462){break H}if((f|0)==1313751342){break Z}if((f|0)==1345203758){break ja}if((f|0)==1346711086){break l}if((f|0)==1346720334){break w}if((f|0)==1346722606){break J}if((f|0)==1346784327){break t}if((f|0)==1347175726){break da}if((f|0)==1347179310){break ea}if((f|0)==1347437358){break O}if((f|0)==1347441454){break P}if((f|0)==1347443502){break M}if((f|0)==1347628590){break W}if((f|0)==1347633710){break ca}if((f|0)==1347634478){break ba}if((f|0)==1347703884){break o}if((f|0)==1347831112){break y}if((f|0)==1347833672){break x}if((f|0)==1349076270){break k}if((f|0)==1349076315){break I}if((f|0)==1349078085){break $}if((f|0)==1349078099){break aa}if((f|0)==1349079131){break L}if((f|0)==1378758190){break p}if((f|0)==1381183022){break A}if((f|0)==1447374382){break m}if((f|0)==1447383630){break u}if((f|0)==1447385902){break K}if((f|0)==1447447623){break r}if((f|0)==1447839022){break ha}if((f|0)==1447842606){break ia}if((f|0)==1448106798){break N}if((f|0)==1448226350){break C}if((f|0)==1448291886){break V}if((f|0)==1448297006){break ga}if((f|0)==1448297774){break fa}if((f|0)!=1682320942){if((f|0)==1718508334){break E}if((f|0)!=1179594286|c>>>0>4){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Mu(b,c),x[q>>2]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+15|0]=r;break g}if(c>>>0>4){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Mu(b,c),x[q+4>>2]=r;break g}if(c>>>0>4){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Mu(b,c),x[q+8>>2]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+61|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+62|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+63|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d- -64|0,r=vd(b,c),v[q|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+81|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+82|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+83|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+84|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+101|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+102|0]=r;break g;case 0:if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+103|0]=r;break g;case 3:break _;case 1:case 2:break f}}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+104|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+16|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+17|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+18|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+19|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+20|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+21|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+22|0]=r;break g}if(c>>>0>2){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=CC(b,c),w[q+28>>1]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+30|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+31|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=BC(b,c),v[q+26|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+27|0]=r;break g}Ud(e,b,c);i=kc(e+24|0,e);yb(e);j=xi(d,0);h=x[j>>2];while(1){if(ie(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[23604]=0;k=S(183,i|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break j}h=x[j>>2];q=zb(h,g),r=k,w[q>>1]=r;g=g+1|0;continue}}Ud(e,b,c);i=kc(e+24|0,e);yb(e);j=xi(d,1);h=x[j>>2];while(1){if(ie(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[23604]=0;k=S(183,i|0)|0;h=x[23604];x[23604]=0;if((h|0)!=1){h=x[j>>2];q=zb(h,g),r=k,w[q>>1]=r;g=g+1|0;continue}break}g=P()|0;break i}Ud(e,b,c);i=kc(e+24|0,e);yb(e);j=xi(d,2);h=x[j>>2];while(1){if(ie(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[23604]=0;k=S(183,i|0)|0;h=x[23604];x[23604]=0;if((h|0)!=1){h=x[j>>2];q=zb(h,g),r=k,w[q>>1]=r;g=g+1|0;continue}break}g=P()|0;break i}Ud(e,b,c);i=kc(e+24|0,e);yb(e);j=xi(d,0);h=x[j>>2];while(1){if(ie(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[23604]=0;k=S(184,i|0)|0;h=x[23604];x[23604]=0;if((h|0)!=1){h=x[j>>2];q=zb(h,g),r=k,v[q+2|0]=r;g=g+1|0;continue}break}g=P()|0;break i}Ud(e,b,c);i=kc(e+24|0,e);yb(e);j=xi(d,1);h=x[j>>2];while(1){if(ie(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[23604]=0;k=S(184,i|0)|0;h=x[23604];x[23604]=0;if((h|0)!=1){h=x[j>>2];q=zb(h,g),r=k,v[q+2|0]=r;g=g+1|0;continue}break}g=P()|0;break i}Ud(e,b,c);i=kc(e+24|0,e);yb(e);j=xi(d,2);h=x[j>>2];while(1){if(ie(h,x[j+4>>2])>>>0<=g>>>0){yb(i);break g}x[23604]=0;k=S(184,i|0)|0;h=x[23604];x[23604]=0;if((h|0)!=1){h=x[j>>2];q=zb(h,g),r=k,v[q+2|0]=r;g=g+1|0;continue}break}g=P()|0;break i}if(c>>>0>128){break f}h=d+108|0;Ud(e,b,c);i=kc(e+24|0,e);yb(e);while(1){if((g|0)==128){yb(i);break g}x[23604]=0;j=S(184,i|0)|0;k=x[23604];x[23604]=0;if((k|0)!=1){q=Gb(h,g),r=j,v[q|0]=r;g=g+1|0;continue}break}g=P()|0;break i}if(c>>>0>256){break f}h=d+236|0;Ud(e,b,c);i=kc(e+24|0,e);yb(e);while(1){if((g|0)==128){yb(i);break g}x[23604]=0;j=S(183,i|0)|0;k=x[23604];x[23604]=0;if((k|0)!=1){q=cc(h,g),r=j,w[q>>1]=r;g=g+1|0;continue}break}g=P()|0;break i}if(c>>>0>32){break f}j=d+492|0;Ud(e,b,c);i=kc(e+24|0,e);yb(e);h=Kb(e);while(1){if((c|0)==(g|0)){break h}x[23604]=0;k=S(185,i|0)|0;m=x[23604];x[23604]=0;ka:{if((m|0)==1){break ka}x[23604]=0;Q(186,h|0,k|0)|0;k=x[23604];x[23604]=0;if((k|0)==1){break ka}g=g+1|0;continue}break}g=P()|0;xb(h);break i}if(c>>>0>32){break f}j=d+524|0;Ud(e,b,c);i=kc(e+24|0,e);yb(e);h=Kb(e);la:{while(1){if((c|0)!=(g|0)){x[23604]=0;k=S(185,i|0)|0;m=x[23604];x[23604]=0;if((m|0)==1){break la}x[23604]=0;Q(186,h|0,k|0)|0;k=x[23604];x[23604]=0;if((k|0)==1){break la}g=g+1|0;continue}break}Bc(j,h);xb(h);yb(i);break g}g=P()|0;xb(h);break i}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+34|0]=r;break g}if(c>>>0>2){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=CC(b,c),w[q+12>>1]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+23|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+24|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+25|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+35|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+36|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+105|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+85|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+65|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+100|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+80|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=vd(b,c),v[q+60|0]=r;break g}if(c>>>0>1){break f}if(!Qb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=BC(b,c),v[q+33|0]=r;break g}g=1;i=so(b,c);if(!ro(i)){break f}v[d+14|0]=i;break f}q=d,r=D(Ku(b,c),1e4)+(A[d+40>>2]%1e4|0)|0,x[q+40>>2]=r;break g}h=(Ku(b,c)>>>0)%1e4|0;g=x[d+40>>2];x[d+40>>2]=h+g-(g>>>0)%1e4;break g}x[e+24>>2]=240;q=e,r=so(b,c),x[q>>2]=r;Zg(d+48|0,x[Fb(e+24|0,e)>>2]);break g}x[e+24>>2]=240;q=e,r=so(b,c),x[q>>2]=r;Zg(d+68|0,x[Fb(e+24|0,e)>>2]);break g}x[e+24>>2]=240;q=e,r=so(b,c),x[q>>2]=r;Zg(d+88|0,x[Fb(e+24|0,e)>>2]);break g}g=P()|0}yb(i);T(g|0);p()}Bc(j,h);xb(h);yb(i)}g=1}hb=e+48|0;if(!g){bc(b,c);break e}if((ym(16608)|0)==(f|0)){e=y[d+15|0];v[d+15|0]=0;v[d+100|0]=y[d+100|0]&224|(e>>>5&4|e>>>6&1);v[d+60|0]=e>>>1&2|(e<<1&4|(y[d+60|0]&240|e&1));v[d+80|0]=y[d+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}}}l=l+1|0;continue}}}return n|0}function Ld(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=hb-16|0;hb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(a>>>0<=244){g=x[23480];h=a>>>0<11?16:a+11&-8;b=h>>>3|0;c=g>>>b|0;if(c&3){b=b+((c^-1)&1)|0;a=b<<3;c=a+93960|0;d=x[a+93968>>2];a=x[d+8>>2];o:{if((c|0)==(a|0)){m=93920,n=Nia(-2,b)&g,x[m>>2]=n;break o}x[a+12>>2]=c;x[c+8>>2]=a}a=d+8|0;c=b<<3;x[d+4>>2]=c|3;c=c+d|0;x[c+4>>2]=x[c+4>>2]|1;break a}k=x[23482];if(k>>>0>=h>>>0){break n}if(c){a=2<<b;a=(0-a|a)&c<<b;d=Iia(0-a&a);a=d<<3;c=a+93960|0;e=x[a+93968>>2];a=x[e+8>>2];p:{if((c|0)==(a|0)){g=Nia(-2,d)&g;x[23480]=g;break p}x[a+12>>2]=c;x[c+8>>2]=a}x[e+4>>2]=h|3;b=e+h|0;a=d<<3;d=a-h|0;x[b+4>>2]=d|1;x[a+e>>2]=d;if(k){c=(k&-8)+93960|0;f=x[23485];a=1<<(k>>>3);q:{if(!(a&g)){x[23480]=a|g;a=c;break q}a=x[c+8>>2]}x[c+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=c;x[f+8>>2]=a}a=e+8|0;x[23485]=b;x[23482]=d;break a}j=x[23481];if(!j){break n}b=x[(Iia(0-j&j)<<2)+94224>>2];f=(x[b+4>>2]&-8)-h|0;c=b;while(1){r:{a=x[c+16>>2];if(!a){a=x[c+20>>2];if(!a){break r}}c=(x[a+4>>2]&-8)-h|0;d=c>>>0<f>>>0;f=d?c:f;b=d?a:b;c=a;continue}break}i=x[b+24>>2];d=x[b+12>>2];if((d|0)!=(b|0)){a=x[b+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}c=b+20|0;a=x[c>>2];if(!a){a=x[b+16>>2];if(!a){break m}c=b+16|0}while(1){e=c;d=a;c=a+20|0;a=x[c>>2];if(a){continue}c=d+16|0;a=x[d+16>>2];if(a){continue}break}x[e>>2]=0;break b}h=-1;if(a>>>0>4294967231){break n}a=a+11|0;h=a&-8;j=x[23481];if(!j){break n}f=0-h|0;g=0;s:{if(h>>>0<256){break s}g=31;if(h>>>0>16777215){break s}a=G(a>>>8|0);g=((h>>>38-a&1)-(a<<1)|0)+62|0}c=x[(g<<2)+94224>>2];t:{u:{v:{if(!c){a=0;break v}a=0;b=h<<((g|0)!=31?25-(g>>>1|0)|0:0);while(1){w:{e=(x[c+4>>2]&-8)-h|0;if(e>>>0>=f>>>0){break w}d=c;f=e;if(e){break w}f=0;a=c;break u}e=x[c+20>>2];c=x[((b>>>29&4)+c|0)+16>>2];a=e?(e|0)==(c|0)?a:e:a;b=b<<1;if(c){continue}break}}if(!(a|d)){d=0;a=2<<g;a=(0-a|a)&j;if(!a){break n}a=x[(Iia(a&0-a)<<2)+94224>>2]}if(!a){break t}}while(1){c=(x[a+4>>2]&-8)-h|0;b=c>>>0<f>>>0;f=b?c:f;d=b?a:d;c=x[a+16>>2];if(c){a=c}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[23482]-h>>>0<=f>>>0){break n}g=x[d+24>>2];b=x[d+12>>2];if((d|0)!=(b|0)){a=x[d+8>>2];x[a+12>>2]=b;x[b+8>>2]=a;break c}c=d+20|0;a=x[c>>2];if(!a){a=x[d+16>>2];if(!a){break l}c=d+16|0}while(1){e=c;b=a;c=a+20|0;a=x[c>>2];if(a){continue}c=b+16|0;a=x[b+16>>2];if(a){continue}break}x[e>>2]=0;break c}b=x[23482];if(b>>>0>=h>>>0){d=x[23485];c=b-h|0;x:{if(c>>>0>=16){x[23482]=c;a=d+h|0;x[23485]=a;x[a+4>>2]=c|1;x[b+d>>2]=c;x[d+4>>2]=h|3;break x}x[23485]=0;x[23482]=0;x[d+4>>2]=b|3;a=b+d|0;x[a+4>>2]=x[a+4>>2]|1}a=d+8|0;break a}i=x[23483];if(i>>>0>h>>>0){c=i-h|0;x[23483]=c;b=x[23486];a=b+h|0;x[23486]=a;x[a+4>>2]=c|1;x[b+4>>2]=h|3;a=b+8|0;break a}a=0;j=h+47|0;if(x[23598]){b=x[23600]}else{x[23601]=-1;x[23602]=-1;x[23599]=4096;x[23600]=4096;x[23598]=l+12&-16^1431655768;x[23603]=0;x[23591]=0;b=4096}e=j+b|0;f=0-b|0;c=e&f;if(c>>>0<=h>>>0){break a}d=x[23590];if(d){b=x[23588];g=b+c|0;if(d>>>0<g>>>0|b>>>0>=g>>>0){break a}}y:{if(!(y[94364]&4)){z:{A:{B:{C:{d=x[23486];if(d){a=94368;while(1){b=x[a>>2];if(b>>>0<=d>>>0&d>>>0<b+x[a+4>>2]>>>0){break C}a=x[a+8>>2];if(a){continue}break}}b=Xn(0);if((b|0)==-1){break z}g=c;d=x[23599];a=d-1|0;if(a&b){g=(c-b|0)+(a+b&0-d)|0}if(g>>>0<=h>>>0){break z}d=x[23590];if(d){a=x[23588];f=a+g|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break z}}a=Xn(g);if((b|0)!=(a|0)){break B}break y}g=f&e-i;b=Xn(g);if((b|0)==(x[a>>2]+x[a+4>>2]|0)){break A}a=b}if((a|0)==-1){break z}if(h+48>>>0<=g>>>0){b=a;break y}b=x[23600];b=b+(j-g|0)&0-b;if((Xn(b)|0)==-1){break z}g=b+g|0;b=a;break y}if((b|0)!=-1){break y}}x[23591]=x[23591]|4}b=Xn(c);a=Xn(0);if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break i}g=a-b|0;if(g>>>0<=h+40>>>0){break i}}a=x[23588]+g|0;x[23588]=a;if(a>>>0>A[23589]){x[23589]=a}D:{e=x[23486];if(e){a=94368;while(1){d=x[a>>2];c=x[a+4>>2];if((d+c|0)==(b|0)){break D}a=x[a+8>>2];if(a){continue}break}break k}a=x[23484];if(!(a>>>0<=b>>>0?a:0)){x[23484]=b}a=0;x[23593]=g;x[23592]=b;x[23488]=-1;x[23489]=x[23598];x[23595]=0;while(1){d=a<<3;c=d+93960|0;x[d+93968>>2]=c;x[d+93972>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=g-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;x[23483]=c;a=a+b|0;x[23486]=a;x[a+4>>2]=c|1;x[(b+d|0)+4>>2]=40;x[23487]=x[23602];break j}if(y[a+12|0]&8|d>>>0>e>>>0|b>>>0<=e>>>0){break k}x[a+4>>2]=c+g;a=e+8&7?-8-e&7:0;b=a+e|0;x[23486]=b;c=x[23483]+g|0;a=c-a|0;x[23483]=a;x[b+4>>2]=a|1;x[(c+e|0)+4>>2]=40;x[23487]=x[23602];break j}d=0;break b}b=0;break c}if(A[23484]>b>>>0){x[23484]=b}c=b+g|0;a=94368;E:{F:{G:{while(1){if((c|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break G}break}if(!(y[a+12|0]&8)){break F}}a=94368;while(1){c=x[a>>2];if(c>>>0<=e>>>0){f=c+x[a+4>>2]|0;if(f>>>0>e>>>0){break E}}a=x[a+8>>2];continue}}x[a>>2]=b;x[a+4>>2]=x[a+4>>2]+g;j=(b+8&7?-8-b&7:0)+b|0;x[j+4>>2]=h|3;g=c+(c+8&7?-8-c&7:0)|0;i=h+j|0;a=g-i|0;if((e|0)==(g|0)){x[23486]=i;a=x[23483]+a|0;x[23483]=a;x[i+4>>2]=a|1;break d}if(x[23485]==(g|0)){x[23485]=i;a=x[23482]+a|0;x[23482]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break d}f=x[g+4>>2];if((f&3)!=1){break e}e=f&-8;if(f>>>0<=255){d=x[g+8>>2];c=f>>>3|0;b=x[g+12>>2];if((b|0)==(d|0)){m=93920,n=x[23480]&Nia(-2,c),x[m>>2]=n;break f}x[d+12>>2]=b;x[b+8>>2]=d;break f}h=x[g+24>>2];b=x[g+12>>2];if((g|0)!=(b|0)){c=x[g+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break g}c=g+20|0;f=x[c>>2];if(!f){f=x[g+16>>2];if(!f){break h}c=g+16|0}while(1){d=c;b=f;c=b+20|0;f=x[c>>2];if(f){continue}c=b+16|0;f=x[b+16>>2];if(f){continue}break}x[d>>2]=0;break g}d=g-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;x[23483]=c;a=a+b|0;x[23486]=a;x[a+4>>2]=c|1;x[(b+d|0)+4>>2]=40;x[23487]=x[23602];a=(f+(f-39&7?39-f&7:0)|0)-47|0;d=a>>>0<e+16>>>0?e:a;x[d+4>>2]=27;a=x[23595];x[d+16>>2]=x[23594];x[d+20>>2]=a;a=x[23593];x[d+8>>2]=x[23592];x[d+12>>2]=a;x[23594]=d+8;x[23593]=g;x[23592]=b;x[23595]=0;a=d+24|0;while(1){x[a+4>>2]=7;c=a+8|0;a=a+4|0;if(c>>>0<f>>>0){continue}break}if((d|0)==(e|0)){break j}x[d+4>>2]=x[d+4>>2]&-2;f=d-e|0;x[e+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){c=(f&-8)+93960|0;b=x[23480];a=1<<(f>>>3);H:{if(!(b&a)){x[23480]=a|b;a=c;break H}a=x[c+8>>2]}x[c+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=c;x[e+8>>2]=a;break j}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;c=(a<<2)+94224|0;I:{d=x[23481];b=1<<a;J:{if(!(d&b)){x[23481]=b|d;x[c>>2]=e;break J}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[c>>2];while(1){c=d;if((f|0)==(x[c+4>>2]&-8)){break I}b=a>>>29|0;a=a<<1;b=(b&4)+c|0;d=x[b+16>>2];if(d){continue}break}x[b+16>>2]=e}x[e+24>>2]=c;x[e+12>>2]=e;x[e+8>>2]=e;break j}a=x[c+8>>2];x[a+12>>2]=e;x[c+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=c;x[e+8>>2]=a}a=x[23483];if(a>>>0<=h>>>0){break i}c=a-h|0;x[23483]=c;b=x[23486];a=b+h|0;x[23486]=a;x[a+4>>2]=c|1;x[b+4>>2]=h|3;a=b+8|0;break a}x[116080]=48;a=0;break a}b=0}if(!h){break f}d=x[g+28>>2];c=(d<<2)+94224|0;K:{if(x[c>>2]==(g|0)){x[c>>2]=b;if(b){break K}m=93924,n=x[23481]&Nia(-2,d),x[m>>2]=n;break f}x[h+(x[h+16>>2]==(g|0)?16:20)>>2]=b;if(!b){break f}}x[b+24>>2]=h;c=x[g+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[g+20>>2];if(!c){break f}x[b+20>>2]=c;x[c+24>>2]=b}a=a+e|0;g=e+g|0;f=x[g+4>>2]}x[g+4>>2]=f&-2;x[i+4>>2]=a|1;x[a+i>>2]=a;if(a>>>0<=255){c=(a&-8)+93960|0;b=x[23480];a=1<<(a>>>3);L:{if(!(b&a)){x[23480]=a|b;a=c;break L}a=x[c+8>>2]}x[c+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=c;x[i+8>>2]=a;break d}f=31;if(a>>>0<=16777215){c=G(a>>>8|0);f=((a>>>38-c&1)-(c<<1)|0)+62|0}x[i+28>>2]=f;x[i+16>>2]=0;x[i+20>>2]=0;c=(f<<2)+94224|0;M:{d=x[23481];b=1<<f;N:{if(!(d&b)){x[23481]=b|d;x[c>>2]=i;break N}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);b=x[c>>2];while(1){c=b;if((x[b+4>>2]&-8)==(a|0)){break M}b=f>>>29|0;f=f<<1;d=(b&4)+c|0;b=x[d+16>>2];if(b){continue}break}x[d+16>>2]=i}x[i+24>>2]=c;x[i+12>>2]=i;x[i+8>>2]=i;break d}a=x[c+8>>2];x[a+12>>2]=i;x[c+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=c;x[i+8>>2]=a}a=j+8|0;break a}O:{if(!g){break O}c=x[d+28>>2];a=(c<<2)+94224|0;P:{if(x[a>>2]==(d|0)){x[a>>2]=b;if(b){break P}j=Nia(-2,c)&j;x[23481]=j;break O}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break O}}x[b+24>>2]=g;a=x[d+16>>2];if(a){x[b+16>>2]=a;x[a+24>>2]=b}a=x[d+20>>2];if(!a){break O}x[b+20>>2]=a;x[a+24>>2]=b}Q:{if(f>>>0<=15){a=f+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break Q}x[d+4>>2]=h|3;e=d+h|0;x[e+4>>2]=f|1;x[e+f>>2]=f;if(f>>>0<=255){c=(f&-8)+93960|0;b=x[23480];a=1<<(f>>>3);R:{if(!(b&a)){x[23480]=a|b;a=c;break R}a=x[c+8>>2]}x[c+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=c;x[e+8>>2]=a;break Q}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;c=(a<<2)+94224|0;S:{b=1<<a;T:{if(!(b&j)){x[23481]=b|j;x[c>>2]=e;break T}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[c>>2];while(1){c=h;if((x[c+4>>2]&-8)==(f|0)){break S}b=a>>>29|0;a=a<<1;b=(b&4)+c|0;h=x[b+16>>2];if(h){continue}break}x[b+16>>2]=e}x[e+24>>2]=c;x[e+12>>2]=e;x[e+8>>2]=e;break Q}a=x[c+8>>2];x[a+12>>2]=e;x[c+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=c;x[e+8>>2]=a}a=d+8|0;break a}U:{if(!i){break U}c=x[b+28>>2];a=(c<<2)+94224|0;V:{if(x[a>>2]==(b|0)){x[a>>2]=d;if(d){break V}m=93924,n=Nia(-2,c)&j,x[m>>2]=n;break U}x[i+(x[i+16>>2]==(b|0)?16:20)>>2]=d;if(!d){break U}}x[d+24>>2]=i;a=x[b+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[b+20>>2];if(!a){break U}x[d+20>>2]=a;x[a+24>>2]=d}W:{if(f>>>0<=15){a=f+h|0;x[b+4>>2]=a|3;a=a+b|0;x[a+4>>2]=x[a+4>>2]|1;break W}x[b+4>>2]=h|3;d=b+h|0;x[d+4>>2]=f|1;x[d+f>>2]=f;if(k){c=(k&-8)+93960|0;e=x[23485];a=1<<(k>>>3);X:{if(!(a&g)){x[23480]=a|g;a=c;break X}a=x[c+8>>2]}x[c+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=c;x[e+8>>2]=a}x[23485]=d;x[23482]=f}a=b+8|0}hb=l+16|0;return a|0}function fV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=hb-304|0;hb=e;xc(b);if(yq(b,17675)){o=Kb(e+288|0);x[23604]=0;g=Q(216,b|0,o|0)|0;d=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{if((d|0)!=1){if(!g){break a}x[23604]=0;g=Q(231,b|0,e+280|0)|0;d=x[23604];x[23604]=0;g:{if((d|0)==1){break g}if(!g){break a}if(!IB(y[e+280|0],y[e+281|0])){break a}h=Uc(HB(e+280|0),lb);g=x[b+8>>2];d=x[b>>2];x[23604]=0;g=W(142,d|0,g|0,h|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break g}if(!g){break a}if(!c){break b}x[23604]=0;R(232,a|0,4096);d=x[23604];x[23604]=0;if((d|0)==1){break g}x[23604]=0;R(233,a+1298308|0,o|0);d=x[23604];x[23604]=0;if((d|0)==1){break g}d=y[e+282|0];w[a+480188>>1]=32;w[a+480192>>1]=d;uh(a,1);x[23604]=0;f=Q(1,e+264|0,9378)|0;d=x[23604];x[23604]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((d|0)!=1){Ab(a+1298344|0,f);xb(f);x[23604]=0;f=Q(1,e+248|0,7011)|0;d=x[23604];x[23604]=0;if((d|0)==1){break p}Ab(a+1298356|0,f);xb(f);x[23604]=0;Y(234,e+48|0);d=x[23604];x[23604]=0;if((d|0)==1){break o}v[e+216|0]=y[e+281|0];x[23604]=0;v[e+8|0]=y[e+280|0];R(235,e+232|0,e+8|0);d=x[23604];x[23604]=0;if((d|0)==1){break n}x[23604]=0;X(236,e+96|0,e+48|0,e+216|0,e+232|0);d=x[23604];x[23604]=0;if((d|0)==1){break m}d=e+96|0;Ab(a+1298368|0,d);xb(d);xb(e+232|0);Db(e+48|0);x[a+1298404>>2]=5;if(y[e+280|0]<2){break i}w[e+96>>1]=8192;x[23604]=0;f=S(180,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break k}w[e+48>>1]=f;s=a,t=D(z[Se(e+96|0,e+48|0)>>1],1e4)>>>8|0,x[s+480204>>2]=t;x[23604]=0;v[e+96|0]=1;f=S(192,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break j}v[e+48|0]=f;s=a,t=y[Ye(e+96|0,e+48|0)|0],x[s+480196>>2]=t;x[23604]=0;Q(174,b|0,3)|0;d=x[23604];x[23604]=0;if((d|0)!=1){x[23604]=0;f=S(180,b|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break h}}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break l}b=P()|0;xb(e+232|0)}Db(e+48|0);break c}b=P()|0;break c}b=P()|0;break c}v[e+96|0]=32;x[23604]=0;f=S(192,b|0)|0;d=x[23604];x[23604]=0;q:{if((d|0)!=1){v[e+48|0]=f;s=a,t=D(y[Ye(e+96|0,e+48|0)|0],1e4),x[s+480204>>2]=t;x[23604]=0;v[e+96|0]=1;f=S(192,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break q}v[e+48|0]=f;s=a,t=y[Ye(e+96|0,e+48|0)|0],x[s+480196>>2]=t;x[23604]=0;f=S(192,b|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break h}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}x[a+480208>>2]=f>>>2&16|12;m=Sb(e+232|0);j=e+96|12;n=Sb(e+216|0);q=a+480190|0;r=1;while(1){r:{s:{d=r&65535;if(d>>>0>z[a+480192>>1]){break s}x[23604]=0;l=W(237,a|0,d|0,0)|0;d=x[23604];x[23604]=0;t:{if((d|0)==1){break t}if(!l){break s}x[23604]=0;f=Q(226,b|0,l+492|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break t}if(!f){break s}x[23604]=0;k=S(192,b|0)|0;d=x[23604];x[23604]=0;u:{v:{w:{if((d|0)!=1){Zb(e+96|0,0,120);if(!k){break r}x:{if(y[e+280|0]){x[23604]=0;f=Q(238,b|0,e+96|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break w}if(!f){break r}if(y[e+280|0]){break x}}d=ec(e+88|0,j,96);f=x[d>>2];d=x[d+4>>2];x[23604]=0;Wm(151,e+48|0,b,f,d);d=x[23604];x[23604]=0;if((d|0)==1){break v}if(!x[e+52>>2]){break r}}h=l+236|0;f=0;break u}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}while(1){if((f|0)!=120){g=z[q>>1];d=y[(e+96|0)+f|0];s=cc(h,f),t=(d+g|0)+1|0,w[s>>1]=t;f=f+1|0;continue}break}x[23604]=0;f=l+48|0;U(239,e+8|0,f|0,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break e}x[23604]=0;i=l+68|0;U(239,e+32|0,i|0,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break e}x[23604]=0;h=l+88|0;U(239,e+80|0,h|0,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break e}x[23604]=0;R(240,b|0,e+72|0);d=x[23604];x[23604]=0;if((d|0)==1){break f}x[l>>2]=(y[e+73|0]|y[e+74|0]<<8)&4095;d=y[e+73|0]|y[e+74|0]<<8;pu(y[e+75|0]|y[e+76|0]<<8,f,0);pu(y[e+75|0]|y[e+76|0]<<8,i,1);pu(y[e+75|0]|y[e+76|0]<<8,h,2);s=e,t=Bb(x[f>>2]),x[s+48>>2]=t;f=d>>>12&3;d=Bb(x[l+52>>2]);while(1){g=x[e+48>>2];if(Ob(g,d)){v[e+44|0]=64;v[e+70|0]=((y[g+2|0]<<6)- -64>>>0)/127;s=g,t=y[Wb(e+44|0,e+70|0)|0],v[s+2|0]=t;Fe(e+48|0);continue}else{s=e,t=Bb(x[i>>2]),x[s+48>>2]=t;d=Bb(x[l+72>>2])}break}while(1){g=x[e+48>>2];if(Ob(g,d)){v[e+44|0]=64;v[e+70|0]=((y[g+2|0]<<6)+128>>>0)/255;s=g,t=y[Wb(e+44|0,e+70|0)|0],v[s+2|0]=t;Fe(e+48|0);continue}break}s=e,t=Bb(x[h>>2]),x[s+48>>2]=t;g=1<<f;i=Bb(x[l+92>>2]);while(1){f=x[e+48>>2];if(Ob(f,i)){d=v[f+2|0];d=Jia(d^-128,d>>31^-1,g,0);h=lb;y:{if((h|0)>=-1&d>>>0>=4294967292|(h|0)>=0){d=d+4|0;d=(((d>>>0<4?h+1|0:h)&7)<<29|d>>>3)&536870911;h=0;break y}h=0-((d>>>0>3)+h|0)|0;d=3-d|0;h=((h&7)<<29|d>>>3)&536870911;d=0-h|0;h=0-((h|0)!=0)|0}s=f,t=Ec(d,h)^128,v[s+2|0]=t;Fe(e+48|0);continue}else{d=z[q>>1]+1|0;w[e+70>>1]=d;f=0;i=d&65535;d=4e3-i|0;h=d>>>0<=4e3?d:0;z:{A:{B:{while(1){if((f|0)==(k|0)){break A}if((f|0)==(h|0)){x[23604]=0;Q(174,b|0,20)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break A}b=P()|0;break d}x[23604]=0;g=f+i|0;Q(226,b|0,((g<<5)+a|0)+946304|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break z}x[23604]=0;R(241,b|0,e+48|0);d=x[23604];x[23604]=0;C:{if((d|0)==1){break C}x[23604]=0;R(242,e+48|0,(D(g,104)+a|0)+484380|0);d=x[23604];x[23604]=0;if((d|0)==1){break C}x[23604]=0;w[e+44>>1]=y[e+72|0]|f<<8&32512|((y[e+67|0]&3)!=0)<<15;R(243,n|0,e+44|0);d=x[23604];x[23604]=0;if((d|0)==1){break B}f=f+1|0;continue}break}b=P()|0;break d}b=P()|0;break d}x[23604]=0;R(243,m|0,e+70|0);d=x[23604];x[23604]=0;if((d|0)!=1){x[e+48>>2]=3999;x[e+44>>2]=k+z[q>>1];s=q,t=x[rd(e+48|0,e+44|0)>>2],w[s>>1]=t;break r}b=P()|0;break d}b=P()|0;break d}}}b=P()|0;break d}g=Kb(e+96|0);x[23604]=0;f=Q(216,b|0,g|0)|0;d=x[23604];x[23604]=0;D:{E:{F:{G:{H:{if((d|0)!=1){I:{if(f){x[23604]=0;U(11,e+48|0,7,g|0);d=x[23604];x[23604]=0;if((d|0)==1){break I}d=e+48|0;Ab(a+1298320|0,d);xb(d)}xb(g);f=0;J:{while(1){if((f|0)==32){x[23604]=0;f=Q(244,b|0,e+32|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break G}if(!f){break F}g=x[e+32>>2];if(g>>>0<12){break H}f=x[b+8>>2];d=x[b>>2];x[23604]=0;f=W(142,d|0,f|0,g-11|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break G}if(f){break J}break H}d=(f<<5)+a|0;Qe(d+480280|0);x[23604]=0;R(217,b|0,d+480289|0);d=x[23604];x[23604]=0;if((d|0)!=1){f=f+1|0;continue}break}b=P()|0;break d}d=x[e+32>>2]-11|0;x[e+80>>2]=d;j=Sb(e+96|0);x[23604]=0;U(220,b|0,j|0,d|0);d=x[23604];x[23604]=0;K:{if((d|0)!=1){x[e+48>>2]=50529027;d=e+48|0;s=e,t=D(x[Fb(e+80|0,d)>>2],85),x[s+72>>2]=t;k=Kb(d);x[e+8>>2]=x[e+36>>2];d=x[Fb(e+72|0,e+8|0)>>2];x[23604]=0;R(45,k|0,d|0);d=x[23604];x[23604]=0;L:{if((d|0)==1){break L}f=0;M:{while(1){d=x[e+80>>2];if(d>>>0<=f>>>0){break M}i=x[j>>2];g=y[Gb(i,f)|0];h=d;d=f+1|0;if(!((g|0)!=255|h-d>>>0<2)){h=v[Gb(i,d)|0];g=y[Gb(i,f+2|0)|0];d=x[Ib(e+24|0,pf(k))>>2];x[23604]=0;X(223,k|0,d|0,g|0,h|0);d=x[23604];x[23604]=0;if((d|0)!=1){f=f+3|0;continue}break L}x[23604]=0;R(46,k|0,g<<24>>24);g=x[23604];x[23604]=0;f=d;if((g|0)!=1){continue}break}break L}x[23604]=0;X(221,e+8|0,5,7,k|0);d=x[23604];x[23604]=0;if((d|0)!=1){N:{d=e+8|0;h=Ab(k,d);xb(d);g=Pb(h);f=y[h+11|0];d=x[h+4>>2];x[23604]=0;ea(222,a+1298332|0,g|0,Qc(d,f)|0,74,0);d=x[23604];x[23604]=0;if((d|0)==1){break N}xb(h);fc(j);break H}}}b=P()|0;xb(k);break K}b=P()|0}fc(j);break d}}b=P()|0;xb(g);break d}f=y[a+484376|0];d=x[a+484360>>2];x[23604]=0;U(224,_b(d,f)|0,b|0,y[e+285|0]|y[e+286|0]<<8);d=x[23604];x[23604]=0;if((d|0)==1){break G}h=c&1;if(h){x[23604]=0;R(211,a+484344|0,y[e+283|0]|y[e+284|0]<<8);d=x[23604];x[23604]=0;if((d|0)==1){break G}}i=a+484344|0;d=b;f=0;while(1){O:{if((y[e+283|0]|y[e+284|0]<<8)>>>0>f>>>0){g=x[d+8>>2];b=x[d>>2];x[23604]=0;g=W(142,b|0,g|0,4)|0;b=x[23604];x[23604]=0;if((b|0)==1){break D}if(g){break O}}if(!(c&2)){break F}f=0;g=a+480190|0;while(1){b=z[g>>1];if(f>>>0>=b>>>0){f=0;h=a+480190|0;while(1){if(b>>>0<=f>>>0){break F}g=z[cc(x[n>>2],f)>>1];c=g&255;P:{if(!c){break P}d=x[m>>2];c=c-1&65535;if(Kc(d,x[m+4>>2])>>>0<=c>>>0){break P}i=b;b=z[cc(d,c)>>1]+(g>>>8&127)&65535;if(i>>>0<b>>>0){break P}c=D(b,104)+a|0;j=c+484380|0;b=x[j>>2];g=c+484400|0;if(!Qd(b,x[g>>2])){break P}d=z[c+484414>>1];i=D(f,104)+a|0;c=i+484484|0;x[c>>2]=b;b=i+484518|0;w[b>>1]=z[b>>1]&65534|d&1;if(!yg(c)){break P}vc(x[i+484504>>2],x[g>>2],lj(x[j>>2],z[j+34>>1]))}f=f+1|0;b=z[h>>1];continue}}b=z[cc(x[n>>2],f)>>1];if(b&255){f=f+1|0;continue}f=f+1|0;c=D(f,104)+a|0;b=Xc(e+96|0,w[c+484414>>1]&1?16:8,1,0,b<<16>>16<0?6:0);x[23604]=0;W(205,b|0,c+484380|0,d|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}break}b=P()|0;break d}x[23604]=0;g=S(143,d|0)|0;b=x[23604];x[23604]=0;Q:{R:{S:{T:{if((b|0)!=1){x[23604]=0;U(176,e+48|0,d|0,g|0);b=x[23604];x[23604]=0;if((b|0)==1){break T}b=e+48|0;j=kc(e+96|0,b);yb(b);if(!h){break R}x[23604]=0;g=S(192,j|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Q}x[23604]=0;Q(174,j|0,1)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Q}x[23604]=0;g=W(212,i|0,f&65535,g+1|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break Q}if(!g){break R}x[23604]=0;g=Q(218,j|0,e+48|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break E}if(!g){break S}b=x[i>>2];x[23604]=0;R(219,ac(b,f)|0,e+48|0);b=x[23604];x[23604]=0;if((b|0)!=1){break S}break E}b=P()|0;break d}b=P()|0;break d}b=x[i>>2];x[23604]=0;U(225,ac(b,f)|0,1,j|0);b=x[23604];x[23604]=0;if((b|0)==1){break E}}yb(j);f=f+1|0;continue}break}break E}b=P()|0;break d}nd(n);nd(m);break b}b=P()|0;yb(j);break d}b=P()|0;break d}r=r+1|0;continue}}b=P()|0;break c}b=P()|0;break c}b=P()|0;break d}b=P()|0}nd(n);nd(m)}xb(o);T(b|0);p()}f=1}xb(o)}hb=e+304|0;return f|0}function iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=hb-400|0;hb=e;xc(b);g=e+376|0;f=LB(b,g);if(!f){su(g)}a:{b:{c:{d:{e:{if(!f){break e}if(!OT(e+376|0)){break e}if(!Qb(x[b>>2],x[b+8>>2],Uc(72,0))){break e}if(!c){d=1;break e}Cd(a,1);x[a+480208>>2]=x[a+480208>>2]&-25231361|16842752;g=y[e+385|0];w[a+480190>>1]=63;w[a+480188>>1]=g;f:{g:{while(1){if((g&65535)>>>0<=d>>>0){h:{Zb(e+304|0,0,64);d=1;i:{while(1){j:{g=d&65535;if(g>>>0>z[a+480190>>1]){RB(b,a+1298308|0);g=e+296|0;d=hb-16|0;hb=d;k:{if(!Qb(x[b>>2],x[b+8>>2],8)){v[d|0]=0;Mh(g,8,d);break k}Im(d+8|0,g);qd(d,b,x[d+8>>2],x[d+12>>2])}hb=d+16|0;n=Sb(e+280|0);g=z[e+386>>1];if(!g){break i}d=0;x[23604]=0;g=W(305,b|0,n|0,D(g,y[e+385|0])<<1)|0;f=x[23604];x[23604]=0;if((f|0)!=1){break j}g=P()|0;break a}f=(D(g,104)+a|0)+484380|0;od(f,1);i=g+(e+304|0)|0;g=Be(b);v[i|0]=g;if(g<<24>>24>=0){B=f,C=MT(b)<<1,x[B>>2]=C}d=d+1|0;continue}break}if(!g){break f}}d=x[n>>2];hc(e+272|0,d,Rc(d,x[n+4>>2])>>>1|0);m=Sb(e+256|0);x[23604]=0;R(306,m|0,z[e+388>>1]<<8);d=x[23604];x[23604]=0;if((d|0)==1){break h}d=0;l:{m:{n:{while(1){g=d&65535;d=z[e+388>>1];if(g>>>0>=d>>>0){break m}x[e+208>>2]=d-g;x[e+152>>2]=2e3;d=e+208|0;f=x[rd(d,e+152|0)>>2];d=Sb(d);x[23604]=0;f=W(305,b|0,d|0,f<<8)|0;h=x[23604];x[23604]=0;if((h|0)==1){break l}if(!f){break n}f=Ib(e+248|0,Bb(x[m+4>>2]));h=Bb(x[d>>2]);j=Bb(x[e+212>>2]);f=x[f>>2];x[23604]=0;X(307,m|0,f|0,h|0,j|0);f=x[23604];x[23604]=0;if((f|0)!=1){fc(d);d=g+2e3|0;continue}break}break c}fc(d);d=0;break g}ke(e+232|0,x[m>>2],x[m+4>>2]);Kg(e+240|0,x[e+232>>2],x[e+236>>2]);q=a+484376|0;d=y[q|0];g=x[a+484360>>2];x[23604]=0;R(308,_b(g,d)|0,z[e+386>>1]);d=x[23604];x[23604]=0;if((d|0)==1){break d}r=a+484344|0;t=c&1;j=0;while(1){if(z[e+386>>1]<=j>>>0){h=c&2;g=1;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{while(1){c=g&65535;if(c>>>0>z[a+480190>>1]){break v}x[23604]=0;d=y[c+(e+304|0)|0];U(309,b|0,((c<<5)+a|0)+946304|0,d&63);f=x[23604];x[23604]=0;if((f|0)==1){break t}A:{B:{if(d<<24>>24<0){break B}x[23604]=0;d=S(310,b|0)|0;f=x[23604];x[23604]=0;C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)==1){break J}c=D(c,104)+a|0;f=c+484392|0;x[f>>2]=d<<1;x[23604]=0;d=S(310,b|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break I}if(d>>>0>=2){x[c+484396>>2]=x[f>>2]+(d<<1);d=c+484414|0;w[d>>1]=z[d>>1]|8}x[23604]=0;d=S(192,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break s}v[e+72|0]=d;v[e+176|0]=64;B=c+484410|0,C=y[Wb(e+72|0,e+176|0)|0]<<2,w[B>>1]=C;x[23604]=0;d=S(192,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break J}v[c+484417|0]=d<<4;c=c+484380|0;YA(c);if(!x[c>>2]){break B}x[23604]=0;f=S(192,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break D}d=0;switch(f|0){case 4:case 5:break C;case 2:case 3:break F;case 1:break G;case 0:break H;default:break g}}g=P()|0;break b}g=P()|0;break b}if(h){f=Sb(e+72|0);j=x[b+8>>2];i=x[b>>2];k=x[c>>2];x[23604]=0;j=W(142,i|0,j|0,k|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break r}if(!j){break w}d=x[c>>2];x[23604]=0;U(311,b|0,f|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break r}B=e,C=Bb(x[f>>2]),x[B+176>>2]=C;j=Bb(x[e+76>>2]);while(1){d=x[e+176>>2];if(Ob(d,j)){i=d;d=y[d|0];v[i|0]=d<<7|(d^-1)>>>1&127;Le(e+176|0);continue}break}ke(e+200|0,x[f>>2],x[e+76>>2]);d=Yd(e+192|0);x[23604]=0;j=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=j;d=rg(312,e+208|0,x[e+200>>2],x[e+204>>2],e+16|0);j=x[23604];x[23604]=0;K:{if((j|0)!=1){j=Xc(e+176|0,16,1,0,16);x[23604]=0;W(205,j|0,c|0,d|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break K}yb(d);fc(f);break B}g=P()|0;break o}g=P()|0;yb(d);break o}c=x[c>>2];break E}f=Sb(e+72|0);d=x[c>>2];x[23604]=0;U(313,e+176|0,b|0,d|0);d=x[23604];x[23604]=0;L:{M:{N:{if((d|0)!=1){d=e+176|0;j=mm(f,d);fc(d);if(h){ke(e+144|0,x[j>>2],x[e+76>>2]);d=Yd(e+136|0);x[23604]=0;i=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=i;d=rg(312,e+152|0,x[e+144>>2],x[e+148>>2],e+24|0);i=x[23604];x[23604]=0;if((i|0)==1){break N}i=Xc(e+176|0,8,1,0,2);x[23604]=0;W(205,i|0,c|0,d|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break M}yb(d)}fc(j);break B}g=V(30848)|0;if((ib|0)!=(da(30848)|0)){break L}_(g|0)|0;d=0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)!=1){break u}g=P()|0;break L}g=P()|0;break L}g=P()|0;yb(d)}fc(f);break b}if(h){d=Xc(e+72|0,(f|0)==2?8:16,1,0,0);x[23604]=0;W(205,d|0,c|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break B}g=P()|0;break b}c=D(x[c>>2],f-1|0)}x[23604]=0;Q(174,b|0,c|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break B}}g=P()|0;break b}j=Sb(e+72|0);d=x[c>>2];x[23604]=0;U(314,e+176|0,b|0,d|0);d=x[23604];x[23604]=0;O:{P:{if((d|0)!=1){i=e+176|0;d=mm(j,i);fc(i);if(!h){break O}if((f|0)!=5){break P}B=e,C=Bb(x[d>>2]),x[B+176>>2]=C;k=Bb(x[e+76>>2]);while(1){i=x[e+176>>2];if(!Ob(i,k)){break P}l=i;i=y[i|0];v[l|0]=y[(i>>>7|0)+26737|0]^i;Le(e+176|0);continue}}g=V(30848)|0;if((ib|0)!=(da(30848)|0)){break x}_(g|0)|0;d=0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)!=1){break A}g=P()|0;break x}ke(e+104|0,x[d>>2],x[e+76>>2]);i=Yd(e+96|0);x[23604]=0;k=x[i+4>>2];x[e+32>>2]=x[i>>2];x[e+36>>2]=k;i=rg(312,e+112|0,x[e+104>>2],x[e+108>>2],e+32|0);k=x[23604];x[23604]=0;if((k|0)==1){break z}f=(f|0)==5;f=Xc(e+176|0,f?16:8,1,0,f?16:1);x[23604]=0;W(205,f|0,c|0,i|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break y}yb(i)}fc(d)}g=g+1|0;continue}break}fc(j);break g}g=P()|0;break x}g=P()|0;yb(i)}fc(j);break b}fc(f);break g}Q:{R:{S:{T:{d=z[e+390>>1]|y[e+392|0]<<16;if(d){c=Sb(e+176|0);x[23604]=0;b=W(305,b|0,c|0,d|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break q}if(!b){break R}ke(e- -64|0,x[c>>2],x[c+4>>2]);b=Yd(e+56|0);x[23604]=0;g=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=g;b=rg(312,e+72|0,x[e+64>>2],x[e+68>>2],e+8|0);g=x[23604];x[23604]=0;if((g|0)==1){break T}x[23604]=0;X(315,a+1298332|0,b|0,d|0,1);d=x[23604];x[23604]=0;if((d|0)==1){break S}yb(b);fc(c)}x[23604]=0;Y(316,e+40|0);b=x[23604];x[23604]=0;if((b|0)!=1){break Q}g=P()|0;break b}g=P()|0;break p}g=P()|0;yb(b);break p}fc(c);d=0;break g}x[23604]=0;U(199,e+176|0,e+40|0,y[e+384|0]);b=x[23604];x[23604]=0;U:{V:{if((b|0)!=1){b=e+176|0;Ab(a+1298344|0,b);xb(b);Db(e+40|0);x[23604]=0;b=Q(1,b|0,9988)|0;c=x[23604];x[23604]=0;if((c|0)==1){break V}Ab(a+1298356|0,b);xb(b);x[23604]=0;b=Q(1,e+40|0,5062)|0;c=x[23604];x[23604]=0;if((c|0)==1){break U}Ab(a+1298368|0,b);xb(b);x[a+1298404>>2]=10;d=1;break g}g=P()|0;Db(e+40|0);break b}g=P()|0;break b}g=P()|0;break b}fc(f);break g}g=P()|0;break b}g=P()|0;break b}g=P()|0;break o}g=P()|0}fc(c);break b}fc(f);break b}B=cc(x[_b(x[a+484360>>2],y[q|0])>>2],j),C=j,w[B>>1]=C;W:{X:{if(!t){break X}x[23604]=0;s=j&65535;d=W(212,r|0,s|0,64)|0;g=x[23604];x[23604]=0;if((g|0)==1){break W}if(!d){break X}f=z[a+480188>>1];i=0;while(1){d=f&65535;if(d>>>0<=i>>>0){break X}d=cc(x[e+272>>2],D(d,j)+i|0);d=y[d|0]|y[d+1|0]<<8;Y:{if(d>>>0>=z[e+388>>1]){break Y}g=0;u=0-i|0;A=d<<8;d=ac(x[r>>2],j);d=cd(x[d>>2],x[x[d+48>>2]+12>>2],0,i&65535);while(1){if((g|0)==64){break Y}eq(e+208|0,x[e+240>>2],x[e+244>>2],(g<<2)+A|0,4);f=x[e+208>>2];h=Gb(f,0);o=y[h|0]&63;v[d|0]=o?o+48|0:0;k=Gb(f,1);v[d+1|0]=y[k|0]<<2&60|y[h|0]>>>6;h=y[k|0];l=Gb(f,2);k=y[Gb(f,3)|0];l=y[l|0];f=k<<4|l>>>4;w[e+72>>1]=f;l=l<<2&60;h=l|h>>>6;Z:{if(!(y[Gb(e+296|0,l>>>3|0)|0]>>>(h&7)&1)|!(f|h)){break Z}v[d+5|0]=f;v[d+3|0]=h;l=k>>>4|0;v[d+4|0]=l;_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{switch(h|0){case 0:case 1:case 2:case 32:case 33:case 34:v[d+3|0]=h&15;Hf(d);if(!y[d+4|0]){break Z}v[d+2|0]=h>>>0<32?3:4;break Z;case 9:v[d+3|0]=10;v[d+5|0]=f>>>1;if(f>>>0<512){break Z}v[d+2|0]=15;v[d+4|0]=k>>>5;break Z;case 10:case 42:if(f>>>0>254){break ia}v[d+3|0]=h&15;break;case 50:break $;case 48:break aa;case 43:break ba;case 47:break ca;case 17:case 18:case 26:case 27:break da;case 22:case 25:case 28:case 29:case 30:break ea;case 16:case 19:case 20:case 21:case 23:case 31:break fa;case 13:break ga;case 11:case 15:break ha;case 3:case 4:case 5:case 6:case 7:case 12:break ja;default:break _}}Hf(d);break Z}v[d+3|0]=19;v[d+5|0]=l|(h>>>0<32?16:32);if(k&15){v[d+2|0]=3;v[d+4|0]=(f&240)>>>4;break Z}v[d+2|0]=4;v[d+4|0]=f&15;break Z}v[d+3|0]=(h|0)==11?12:16;B=d,C=Yt(f),v[B+5|0]=C;break Z}v[d+3|0]=14;if((f&255)>>>0<64){break Z}v[d+5|0]=0;break Z}v[d+3|0]=19;v[d+5|0]=f&15|h<<4;break Z}v[d+3|0]=19;w[e+152>>1]=15;B=d,C=y[Wc(e+72|0,e+152|0)|0]|h<<4,v[B+5|0]=C;break Z}v[d+3|0]=19;if(f&255){v[d+5|0]=f&15|((h|0)==17?16:(h|0)==26?16:32);if(k>>>0<16){break Z}v[d+2|0]=h>>>0>25?6:5;break Z}v[d+5|0]=l|(h>>>0>25?-80:-96);break Z}if(!f){break _}v[d+3|0]=17;x[e+152>>2]=8;x[e+112>>2]=f+4;B=d,C=ri(x[Je(e+152|0,e+112|0)>>2]/8|0),v[B+5|0]=C;break Z}v[d+3|0]=14;k=D(u,6)+d|0;o=z[a+480188>>1];f=0;while(1){if((f|0)==(o|0)){break Z}h=k+D(f,6)|0;if(!y[h+3|0]){v[h+3|0]=12;B=h,C=Yt(s),v[B+5|0]=C}f=f+1|0;continue}}v[d+3|0]=9;h=f&7;if(h){v[d+5|0]=y[h+26729|0];break Z}h=f>>>4|0;if((h|0)==128){break _}v[d+5|0]=h;if(f>>>0<=2047){v[d+5|0]=h^128;break Z}v[d+5|0]=h^-1;break Z}v[d+5|0]=0;v[d+3|0]=0;if(!o){v[d|0]=255;break Z}v[d+3|0]=25;break Z}v[d+3|0]=0}g=g+1|0;f=z[a+480188>>1];d=D(f,6)+d|0;continue}}i=i+1|0;continue}}j=j+1|0;continue}break}g=P()|0;break b}break c}}else{WA(a,d&65535);w[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;g=z[a+480188>>1];continue}break}g=P()|0;break b}fc(m)}fc(n)}hb=e+400|0;return d|0}g=P()|0;break b}g=P()|0;fc(d)}fc(m)}fc(n);T(g|0);p()}function yG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=0,H=E(0),I=0;e=hb-144|0;hb=e;d=Zb(e,0,144);x[d+76>>2]=-1;x[d+44>>2]=a;x[d+32>>2]=1065;x[d+84>>2]=a;s=c;a=0;j=hb-304|0;hb=j;a:{b:{c:{d:{if(x[d+4>>2]){break d}Aw(d);if(x[d+4>>2]){break d}break c}h=y[b|0];if(!h){break a}e:{f:{g:{h:{while(1){i:{c=h&255;j:{if(vk(c)){while(1){h=b;b=b+1|0;if(vk(y[h+1|0])){continue}break}Zh(d,0,0);while(1){b=x[d+4>>2];k:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break k}b=md(d)}if(vk(b)){continue}break}b=x[d+4>>2];c=x[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;e=b;g=m+x[d+124>>2]|0;c=b>>31;b=n+x[d+120>>2]|0;g=c+(b>>>0<n>>>0?g+1|0:g)|0;n=b+e|0;m=n>>>0<b>>>0?g+1|0:g;break j}l:{m:{n:{if((c|0)==37){e=y[b+1|0];if((e|0)==42){break n}if((e|0)!=37){break m}}Zh(d,0,0);o:{if(y[b|0]==37){while(1){c=x[d+4>>2];p:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;h=y[c|0];break p}h=md(d)}if(vk(h)){continue}break}b=b+1|0;break o}c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;h=y[c|0];break o}h=md(d)}if(y[b|0]!=(h|0)){b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}if((h|0)>=0){break a}f=0;if(t){break a}break c}c=x[d+4>>2]-x[d+44>>2]|0;i=c;m=m+x[d+124>>2]|0;e=c>>31;c=n+x[d+120>>2]|0;f=e+(c>>>0<n>>>0?m+1|0:m)|0;n=c+i|0;m=n>>>0<c>>>0?f+1|0:f;h=b;break j}l=0;b=b+2|0;break l}if(!(!Dj(e)|y[b+2|0]!=36)){c=hb-16|0;x[c+12>>2]=s;f=c;c=e-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+s|0;x[f+8>>2]=c+4;l=x[c>>2];b=b+3|0;break l}l=x[s>>2];s=s+4|0;b=b+1|0}c=0;while(1){e=y[b|0];if(Dj(e)){b=b+1|0;c=(D(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){p=0;r=(l|0)!=0;e=y[b+1|0];b=b+1|0;a=0}h=b+1|0;k=3;f=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=y[b+1|0]==104;h=b?e:h;k=b?-2:-1;break q;case 43:e=b+2|0;b=y[b+1|0]==108;h=b?e:h;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;h=b}e=y[h|0];b=(e&47)==3;u=b?1:k;q=b?e|32:e;s:{if((q|0)==91){break s}t:{if((q|0)!=110){if((q|0)!=99){break t}c=(c|0)<=1?1:c;break s}zG(l,u,n,m);break j}Zh(d,0,0);while(1){b=x[d+4>>2];u:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break u}b=md(d)}if(vk(b)){continue}break}b=x[d+4>>2];e=x[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;i=b;g=m+x[d+124>>2]|0;e=b>>31;b=n+x[d+120>>2]|0;m=e+(b>>>0<n>>>0?g+1|0:g)|0;n=b+i|0;m=n>>>0<b>>>0?m+1|0:m}i=c;o=c>>31;Zh(d,c,o);b=x[d+4>>2];v:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;break v}if((md(d)|0)<0){break f}}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(q-88|0){default:b=q-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:BG(j+8|0,d,u,0);c=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]!=(0-c|0)|x[d+124>>2]!=(0-((c>>31)+((c|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((q|16)==115){Zb(j+32|0,-1,257);v[j+32|0]=0;if((q|0)!=115){break x}v[j+65|0]=0;v[j+46|0]=0;w[j+42>>1]=0;w[j+44>>1]=0;break x}g=y[h+1|0];e=(g|0)==94;Zb(j+32|0,e,257);v[j+32|0]=0;b=e?h+2|0:h+1|0;B:{C:{D:{e=y[(e?2:1)+h|0];if((e|0)!=45){if((e|0)==93){break D}k=(g|0)!=94;break B}k=(g|0)!=94;v[j+78|0]=k;break C}k=(g|0)!=94;v[j+126|0]=k}b=b+1|0}h=b;while(1){e=y[h|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=y[h+1|0];if(!f|(f|0)==93){break E}g=h+1|0;b=y[h-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;v[b+(j+32|0)|0]=k;e=y[g|0];if(e>>>0>b>>>0){continue}break}}h=g}v[(e+j|0)+33|0]=k;h=h+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}i=0;g=0;e=0;f=0;A=0;z=hb-16|0;hb=z;G:{if((b|0)==1){x[116080]=28;break G}while(1){c=x[d+4>>2];H:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break H}c=md(d)}if(vk(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}A=(c|0)==45?-1:0;c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break I}c=md(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=x[d+4>>2];O:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break O}c=md(d)}if((c&-33)==88){b=16;c=x[d+4>>2];P:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break P}c=md(d)}if(y[c+78353|0]<16){break M}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}Zh(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>y[c+78353|0]){break N}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}Zh(d,0,0);x[116080]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=D(b,10)+e|0;f=b>>>0<429496729;c=x[d+4>>2];Q:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break Q}c=md(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}i=b}R:{if(e>>>0>9){break R}b=Jia(i,0,10,0);k=lb;f=e;while(1){g=k;i=b+f|0;g=i>>>0<f>>>0?g+1|0:g;b=(g|0)==429496729&i>>>0>=2576980378|g>>>0>429496729;c=x[d+4>>2];S:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break S}c=md(d)}e=c-48|0;if(b|e>>>0>9){break R}b=Jia(i,g,10,0);f=e;k=lb;if((k|0)==-1&(e^-1)>>>0>=b>>>0|(k|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){f=y[c+78353|0];if(f>>>0<b>>>0){while(1){e=D(b,e)+f|0;i=e>>>0<119304647;c=x[d+4>>2];T:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break T}c=md(d)}f=y[c+78353|0];if(i&f>>>0<b>>>0){continue}break}i=e}if(b>>>0<=f>>>0){break L}o=b;while(1){e=Jia(i,g,o,0);k=lb;f=f&255;if((k|0)==-1&(f^-1)>>>0<e>>>0){break L}g=k;i=e+f|0;g=i>>>0<f>>>0?g+1|0:g;c=x[d+4>>2];U:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break U}c=md(d)}f=y[c+78353|0];if(b>>>0<=f>>>0){break L}kf(z,o,0,0,0,i,g,0,0);if(!(x[z+8>>2]|x[z+12>>2])){continue}break}break L}k=v[(D(b,23)>>>5&7)+78609|0];e=y[c+78353|0];if(e>>>0<b>>>0){while(1){f=f<<k|e;i=f>>>0<134217728;c=x[d+4>>2];V:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break V}c=md(d)}e=y[c+78353|0];if(i&e>>>0<b>>>0){continue}break}i=f}if(b>>>0<=e>>>0){break L}o=k&31;if((k&63)>>>0>=32){f=0;o=-1>>>o|0}else{f=-1>>>o|0;o=f|(1<<o)-1<<32-o}if(!f&i>>>0>o>>>0){break L}while(1){F=e&255;c=i;e=k&31;if((k&63)>>>0>=32){g=c<<e;c=0}else{g=(1<<e)-1&c>>>32-e|g<<e;c=c<<e}i=F|c;c=x[d+4>>2];W:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break W}c=md(d)}e=y[c+78353|0];if(b>>>0<=e>>>0){break L}if((g|0)==(f|0)&i>>>0<=o>>>0|g>>>0<f>>>0){continue}break}}if(y[c+78353|0]>=b>>>0){break K}while(1){c=x[d+4>>2];X:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break X}c=md(d)}if(y[c+78353|0]<b>>>0){continue}break}x[116080]=68;i=-1;g=-1;A=0}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=A;e=b^i;i=e-b|0;c=b>>31;g=(c^g)-((b>>>0>e>>>0)+c|0)|0}hb=z+16|0;c=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]==(0-c|0)&x[d+124>>2]==(0-((c>>31)+((c|0)!=0)|0)|0)){break g}if(!(!l|(q|0)!=112)){x[l>>2]=i;break w}zG(l,u,i,g);break w}if(!l){break w}c=x[j+16>>2];i=x[j+20>>2];b=x[j+8>>2];e=x[j+12>>2];Y:{switch(u|0){case 0:G=l,H=BD(b,e,c,i),B[G>>2]=H;break w;case 1:G=l,I=qv(b,e,c,i),C[G>>3]=I;break w;case 2:break Y;default:break w}}x[l>>2]=b;x[l+4>>2]=e;x[l+8>>2]=c;x[l+12>>2]=i;break w}k=(q|0)==99;c=k?c+1|0:31;Z:{if((u|0)==1){e=l;if(r){e=Ld(c<<2);if(!e){break h}}x[j+296>>2]=0;x[j+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=x[d+4>>2];$:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break $}e=md(d)}if(!y[(e+j|0)+33|0]){break _}v[j+27|0]=e;e=Er(j+28|0,j+27|0,1,j+296|0);if((e|0)==-2){continue}p=0;if((e|0)==-1){break f}if(a){x[(b<<2)+a>>2]=x[j+28>>2];b=b+1|0}if(!((b|0)==(c|0)&r)){continue}break}f=1;b=c;c=b<<1|1;e=At(a,c<<2);if(e){continue}break e}break}p=0;c=a;if(j+296|0?x[j+296>>2]:0){break f}break Z}if(r){b=0;e=Ld(c);if(!e){break h}while(1){a=e;while(1){e=x[d+4>>2];aa:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break aa}e=md(d)}if(!y[(e+j|0)+33|0]){c=0;p=a;break Z}v[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}f=1;b=c;c=b<<1|1;e=At(a,c);if(e){continue}break}p=a;a=0;break e}b=0;if(l){while(1){a=x[d+4>>2];ba:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ba}a=md(d)}if(y[(a+j|0)+33|0]){v[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;p=a;break Z}}}while(1){a=x[d+4>>2];ca:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ca}a=md(d)}if(y[(a+j|0)+33|0]){continue}break}a=0;p=0;c=0}e=x[d+4>>2];g=x[d+116>>2];if((g|0)>0|(g|0)>=0){e=e-1|0;x[d+4>>2]=e}e=e-x[d+44>>2]|0;g=e+x[d+120>>2]|0;f=x[d+124>>2]+(e>>31)|0;f=e>>>0>g>>>0?f+1|0:f;if(!(f|g)|((g|0)!=(i|0)|(f|0)!=(o|0))&(q|0)==99){break i}if(r){x[l>>2]=a}da:{if(k){break da}if(c){x[(b<<2)+c>>2]=0}if(!p){p=0;break da}v[b+p|0]=0}a=c}b=x[d+4>>2]-x[d+44>>2]|0;e=b;m=m+x[d+124>>2]|0;c=b>>31;b=n+x[d+120>>2]|0;g=c+(b>>>0<n>>>0?m+1|0:m)|0;n=b+e|0;m=n>>>0<b>>>0?g+1|0:g;t=((l|0)!=0)+t|0}b=h+1|0;h=y[h+1|0];if(h){continue}break a}break}a=c;break g}f=1;p=0;a=0;break e}f=r;break b}f=r}if(t){break b}}t=-1}if(!f){break a}Hb(p);Hb(a)}hb=j+304|0;hb=d+144|0;return t}function b4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;h=hb-32|0;hb=h;e=Xb(h+16|0,11475);d=Ng(c,e);xb(e);a:{b:{c:{d:{e:{if(d){Hk(a,x[b+24>>2]+1298356|0);break e}e=Xb(h+16|0,10864);d=Ng(c,e);xb(e);if(d){Hk(a,x[b+24>>2]+1298344|0);break e}e=Xb(h+16|0,11305);d=Ng(c,e);xb(e);if(d){Hk(a,x[b+24>>2]+1298392|0);break e}e=Xb(h+16|0,10856);d=Ng(c,e);xb(e);if(d){Hk(a,x[b+24>>2]+1298380|0);break e}e=Xb(h+16|0,8161);d=Ng(c,e);xb(e);if(d){c=h+16|0;e=x[x[b+24>>2]+480184>>2];b=33152;f:{g:{while(1){if((b|0)==33200){break g}if((e|0)!=x[b>>2]){b=b+12|0;continue}break}Jm(c,0,x[b+8>>2]);break f}Kb(c)}x[23604]=0;R(962,a|0,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break d}xb(h+16|0);break e}e=Xb(h+16|0,10841);d=Ng(c,e);xb(e);if(d){f=x[x[b+24>>2]+480184>>2];c=hb+-64|0;hb=c;b=33152;g=ag(c+48|0);j=h+16|0;e=Kb(j);while(1){if((b|0)!=33200){if((f|0)==x[b>>2]){x[23604]=0;d=Q(1,c+32|0,x[b+4>>2])|0;i=x[23604];x[23604]=0;h:{i:{j:{k:{l:{m:{if((i|0)!=1){x[23604]=0;U(798,c+24|0,g|0,d|0);i=x[23604];x[23604]=0;if((i|0)==1){break k}if(!y[c+28|0]){break h}if(!wd(x[e+4>>2],y[e+11|0])){x[23604]=0;i=Q(1,c+8|0,17620)|0;m=x[23604];x[23604]=0;if((m|0)==1){break m}x[23604]=0;Q(87,e|0,i|0)|0;m=x[23604];x[23604]=0;if((m|0)==1){break l}xb(i)}x[23604]=0;Q(87,e|0,d|0)|0;i=x[23604];x[23604]=0;if((i|0)!=1){break h}b=P()|0;break j}b=P()|0;break i}b=P()|0;break j}b=P()|0;xb(i);break j}b=P()|0}xb(d)}xb(e);GL(g);T(b|0);p()}xb(d)}b=b+12|0;continue}break}GL(g);hb=c- -64|0;x[23604]=0;R(962,a|0,j|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(h+16|0);break e}c=P()|0;xb(h+16|0);break a}e=Xb(h+16|0,8227);d=Ng(c,e);xb(e);if(d){Hk(a,x[b+24>>2]+1298368|0);break e}e=Xb(h+16|0,5581);d=Ng(c,e);xb(e);if(d){Hk(a,x[b+24>>2]+1298320|0);break e}e=Xb(h+16|0,11879);d=Ng(c,e);xb(e);if(d){c=h+16|0;lg(c,x[b+24>>2]+1298308|0);b=x[b+24>>2];x[23604]=0;U(956,a|0,b|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(h+16|0);break e}c=P()|0;xb(h+16|0);break a}e=Xb(h+16|0,11248);d=Ng(c,e);xb(e);if(d){c=x[b+24>>2]+1298408|0;b=x[c+4>>2];n:{if(!tc(x[c>>2],b)){b=b-48|0;if(td(x[b+12>>2])){break n}}Kb(a);break e}m=h+16|0;g=hb-144|0;hb=g;vc(g+96|0,b,44);i=x[b+44>>2];if(i){vc(g+44|0,b,44);e=hb-16|0;hb=e;f=e+8|0;b=Jw(x[g+64>>2]+1900|0,x[g+60>>2]+1|0,x[g+56>>2])-Jw(1970,1,1)|0;b=Jia(b,b>>31,86400,0);c=D(x[g+52>>2],3600);b=b+c|0;d=lb+(c>>31)|0;d=b>>>0<c>>>0?d+1|0:d;c=D(x[g+48>>2],60);j=c;b=c+b|0;c=(c>>31)+d|0;c=b>>>0<j>>>0?c+1|0:c;d=x[g+44>>2];j=d;b=d+b|0;d=(d>>31)+c|0;c=Jh(f,b,b>>>0<j>>>0?d+1|0:d);b=x[c>>2];d=x[c+4>>2];hb=e+16|0;f=g+88|0;e=2147483647;l=ee(+(i>>>0)/18.2);c=-1;o:{if(l>=0x8000000000000000){break o}e=-2147483648;c=0;if(l<=-0x8000000000000000){break o}if(F(l)<0x8000000000000000){e=F(l)>=1?~~(l>0?H(J(l*2.3283064365386963e-10),4294967295):K((l-+(~~l>>>0>>>0))*2.3283064365386963e-10))>>>0:0;c=~~l>>>0;break o}c=0}d=d+e|0;e=b;b=b+c|0;d=e>>>0>b>>>0?d+1|0:d;b=Jh(f,b,d);i=x[b>>2];c=x[b+4>>2];o=c;b=hb-16|0;hb=b;x[b+12>>2]=0;x[b+8>>2]=0;x[b+4>>2]=0;f=Jw(1970,1,1)+Kia(i,c,86400,0)|0;j=f>>31;e=Jia(f,j,1e4,0);c=lb;e=e+14780|0;c=e>>>0<14780?c+1|0:c;k=Kia(e,c,-14609700,-1);d=j+lb|0;k=f+k|0;d=k>>>0<f>>>0?d+1|0:d;n=Kia(e,c,365242500,0);k=n+k|0;d=lb+d|0;d=k>>>0<n>>>0?d+1|0:d;n=Kia(e,c,-146097e4,-1);k=n+k|0;d=lb+d|0;d=k>>>0<n>>>0?d+1|0:d;c=Kia(e,c,3652425,0);e=lb;n=e;q=k;k=Jia(c,e,-365,-1);e=q+k|0;d=lb+d|0;d=e>>>0<k>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){e=c-1|0;c=Jia(e,n-!c|0,-365,-1);d=j+lb|0;c=c+f|0;d=c>>>0<f>>>0?d+1|0:d;j=c;c=e;f=(c|0)/-4|0;e=j+f|0;d=(f>>31)+d|0;d=e>>>0<f>>>0?d+1|0:d;f=(c|0)/100|0;e=f+e|0;d=(f>>31)+d|0;d=e>>>0<f>>>0?d+1|0:d;f=(c|0)/-400|0;e=f+e|0;d=(f>>31)+d|0;d=e>>>0<f>>>0?d+1|0:d}f=c;d=Jia(e,d,100,0);c=lb;d=d+52|0;c=d>>>0<52?c+1|0:c;j=f;c=Kia(d,c,3060,0);d=c+2|0;f=(d|0)/12|0;x[b+12>>2]=j+f;x[b+8>>2]=(d+D(f,-12)|0)+1;c=Jia(c,lb,306,0);d=lb;c=c+5|0;d=c>>>0<5?d+1|0:d;c=Kia(c,d,-10,-1)+e|0;x[b+4>>2]=c+1;x[g+136>>2]=0;x[g+128>>2]=0;x[g+132>>2]=0;x[g+120>>2]=0;x[g+124>>2]=0;x[g+116>>2]=x[b+12>>2]-1900;x[g+112>>2]=x[b+8>>2]-1;c=x[b+4>>2];r=g,s=Lia(Kia(i,o,3600,0),lb,24),x[r+104>>2]=s;x[g+108>>2]=c;c=Kia(i,o,60,0);e=lb;r=g,s=Lia(c,e,60),x[r+100>>2]=s;c=Jia(c,e,-60,0)+i|0;x[g+96>>2]=c;hb=b+16|0}c=vc(g,g+96|0,44);b=hb-176|0;hb=b;d=Kb(b+160|0);x[23604]=0;e=Q(1,b+144|0,13341)|0;g=x[23604];x[23604]=0;p:{q:{r:{s:{t:{if((g|0)!=1){g=x[c+20>>2];if(!g){break q}x[23604]=0;x[b+112>>2]=g+1900;R(86,b+128|0,b+112|0);g=x[23604];x[23604]=0;if((g|0)!=1){x[23604]=0;i=Q(87,d|0,b+128|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break t}xb(b+128|0);f=x[c+16>>2];if(f>>>0>11){break q}x[23604]=0;g=Q(1,b+112|0,16647)|0;j=x[23604];x[23604]=0;u:{v:{w:{x:{y:{z:{if((j|0)!=1){x[23604]=0;x[b+80>>2]=f+1;R(88,b+96|0,b+80|0);f=x[23604];x[23604]=0;if((f|0)==1){break z}x[23604]=0;U(2,b+128|0,g|0,b+96|0);f=x[23604];x[23604]=0;if((f|0)==1){break y}x[23604]=0;i=Q(87,i|0,b+128|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break x}xb(b+128|0);xb(b+96|0);xb(g);if(x[c+12>>2]-32>>>0>=4294967265){break u}break q}a=P()|0;break s}a=P()|0;break v}a=P()|0;break w}a=P()|0;xb(b+128|0)}xb(b+96|0)}xb(g);break s}x[23604]=0;g=Q(1,b+96|0,16647)|0;f=x[23604];x[23604]=0;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((f|0)!=1){x[23604]=0;R(88,b+80|0,c+12|0);f=x[23604];x[23604]=0;if((f|0)==1){break Z}x[23604]=0;U(2,b+128|0,g|0,b+80|0);f=x[23604];x[23604]=0;if((f|0)==1){break Y}x[23604]=0;i=Q(87,i|0,b+128|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break X}xb(b+128|0);xb(b+80|0);xb(g);j=x[c>>2];g=x[c+8>>2];f=x[c+4>>2];if(!(j|(g|f))|g>>>0>23|f>>>0>59){break q}x[23604]=0;g=Q(1,b+128|0,13501)|0;f=x[23604];x[23604]=0;if((f|0)==1){break U}x[23604]=0;i=Q(87,i|0,g|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break T}xb(g);if(x[c+32>>2]>0){x[23604]=0;g=Q(1,b+80|0,15430)|0;f=x[23604];x[23604]=0;if((f|0)==1){break S}Ab(e,g);xb(g)}x[23604]=0;R(88,b+32|0,c+8|0);g=x[23604];x[23604]=0;if((g|0)==1){break R}x[23604]=0;g=Q(1,b+16|0,14506)|0;f=x[23604];x[23604]=0;if((f|0)==1){break Q}x[23604]=0;U(2,b+48|0,b+32|0,g|0);f=x[23604];x[23604]=0;if((f|0)==1){break P}x[23604]=0;R(88,b|0,c+4|0);f=x[23604];x[23604]=0;if((f|0)==1){break O}x[23604]=0;U(2,b- -64|0,b+48|0,b|0);f=x[23604];x[23604]=0;if((f|0)==1){break N}x[23604]=0;i=Q(87,i|0,b- -64|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break M}xb(b- -64|0);xb(b);xb(b+48|0);xb(g);xb(b+32|0);if(j>>>0<62){break H}x[23604]=0;U(89,m|0,i|0,e|0);g=x[23604];x[23604]=0;if((g|0)==1){break G}break p}a=P()|0;break s}a=P()|0;break V}a=P()|0;break W}a=P()|0;xb(b+128|0)}xb(b+80|0)}xb(g);break s}a=P()|0;break s}a=P()|0;xb(g);break s}a=P()|0;break s}a=P()|0;break s}a=P()|0;break I}a=P()|0;break J}a=P()|0;break K}a=P()|0;break L}a=P()|0;xb(b- -64|0)}xb(b)}xb(b+48|0)}xb(g)}xb(b+32|0);break s}x[23604]=0;g=Q(1,b+48|0,14506)|0;f=x[23604];x[23604]=0;if((f|0)==1){break F}x[23604]=0;R(88,b+32|0,c|0);f=x[23604];x[23604]=0;if((f|0)==1){break E}x[23604]=0;U(2,b- -64|0,g|0,b+32|0);f=x[23604];x[23604]=0;if((f|0)==1){break D}x[23604]=0;i=Q(87,i|0,b- -64|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break C}xb(b- -64|0);xb(b+32|0);xb(g);x[23604]=0;Q(87,i|0,e|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){break q}}a=P()|0;break s}a=P()|0;break s}a=P()|0;break A}a=P()|0;break B}a=P()|0;xb(b- -64|0)}xb(b+32|0)}xb(g);break s}a=P()|0;break s}a=P()|0;break r}a=P()|0;xb(b+128|0)}xb(e)}xb(d);T(a|0);p()}dd(m,d)}xb(e);xb(d);hb=b+176|0;hb=c+144|0;x[23604]=0;R(962,a|0,m|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(h+16|0);break e}c=P()|0;xb(h+16|0);break a}e=Xb(h+16|0,12080);d=Ng(c,e);xb(e);if(d){iP(h+16|0,x[b+24>>2]+1298332|0);_:{if(!wd(x[h+20>>2],y[h+27|0])){break _}e=x[x[b+24>>2]+480180>>2];$:{aa:{if((e|0)==33554432){break aa}c=1;if((e|0)==32){break $}if((e|0)==16384){break aa}if((e|0)==16777216){break $}}c=2}ba:{switch(c-1|0){case 0:x[23604]=0;R(963,h|0,b|0);c=x[23604];x[23604]=0;if((c|0)!=1){Ab(h+16|0,h);xb(h);break _}break b;case 1:break ba;default:break _}}x[23604]=0;R(964,h|0,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Ab(h+16|0,h);xb(h);if(!wd(x[h+20>>2],y[h+27|0])){break _}x[23604]=0;R(963,h|0,b|0);e=x[23604];x[23604]=0;if((e|0)==1){break b}Ab(c,h);xb(h)}b=x[b+24>>2];x[23604]=0;U(956,a|0,b|0,h+16|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(h+16|0);break e}break b}e=Xb(h+16|0,5433);d=Ng(c,e);xb(e);if(d){c=h+16|0;iP(c,x[b+24>>2]+1298332|0);b=x[b+24>>2];x[23604]=0;U(956,a|0,b|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(h+16|0);break e}c=P()|0;xb(h+16|0);break a}e=c;c=Xb(h+16|0,7253);e=Ng(e,c);xb(c);if(e){a=Kb(a);r=h,s=Bb(x[b+68>>2]),x[r+16>>2]=s;b=Bb(x[b+72>>2]);c=1;while(1){e=x[h+16>>2];if(!Ob(e,b)){break e}if(!(c&1)){x[23604]=0;Q(889,a|0,21472)|0;c=x[23604];x[23604]=0;if((c|0)==1){break c}}x[23604]=0;Q(753,a|0,e|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break c}Wp(h+16|0);c=0;continue}}Xb(a,21502)}hb=h+32|0;return}c=P()|0;xb(h+16|0);break a}c=P()|0;xb(a);break a}c=P()|0;xb(h+16|0)}T(c|0);p()}function Bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=hb-208|0;hb=j;if(!jt(a)){f=j+48|0;vc(f,a,128);e=j+176|0;df(e,f,128,2);f=j+192|0;Dc(f,e);Bc(b+492|0,f);xb(f)}w[c+34>>1]=z[c+34>>1]&65489;q=j+192|0;g=hb-32|0;hb=g;a:{b:{switch(y[a+128|0]-4|0){default:x[g+28>>2]=0;hj(q,0,g+28|0);break a;case 0:case 4:break b}}v[g+28|0]=y[a+129|0];v[g+24|0]=100;f=g+24|0;e=y[Wb(g+28|0,f)|0];v[g+24|0]=y[a+130|0];v[g+20|0]=100;f=y[Wb(f,g+20|0)|0];x[g+28>>2]=f;c:{if(y[a+140|0]&16){i=Lb(y[a+150|0]|y[a+151|0]<<8);k=Lb(y[a+152|0]|y[a+153|0]<<8);l=x[c>>2];s=+(l>>>0)/6553600;e=cq(s*+((i|e<<16)>>>0));x[g+24>>2]=l-e;t=g,u=cq(s*+((k|f<<16)>>>0)),x[t+20>>2]=u;t=g,u=x[Fb(g+24|0,g+20|0)>>2],x[t+28>>2]=u;break c}i=x[c>>2];k=x[c+20>>2];if(!Qd(i,k)){break c}l=i>>>7|0;e=D(l,(e<<7>>>0)/100|0);x[g+24>>2]=i-e;x[g+20>>2]=D(l,(f<<7>>>0)/100|0);f=x[Fb(g+24|0,g+20|0)>>2];l=z[c+34>>1];i=D(Gd(l),i);d:{if(l&1){hc(g+8|0,k,i);k=x[g+8>>2];l=Gd(z[c+34>>1]);i=k+(D(l,e+f|0)<<1)|0;n=w[k+(D(e,l)<<1)>>1];l=0-l<<1;while(1){e:{f:{if(f){p=w[i>>1]-n|0;k=p>>31;if((k^p)-k>>>0>=1536){break f}}else{f=0}break e}f=f-1|0;i=i+l|0;continue}break}break d}hc(g,k,i);k=x[g>>2];l=Gd(z[c+34>>1]);n=0-l|0;i=k+D(l,e+f|0)|0;l=v[k+D(e,l)|0];while(1){g:{h:{if(f){p=v[i|0]-l|0;k=p>>31;if((k^p)-k>>>0>=6){break h}}else{f=0}break g}f=f-1|0;i=i+n|0;continue}break}}x[g+28>>2]=f}hj(q,e,g+28|0)}hb=g+32|0;q=jc(q);if(!(!x[q>>2]|y[a+128|0]!=4)){w[c+34>>1]=z[c+34>>1]|2;f=x[j+192>>2];x[c+4>>2]=f;x[c+8>>2]=f+x[q>>2]}e=j;f=y[a+134|0];if((f-1&255)>>>0<=198){v[j+48|0]=f;v[j+176|0]=100;f=(y[Wb(j+48|0,j+176|0)|0]<<7>>>0)/100|0}else{f=128}v[e+47|0]=f;v[j+48|0]=64;f=j+47|0;e=j+48|0;t=c,u=y[Ye(f,e)|0]>>>1|0,w[t+32>>1]=u;v[j+48|0]=64;t=b,u=y[Wb(f,e)|0],x[t+4>>2]=u;x[c+24>>2]=40460;bq(c,+v[a+139|0]/12+ +(0-y[a+143|0]|0)+ +v[a+138|0]/1536);v[b+34|0]=y[a+142|0]&2?2:1;if(y[a+142|0]&2){Bm(b,127,1);Am(b,0,1)}i:{if(!Qd(x[c>>2],x[c+20>>2])){break i}b=y[a+140|0];if(b&1){b=x[c>>2];f=x[c+20>>2];j:{if(!Qd(b,f)|b>>>0<2){break j}k:{l:{switch(gk(z[c+34>>1])-1|0){case 3:e=0;g=b>>>1|0;while(1){if((e|0)!=(g|0)){qc(f+(e<<2)|0,f+(b+(e^-1)<<2)|0);e=e+1|0;continue}break};break k;case 1:e=0;g=b>>>1|0;while(1){if((e|0)!=(g|0)){KL(f+(e<<1)|0,f+(b+(e^-1)<<1)|0);e=e+1|0;continue}break};break k;case 0:break l;default:break j}}e=0;g=b>>>1|0;while(1){if((e|0)!=(g|0)){Xg(e+f|0,f+(b+(e^-1)|0)|0);e=e+1|0;continue}break}}aj(c,d)}b=y[a+140|0]}if(b&4){m:{f=x[c>>2];b=x[c+20>>2];if(!Qd(f,b)){break m}e=z[c+34>>1];f=D(Gd(e),f);n:{o:{switch(Fm(e)-1|0){case 1:e=0;while(1){if((e|0)!=(f|0)){g=b+(e<<1)|0;w[g>>1]=z[g>>1]^-1;e=e+1|0;continue}break};break n;case 0:break o;default:break m}}e=0;while(1){if((e|0)!=(f|0)){g=b+e|0;v[g|0]=y[g|0]^-1;e=e+1|0;continue}break}}aj(c,d)}}m=y[a+170|0]!=2|y[a+171|0]>100?m:y[a+172|0]<101;b=z[c+34>>1];if(!(!(m|y[a+160|0]!=0|y[a+141|0])|b&1)){f=it(x[c>>2],Gd(b)<<1&254);if(!f){break i}b=f;e=x[c>>2];g=z[c+34>>1];i=D(Gd(g),e);k=x[c+20>>2];g=lj(e,g);e=hb-16|0;hb=e;x[e+12>>2]=i;wc(e+12|0,g);i=x[e+12>>2];while(1){if(i){w[b>>1]=v[k|0]<<8;k=k+1|0;b=b+2|0;i=i-1|0;continue}break}hb=e+16|0;w[c+34>>1]=z[c+34>>1]|1;LP(c,f,x[c>>2],d)}p:{if(v[a+141|0]>=0){break p}hc(j+48|0,x[c+20>>2],D(x[c>>2],Gd(z[c+34>>1])));g=x[j+52>>2];f=x[j+48>>2];q:while(1){if((0-v[a+141|0]|0)<=(h|0)){break p}e=w[f>>1];i=cc(f,g);b=f;while(1)if((b|0)==(i|0)){h=h+1|0;continue q}else{e=gd(w[b>>1]-gd(e,1)|0,1);w[b>>1]=e;b=b+2|0;continue}}}r:{if(!m){break r}hc(j+48|0,x[c+20>>2],D(x[c>>2],Gd(z[c+34>>1])));g=x[j+52>>2];b=(g|0)/2|0;e=b;i=e>>31;h=y[a+172|0];f=y[a+171|0];b=h-f|0;m=b<<24;e=m+e|0;b=(0-(f>>>0>h>>>0)<<24|b>>>8)+i|0;h=Ec(Kia(e,e>>>0<m>>>0?b+1|0:b,g,g>>31),lb);m=h>>31;f=f<<24;e=f>>31;b=x[j+48>>2];g=cc(b,g);while(1){if((b|0)==(g|0)){break r}i=w[b>>1];k=Jia(f,e,i,i>>31);i=lb;k=k+838860800|0;i=k>>>0<838860800?i+1|0:i;t=b,u=Ec(Kia(k,i,1677721600,0),lb),w[t>>1]=u;b=b+2|0;e=e+m|0;f=f+h|0;e=f>>>0<h>>>0?e+1|0:e;continue}}s:{if(!y[a+160|0]){break s}hc(j+176|0,x[c+20>>2],D(x[c>>2],Gd(z[c+34>>1])));m=y[a+163|0];l=y[a+162|0];e=0;f=x[j+180>>2];k=0;i=0;if(y[a+161|0]>=2){b=(f|0)/2|0;g=b>>31;h=y[a+164|0];i=0-(h>>>0<l>>>0)|0;h=h-l|0;n=h<<23;k=n+b|0;h=(i<<23|h>>>9)+g|0;p=f>>31;k=Ec(Kia(k,k>>>0<n>>>0?h+1|0:h,f,p),lb);h=y[a+165|0];i=0-(h>>>0<m>>>0)|0;h=h-m|0;n=b+(h<<23)|0;h=g+(i<<23|h>>>9)|0;i=Ec(Kia(n,b>>>0>n>>>0?h+1|0:h,f,p),lb)}m=m<<23;h=l<<23;g=(j+48|0)+((y[a+160|0]&2)<<2)|0;b=x[j+176>>2];l=cc(b,f);f=0;while(1){if((b|0)==(l|0)){break s}n=(w[b>>1]>>1)-f|0;x[j+56>>2]=n;o=n;n=(h|0)/8388608|0;e=gd(D(o,n),8)+e|0;x[j+52>>2]=e;f=gd(D(e,n),6)+f|0;f=gd(gd(D(f,(m|0)/8388608|0),6)+f|0,2);x[j+48>>2]=f;t=b,u=Vc(x[g>>2]),w[t>>1]=u;b=b+2|0;m=i+m|0;h=h+k|0;continue}}t:{if(v[a+141|0]<=0){break t}hc(j+48|0,x[c+20>>2],D(x[c>>2],Gd(z[c+34>>1])));h=0;g=x[j+52>>2];f=x[j+48>>2];u:while(1){if(v[a+141|0]<=(h|0)){break t}e=w[f>>1];i=cc(f,g);b=f;while(1)if((b|0)==(i|0)){h=h+1|0;continue u}else{e=((w[b>>1]<<1)+e|0)/3|0;w[b>>1]=e;b=b+2|0;continue}}}b=x[c+20>>2];e=z[c+34>>1];f=D(x[c>>2],Gd(e));v:{if(e&1){hc(j+32|0,b,f);f=hb-16|0;hb=f;b=x[j+32>>2];m=cc(b,x[j+36>>2]);n=hb-16|0;hb=n;l=hb-16|0;hb=l;x[l+12>>2]=b;ec(l,n+8|0,n);o=f+8|0;g=hj(o,b,l+12|0);w:{if((b|0)==(m|0)){break w}e=b+2|0;if((m|0)==(e|0)){break w}t=(Xk(z[e>>1],z[x[g>>2]>>1])?0:4)+g|0,u=e,x[t>>2]=u;i=g+4|0;while(1){h=e+2|0;if((m|0)==(h|0)){break w}k=z[e+2>>1];e=e+4|0;if((m|0)==(e|0)){if(!Xk(k,z[x[g>>2]>>1])){g=i;if(Xk(k,z[x[g>>2]>>1])){break w}}x[g>>2]=h;break w}p=z[x[g>>2]>>1];r=z[e>>1];x:{if(Xk(r,k)){if(Xk(r,p)){x[g>>2]=e}if(Xk(k,z[x[i>>2]>>1])){continue}break x}if(Xk(k,p)){x[g>>2]=h}h=e;if(Xk(r,z[x[i>>2]>>1])){continue}}x[i>>2]=h;continue}}hb=l+16|0;hb=n+16|0;x[f+4>>2]=0-w[x[f+8>>2]>>1];t=f,u=w[x[jc(o)>>2]>>1],x[t>>2]=u;y:{e=x[Je(f+4|0,f)>>2];if((e|0)>32766|!e){break y}while(1){if((b|0)==(m|0)){break y}w[b>>1]=(D(w[b>>1],32767)|0)/(e|0);b=b+2|0;continue}}break v}hc(j+24|0,b,f);f=hb-16|0;hb=f;b=x[j+24>>2];m=Gb(b,x[j+28>>2]);n=hb-16|0;hb=n;l=hb-16|0;hb=l;x[l+12>>2]=b;ec(l,n+8|0,n);o=f+8|0;g=hj(o,b,l+12|0);z:{if((b|0)==(m|0)){break z}e=b+1|0;if((m|0)==(e|0)){break z}t=(Yk(y[e|0],y[x[g>>2]])?0:4)+g|0,u=e,x[t>>2]=u;i=g+4|0;while(1){h=e+1|0;if((m|0)==(h|0)){break z}k=y[e+1|0];e=e+2|0;if((m|0)==(e|0)){if(!Yk(k,y[x[g>>2]])){g=i;if(Yk(k,y[x[g>>2]])){break z}}x[g>>2]=h;break z}p=y[x[g>>2]];r=y[e|0];A:{if(Yk(r,k)){if(Yk(r,p)){x[g>>2]=e}if(Yk(k,y[x[i>>2]])){continue}break A}if(Yk(k,p)){x[g>>2]=h}h=e;if(Yk(r,y[x[i>>2]])){continue}}x[i>>2]=h;continue}}hb=l+16|0;hb=n+16|0;x[f+4>>2]=0-v[x[f+8>>2]];t=f,u=v[x[jc(o)>>2]],x[t>>2]=u;B:{e=x[Je(f+4|0,f)>>2];if((e|0)>126|!e){break B}while(1){if((b|0)==(m|0)){break B}v[b|0]=(D(v[b|0],127)|0)/(e|0);b=b+1|0;continue}}}hb=f+16|0;C:{if((y[a+134|0]-101&255)>>>0>98){break C}e=z[c+34>>1];f=D(x[c>>2],Gd(e));b=x[c+20>>2];if(e&1){x[j+16>>2]=b;x[j+20>>2]=(b+(f<<1)|0)-b>>1;b=(3276800-(y[a+134|0]<<14)|0)/100|0;g=0-b|0;e=32768-b|0;f=x[j+16>>2];i=cc(f,x[j+20>>2]);while(1){if((f|0)!=(i|0)){h=w[f>>1];D:{if((h|0)>(b|0)){o=e+((D(b,h-b|0)|0)/(e|0)|0)|0;break D}o=((D(b,b+h|0)|0)/(e|0)|0)-e|0;if((g|0)>(h|0)){break D}o=(D(e,h)|0)/(b|0)|0}t=f,u=Vc(o),w[t>>1]=u;f=f+2|0;continue}break}break C}h=fn(j+8|0,b,b+f|0);f=x[h>>2];b=(3276800-(y[a+134|0]<<14)|0)/100|0;g=0-b|0;e=32768-b|0;i=Gb(f,x[h+4>>2]);while(1){if((f|0)!=(i|0)){h=v[f|0]<<8;E:{if((h|0)>(b|0)){o=e+((D(b,h-b|0)|0)/(e|0)|0)|0;break E}o=((D(b,b+h|0)|0)/(e|0)|0)-e|0;if((g|0)>(h|0)){break E}o=(D(e,h)|0)/(b|0)|0}t=f,u=LR((o|0)/256|0),v[t|0]=u;f=f+1|0;continue}break}}KP(c);if(y[a+128|0]!=8){break i}b=y[a+131|0];if(!b){break i}f=x[q>>2];if(!f){break i}e=x[j+192>>2];t=zb(c+68|0,0),u=e+D(f,b+1|0)|0,x[t>>2]=u;b=x[j+192>>2];x[c+12>>2]=b;x[c+16>>2]=b+x[q>>2];g=x[q>>2];h=y[a+131|0];if(g>>>0>268435456/(h>>>0)>>>0){break i}e=x[c>>2];f=D(g,h);if(e>>>0>268435456-f>>>0){break i}e=e+f|0;f=gk(z[c+34>>1]);m=it(e,f);if(!m){break i}i=b+D(g,h+1|0)|0;x[c>>2]=e;b=m;m=x[c+20>>2];h=x[j+192>>2];g=vc(b,m,D(f,h+x[q>>2]|0));k=m+D(f,h)|0;a=y[a+131|0];b=0;while(1){if((a|0)==(b|0)){vc(g+D(f,i)|0,m+D(f,h+x[q>>2]|0)|0,D(f,e-i|0));LP(c,g,e,d)}else{b=b+1|0;l=x[q>>2];vc(g+D(f,h+D(b,l)|0)|0,k,D(f,l));continue}break}}hb=j+208|0}function k9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-784|0;hb=d;xc(b);a:{b:{c:{d:{e:{f:{if(!Th(b,d+776|0)){break f}if(!yL(x[d+776>>2],x[d+780>>2])){break f}if(!kA(b,d+768|0)){break f}g=x[d+768>>2];if(!xL(g)){break f}g:{if((g|0)==1179012417){f=1;e=1313423693;break g}if((g|0)!=538987841){break f}f=2;e=1414090313}n=ge(d+744|0,b);j=Sb(d+728|0);h:{i:{j:{k:{l:{m:{n:{if(!c){x[23604]=0;X(804,d+136|0,n|0,f|0,e|0);b=x[23604];x[23604]=0;if((b|0)!=1){break n}a=P()|0;break a}x[23604]=0;U(805,d+136|0,n|0,f|0);b=x[23604];x[23604]=0;if((b|0)==1){break m}}b=d+136|0;st(j,b);Xd(b);x[23604]=0;U(806,d+704|0,j|0,e|0);b=x[23604];x[23604]=0;if((b|0)!=1){x[23604]=0;b=S(164,x[d+704>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}f=0;if(!b){break h}x[23604]=0;b=Q(807,d+704|0,d+624|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}if(!b){break h}b=y[d+689|0];if(!b){break h}x[23604]=0;f=W(142,x[d+704>>2],x[d+712>>2],b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break l}if(!c|f^1){break h}x[23604]=0;R(232,a|0,8388608);b=x[23604];x[23604]=0;if((b|0)==1){break l}x[a+480208>>2]=y[d+688|0]<<4&16^28;w[d+136>>1]=y[d+689|0];w[d+496>>1]=127;q=a,r=z[Wc(d+136|0,d+496|0)>>1],w[q+480188>>1]=r;x[a+480196>>2]=y[d+690|0];x[a+480204>>2]=D(y[d+691|0],1e4);x[a+480200>>2]=y[d+696|0]<<1;x[23604]=0;R(122,a+1298344|0,((g|0)==1179012417?16818:16784)|0);b=x[23604];x[23604]=0;if((b|0)==1){break l}x[23604]=0;b=Q(1,d+608|0,13125)|0;e=x[23604];x[23604]=0;if((e|0)==1){break j}Ab(a+1298356|0,b);xb(b);x[a+1298404>>2]=5;b=d+496|0;Sz(b,2,d+624|0);x[23604]=0;R(208,d+136|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break k}k=(g|0)!=1179012417;b=d+136|0;Ab(a+1298308|0,b);xb(b);l=(g|0)==1179012417;b=0;while(1){o:{p:{q:{if(z[a+480188>>1]<=b>>>0){b=Bb(x[j>>2]);f=Bb(x[j+4>>2]);e=hb-16|0;hb=e;x[e+8>>2]=b;while(1){r:{if(!Ob(b,f)){break r}if(bU(1380209231,x[b>>2],x[b+4>>2])){break r}b=x[pm(e+8|0)>>2];continue}break}hb=e+16|0;if(Ob(b,Bb(x[j+4>>2]))){break q}break i}f=(b<<5)+a|0;h=f+480280|0;Qe(h);x[23604]=0;e=S(192,d+704|0)|0;m=x[23604];x[23604]=0;s:{t:{if((m|0)!=1){if(l){break s}if(e>>>0<129){break t}break p}a=P()|0;break b}w[f+480284>>1]=e<<1;break o}if(e<<24>>24<0){break p}x[d+136>>2]=e<<2;x[d+496>>2]=256;q=f+480284|0,r=x[rd(d+136|0,d+496|0)>>2],w[q>>1]=r;break o}x[23604]=0;U(806,d+136|0,j|0,1380209231);b=x[23604];x[23604]=0;u:{if((b|0)!=1){x[23604]=0;b=S(192,d+136|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break u}e=y[a+484376|0];f=x[a+484360>>2];x[23604]=0;ea(324,_b(f,e)|0,d+136|0,b+1&255,255,254);b=x[23604];x[23604]=0;if((b|0)==1){break u}yb(d+136|0);break i}a=P()|0;break b}a=P()|0;yb(d+136|0);break b}x[h>>2]=1024}b=b+1|0;continue}}a=P()|0;break a}a=P()|0;break a}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}v:{if(!(c&1)){break v}w[d+56>>1]=0;x[23604]=0;U(808,d+560|0,j|0,1414807888);b=x[23604];x[23604]=0;if((b|0)==1){break c}b=x[d+564>>2];e=x[d+560>>2];x[23604]=0;f=a+484344|0;R(211,f|0,Bf(e,b)&65535);b=x[23604];x[23604]=0;w:{if((b|0)!=1){q=d,r=Bb(x[d+560>>2]),x[q+88>>2]=r;l=Bb(x[d+564>>2]);x:{y:{z:{A:{B:{while(1){b=x[d+88>>2];if(!Ob(b,l)){k=a+484348|0;b=0;break x}b=ge(d+136|0,b);x[23604]=0;e=S(192,b|0)|0;h=x[23604];x[23604]=0;if((h|0)!=1){x[23604]=0;w[d+480>>1]=e;e=S(143,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break B}x[23604]=0;U(176,d+496|0,b|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break A}e=kc(d+584|0,d+496|0);x[23604]=0;h=x[e+12>>2];x[d+8>>2]=x[e+8>>2];x[d+12>>2]=h;x[d+16>>2]=x[e+16>>2];h=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=h;X(809,d|0,z[d+480>>1],k|0,a|0);e=x[23604];x[23604]=0;if((e|0)==1){break z}yb(d+496|0);q=d,r=z[Se(d+56|0,d+480|0)>>1],w[q+56>>1]=r;yb(b);rh(d+88|0);continue}break}a=P()|0;break y}a=P()|0;break y}a=P()|0;break y}a=P()|0;yb(d+496|0)}yb(b);break w}while(1){e=b&65535;if(e>>>0>=z[d+56>>1]){jd(d+560|0);break v}C:{if(!pe(x[a+484344>>2],x[k>>2],e)){x[23604]=0;W(212,f|0,e|0,64)|0;e=x[23604];x[23604]=0;if((e|0)==1){break C}}b=b+1|0;continue}break}a=P()|0;break w}a=P()|0}jd(d+560|0);break b}D:{if((g|0)==1179012417){x[23604]=0;U(808,d+88|0,j|0,1414745673);b=x[23604];x[23604]=0;if((b|0)==1){break d}q=d,r=Bb(x[d+88>>2]),x[q+120>>2]=r;g=c&2;k=d+504|0;l=Bb(x[d+92>>2]);e=a+480190|0;while(1){b=x[d+120>>2];if(!Ob(b,l)){jd(d+88|0);break D}c=ge(d+560|0,b);x[23604]=0;b=Q(810,c|0,d+136|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){E:{if(!b){break E}b=y[d+137|0];if((b|0)==255){break E}x[23604]=0;f=W(237,a|0,b+1|0,0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}if(!f){break E}h=z[e>>1];b=0;x[23604]=0;U(811,d+136|0,f|0,h|0);f=x[23604];x[23604]=0;if((f|0)==1){break e}while(1){if(y[d+166|0]<=b>>>0){break E}F:{if(!Nh(z[e>>1])){break F}x[23604]=0;f=Q(812,c|0,d+496|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break e}if(!f){break F}f=z[e>>1]+1|0;w[e>>1]=f;if(x[d+496>>2]!=1347240275){break F}h=d+480|0;hl(h,2,k);x[23604]=0;R(208,d+56|0,h|0);h=x[23604];x[23604]=0;G:{if((h|0)!=1){f=f&65535;h=d+56|0;Bc(((f<<5)+a|0)+946304|0,h);xb(h);x[23604]=0;h=D(f,104)+a|0;f=h+484380|0;U(813,d+496|0,d+136|0,f|0);m=x[23604];x[23604]=0;if((m|0)==1){break e}if(!g){break G}h=d+56|0;wL(h,z[d+534>>1]);x[23604]=0;W(205,h|0,f|0,c|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){break F}break e}break e}h=z[h+484414>>1];f=x[f>>2];x[23604]=0;Q(174,c|0,lj(f,h)|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break e}}b=b+1|0;continue}}yb(c);rh(d+120|0);continue}break}break e}x[23604]=0;U(808,d+480|0,j|0,1179011410);b=x[23604];x[23604]=0;if((b|0)!=1){q=d,r=Bb(x[d+480>>2]),x[q+472>>2]=r;k=c&2;l=d+496|4;h=Bb(x[d+484>>2]);f=a+480190|0;H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{while(1){b=x[d+472>>2];if(!Ob(b,h)){jd(d+480|0);break D}c=ge(d+560|0,b);x[23604]=0;b=S(143,c|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break Q}R:{S:{if((b|0)!=538986817){break S}x[23604]=0;b=Q(814,c|0,d+464|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break P}if(!(b&x[d+464>>2]==1414745673)){break S}x[23604]=0;b=Q(815,c|0,d+136|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break O}if(!b){break S}b=y[d+141|0];if((b|0)==255){break S}x[23604]=0;b=W(237,a|0,b+1|0,0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break N}if(!b){break S}e=z[f>>1];x[23604]=0;U(816,d+136|0,b|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break N}x[23604]=0;U(805,d+496|0,c|0,2);b=x[23604];x[23604]=0;if((b|0)==1){break R}x[23604]=0;U(808,d+120|0,d+496|0,1179011410);b=x[23604];x[23604]=0;if((b|0)==1){break M}Xd(d+496|0);q=d,r=Bb(x[d+120>>2]),x[q+112>>2]=r;m=Bb(x[d+124>>2]);T:{U:{while(1){b=x[d+112>>2];if(!Ob(b,m)){break T}b=ge(d+88|0,b);x[23604]=0;e=S(143,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break L}V:{W:{if((e|0)!=538989377){break W}e=z[f>>1];if(!Nh(e)){break W}g=z[d+460>>1];w[d+460>>1]=g-1;if(!g){yb(b);break T}i=e+1|0;w[f>>1]=i;x[23604]=0;e=Q(814,b|0,d+80|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break K}if(!(e&x[d+80>>2]==1347240275)){break U}x[23604]=0;U(176,d+496|0,b|0,x[d+84>>2]);e=x[23604];x[23604]=0;X:{if((e|0)!=1){g=d+496|0;e=kc(d+56|0,g);yb(g);x[23604]=0;g=Q(817,e|0,g|0)|0;o=x[23604];x[23604]=0;if((o|0)==1){break V}if(g){break X}yb(e);yb(b);break T}a=P()|0;break I}g=d+24|0;We(g,2,l);x[23604]=0;R(208,d+40|0,g|0);g=x[23604];x[23604]=0;if((g|0)==1){break J}g=i&65535;i=d+40|0;Bc(((g<<5)+a|0)+946304|0,i);xb(i);x[23604]=0;g=(D(g,104)+a|0)+484380|0;U(818,d+496|0,d+136|0,g|0);i=x[23604];x[23604]=0;if((i|0)==1){break V}Y:{if(!k){break Y}x[23604]=0;Q(141,e|0,x[d+496>>2]+4|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break V}i=d+40|0;wL(i,z[d+536>>1]);x[23604]=0;W(205,i|0,g|0,e|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){break Y}break J}yb(e)}yb(b);rh(d+112|0);continue}break}break J}yb(b)}jd(d+120|0)}yb(c);rh(d+472|0);continue}break}a=P()|0;break H}a=P()|0;break H}a=P()|0;break H}a=P()|0;break H}a=P()|0;break H}a=P()|0;Xd(d+496|0);break H}a=P()|0;break I}a=P()|0;break I}a=P()|0;yb(e)}yb(b);jd(d+120|0)}yb(c);jd(d+480|0);break b}a=P()|0;break b}f=1}yb(d+704|0);Xd(j);yb(n)}hb=d+784|0;return f|0}a=P()|0;yb(c);jd(d+88|0);break b}a=P()|0;break b}a=P()|0}yb(d+704|0)}Xd(j);yb(n);T(a|0);p()}function sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0;e=hb+-64|0;hb=e;xc(a);a:{b:{if(b>>>0<=2){F=e,G=Be(a),v[F+56|0]=G;bc(a,2);F=e,G=Cg(a),w[F+58>>1]=G;F=e,G=kg(a),x[F+60>>2]=G;break b}iq(a,e+56|0);if(b>>>0>5){break a}}v[e+57|0]=0}c:{n=d+484344|0;A=Td(z[e+58>>1],1,1024);m=cB(n,A);if((m|0)==65535){break c}b=ac(x[d+484344>>2],m);g=of(x[b>>2],x[x[b+48>>2]+12>>2],0);f=z[d+480188>>1];w[e>>1]=f-1;w[e+40>>1]=y[e+56|0];B=z[Wc(e,e+40|0)>>1];k=B+1|0;b=k&65535;f=b>>>0<f>>>0?f:b;while(1){if((b|0)==(f|0)){d:{v[c+13|0]=y[e+57|0]>>>4;b=y[c+12|0];v[e|0]=0;b=(b|0)!=0;r=tm(e+40|0,k,e);C=d+480188|0;e:while(1){if((j|0)==(A|0)){fc(r);break c}f:{d=Gb(x[r>>2],0);f=y[d|0];g:{if(!f){x[23604]=0;d=S(192,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break d}d=d<<24>>24;if((d|0)<0){x[23604]=0;f=S(192,a|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}F=Gb(x[r>>2],0),G=f,v[F|0]=G}v[e|0]=0;h:{i:{d=d&63;if(!d){break i}x[23604]=0;i=S(192,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break h}v[e|0]=i;j:{k:{switch(d-1|0){case 0:v[c+12|0]=0;v[e+36|0]=1;F=c,G=y[Ye(e+36|0,e)|0],v[F+14|0]=G;v[c+15|0]=0;break j;case 1:if(!i){break i}v[c+15|0]=i;v[c+12|0]=1;b=y[c+13|0];if(!b){break j}v[c+14|0]=D(D(b,i),15);break j;case 2:v[c+13|0]=i>>>4;if(i>>>0>=16){b=y[c+12|0];i=0;x[e+36>>2]=0;x[e+32>>2]=0;q=0;if(b){break g}break f}i=0;v[c+12|0]=0;x[e+36>>2]=0;x[e+32>>2]=0;q=0;if(b&1){break g}break f;case 3:q=0;x[e+36>>2]=0;x[e+32>>2]=0;if(b&1){break g}break f;case 5:if(!i){break i}d=(y[c+12|0]?15:14)+c|0;b=y[d|0];v[d|0]=b>>>0>=256-i>>>0?-1:b+i|0;break j;case 6:break k;default:break i}}if(!i){break i}d=(y[c+12|0]?15:14)+c|0;b=y[d|0];v[d|0]=b>>>0<=i+1>>>0?1:b-i|0}i=0;x[e+36>>2]=0;x[e+32>>2]=0;break g}i=0;x[e+36>>2]=0;x[e+32>>2]=0;q=0;if(b&1){break g}break f}break d}v[d|0]=f-1;i=0;x[e+36>>2]=0;x[e+32>>2]=0;q=0;if(!(b&1)){break f}}b=y[c+13|0];d=y[c+12|0];if(d){q=0;if(!b){break f}}l:{if(d){x[e>>2]=1;x[e+28>>2]=D(b,y[c+15|0])<<1;f=x[Je(e,e+28|0)>>2];break l}f=D(y[c+14|0],30)+30|0}b=255;d=0;g=0;while(1){m:{if(b){k=D(b,f);g=(k|0)/48|0;if(k-1536>>>0>=10752){break m}d=b}x[e+32>>2]=g;x[e+36>>2]=d;fe(e+32|0,32,255);q=1;x[e>>2]=1;F=c,G=x[Je(e,e+36|0)>>2],v[F+16|0]=G;break f}b=b-1|0;continue}}t=j-1|0;u=1;b=ac(x[n>>2],m);b=cd(x[b>>2],x[x[b+48>>2]+12>>2],j,1);while(1){h=u&65535;if(h>>>0>B>>>0){if(q){he(ac(x[n>>2],m),vh(jo(Ce(ye(e,17,y[e+32|0]),j),0)));he(ac(x[n>>2],m),vh(Ce(ye(e,16,y[e+36|0]),j)))}if(i>>>0>=16){he(ac(x[n>>2],m),jU(Ce(ye(e,20,i>>>4|224),j)))}b=i&15;if(b){he(ac(x[n>>2],m),jU(Ce(ye(e,20,Td((D(b,y[c+16|0])>>>0)/15&255,1,15)|96),j)))}j=j+1|0;b=0;continue e}n:{o:{p:{q:{r:{d=Gb(x[r>>2],h);f=y[d|0];if(!f){x[23604]=0;d=S(192,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break d}d=d<<24>>24;if((d|0)<0){x[23604]=0;f=S(192,a|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}F=Gb(x[r>>2],h),G=f,v[F|0]=G}E=1;l=d&255;if(l&64){x[23604]=0;d=S(192,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break d}v[b+1|0]=d;E=!d}if(!(l&32)){d=y[b|0];break r}x[23604]=0;d=S(192,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break d}v[b|0]=d;if((d-1&255)>>>0<=107){d=nm(d+24|0);v[b|0]=d;F=Bd(x[c>>2],h),G=d,v[F+1|0]=G;d=y[b|0];break o}if((d+127&255)>>>0<=107){d=nm((d&127)+24|0);F=Bd(x[c>>2],h),G=d,v[F|0]=G;v[b|0]=0;break q}if((d|0)!=255){break r}d=254;break p}v[d|0]=f-1;break n}if(d&255){break o}}if(!y[b+1|0]){d=0;break o}d=y[Bd(x[c>>2],h)+1|0];v[b+1|0]=0}v[b|0]=d}if(Tc(d)){F=Bd(x[c>>2],h),G=0,v[F+5|0]=G}v[e+28|0]=0;v[e+27|0]=0;v[e+26|0]=0;v[e+25|0]=0;v[e+24|0]=0;v[e+23|0]=0;if(l&16){v[b+2|0]=1;x[23604]=0;d=S(192,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break d}v[b+4|0]=d+2>>>2}o=0;k=0;s:{if(!(l&8)){break s}x[23604]=0;d=S(192,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break d}x[23604]=0;f=S(192,a|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}v[e+25|0]=f;t:{u:{switch(d-1|0){case 1:v[b|0]=255;break t;case 2:d=Bd(x[c>>2],h);v[b|0]=y[d+1|0];v[d+5|0]=0;break t;case 3:d=au(f,y[c+16|0]);v[e+25|0]=d;v:{if(d){v[e+28|0]=20;v[e+25|0]=d|208;k=20;break v}v[e+28|0]=0;k=0}if(y[b|0]){break s}d=Bd(x[c>>2],h);v[b|0]=y[d+1|0];v[d+5|0]=0;break s;case 4:v[e|0]=1;F=e,G=au(f,y[c+16|0]),v[F+22|0]=G;F=e,G=y[Ye(e,e+22|0)|0],v[F+25|0]=G;v[e+28|0]=15;F=Bd(x[c>>2],h),G=0,v[F+5|0]=G;k=20;break s;case 5:case 6:case 7:case 8:w:{if(!j){break w}if((d|0)==y[Bd(x[c>>2],h)+4|0]){break w}if(!he(ac(x[n>>2],m),om(jo(Ce(ye(e,20,(d+122|160)&255),t),h)))){break w}F=Bd(x[c>>2],h),G=d,v[F+4|0]=G}v[e+28|0]=10;d=Bd(x[c>>2],h);if(!y[b|0]){v[b|0]=y[d+1|0]}v[d+5|0]=0;k=20;break s;case 9:k=20;v[e+28|0]=20;d=Bd(x[c>>2],h);f=y[d+5|0];v[e+25|0]=f?-98:-97;v[d+5|0]=f^1;break s;case 0:break u;default:break t}}v[b|0]=254}v[e+28|0]=0}x:{if(!(l&4)){d=0;break x}x[23604]=0;d=S(192,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break d}x[23604]=0;f=S(192,a|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}v[e+24|0]=f;y:{z:{switch(d-1|0){case 0:bB(e,f<<24>>24<<3,128);d=y[b|0];if(Tc(d)){F=b,G=nm(d+x[e>>2]|0),v[F|0]=G}d=35;v[e+27|0]=35;v[e+24|0]=y[e+4|0]^128;break x;case 1:f=au(f,y[c+16|0]);v[e+24|0]=f;if(f){d=20;v[e+27|0]=20;v[e+24|0]=f|208;o=1;break x}d=0;break y;case 2:d=1;break y;case 3:case 4:o=1;f=iU(f,y[c+16|0],1);d=(d|0)==4?2:3;v[e+27|0]=d;v[e+24|0]=f;break x;case 5:d=4;if(!y[b|0]){F=b,G=y[Bd(x[c>>2],h)|0],v[F|0]=G;f=y[e+24|0]}f=iU(f&255,y[c+16|0],0);v[e+27|0]=4;v[e+24|0]=f;o=1;break x;case 6:F=b,G=nm(f+25|0),v[F|0]=G;v[e+24|0]=255;d=4;break y;case 7:case 8:case 9:A:{if(!j){break A}if((d|0)==y[Bd(x[c>>2],h)+2|0]){break A}if(!he(ac(x[n>>2],m),om(jo(Ce(ye(e,20,(d-8|48)&255),t),h)))){break A}F=Bd(x[c>>2],h),G=d,v[F+2|0]=G}d=5;v[e+27|0]=5;F=e,G=aB(y[e+24|0],y[c+16|0]),v[F+24|0]=G;o=1;break x;case 10:g=y[c+16|0];d=18;v[e+27|0]=18;F=e,G=gU(f,g),v[F+24|0]=G;o=1;break x;case 11:f=au(f,y[c+16|0]);v[e+24|0]=f;if(f){d=20;v[e+27|0]=20;v[e+24|0]=f|192;o=1;break x}d=0;v[e+27|0]=0;v[b|0]=254;o=1;break x;default:break z}}d=0;v[e+27|0]=0;break x}v[e+27|0]=d;o=1}s=1;B:{C:{g=0;D:{if(!(l&2)){break D}x[23604]=0;f=S(192,a|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}x[23604]=0;l=S(192,a|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}v[e+23|0]=l;E:{switch(f-1|0){case 0:case 1:g=11;f=fU(l,y[c+16|0],(f|0)==1);v[e+26|0]=11;v[e+23|0]=f;s=0;f=1;break B;case 2:f=y[c+16|0];g=18;v[e+26|0]=18;F=e,G=gU(l,f),v[F+23|0]=G;break C;case 3:case 4:case 5:F:{if(!j){break F}if((f|0)==y[Bd(x[c>>2],h)+3|0]){break F}if(!he(ac(x[n>>2],m),om(jo(Ce(ye(e,20,(f-4|64)&255),t),h)))){break F}F=Bd(x[c>>2],h),G=f,v[F+3|0]=G}g=8;v[e+26|0]=8;F=e,G=aB(y[e+23|0],y[c+16|0]),v[F+23|0]=G;break C;case 6:v[e+26|0]=9;s=0;g=9;break D;case 7:case 8:g=29;f=fU(l,y[c+16|0],(f|0)==8);v[e+26|0]=29;v[e+23|0]=f;break C;case 9:g=27;v[e+26|0]=27;F=e,G=aB(l,y[c+16|0]),v[F+23|0]=G;break C;default:break E}}v[e+26|0]=0;g=0}f=0;break B}s=0;f=1}if(o){eU(b,j,z[C>>1],d,e+24|0)}if(f){eU(b,j,z[C>>1],g,e+23|0)}G:{H:{if(!E){break H}if(!Tc(y[b|0])){break H}if(!d){v[e+24|0]=255;v[e+27|0]=4;f=4;break G}f=4;if(!s|(d|0)==4){break G}v[e+23|0]=255;g=4;v[e+26|0]=4;f=4;break G}f=d}I:{if(y[b+2|0]!=1){break I}J:{if(!f){v[e+27|0]=13;v[e+24|0]=y[b+4|0];break J}if(g){break I}v[e+26|0]=13;v[e+23|0]=y[b+4|0]}v[b+2|0]=0}oo(e,e+27|0,e+24|0,e+26|0,e+23|0);K:{if(y[b+2|0]){break K}d=y[e+27|0];if(!d){break K}v[b+2|0]=d;v[b+4|0]=y[e+24|0]}L:{if(k){oo(e,e+26|0,e+23|0,e+28|0,e+25|0);M:{if(y[b+2|0]){break M}d=y[e+26|0];if(!d){break M}v[b+2|0]=d;v[b+4|0]=y[e+23|0]}g=e+25|0;d=y[e+28|0];break L}g=e+23|0;d=y[e+26|0];if(!d){break n}}v[b+3|0]=d;v[b+5|0]=y[g|0]}b=b+6|0;u=u+1|0;continue}}}}else{v[g+D(b,6)|0]=254;b=b+1|0;continue}break}a=P()|0;fc(r);T(a|0);p()}hb=e- -64|0;return m|0}function gK(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=hb-336|0;hb=k;n=h;p=i&65535;o=d;m=e&65535;u=(e^i)&-2147483648;s=i>>>16&32767;q=e>>>16&32767;a:{b:{if(s-32767>>>0>4294934529&q-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){r=d;u=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){r=h;u=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;u=2147450880;break a}u=u|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));r=b?0:r;u=b?2147450880:u;b=0;c=0;break a}if(!(f|h|(e|g))){u=u|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){d=!(m|o);i=d;j=d?b:o;d=d<<6;h=d;i=G(i?c:m);d=d+((i|0)==32?G(j)+32|0:i)|0;vf(k+320|0,b,c,o,m,d-15|0);v=16-d|0;o=x[k+328>>2];m=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|p);h=d;i=d?f:n;d=d<<6;e=d;h=G(h?g:p);d=d+((h|0)==32?G(i)+32|0:h)|0;vf(k+304|0,f,g,n,p,d-15|0);v=(d+v|0)-16|0;n=x[k+312>>2];p=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=p|65536;C=e;D=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=e;i=0-d|0;h=j;j=1963258675-(j+((d|0)!=0)|0)|0;kf(k+288|0,d,h,0,0,i,j,0,0);d=x[k+296>>2];kf(k+272|0,0-d|0,0-(x[k+300>>2]+((d|0)!=0)|0)|0,0,0,i,j,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;kf(k+256|0,i,d,0,0,e,h,0,0);j=x[k+264>>2];kf(k+240|0,i,d,0,0,0-j|0,0-(x[k+268>>2]+((j|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;kf(k+224|0,j,d,0,0,e,h,0,0);i=x[k+232>>2];kf(k+208|0,j,d,0,0,0-i|0,0-(x[k+236>>2]+((i|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;kf(k+192|0,i,d,0,0,e,h,0,0);j=x[k+200>>2];kf(k+176|0,i,d,0,0,0-j|0,0-(x[k+204>>2]+((j|0)!=0)|0)|0,0,0);i=e;e=x[k+184>>2];d=h;n=e<<1|x[k+180>>2]>>>31;h=n-1|0;e=(x[k+188>>2]<<1|e>>>31)-!n|0;kf(k+160|0,i,d,0,0,h,e,0,0);d=h;kf(k+144|0,f<<15,g<<15|f>>>17,0,0,d,e,0,0);t=k+112|0;z=x[k+168>>2];h=x[k+172>>2];n=x[k+160>>2];i=x[k+152>>2];l=n+i|0;p=x[k+164>>2];j=p+x[k+156>>2]|0;j=i>>>0>l>>>0?j+1|0:j;i=j;j=(p|0)==(j|0)&l>>>0<n>>>0|j>>>0<p>>>0;p=j+z|0;j=j>>>0>p>>>0?h+1|0:h;n=!i&l>>>0>1|(i|0)!=0;h=n+p|0;j=n>>>0>h>>>0?j+1|0:j;kf(t,d,e,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);kf(k+128|0,1-l|0,0-((l>>>0>1)+i|0)|0,0,0,d,e,0,0);K=(q-s|0)+v|0;e=x[k+116>>2];t=e;d=x[k+112>>2];j=e<<1|d>>>31;n=d<<1;q=j;d=j;h=x[k+140>>2];B=h;e=x[k+136>>2];j=h<<1|e>>>31;i=e<<1|x[k+132>>2]>>>31;h=i+n|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;y=d;z=d;l=0;j=m|65536;L=j;M=o;d=o;j=j<<1|d>>>31;O=d<<1;P=j;F=j;d=Jia(y,l,j,0);j=lb;H=d;w=j;v=b<<1;d=c<<1|b>>>31;s=d;j=0;p=j;i=h-13927|0;y=(e|0)==(y|0)&i>>>0<h>>>0|e>>>0>y>>>0;e=(e|0)==(q|0)&h>>>0<n>>>0|e>>>0<q>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;d=d<<1|t>>>31;j=h;l=B>>>31|0;d=l+d|0;j=d>>>0<l>>>0?j+1|0:j;h=d;d=d+e|0;l=h>>>0>d>>>0?j+1|0:j;e=d;d=d+y|0;l=e>>>0>d>>>0?l+1|0:l;e=d-1|0;y=l-!d|0;q=0;j=Jia(s,p,y,q);d=j+H|0;h=lb+w|0;h=d>>>0<j>>>0?h+1|0:h;t=(w|0)==(h|0)&d>>>0<H>>>0|h>>>0<w>>>0;j=0;B=e;N=c>>>31|0;E=N|o<<1;w=0;e=Jia(e,j,E,w);o=e+d|0;j=lb+h|0;l=0;j=e>>>0>o>>>0?j+1|0:j;n=j;d=(j|0)==(h|0)&d>>>0>o>>>0|h>>>0>j>>>0;e=d;d=d+t|0;l=e>>>0>d>>>0?1:l;e=Jia(F,p,y,q);d=e+d|0;j=lb+l|0;t=d;d=d>>>0<e>>>0?j+1|0:j;e=Jia(F,p,B,w);m=lb;h=e;e=Jia(E,w,y,q);l=h+e|0;j=lb+m|0;j=e>>>0>l>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&h>>>0>l>>>0|j>>>0<m>>>0;m=t+e|0;d=d+j|0;d=m>>>0<e>>>0?d+1|0:d;t=m;m=d;e=0;d=e+o|0;j=l+n|0;j=d>>>0<e>>>0?j+1|0:j;e=j;h=(j|0)==(n|0)&d>>>0<o>>>0|j>>>0<n>>>0;j=m;l=h;h=h+t|0;j=l>>>0>h>>>0?j+1|0:j;I=h;l=j;t=d;m=d;o=e;H=i;d=Jia(i,0,E,w);h=lb;e=d;i=Jia(z,r,s,r);d=d+i|0;j=lb+h|0;j=d>>>0<i>>>0?j+1|0:j;i=(h|0)==(j|0)&d>>>0<e>>>0|h>>>0>j>>>0;h=j;J=v&-2;e=Jia(B,w,J,0);n=e+d|0;j=lb+j|0;j=e>>>0>n>>>0?j+1|0:j;e=j;d=(j|0)==(h|0)&d>>>0>n>>>0|h>>>0>j>>>0;h=0;i=d+i|0;d=(i>>>0<d>>>0?1:h)+o|0;j=l;m=i+m|0;d=m>>>0<i>>>0?d+1|0:d;i=d;d=(d|0)==(o|0)&m>>>0<t>>>0|d>>>0<o>>>0;h=d;d=d+I|0;j=h>>>0>d>>>0?j+1|0:j;Q=d;t=j;d=Jia(F,p,H,r);I=lb;F=d;h=Jia(y,q,J,r);d=d+h|0;j=lb+I|0;o=d;p=Jia(z,r,E,w);l=d+p|0;h=d>>>0<h>>>0?j+1|0:j;d=h+lb|0;d=l>>>0<p>>>0?d+1|0:d;q=l;j=Jia(s,r,B,w);p=l+j|0;l=lb+d|0;l=j>>>0>p>>>0?l+1|0:l;B=0;E=(d|0)==(l|0)&p>>>0<q>>>0|d>>>0>l>>>0;j=(h|0)==(I|0)&o>>>0<F>>>0|h>>>0<I>>>0;d=(d|0)==(h|0)&o>>>0>q>>>0|d>>>0<h>>>0;d=d+j|0;d=d+E|0;h=l;q=h+m|0;j=(d|B)+i|0;j=h>>>0>q>>>0?j+1|0:j;o=j;d=(i|0)==(j|0)&m>>>0>q>>>0|i>>>0>j>>>0;j=t;h=d;d=d+Q|0;j=h>>>0>d>>>0?j+1|0:j;B=d;i=j;d=Jia(z,r,J,r);z=lb;m=d;h=Jia(s,r,H,r);d=d+h|0;j=lb+z|0;j=d>>>0<h>>>0?j+1|0:j;t=0;h=(j|0)==(z|0)&d>>>0<m>>>0|j>>>0<z>>>0;m=j;d=j+n|0;j=(h|t)+e|0;j=d>>>0<m>>>0?j+1|0:j;h=j;m=(e|0)==(j|0)&d>>>0<n>>>0|e>>>0>j>>>0;j=p;p=0;n=p+d|0;l=h+j|0;j=0;l=n>>>0<p>>>0?l+1|0:l;d=(h|0)==(l|0)&d>>>0>n>>>0|h>>>0>l>>>0;e=d;d=d+m|0;j=(e>>>0>d>>>0?1:j)+o|0;l=i;e=d;d=d+q|0;j=e>>>0>d>>>0?j+1|0:j;e=j;h=(o|0)==(j|0)&d>>>0<q>>>0|j>>>0<o>>>0;i=h;h=h+B|0;l=i>>>0>h>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){M=O|N;L=w|P;kf(k+80|0,d,e,h,i,f,g,D,C);l=x[k+84>>2];p=l;j=b<<17;n=0;m=x[k+88>>2];c=n-m|0;b=x[k+80>>2];l=(l|b)!=0;o=c-l|0;m=(j-(x[k+92>>2]+(m>>>0>n>>>0)|0)|0)-(c>>>0<l>>>0)|0;n=0-b|0;p=0-(((b|0)!=0)+p|0)|0;b=K+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;kf(k+96|0,d,e,h,i,f,g,D,C);o=x[k+100>>2];s=o;v=x[k+104>>2];n=0-v|0;l=x[k+96>>2];m=(o|l)!=0;o=n-m|0;m=((b<<16)-(x[k+108>>2]+(p>>>0<v>>>0)|0)|0)-(m>>>0>n>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+s|0)|0;v=b;s=c;b=K+16383|0}if((b|0)>=32767){u=u|2147418112;b=0;c=0;break a}d:{if((b|0)>0){l=m<<1|o>>>31;o=o<<1|p>>>31;m=l;v=h;s=i&65535|b<<16;l=p<<1|n>>>31;i=n<<1;break d}if((b|0)<=-113){b=0;c=0;break a}Ul(k- -64|0,d,e,h,i,1-b|0);vf(k+48|0,v,s,M,L,b+112|0);d=x[k+64>>2];e=x[k+68>>2];v=x[k+72>>2];s=x[k+76>>2];kf(k+32|0,f,g,D,C,d,e,v,s);b=x[k+40>>2];c=x[k+56>>2];l=x[k+36>>2];o=b<<1|l>>>31;n=c-o|0;m=x[k+60>>2]-((x[k+44>>2]<<1|b>>>31)+(c>>>0<o>>>0)|0)|0;b=x[k+32>>2];h=l<<1|b>>>31;j=b<<1;i=x[k+52>>2];c=x[k+48>>2];b=(h|0)==(i|0)&j>>>0>c>>>0|h>>>0>i>>>0;o=n-b|0;m=m-(b>>>0>n>>>0)|0;l=i-((c>>>0<j>>>0)+h|0)|0;i=c-j|0}b=i;kf(k+16|0,f,g,D,C,3,0,0,0);kf(k,f,g,D,C,5,0,0,0);c=0;h=l+c|0;j=d&1;b=b+j|0;h=i>>>0>b>>>0?h+1|0:h;i=b;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;l=m;b=(c|0)==(h|0)&b>>>0<j>>>0|c>>>0>h>>>0;f=b+o|0;l=b>>>0>f>>>0?l+1|0:l;j=e;b=(l|0)==(C|0);b=b&(f|0)==(D|0)?g:b&f>>>0>D>>>0|l>>>0>C>>>0;c=b;b=b+d|0;j=c>>>0>b>>>0?j+1|0:j;c=j;d=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;j=s;e=d;d=d+v|0;j=e>>>0>d>>>0?j+1|0:j;g=d;e=x[k+20>>2];m=(e|0)==(h|0)&A[k+16>>2]<i>>>0|e>>>0<h>>>0;e=x[k+28>>2];d=x[k+24>>2];e=j>>>0<2147418112&((d|0)==(f|0)&(e|0)==(l|0)?m:(e|0)==(l|0)&d>>>0<f>>>0|e>>>0<l>>>0);d=c;m=e;e=b+e|0;d=m>>>0>e>>>0?d+1|0:d;b=(c|0)==(d|0)&b>>>0>e>>>0|c>>>0>d>>>0;c=b;b=b+g|0;j=c>>>0>b>>>0?j+1|0:j;g=b;c=x[k+4>>2];h=(c|0)==(h|0)&A[k>>2]<i>>>0|c>>>0<h>>>0;c=x[k+12>>2];b=x[k+8>>2];b=j>>>0<2147418112&((b|0)==(f|0)&(c|0)==(l|0)?h:(c|0)==(l|0)&b>>>0<f>>>0|c>>>0<l>>>0);c=b;b=b+e|0;l=c>>>0>b>>>0?d+1|0:d;c=l;e=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;d=j;f=e;e=e+g|0;d=f>>>0>e>>>0?d+1|0:d;r=e|r;u=d|u}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=r;x[a+12>>2]=u;hb=k+336|0}function JW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0;e=hb-1472|0;hb=e;xc(b);Fo(a);a:{b:{c:{if(!$q(b,e+1448|0)){break c}if(!ED(e+1448|0)){break c}if(!c){j=1;break c}if(!_q(x[b>>2],z[e+1466>>1]|z[e+1468>>1]<<16)){break c}if(!_q(x[b>>2],(z[e+1466>>1]|z[e+1468>>1]<<16)+(z[e+1460>>1]<<2)|0)){break c}ov(a);w=e,B=nv(),x[w+72>>2]=B;c=e+72|0;mv(Uh(x[a+4>>2])+32|0,c);Zq(c);m=x[Uh(x[a+4>>2])+32>>2];x[e+1444>>2]=z[e+1462>>1]|z[e+1464>>1]<<16;w=e,B=Fg(x[b>>2]),x[w+1184>>2]=B;x[e+1144>>2]=214748364;d=e+1184|0;w=e,B=D(x[Fb(d,e+1144|0)>>2],20),x[w+72>>2]=B;dn(m,x[Fb(e+1444|0,c)>>2]);Zb(d,0,256);s=Sb(e+1168|0);while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{j=z[e+1460>>1]<=t>>>0;if(!j){x[23604]=0;c=Q(141,b|0,(z[e+1466>>1]|z[e+1468>>1]<<16)+(t<<2)|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break s}if(!c){break h}c=x[b+8>>2];d=x[b>>2];x[23604]=0;c=W(142,d|0,c|0,4)|0;d=x[23604];x[23604]=0;if((d|0)==1){break s}if(!c){break h}x[23604]=0;c=S(143,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break r}x[23604]=0;d=Q(141,b|0,c|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break r}if(!d){break h}x[23604]=0;d=Q(144,b|0,e+1144|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break q}if(!d){break h}x[23604]=0;d=W(145,b|0,s|0,z[e+1156>>1])|0;f=x[23604];x[23604]=0;if((f|0)==1){break q}if(!d){break h}f=x[s>>2];g=x[b>>2];x[23604]=0;d=z[e+1156>>1];g=S(146,g|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break p}i=c+20|0;if(g>>>0<=i+(d<<3)>>>0){break h}c=d?f:0;f=z[e+1156>>1];g=i+(f<<3)|0;d=0;i=z[e+1158>>1];if(!(i&1)){while(1){if(d>>>0>=f>>>0){break d}if(!c){break h}f=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);i=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23604]=0;f=fa(147,i|0,f|0,m|0,x[e+1444>>2])|0;i=x[23604];x[23604]=0;if((i|0)==1){break o}if(!f){break h}x[23604]=0;f=Q(141,b|0,g|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break o}if(!f){break h}f=ec(e+1136|0,Gb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24));i=x[f>>2];f=x[f+4>>2];x[23604]=0;Wm(148,e+72|0,b,i,f);f=x[23604];x[23604]=0;if((f|0)==1){break n}if(x[e+76>>2]!=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))){break h}d=d+1|0;c=c+8|0;f=z[e+1156>>1];continue}}t:{if(i&4){if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23604]=0;d=fa(147,f|0,d|0,m|0,x[e+1444>>2])|0;f=x[23604];x[23604]=0;if((f|0)==1){break m}if(!d){break h}n=Gb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!l){break h}x[23604]=0;f=z[e+1162>>1];d=Q(141,b|0,g+z[e+1160>>1]|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break l}if(!d){break h}d=x[b+8>>2];g=x[b>>2];x[23604]=0;d=W(142,g|0,d|0,x[e+1148>>2]-z[e+1160>>1]|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break l}if(!d){break h}x[23604]=0;U(149,e+48|0,b|0,x[e+1148>>2]-z[e+1160>>1]|0);d=x[23604];x[23604]=0;if((d|0)==1){break b}d=e+48|0;k=Yq(e+72|0,d);yb(d);r=0;i=0;while(1){g=0;u:{while(1){if(z[e+1156>>1]<=(i&65535)>>>0){break e}x[23604]=0;d=Q(150,k|0,f+1|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break u}h=f&15;o=z[(h<<1)+26352>>1];v:{w:{if(o>>>0<=d>>>0){x[23604]=0;h=y[h+26400|0];q=Q(150,k|0,h|0)|0;u=x[23604];x[23604]=0;if((u|0)==1){break u}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&15;break v}x[23604]=0;d=Q(150,k|0,4)|0;h=x[23604];x[23604]=0;if((h|0)==1){break u}if((d|0)==15){x[23604]=0;h=Q(150,k|0,1)|0;d=x[23604];x[23604]=0;if((d|0)==1){break u}d=65535;if(!h){break w}break e}d=d+65520|0}if(d>>>0>65535){break v}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;q=g+n|0;h=z[e+1158>>1];x:{if(h&2){r=d+r|0;d=r;break x}d=h&512?d:d^32768}o=d>>>8|0;h=h&1024;v[q+1|0]=h?d:o;v[q|0]=h?o:d;g=g+2|0}if(g>>>0<l>>>0){continue}break}i=i+1|0;if(i>>>0>=z[e+1156>>1]){break e}d=(i<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);l=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[23604]=0;g=fa(147,g|0,l|0,m|0,x[e+1444>>2])|0;l=x[23604];x[23604]=0;if((l|0)==1){break u}if(!g){break t}l=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!l){break t}n=Gb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=V(30848)|0;if((ib|0)==(da(30848)|0)){_(j|0)|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;if((c|0)!=1){break e}j=P()|0}yb(k);break a}if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23604]=0;d=fa(147,f|0,d|0,m|0,x[e+1444>>2])|0;f=x[23604];x[23604]=0;if((f|0)==1){break k}if(!d){break h}r=Gb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));if(z[e+1160>>1]>256){break h}n=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=z[e+1162>>1];x[23604]=0;d=Q(141,b|0,g|0)|0;g=x[23604];x[23604]=0;y:{z:{if((g|0)!=1){if(!d){break h}d=ec(e+40|0,e+1184|0,z[e+1160>>1]);g=x[d>>2];d=x[d+4>>2];x[23604]=0;Wm(151,e+72|0,b,g,d);d=x[23604];x[23604]=0;if((d|0)==1){break z}d=z[e+1160>>1];if(d>>>0>A[e+76>>2]){break h}g=x[b+8>>2];i=x[b>>2];x[23604]=0;d=W(142,i|0,g|0,x[e+1148>>2]-d|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){break y}}j=P()|0;break a}j=P()|0;break a}if(!d){break h}x[23604]=0;U(149,e+48|0,b|0,x[e+1148>>2]-z[e+1160>>1]|0);d=x[23604];x[23604]=0;if((d|0)==1){break f}d=e+48|0;k=Yq(e+72|0,d);yb(d);l=0;i=0;while(1){g=0;A:{while(1){if(z[e+1156>>1]<=(l&65535)>>>0){break g}x[23604]=0;d=Q(150,k|0,f+1|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break A}h=f&7;o=y[h+26384|0];B:{C:{if(o>>>0<=d>>>0){x[23604]=0;h=y[h+26392|0];q=Q(150,k|0,h|0)|0;u=x[23604];x[23604]=0;if((u|0)==1){break A}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&7;break B}x[23604]=0;d=Q(150,k|0,3)|0;h=x[23604];x[23604]=0;if((h|0)==1){break A}if((d|0)==7){x[23604]=0;h=Q(150,k|0,1)|0;d=x[23604];x[23604]=0;if((d|0)==1){break A}d=255;if(!h){break C}break g}d=d+248|0}if(d>>>0>255){break B}}d=y[(e+1184|0)+d|0];h=d+i|0;q=d;d=z[e+1158>>1]&2;v[g+r|0]=d?h:q;i=d?h:i;g=g+1|0}if(g>>>0<n>>>0){continue}break}l=l+1|0;if(l>>>0>=z[e+1156>>1]){break g}d=(l<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[23604]=0;g=fa(147,g|0,n|0,m|0,x[e+1444>>2])|0;n=x[23604];x[23604]=0;if((n|0)==1){break A}if(!g){break j}n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);r=Gb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=V(30848)|0;if((ib|0)==(da(30848)|0)){_(j|0)|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;if((c|0)!=1){break g}j=P()|0}yb(k);break a}yb(k);break h}ke(e+24|0,x[m>>2],x[m+4>>2]);Kg(e+32|0,x[e+24>>2],x[e+28>>2]);b=Yd(e+16|0);x[23604]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;b=rg(152,e+72|0,x[e+32>>2],x[e+36>>2],e+8|0);c=x[23604];x[23604]=0;if((c|0)==1){break i}$c(Uh(x[a+4>>2])+12|0,b);yb(b);break h}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}yb(k);break h}j=P()|0;break a}je(s);break c}yb(k);break d}j=P()|0;break a}yb(k)}t=t+1|0;continue}}hb=e+1472|0;return j|0}j=P()|0}je(s);T(j|0);p()}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;d=hb-1344|0;hb=d;xc(b);e=hb-16|0;hb=e;cR(e+8|0,d+232|0);h=x[e+12>>2];mc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(h|0)){bc(b,x[e+12>>2])}hb=e+16|0;a:{if((h|0)!=(j|0)){break a}if(!fR(d+232|0)){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(dR(x[d+1336>>2]),lb))){break a}if(!c){l=1;break a}xc(b);b=ge(d+232|0,b);x[23604]=0;R(569,d+216|0,b|0);e=x[23604];x[23604]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){yb(b);x[23604]=0;U(570,d+200|0,d+216|0,1196314451);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;U(570,d+184|0,d+216|0,1280331091);b=x[23604];x[23604]=0;if((b|0)==1){break h}if(tc(x[d+200>>2],x[d+204>>2])){break b}if(!tc(x[d+184>>2],x[d+188>>2])){break g}break b}c=P()|0;yb(b);break d}c=P()|0;break e}c=P()|0;break f}x[23604]=0;R(232,a|0,1);b=x[23604];x[23604]=0;j:{k:{l:{m:{if((b|0)!=1){Ag(a);x[a+480188>>2]=4;x[a+480208>>2]=25231360;C=d,E=Bb(x[d+184>>2]),x[C+48>>2]=E;g=c&2;m=Bb(x[d+188>>2]);e=a+480190|0;n:{o:{while(1){h=x[d+48>>2];if(!Ob(h,m)){break o}b=z[e>>1];if(!Nh(b)){break o}b=b+1|0;w[e>>1]=b;x[23604]=0;b=D(b&65535,104)+a|0;j=b+484380|0;R(262,j|0,1);i=x[23604];x[23604]=0;p:{q:{if((i|0)!=1){x[23604]=0;i=Q(571,h|0,d+232|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break q}if(!i){break c}if(ut(d+232|0)){break p}break c}c=P()|0;break j}c=P()|0;break j}x[23604]=0;i=Q(54,d+168|0,d+232|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break n}Bc(((z[e>>1]<<5)+a|0)+946304|0,i);xb(i);i=x[d+268>>2];x[b+484388>>2]=i;x[j>>2]=i;x[b+484384>>2]=x[d+264>>2];i=b+484414|0;w[i>>1]=z[i>>1]|2;w[b+484410>>1]=255;r:{if(g){b=Xc(d+16|0,8,1,0,0);x[23604]=0;W(205,b|0,j|0,h|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break r}}rh(d+48|0);continue}break}c=P()|0;break j}C=d,E=Bb(x[d+200>>2]),x[C+160>>2]=E;s=a+484344|0;t=c&1;u=a+484360|0;B=Bb(x[d+204>>2]);o=a+484376|0;q=a+480190|0;c=1;l=1;while(1){s:{t:{u:{v:{w:{x:{b=x[d+160>>2];if(!Ob(b,B)){break x}if(!(c&1)){x[23604]=0;c=S(257,u|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break w}if(!c){break x}}Fc(_b(x[a+484360>>2],y[o|0]));x[23604]=0;c=Q(572,b|0,d+232|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break v}if(!(c&!z[d+1318>>1])|x[d+1320>>2]-5>>>0<4294967292){break c}c=y[o|0];e=x[a+484360>>2];x[23604]=0;U(5,d+48|0,5,d+232|0);h=x[23604];x[23604]=0;if((h|0)==1){break k}x[23604]=0;R(258,_b(e,c)|0,d+48|0);c=x[23604];x[23604]=0;if((c|0)==1){break l}xb(d+48|0);y:{if(t){x[23604]=0;U(176,d+48|0,b|0,x[d+1328>>2]);b=x[23604];x[23604]=0;if((b|0)!=1){break y}c=P()|0;break j}x[23604]=0;b=S(160,d+112|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break m}qD(d+48|0,b)}b=d+48|0;m=kc(d+136|0,b);yb(b);if(!t){yb(d+112|0)}Zb(d+48|0,0,64);c=1;z:{A:{B:{while(1){if((c|0)==32){break B}b=(D(c,34)+d|0)+230|0;Cm(d,b);C:{D:{if(!y[x[d>>2]]){break D}e=y[b+32|0];if(e>>>0>15){break A}h=y[b+33|0];if(h>>>0>64){break A}if(!ut(b)){break A}j=h<<2;i=e<<4;h=0;b=1;E:{while(1){g=b&65535;e=z[q>>1];if(g>>>0>e>>>0){break E}x[23604]=0;U(472,d+16|0,x[d>>2],x[d+4>>2]);e=x[23604];x[23604]=0;if((e|0)==1){break C}e=hb-32|0;hb=e;k=d+16|0;ve(e+24|0,k);aR(e+16|0,((g<<5)+a|0)+946304|0);f=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=f;f=x[e+24>>2];r=x[e+12>>2];n=x[e+28>>2];if((r|0)==(n|0)){f=(MS(f,n,x[e+8>>2],r)|0)!=0}else{f=1}hb=e+32|0;xb(k);F:{G:{if(f){break G}C=cc(d+48|0,c),E=b,w[C>>1]=E;e=D(g,104)+a|0;g=e+484410|0;f=z[g>>1];if((f|0)==255){break F}h=b;if(y[e+484417|0]!=(i&255)){break G}if((f|0)==(j|0)){break F}}b=b+1|0;continue}break}w[g>>1]=j;v[e+484417|0]=i;break D}h=h&65535;if(!h){break D}if(!Nh(e)){break D}b=e+1|0;w[q>>1]=b;C=cc(d+48|0,c),E=b,w[C>>1]=E;b=D(z[q>>1],104)+a|0;e=b+484380|0;im(e);f=e;e=(D(h,104)+a|0)+484380|0;g=_n(f,e);w[b+484410>>1]=j;v[b+484417|0]=i;VR(g,e);e=(h<<5)+a|0;h=e+946328|0;i=x[h+4>>2];b=(z[q>>1]<<5)+a|0;j=b+946328|0;x[j>>2]=x[h>>2];x[j+4>>2]=i;j=e+946320|0;i=x[j+4>>2];h=b+946320|0;x[h>>2]=x[j>>2];x[h+4>>2]=i;j=e+946312|0;i=x[j+4>>2];h=b+946312|0;x[h>>2]=x[j>>2];x[h+4>>2]=i;e=e+946304|0;h=x[e+4>>2];b=b+946304|0;x[b>>2]=x[e>>2];x[b+4>>2]=h}c=c+1|0;continue}break}break u}i=0;x[d+40>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;e=64;j=65535;r=z[d+1320>>1];h=0;H:while(1){I:{if(h){break I}b=x[m>>2];x[23604]=0;b=W(142,b|0,x[d+144>>2],1)|0;c=x[23604];x[23604]=0;if((c|0)==1){break z}if(b){break I}c=j;b=e;break t}b=e+1|0;J:{if(e>>>0<63){e=b;break J}x[23604]=0;j=Q(343,s|0,64)|0;c=x[23604];x[23604]=0;if((c|0)==1){break z}c=65535;if((j|0)==65535){break t}b=y[o|0];c=x[a+484360>>2];e=0;x[23604]=0;R(470,_b(c,b)|0,j|0);b=x[23604];x[23604]=0;if((b|0)==1){break z}}b=0;c=ac(x[s>>2],j&65535);c=cd(x[c>>2],x[x[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(r|0)){continue H}g=(d+16|0)+D(b,7)|0;f=y[g+6|0];K:{if(f){v[g+6|0]=f-1;f=y[g+4|0]|y[g+5|0]<<8;v[c+4|0]=f;v[c+5|0]=f>>>8;g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[c|0]=g;v[c+1|0]=g>>>8;v[c+2|0]=g>>>16;v[c+3|0]=g>>>24;h=h-1|0;break K}f=x[m>>2];x[23604]=0;f=W(142,f|0,x[d+144>>2],1)|0;k=x[23604];x[23604]=0;if((k|0)==1){break u}if(!f){break K}if(x[d+144>>2]==x[d+1324>>2]){i=_b(x[a+484360>>2],y[o|0]);Xe(i,eB(x[i>>2],x[i+4>>2]));i=e}x[23604]=0;f=S(192,m|0)|0;k=x[23604];x[23604]=0;L:{if((k|0)!=1){f=f<<24>>24;if((f|0)>=0){break L}f=f&127;v[g+6|0]=f;k=y[g+4|0]|y[g+5|0]<<8;v[c+4|0]=k;v[c+5|0]=k>>>8;g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[c|0]=g;v[c+1|0]=g>>>8;v[c+2|0]=g>>>16;v[c+3|0]=g>>>24;h=f+h|0;break K}break u}if((f-1&255)>>>0<=35){v[c|0]=f+48}x[23604]=0;f=S(192,m|0)|0;k=x[23604];x[23604]=0;M:{N:{if((k|0)!=1){f=f<<24>>24;C=c,E=y[cc(d+48|0,f&31)|0],v[C+1|0]=E;if((f|0)>=0){break N}v[c+3|0]=y[g+3|0];v[c+5|0]=y[g+5|0];break M}break u}x[23604]=0;R(245,d|0,m|0);f=x[23604];x[23604]=0;O:{if((f|0)!=1){f=y[d|0];if(f>>>0>19){break M}n=f<<1;A=y[n+27312|0];v[c+3|0]=A;k=y[hd(d)|0];v[c+5|0]=k;if((A|0)!=16|k>>>0<32){break O}v[c+3|0]=17;break M}break u}if(819137>>>f&1){break M}v[c+5|0]=y[n+27313|0]|k&15}f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[g|0]=f;v[g+1|0]=f>>>8;v[g+2|0]=f>>>16;v[g+3|0]=f>>>24;f=y[c+4|0]|y[c+5|0]<<8;v[g+4|0]=f;v[g+5|0]=f>>>8}c=c+6|0;b=b+1|0;continue}}}l=0;break s}break u}ui(u,0);x[23604]=0;b=Q(1,d+232|0,6428)|0;c=x[23604];x[23604]=0;P:{if((c|0)!=1){Ab(a+1298344|0,b);xb(b);x[23604]=0;b=Q(1,d+48|0,6730)|0;c=x[23604];x[23604]=0;if((c|0)==1){break P}Ab(a+1298356|0,b);xb(b);x[a+1298404>>2]=5;l=1;break b}c=P()|0;break j}c=P()|0;break j}c=P()|0;break j}c=P()|0;break j}c=P()|0;yb(m);break j}Q:{if(!((i|0)!=0|b>>>0<63)){break Q}c=c&65535;if((c|0)==65535){break Q}he(ac(x[s>>2],c),vh(Ce(ye(d,14,i&255),b)))}c=32}yb(m);if(c>>>0<32){break b}rh(d+160|0);c=0;continue}}c=P()|0;break j}c=P()|0;break j}c=P()|0;break j}c=P()|0;xb(d+48|0);break j}c=P()|0}jd(d+184|0)}jd(d+200|0)}Xd(d+216|0)}T(c|0);p()}l=0}jd(d+184|0);jd(d+200|0);Xd(d+216|0)}hb=d+1344|0;return l|0}function wia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-304|0;hb=e;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!oU(b,e+232|0)){break p}if(!pU(e+232|0)){break p}if(!c){d=1;break p}Cd(a,131072);d=hb-16|0;hb=d;i=e+136|0;f=Xb(d,3913);dd(i,f);xb(f);hb=d+16|0;x[23604]=0;U(289,e+184|0,i|0,e+232|4);d=x[23604];x[23604]=0;q:{if((d|0)!=1){d=e+184|0;Ab(a+1298344|0,d);xb(d);i=e+136|0;Db(i);f=Xb(d,11004);Ab(a+1298356|0,f);xb(f);x[a+1298404>>2]=5;ju(i,3,e+245|0);Dc(d,i);Ab(a+1298308|0,d);xb(d);f=e+112|0;jj(f,3,e+275|0);Dc(i,f);x[23604]=0;U(11,d|0,5,i|0);d=x[23604];x[23604]=0;if((d|0)==1){break b}d=e+184|0;Ab(a+1298320|0,d);xb(d);xb(e+136|0);d=kq(d);o=d,q=Td(y[e+295|0],1,31),x[o+12>>2]=q;o=d,q=Td(y[e+296|0],1,12)-1|0,x[o+16>>2]=q;x[d+20>>2]=y[e+297|0];i=a+1298408|0;Fc(i);lU(i,d);g=e+144|0;i=Sb(e+168|0);r:{s:{t:{while(1){d=x[b+8>>2];f=x[b>>2];x[23604]=0;d=W(142,f|0,d|0,8)|0;f=x[23604];x[23604]=0;u:{v:{w:{x:{y:{if((f|0)!=1){if(!d){break r}x[23604]=0;R(290,b|0,e+72|0);d=x[23604];x[23604]=0;if((d|0)==1){break y}d=x[e+76>>2];z:{l=y[e+236|0];switch(l-3|0){case 1:break x;case 0:break z;default:break w}}f=2;if(x[e+72>>2]!=1431389523){break v}break u}b=P()|0;break c}b=P()|0;break c}f=4;if(x[e+72>>2]!=1431389523){break v}break u}f=0;if(l>>>0>7){break u}}d=x[e+72>>2]==1146113363?-1:d;f=0}l=x[e+76>>2];x[e+136>>2]=x[e+72>>2];x[e+140>>2]=l;x[23604]=0;U(176,e+112|0,b|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break t}kc(g,e+112|0);x[23604]=0;R(291,i|0,e+136|0);d=x[23604];x[23604]=0;if((d|0)==1){break s}Md(e+136|0);yb(e+112|0);x[23604]=0;Q(174,b|0,f|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){continue}break}b=P()|0;break c}b=P()|0;break c}b=P()|0;Md(e+136|0);yb(e+112|0);break c}x[23604]=0;l=S(160,e+136|0)|0;b=x[23604];x[23604]=0;A:{B:{C:{if((b|0)!=1){x[23604]=0;U(292,e+112|0,i|0,1431389523);b=x[23604];x[23604]=0;if((b|0)==1){break C}d=e+112|0;b=$c(l,d);yb(d);w[e+110>>1]=0;w[e+108>>1]=65534;if(y[e+236|0]<3){break A}x[23604]=0;d=S(180,b|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){break B}break e}b=P()|0;break c}b=P()|0;break d}w[e+110>>1]=d;if(y[e+236|0]<4){break A}x[23604]=0;d=S(180,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break e}w[e+108>>1]=y[e+236|0]==4?d?d:-2:d}d=y[a+484376|0];f=x[a+484360>>2];x[23604]=0;g=S(188,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break e}x[23604]=0;U(224,_b(f,d)|0,b|0,g>>>1|0);d=x[23604];x[23604]=0;if((d|0)==1){break e}d=_b(x[a+484360>>2],y[a+484376|0]);d=eB(x[d>>2],x[d+4>>2]);pg(e+110|0,d);pg(e+108|0,d);x[23604]=0;U(292,e+112|0,i|0,1414807888);d=x[23604];x[23604]=0;if((d|0)==1){break h}d=e+112|0;b=$c(b,d);yb(d);d=x[b>>2];x[23604]=0;d=S(164,d|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break e}if(!(c&1)|d^1){break q}x[23604]=0;R(293,b|0,e+8|0);d=x[23604];x[23604]=0;if((d|0)==1){break i}o=a+480188|0,q=Td(y[e+10|0],1,32)+1|0,w[o>>1]=q;x[23604]=0;d=Q(204,e+96|0,z[e+8>>1])|0;f=x[23604];x[23604]=0;if((f|0)==1){break j}o=e,q=Bb(x[d>>2]),x[o+48>>2]=q;g=Bb(x[d+4>>2]);D:{E:{while(1){h=x[e+48>>2];if(!Ob(h,g)){f=z[a+480188>>1];x[23604]=0;f=Q(294,e+112|0,f|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){g=a+484376|0;h=_b(x[a+484360>>2],y[g|0]);h=il(x[h>>2],x[h+4>>2]);x[23604]=0;k=a+484344|0;R(211,k|0,h|0);h=x[23604];x[23604]=0;if((h|0)==1){break g}g=_b(x[a+484360>>2],y[g|0]);o=e,q=Bb(x[g>>2]),x[o+72>>2]=q;h=Bb(x[g+4>>2]);F:{while(1){G:{g=x[e+72>>2];if(!Ob(g,h)){g=y[a+484376|0];h=x[a+484360>>2];x[23604]=0;j=_b(h,g);h=z[e+108>>1];g=Q(295,j|0,h|0)|0;j=x[23604];x[23604]=0;if((j|0)!=1){break G}break g}j=x[d>>2];n=Bf(j,x[d+4>>2]);m=z[g>>1];if(n>>>0>m>>>0){x[23604]=0;j=fa(296,zg(j,m)|0,y[e+236|0],f|0,a|0)|0;m=x[23604];x[23604]=0;if((m|0)==1){break F}w[g>>1]=j}Pe(e+72|0);continue}break}H:{if(!g){break H}g=_b(x[a+484360>>2],y[a+484376|0]);j=z[e+110>>1];if(!j){if(eB(x[g>>2],x[g+4>>2])>>>0<=h>>>0){break H}}g=ac(x[k>>2],z[cc(x[g>>2],h)>>1]);he(g,om(Ce(ye(e+72|0,12,j&255),x[g+12>>2]-1|0)))}Zj(f);jd(d);break q}break g}b=P()|0;break f}x[23604]=0;f=y[e+236|0]<3?9:8;Q(174,b|0,f-4|0)|0;k=x[23604];x[23604]=0;if((k|0)!=1){x[23604]=0;k=S(143,b|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break E}hg(b,f);x[23604]=0;U(176,e+72|0,b|0,f+k|0);f=x[23604];x[23604]=0;if((f|0)==1){break D}j=h;f=e+72|0;h=kc(e+112|0,f);$c(j,h);yb(h);yb(f);rh(e+48|0);continue}break}b=P()|0;break f}b=P()|0;break f}b=P()|0;break f}b=P()|0;Db(e+136|0);break a}x[23604]=0;U(292,e+72|0,i|0,1196641603);d=x[23604];x[23604]=0;if((d|0)==1){break n}d=e+72|0;b=$c(b,d);yb(d);d=x[b>>2];x[23604]=0;d=S(164,d|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break e}if(d){x[23604]=0;Q(174,b|0,1)|0;d=x[23604];x[23604]=0;if((d|0)==1){break e}x[23604]=0;d=S(188,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break e}x[23604]=0;ea(297,a+1298332|0,b|0,d|0,40,0);d=x[23604];x[23604]=0;if((d|0)==1){break e}}x[23604]=0;U(292,e+72|0,i|0,1146113363);d=x[23604];x[23604]=0;if((d|0)==1){break k}x[23604]=0;U(292,e+48|0,i|0,1229999443);d=x[23604];x[23604]=0;if((d|0)==1){break o}d=e+48|0;b=$c(b,d);yb(d);x[23604]=0;d=S(192,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break m}h=a+480190|0;w[h>>1]=d;k=!(c&2);f=1;I:{while(1){J:{c=f&65535;if(c>>>0>(d&65535)>>>0){break I}d=30;K:{L:{M:{if(y[e+236|0]>=2){x[23604]=0;d=S(192,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break M}}x[23604]=0;U(298,b|0,((c<<5)+a|0)+946304|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break M}x[23604]=0;R(299,b|0,e+32|0);d=x[23604];x[23604]=0;if((d|0)==1){break L}x[23604]=0;g=D(c,104)+a|0;j=g+484380|0;R(300,e+32|0,j|0);c=x[23604];x[23604]=0;if((c|0)==1){break L}d=y[e+236|0];if(d>>>0>=8){x[23604]=0;R(301,b|0,g+484423|0);c=x[23604];x[23604]=0;if((c|0)==1){break L}d=y[e+236|0]}x[23604]=0;Q(174,b|0,((d&255)>>>0>1?6:2)|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break L}x[23604]=0;c=S(143,e+72|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){x[23604]=0;U(176,e+8|0,e+72|0,c|0);c=x[23604];x[23604]=0;if((c|0)!=1){break K}}b=P()|0;break l}b=P()|0;break l}b=P()|0;break l}d=e+8|0;c=kc(e+48|0,d);yb(d);d=x[c>>2];x[23604]=0;d=S(164,d|0)|0;m=x[23604];x[23604]=0;if((m|0)!=1){N:{if(k|d^1){break N}d=Xc(e+8|0,w[g+484414>>1]&1?16:8,1,0,(y[e+47|0]&12)==4?7:0);x[23604]=0;W(205,d|0,j|0,c|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break N}break J}yb(c);f=f+1|0;d=z[h>>1];continue}}break}b=P()|0;yb(c);break l}Ag(a);x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;x[23604]=0;d=1;W(249,a+1074312|0,114,1)|0;a=x[23604];x[23604]=0;if((a|0)==1){break m}yb(e+72|0);yb(b);Xd(i)}hb=e+304|0;return d|0}b=P()|0;break l}b=P()|0;break d}b=P()|0}yb(e+72|0);break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;Zj(f)}jd(d);break d}b=P()|0}yb(l)}Xd(i);break a}b=P()|0;xb(e+136|0)}T(b|0);p()}function tfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,S=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=hb-336|0;hb=d;a:{if(!Yc(b,1080)){break a}if(!fo(b,d+332|0)){break a}Cd(a,1);m=JR(d+312|0);if(!IR(d+332|0,m)){break a}h=z[m+10>>1];e=h;if(!e|e>>>0>127){break a}if(!c){g=1;break a}u=a+480188|0;w[u>>1]=h;t=y[m+14|0];K=y[m+13|0];f=y[m+12|0];E=1;if(!ce(d+332|0,27242)){E=ce(d+332|0,27247)}if(y[m+15|0]){Nb(a+1074312|0,5,1);h=z[a+480188>>1]}g=d+332|0;r=ce(g,16575);e=1;if(!ce(g,17339)){e=ce(d+332|0,13455)}A=(h&65535)==8&(K|0)!=0;Yc(b,0);CA(b,a+1298308|0,20);w[a+480190>>1]=31;n=(f|0)!=0;q=a+480188|0;g=1;h=r;while(1)if((g|0)==32){b:{c:{d:{e:{f:{g:{L=x[m+4>>2];if(L>>>0>=F>>>0){f=d+176|0;ER(b,f);Yc(b,z[m+8>>1]);g=y[d+177|0];e=128;i=a+484376|0;mq(_b(x[a+484360>>2],y[i|0]),f|2,128);h=!g&h;k=h?k:0;f=y[d+176|0];h:{if(f>>>0>128){break h}e=f;if(e){break h}f=x[_b(x[a+484360>>2],y[a+484376|0])>>2];g=128;while(1){e=g;if(e>>>0<2){e=1;break h}g=e-1|0;if(!z[cc(f,g)>>1]){continue}break}}s=DR(b,_b(x[a+484360>>2],y[i|0]),e&65535,j,u,k,0);G=1;i:{if(!(h&z[a+480188>>1]==8)){G=(t|0)!=0;break i}x[m>>2]=11138}j:{if(!A){break j}f=_b(x[a+484360>>2],y[a+484376|0]);aa=d,ba=Bb(x[f>>2]),x[aa+160>>2]=ba;h=Bb(x[f+4>>2]);while(1){f=x[d+160>>2];if(!Ob(f,h)){break j}w[f>>1]=z[f>>1]>>>1;Pe(d+160|0);continue}}f=a+484376|0;Xe(_b(x[a+484360>>2],y[f|0]),y[d+177|0]);M=e-1|0;e=y[d+177|0];k:{if((M&65535)>>>0>=e>>>0){g=z[u>>1];if((e|0)!=120|(g|0)!=4){break k}}Xe(_b(x[a+484360>>2],y[f|0]),0);g=z[a+480188>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;x[a+480208>>2]=0;aa=a,ba=Yb(256/((g&65535)>>>0)|0,32,128),x[aa+480228>>2]=ba;uh(a,0);v[d+175|0]=0;t=1;g=0;N=1;if(!n){o=d+160|5;n=0;e=0;k=0;f=r;l:while(1){if(s>>>0>(k&65535)>>>0){i=0;g=0;while(1)if((g|0)==256){k=k+1|0;continue l}else{h=Oh(d+160|0);eu(b,h);q=LA(y[h|0]);m:{n:{o:{p:{h=y[d+163|0];if((h-7&255)>>>0<3){f=0;break p}j=y[d+165|0];if(!((h|0)!=14|j>>>0<=1)){f=0;break o}if(!((h|0)==15&(j&255)>>>0>31)){f=q?f:0;if((h|0)!=13){break p}i=i+1|0;if((i&65535)>>>0<2){break m}}f=0;break m}if((h|0)==8){break n}if((h|0)!=14){break m}j=y[d+165|0]}if((j&240)!=128){break m}v[d+144|0]=j<<4;aa=d,ba=y[Ye(d+175|0,d+144|0)|0],v[aa+175|0]=ba;break m}aa=d,ba=y[Ye(d+175|0,o)|0],v[aa+175|0]=ba;h=v[d+165|0];if((h|0)>=0){n=1;break m}e=(h|0)!=-92&h>>>0>4294967183|e}t=q&t;g=g+1|0;continue}}break}g=0;g=(n^-1|e)&1?g:y[d+175|0]>47;N=f&1}Yc(b,z[m+8>>1]);e=z[a+480188>>1];q=a+484344|0;H=s+A&65535;gg(q,H);O=A?4:e;n=a+1074312|0;Z=g^1;_=c&1;k=0;j=0;s=0;o=0;q:{r:{s:{while(1){if((k|0)==(H|0)){break r}t:{if(A){e=(k&65534)>>>1|0;f=k&1;if(!f){if(!Yg(q,e,64)){break r}}h=f<<2;e=ac(x[q>>2],e);break t}if(!Yg(q,k&65535,64)){break r}h=0;e=ac(x[q>>2],k)}i=0;I=cd(x[e>>2],x[x[e+48>>2]+12>>2],0,h);if(!_){s=0;o=0;break q}e=z[u>>1];v[d+80|0]=0;f=e;e=d+80|0;i=tm(d+160|0,f,e);f=z[u>>1];x[23604]=0;v[d+80|0]=0;B=W(528,d+144|0,f|0,e|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){J=0;u:while(1){if((J|0)!=64){h=0;f=0;Q=0;while(1){if((h|0)==(O|0)){J=J+1|0;s=f&Q|s;I=D(z[u>>1],6)+I|0;continue u}x[23604]=0;g=D(h,6)+I|0;R(529,b|0,g|0);e=x[23604];x[23604]=0;v:{w:{if((e|0)!=1){e=y[g+3|0];x:{y:{z:{if(!e){if(y[g+5|0]){break z}break y}if(!K){break z}A:{switch(e-14|0){case 0:v[g+3|0]=0;v[g+5|0]=0;break z;case 1:break A;default:break z}}if(y[g+5|0]<32){break z}v[g+5|0]=31}Hf(g);e=1;B:{C:{D:{l=y[g+3|0];switch(l-14|0){case 2:break x;case 0:break C;case 3:break D;default:break B}}j=y[g+5|0]<100|j;Q=1;break y}if(!N){break y}v[g+5|0]=0;break y}if(!((l|0)!=9|Z)){e=y[g+5|0];if((e|0)==164){v[g+3|0]=20;v[g+5|0]=145;break y}aa=g,ba=ri(e<<1),v[aa+5|0]=ba;break y}if((l|0)!=19){break y}e=y[g+5|0];if(e>>>0>15){break y}l=e&1;e=!l;$=!l;l=S&1;S=(l|0)==(e|0)?S:$;o=((e|0)!=(l|0))+o|0}e=f}if(y[g|0]){break w}f=y[g+1|0];if(!f|A){break v}l=y[Gb(x[i>>2],h)|0];if(!l|(f|0)==(l|0)){break v}l=Gb(x[B>>2],h);f=y[l|0]+1|0;v[l|0]=f;if((f&255)>>>0<4){break v}x[23604]=0;W(249,n|0,85,1)|0;f=x[23604];x[23604]=0;if((f|0)!=1){break v}}h=P()|0;fc(B);break s}aa=Gb(x[B>>2],h),ba=0,v[aa|0]=ba}f=y[g+1|0];if(f){aa=Gb(x[i>>2],h),ba=f,v[aa|0]=ba}h=h+1|0;f=e;continue}}break}fc(B);fc(i);k=k+1|0;continue}break}h=P()|0}fc(i);break b}i=j}E:{F:{G:{if((t^-1|V)&1){break G}H:{if(ce(d+332|0,16575)){break H}if(ce(d+332|0,17344)){break H}if(!ce(d+332|0,13445)){break G}}x[a+480208>>2]=x[a+480208>>2]|2162688;e=Nb(Nb(Nb(n,85,1),91,1),92,1);I:{if(y[d+175|0]>47){break I}e=Nb(e,84,1);if(y[d+177|0]==127){break I}Nb(e,83,1)}if(!(t&1)){break E}break F}if(t&1){break F}if(!(r&(y[d+177|0]==127&(M&65535)>>>0<129))){break E}x[m>>2]=8412;break E}if((o|0)>6|G){break E}x[a+480208>>2]=x[a+480208>>2]|8388608}if((r|G)==1){Nb(n,89,1)}if(E){Nb(n,84,1)}J:{if(!(c&2)){break J}Yc(b,z[m+8>>1]+(D(H,O)<<8)|0);f=(t&r^1|X)&1;g=1;while(1){if((g|0)==32){break J}h=D(g,104)+a|0;c=h+484380|0;e=x[c>>2];if(e){j=2;if(!E){j=CR(b,13709)?10:0;e=x[c>>2]}j=Xc(d+160|0,8,1,0,j);e=EA(j,e)+x[b+8>>2]|0;if(!f){aa=c,ba=x[_c(c,h+484388|0)>>2],x[aa>>2]=ba}fg(j,c,b);Yc(b,e)}g=g+1|0;continue}}K:{if((i&r^-1|s)&1){break K}b=BR(d+120|0,0);c=x[b+20>>2];x[d+40>>2]=x[b+16>>2];x[d+44>>2]=c;c=x[b+12>>2];x[d+32>>2]=x[b+8>>2];x[d+36>>2]=c;c=x[b+4>>2];x[d+24>>2]=x[b>>2];x[d+28>>2]=c;b=d+160|0;yt(b,a,0,d+24|0);Y=C[x[d+160>>2]>>3];ni(b);if(!(Y>=480)){break K}c=Nb(n,5,1);b=AR(d+96|0,Y);e=x[b+20>>2];x[d+16>>2]=x[b+16>>2];x[d+20>>2]=e;e=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=e;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=d+160|0;yt(b,a,0,d);e=y[x[d+160>>2]+26|0];ni(b);if(e){zf(c,5);break K}x[m>>2]=16927}b=d+332|0;e=b;f=jc(e);c=e;while(1){if((e|0)!=(f|0)){r=y[e|0];v[c|0]=r>>>0<=32?32:r;c=c+1|0;e=e+1|0;continue}break}ef(d+80|0,16680);x[23604]=0;b=W(530,d+48|0,b|0,f|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break g}x[23604]=0;U(11,d- -64|0,1,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break f}x[23604]=0;U(131,d+160|0,d+80|0,d- -64|0);c=x[23604];x[23604]=0;if((c|0)==1){break e}c=d+160|0;Ab(a+1298344|0,c);xb(c);xb(d- -64|0);xb(b);Db(d+80|0);b=Xb(c,12193);Ab(a+1298356|0,b);xb(b);b=x[m>>2];if(b){Zc(a+1298368|0,b)}x[a+1298404>>2]=13}g=F>>>0<=L>>>0;break a}h=P()|0;break c}h=P()|0;break d}h=P()|0;xb(d- -64|0)}xb(b)}Db(d+80|0)}T(h|0);p()}else{i=D(g,104)+a|0;f=i+484380|0;s=$z(b,d+176|0,f,((g<<5)+a|0)+946304|0,z[q>>1]==4);f=x[f>>2];L:{if(e){v[i+484417|0]=0-(y[d+200|0]<<3);break L}n=f>>>0<65536&n}i=Lb(z[d+198>>1]);M:{if(i){V=!Lb(z[d+204>>1])|V;break M}X=y[d+201|0]==64|X}o=h&1;h=0;N:{if(!o){break N}k=(i<<1)+k|0;o=y[d+200|0];h=!o;if(o|!i){break N}h=y[d+201|0]==64}F=s+F|0;j=f+j|0;g=g+1|0;continue}}hb=d+336|0;return g|0}function l6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=E(0),k=E(0),l=0,m=0,n=0,o=E(0),p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=E(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=E(0),Z=0,_=0,$=E(0);a:{if(!y[a+5046|0]){break a}g=B[a+4268>>2];bK(a);if(g==B[a+4268>>2]){break a}kx(a)}b:{if(!y[a+5045|0]){break b}if(!Qh(a+44|0)){break b}i=x[a+44>>2];p=Cc(i,0);q=Cc(i,1);i=x[a+56>>2];l=Cc(i,0);m=Cc(i,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[l>>2]=B[a+5036>>2];B[m>>2]=B[a+5040>>2];v[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;t=a+4864|0;U=a+4504|0;V=a+4960|0;W=a+4868|0;X=a+4892|0;C=a+4628|0;D=a+4604|0;Q=a+4916|0;F=a+4532|0;G=a+4508|0;H=a+4772|0;I=a+4748|0;R=a+4940|0;J=a+4676|0;K=a+4652|0;L=a+4724|0;M=a+4700|0;S=a+4844|0;N=a+4580|0;O=a+4556|0;T=a+4820|0;d:{while(1){if(!r){break d}g=B[p>>2];g=E(E(E(B[a+5008>>2]-g)*B[a+4276>>2])+g);B[a+5008>>2]=g;_=Hc(x[a+4864>>2],x[W>>2],x[a+4880>>2]),$=g,B[_>>2]=$;g=B[q>>2];g=E(E(E(B[a+5012>>2]-g)*B[a+4276>>2])+g);B[a+5012>>2]=g;_=Hc(x[a+4888>>2],x[X>>2],x[a+4904>>2]),$=g,B[_>>2]=$;g=E(E(E(E(E(Hh(t,x[a+4356>>2])*E(.6800000071525574))+E(Hh(t,x[a+4360>>2])*E(-.5)))-E(Hh(t,x[a+4364>>2])*E(.6200000047683716)))+E(Hh(t,x[a+4368>>2])*E(-.5)))-E(Hh(t,x[a+4372>>2])*E(.6200000047683716)));if(v[a+4264|0]&1){e=g;g=E(B[Hc(x[a+4816>>2],x[T>>2],x[a+4836>>2])>>2]+E(e*E(.6180340051651001)));_=Hc(x[a+4816>>2],x[T>>2],x[a+4832>>2]),$=E(e-E(g*E(.6180340051651001))),B[_>>2]=$}u=B[a+4280>>2];_=a,$=E(Hh(t,x[a+4352>>2])+B[a+5020>>2]),B[_+5020>>2]=$;e=E(Hh(s,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=e;f=B[a+5020>>2];h=E(E(E(B[a+4980>>2]-B[Hc(x[a+4624>>2],x[C>>2],x[a+4644>>2])>>2])*B[a+4444>>2])+B[Hc(x[a+4624>>2],x[C>>2],x[a+4644>>2])>>2]);B[a+4980>>2]=h;P=E(h*B[a+4440>>2]);k=E(e*E(.7070000171661377));j=E(f*E(-.7070000171661377));f=E(k+j);h=B[a+4272>>2];e=E(P+E(f*h));_=Hc(x[a+4624>>2],x[C>>2],x[a+4640>>2]),$=E(f-E(h*e)),B[_>>2]=$;f=E(E(E(B[a+4976>>2]-B[Hc(x[a+4600>>2],x[D>>2],x[a+4620>>2])>>2])*B[a+4436>>2])+B[Hc(x[a+4600>>2],x[D>>2],x[a+4620>>2])>>2]);B[a+4976>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4432>>2])+E(e*h));_=Hc(x[a+4600>>2],x[D>>2],x[a+4616>>2]),$=E(e-E(h*f)),B[_>>2]=$;w=E(E(e*E(-.15000000596046448))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){e=E(E(E(B[a+4972>>2]-B[Hc(x[a+4576>>2],x[N>>2],x[a+4596>>2])>>2])*B[a+4428>>2])+B[Hc(x[a+4576>>2],x[N>>2],x[a+4596>>2])>>2]);B[a+4972>>2]=e;h=B[a+4272>>2];e=E(E(e*B[a+4424>>2])+E(f*h));_=Hc(x[a+4576>>2],x[N>>2],x[a+4592>>2]),$=E(f-E(h*e)),B[_>>2]=$;f=E(E(E(B[a+4968>>2]-B[Hc(x[a+4552>>2],x[O>>2],x[a+4572>>2])>>2])*B[a+4420>>2])+B[Hc(x[a+4552>>2],x[O>>2],x[a+4572>>2])>>2]);B[a+4968>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4416>>2])+E(e*h));_=Hc(x[a+4552>>2],x[O>>2],x[a+4568>>2]),$=E(e-E(h*f)),B[_>>2]=$;w=E(E(E(e*E(.3499999940395355))+w)+E(f*E(-.3799999952316284)))}_=Hc(x[a+4912>>2],x[Q>>2],x[a+4928>>2]),$=f,B[_>>2]=$;e=E(B[Hc(x[a+4912>>2],x[Q>>2],x[a+4932>>2])>>2]*B[a+4496>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-e)*B[a+4500>>2])+e;e=E(E(E(B[a+4964>>2]-B[Hc(x[a+4528>>2],x[F>>2],x[a+4548>>2])>>2])*B[a+4412>>2])+B[Hc(x[a+4528>>2],x[F>>2],x[a+4548>>2])>>2]);B[a+4964>>2]=e;f=B[a+5028>>2];o=B[a+4272>>2];h=E(E(f*o)+E(e*B[a+4408>>2]));_=Hc(x[a+4528>>2],x[F>>2],x[a+4544>>2]),$=E(f-E(o*h)),B[_>>2]=$;e=E(E(E(B[a+4960>>2]-B[Hc(x[a+4504>>2],x[G>>2],x[a+4524>>2])>>2])*B[a+4404>>2])+B[Hc(x[a+4504>>2],x[G>>2],x[a+4524>>2])>>2]);B[a+4960>>2]=e;f=E(e*B[a+4400>>2]);e=B[a+4272>>2];o=E(f+E(h*e));_=Hc(x[a+4504>>2],x[G>>2],x[a+4520>>2]),$=E(h-E(e*o)),B[_>>2]=$;B[a+5020>>2]=o;e=E(E(E(E(E(Hh(s,x[a+4380>>2])*E(.7070000171661377))+E(Hh(s,x[a+4384>>2])*E(-.6000000238418579)))-E(Hh(s,x[a+4388>>2])*E(.5)))+E(Hh(s,x[a+4392>>2])*E(-.6000000238418579)))-E(Hh(s,x[a+4396>>2])*E(.5)));if(v[a+4264|0]&1){f=e;e=E(B[Hc(x[a+4840>>2],x[S>>2],x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));_=Hc(x[a+4840>>2],x[S>>2],x[a+4856>>2]),$=E(f-E(e*E(.6180340051651001))),B[_>>2]=$}Y=B[a+4280>>2];f=E(E(E(B[a+5004>>2]-B[Hc(x[a+4768>>2],x[H>>2],x[a+4788>>2])>>2])*B[a+4492>>2])+B[Hc(x[a+4768>>2],x[H>>2],x[a+4788>>2])>>2]);B[a+5004>>2]=f;P=E(f*B[a+4488>>2]);f=E(j-k);j=B[a+4272>>2];k=E(P+E(f*j));_=Hc(x[a+4768>>2],x[H>>2],x[a+4784>>2]),$=E(f-E(j*k)),B[_>>2]=$;f=E(E(E(B[a+5e3>>2]-B[Hc(x[a+4744>>2],x[I>>2],x[a+4764>>2])>>2])*B[a+4484>>2])+B[Hc(x[a+4744>>2],x[I>>2],x[a+4764>>2])>>2]);B[a+5e3>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4480>>2])+E(k*j));_=Hc(x[a+4744>>2],x[I>>2],x[a+4760>>2]),$=E(k-E(j*f)),B[_>>2]=$;k=E(E(E(h*E(.3799999952316284))+E(k*E(-.15000000596046448)))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){h=E(E(E(B[a+4996>>2]-B[Hc(x[a+4720>>2],x[L>>2],x[a+4740>>2])>>2])*B[a+4476>>2])+B[Hc(x[a+4720>>2],x[L>>2],x[a+4740>>2])>>2]);B[a+4996>>2]=h;j=B[a+4272>>2];h=E(E(h*B[a+4472>>2])+E(f*j));_=Hc(x[a+4720>>2],x[L>>2],x[a+4736>>2]),$=E(f-E(j*h)),B[_>>2]=$;f=E(E(E(B[a+4992>>2]-B[Hc(x[a+4696>>2],x[M>>2],x[a+4716>>2])>>2])*B[a+4468>>2])+B[Hc(x[a+4696>>2],x[M>>2],x[a+4716>>2])>>2]);B[a+4992>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4464>>2])+E(h*j));_=Hc(x[a+4696>>2],x[M>>2],x[a+4712>>2]),$=E(h-E(j*f)),B[_>>2]=$;k=E(E(E(h*E(.3499999940395355))+k)+E(f*E(-.3799999952316284)))}Z=q+4|0;n=p+4|0;h=E(g*u);w=E(w-E(o*E(.3799999952316284)));o=E(e*Y);_=Hc(x[a+4936>>2],x[R>>2],x[a+4952>>2]),$=f,B[_>>2]=$;g=E(B[Hc(x[a+4936>>2],x[R>>2],x[a+4956>>2])>>2]*B[a+4496>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-g)*B[a+4500>>2])+g;g=E(E(E(B[a+4988>>2]-B[Hc(x[a+4672>>2],x[J>>2],x[a+4692>>2])>>2])*B[a+4460>>2])+B[Hc(x[a+4672>>2],x[J>>2],x[a+4692>>2])>>2]);B[a+4988>>2]=g;e=B[a+5032>>2];f=B[a+4272>>2];g=E(E(e*f)+E(g*B[a+4456>>2]));_=Hc(x[a+4672>>2],x[J>>2],x[a+4688>>2]),$=E(e-E(f*g)),B[_>>2]=$;f=B[a+4284>>2];e=E(E(E(B[a+4984>>2]-B[Hc(x[a+4648>>2],x[K>>2],x[a+4668>>2])>>2])*B[a+4452>>2])+B[Hc(x[a+4648>>2],x[K>>2],x[a+4668>>2])>>2]);B[a+4984>>2]=e;u=B[a+4272>>2];e=E(E(e*B[a+4448>>2])+E(g*u));_=Hc(x[a+4648>>2],x[K>>2],x[a+4664>>2]),$=E(g-E(u*e)),B[_>>2]=$;B[a+5024>>2]=e;e=E(-e);u=B[a+4288>>2];i=U;e:{f:{while(1){if((i|0)==(V|0)){g:{e=E(o+E(E(E(e*E(.3799999952316284))+k)*u));g=E(h+E(E(E(g*E(.3799999952316284))+w)*f));if(!(y[a+4264|0]&2)){break g}p=n;n=Z;break f}}else{z=x[i+16>>2];A=z-1|0;x[i+16>>2]=A;if((z|0)<=0){x[i+16>>2]=A+x[i+12>>2]}z=x[i+20>>2];A=z-1|0;x[i+20>>2]=A;if((z|0)<=0){x[i+20>>2]=A+x[i+12>>2]}i=i+24|0;continue}break}B[l>>2]=E(g+B[a+5036>>2])*E(.5);B[m>>2]=E(e+B[a+5040>>2])*E(.5);B[a+5040>>2]=e;B[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;B[l>>2]=g;B[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}v[a+5044|0]=1}n=a;a=x[a+56>>2];di(n,b,c,Cc(a,0),Cc(a,1),d)}}function uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;h=hb-288|0;hb=h;d=hb-128|0;hb=d;f=ge(h+104|0,c);x[23604]=0;n=S(160,f+20|0)|0;c=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){x[23604]=0;q=S(160,f+40|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break B}x[23604]=0;r=S(160,f+60|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break A}x[23604]=0;j=S(160,f+80|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break z}x[23604]=0;o=S(160,f+100|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break y}x[23604]=0;k=S(160,f+120|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break x}i=Sb(f+140|0);xc(f);x[f+172>>2]=1873739776;w[f+176>>1]=0;x[23604]=0;e=Q(722,f|0,d+112|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break w}if(!e){break n}e=x[d+112>>2];if((e|0)!=1414744396&(e|0)!=1179011410){break n}c=x[d+120>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}v[f+176|0]=(e|0)==1414744396;x[23604]=0;U(723,d+96|0,f|0,2);c=x[23604];x[23604]=0;if((c|0)==1){break v}g=x[d+96>>2];C:{if(nq(g,x[d+100>>2])>>>0<4){break C}c=Ox(g,1);e=x[c>>2];c=x[c+4>>2];ti(d+40|0,e,c);if(x[d+40>>2]!=1635017060){break C}ti(d- -64|0,e,c);if(!(v[d+68|0]&1)){break C}c=Ox(g,2);ti(d+24|0,x[c>>2],x[c+4>>2]);if(x[d+28>>2]){break C}c=Ox(g,3);ti(d+88|0,x[c>>2],x[c+4>>2]);if(x[d+88>>2]){break C}x[23604]=0;Q(141,f|0,12)|0;c=x[23604];x[23604]=0;if((c|0)==1){break u}x[23604]=0;U(723,d+40|0,f|0,1);c=x[23604];x[23604]=0;if((c|0)==1){break t}c=d+40|0;st(d+96|0,c);Xd(c)}x[23604]=0;U(724,d- -64|0,d+96|0,544501094);c=x[23604];x[23604]=0;if((c|0)==1){break s}x[23604]=0;e=Q(725,d- -64|0,f+156|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break k}if(!e){break o}e=z[f+156>>1];if((e|0)!=1){break q}x[23604]=0;e=S(188,d- -64|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break r}break k}e=P()|0;break b}e=P()|0;break c}e=P()|0;break d}e=P()|0;break e}e=P()|0;break f}e=P()|0;break g}e=P()|0;break h}e=P()|0;break h}e=P()|0;break i}e=P()|0;break i}e=P()|0;break i}if((e|0)==4){x[23604]=0;g=S(183,d- -64|0)|0;c=x[23604];x[23604]=0;D:{if((c|0)!=1){x[23604]=0;e=S(183,d- -64|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break D}if((g|0)!=2|(e|0)!=1){break p}v[f+177|0]=1;break p}e=P()|0;break j}e=P()|0;break j}e=z[f+156>>1]}if((e&65535)!=65534){break p}x[23604]=0;e=Q(726,d- -64|0,d+40|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break l}if(!e){break o}c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;c=x[d+52>>2];x[d+8>>2]=x[d+48>>2];x[d+12>>2]=c;c=d+24|0;x[c>>2]=y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24);w[c+4>>1]=y[d+12|0]|y[d+13|0]<<8;w[c+6>>1]=y[d+14|0]|y[d+15|0]<<8;s=c,t=Gz(y[d+16|0]|y[d+17|0]<<8|(y[d+18|0]<<16|y[d+19|0]<<24),y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24)),x[s+8>>2]=t;x[c+12>>2]=lb;w[f+172>>1]=x[c>>2]}x[23604]=0;U(724,d+40|0,d+96|0,1635017060);c=x[23604];x[23604]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=d+40|0;m=$c(n,c);yb(c);c=x[m>>2];x[23604]=0;e=S(164,c|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break k}if(!e){x[23604]=0;U(724,d+40|0,d+96|0,544039792);c=x[23604];x[23604]=0;if((c|0)==1){break J}c=d+40|0;$c(m,c);yb(c)}x[23604]=0;U(724,d+40|0,d+96|0,1952670054);c=x[23604];x[23604]=0;if((c|0)==1){break I}x[23604]=0;e=S(143,d+40|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break H}x[f+152>>2]=e;yb(d+40|0);if(x[f+152>>2]?z[f+156>>1]==17:0){break E}g=z[f+158>>1];e=CL(g,z[f+170>>1]);if(!e){break E}c=z[f+168>>1];if((c>>>0)/(g>>>0)>>>0<e<<1>>>0?c:0){break G}c=x[m>>2];x[23604]=0;e=S(146,c|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break k}c=CL(z[f+158>>1],z[f+170>>1]);break F}e=P()|0;break j}e=P()|0;break j}e=P()|0;break j}e=P()|0;yb(d+40|0);break j}c=x[m>>2];x[23604]=0;e=S(146,c|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break k}c=z[f+168>>1]}x[f+152>>2]=(e>>>0)/((c&65535)>>>0)}x[23604]=0;e=Q(727,f|0,d+96|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break k}w[f+174>>1]=e;x[23604]=0;R(728,f|0,d+96|0);c=x[23604];x[23604]=0;if((c|0)==1){break k}x[23604]=0;U(724,d+40|0,d+96|0,1886221175);c=x[23604];x[23604]=0;if((c|0)==1){break m}c=d+40|0;$c(o,c);yb(c)}yb(d- -64|0);Xd(d+96|0)}hb=d+128|0;break a}e=P()|0;break j}e=P()|0;break j}e=P()|0}yb(d- -64|0)}Xd(d+96|0)}Xd(i);yb(k)}yb(o)}yb(j)}yb(r)}yb(q)}yb(n)}yb(f);T(e|0);p()}c=x[f+20>>2];x[23604]=0;e=S(665,c|0)|0;c=x[23604];x[23604]=0;K:{L:{if((c|0)!=1){M:{if(!e|(z[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=z[f+170>>1];P:{if(!c){if((Nj(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Nj(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}e=Nj(f);c=30608;while(1){Q:{R:{if((c|0)!=30632){if((e|0)!=x[c>>2]){break R}}else{c=30632}break Q}c=c+4|0;continue}break}if((c|0)==30632){break M}Ss(a,b);x[23604]=0;g=Q(54,h+88|0,21502)|0;c=x[23604];x[23604]=0;S:{T:{U:{V:{W:{if((c|0)!=1){e=Bc(((b<<5)+a|0)+946304|0,g);xb(g);x[23604]=0;g=D(b,104)+a|0;j=g+484380|0;R(262,j|0,0);c=x[23604];x[23604]=0;if((c|0)==1){break W}x[j>>2]=x[f+152>>2];x[g+484404>>2]=x[f+160>>2];c=x[a+1298404>>2];x[23604]=0;X(666,f|0,j|0,c|0,e|0);c=x[23604];x[23604]=0;if((c|0)==1){break W}ge(h- -64|0,f+20|0);e=z[f+158>>1];i=Xc(h+56|0,8,e>>>0>1?2:1,0,0);c=Nj(f);if((c|0)!=17|e>>>0>2){break U}wc(j,268435456);b=g+484414|0;w[b>>1]=z[b>>1]&65470|((e|0)==2)<<6|1;if(yg(j)){break V}break S}l=P()|0;break K}l=P()|0;break K}i=x[g+484380>>2];g=x[g+484400>>2];k=ge(h+32|0,h- -64|0);e=z[f+158>>1];c=z[f+168>>1];x[23604]=0;b=x[k+12>>2];x[h+16>>2]=x[k+8>>2];x[h+20>>2]=b;x[h+24>>2]=x[k+16>>2];b=x[k+4>>2];x[h+8>>2]=x[k>>2];x[h+12>>2]=b;ea(667,g|0,i|0,h+8|0,c|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break L}aj(j,a);break T}if((c|0)==85){x[23604]=0;c=W(509,a|0,b|0,h- -64|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(vP(z[f+156>>1])){break Z}_:{if(!ud(y[f+177|0])){break _}if((Nj(f)|0)!=1|z[f+170>>1]!=32|z[f+168>>1]!=e<<2){break _}id(i,32);b=12;break Y}if((Nj(f)|0)!=1|z[f+170>>1]!=24|z[f+168>>1]!=e<<2){break Z}id(i,32);b=13;break Y}if((Nj(f)&65534)!=6){break X}id(i,16);b=(Nj(f)|0)==6?17:16}Lf(i,b);x[23604]=0;W(205,i|0,j|0,h- -64|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break T}break L}e=z[f+170>>1];c=e-1|0;b=c&-8;g=b&31;id(i,(c>>>0>=64?8:(b&63)>>>0>=32?1074268168>>>g|0:((1<<g)-1&1074268168)<<32-g|538447880>>>g)&255);if(e>>>0<9){Lf(i,1)}if((Nj(f)|0)==3){Lf(i,3)}x[23604]=0;W(205,i|0,j|0,h- -64|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break L}}kz(j,x[a+480180>>2]);aj(j,a);l=1}yb(h- -64|0)}uP(f);hb=h+288|0;return l|0}l=P()|0;break K}l=P()|0;yb(h- -64|0)}uP(f);T(l|0);p()}function Dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;f=hb-1344|0;hb=f;xc(b);d=hb-16|0;hb=d;k=f+768|0;iT(d+8|0,k);i=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(i|0)){bc(b,x[d+12>>2])}hb=d+16|0;d=(i|0)==(j|0);if(!d){hT(k)}a:{if(!d){break a}if(!kT(f+768|0)){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(jT(z[f+802>>1],z[f+804>>1]),lb))){break a}if(!c){e=1;break a}r=zc(f+760|0);b:{while(1){if((e|0)!=32){d=(e<<5)+a|0;i=d+480280|0;Qe(i);k=(f+768|0)+(e<<4)|0;w[d+480284>>1]=((y[k+78|0]<<8&65280)>>>0)/255;l=f+496|0;Wj(l,1,k- -64|0);j=f+112|0;Dc(j,l);vm(d+480289|0,j);xb(j);c:{d:{switch(y[k+79|0]){case 0:m=g+1|0;break c;case 1:x[i>>2]=1024;m=e+1|0;break c;case 2:break d;default:break b}}x[i>>2]=1024;d=f+112|0;zl(d,r,e);km(d)}g=g+1|0;e=e+1|0;continue}break}Cd(a,33554432);w[a+480188>>1]=m&255;g=f+112|0;d=Xb(g,6734);Ab(a+1298344|0,d);xb(d);g=Xb(g,11e3);Ab(a+1298356|0,g);xb(g);x[a+1298404>>2]=5;e:{if(y[f+847|0]){break e}e=1;j=1;while(1){if((e|0)==16){while(1){if((j|0)==16){break e}g=((j<<5)+a|0)+480280|0;x[g>>2]=x[g>>2]&-1025;j=j+1|0;continue}}g=e<<4;e=e+1|0;if(y[(f+g|0)+847|0]==1){continue}break}}g=f+496|0;We(g,1,f+768|0);d=f+112|0;Dc(d,g);Ab(a+1298308|0,d);xb(d);x[a+480208>>2]=x[a+480208>>2]&-17|z[f+806>>1]<<4&16;x[a+480196>>2]=y[f+816|0];x[a+480204>>2]=D(y[f+817|0],1e4);x[a+480200>>2]=y[f+818|0]<<2;x[a+480228>>2]=y[f+819|0];d=z[f+804>>1];w[a+480190>>1]=0;w[a+480192>>1]=d;Gu(b,g);Bq(_b(x[a+484360>>2],y[a+484376|0]),g,z[f+800>>1],65535,255);s=c&1;if(s){gg(a+484344|0,z[f+802>>1])}n=a+484344|0;u=a+480188|0;f:{while(1){g:{if(z[f+802>>1]<=h>>>0){m=c&2;l=f+108|0;r=a+480192|0;g=1;c=0;h:while(1){if(z[r>>1]<=(c&65535)>>>0){e=32;break b}c=c+1|0;d=FB(a,c&65535,0);i=!d;e=hb-16|0;hb=e;k=f+112|0;hc(e+8|0,k,384);h=x[e+12>>2];mc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(h|0)){bc(b,x[e+12>>2])}hb=e+16|0;e=(h|0)==(j|0);if(!e){Zb(k,0,384)}if(!e|i){continue}k=g&65535;e=hb-32|0;hb=e;h=f+112|0;We(e,1,h);i=e+16|0;Dc(i,e);Bc(d+492|0,i);xb(i);i:{if(!(y[h+378|0]|y[h+379|0]<<8)){break i}i=d+236|0;j=0;while(1){x[e+16>>2]=120;x[e>>2]=116;if(A[Fb(e+16|0,e)>>2]<=j>>>0){break i}n=y[(h+j|0)+32|0];B=cc(i,j+12|0),C=k+n|0,w[B>>1]=C;j=j+1|0;continue}}i=y[h+376|0]|y[h+377|0]<<8;v[d+33|0]=1;x[d>>2]=i;KA(h,d+48|0,0);KA(h,d+68|0,1);KA(h,d+88|0,2);h=y[d+100|0];if(h&1){v[d+100|0]=h|16}if(!(x[d>>2]|v[d+60|0]&1)){x[d>>2]=32767}hb=e+32|0;e=0;while(1){d=z[f+490>>1];if(d>>>0<=e>>>0){g=d+g|0;continue h}RT(b,f+48|0);j:{k:{if(Rb(l,15378,4)){break k}d=e+g|0;k=d&65535;if(k>>>0>3999){break k}w[a+480190>>1]=d;i=hb-32|0;hb=i;j=D(k,104)+a|0;d=j+484380|0;od(d,0);Ph(i,1,f+48|0);h=i+16|0;Dc(h,i);ze(d+43|0,h);xb(h);n=y[f+64|0]|y[f+65|0]<<8|(y[f+66|0]<<16|y[f+67|0]<<24);x[d>>2]=n;q=y[f+68|0]|y[f+69|0]<<8|(y[f+70|0]<<16|y[f+71|0]<<24);x[d+4>>2]=q;o=y[f+72|0]|y[f+73|0]<<8|(y[f+74|0]<<16|y[f+75|0]<<24);x[d+8>>2]=o;x[d+24>>2]=y[f+76|0]|y[f+77|0]<<8|(y[f+78|0]<<16|y[f+79|0]<<24);w[d+30>>1]=y[f+80|0]<<2;w[d+28>>1]=y[f+81|0];h=y[f+96|0];if(h&1){w[d+34>>1]=z[d+34>>1]|2;h=y[f+96|0]}if(h&2){w[d+34>>1]=z[d+34>>1]|4;h=y[f+96|0]}if(h&4){x[d+8>>2]=o>>>1;x[d+4>>2]=q>>>1;x[d>>2]=n>>>1;w[d+34>>1]=z[d+34>>1]|1;h=y[f+96|0]}if(h&8){w[d+34>>1]=z[d+34>>1]|32}hb=i+32|0;h=hb-16|0;hb=h;Pu(h+8|0,j+484423|0);i=f+24|0;Gq(i,x[h+8>>2],x[h+12>>2]);hb=h+16|0;Bc(((k<<5)+a|0)+946304|0,i);xb(i);h=x[f+64>>2];if(!h){break k}Ud(f,b,h);h=kc(f+24|0,f);yb(f);if(m){i=Xc(f,w[j+484414>>1]&1?16:8,1,0,0);x[23604]=0;W(205,i|0,d|0,h|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break j}}yb(h)}e=e+1|0;continue}break}break}a=P()|0;yb(h);break f}d=Cg(b);q=Cg(b);g=f+48|0;Ud(g,b,d-4|0);l=kc(f+112|0,g);yb(g);l:{m:{if(!s){break m}x[23604]=0;g=W(212,n|0,h&65535,q|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break l}if(!g){break m}m=0;k=Oh(f+24|0);while(1){if(m>>>0>=q>>>0){break m}x[23604]=0;i=S(192,l|0)|0;g=x[23604];x[23604]=0;n:{if((g|0)!=1){if(i){break n}m=m+1|0;continue}break g}e=k;o=i&31;if(o>>>0<z[u>>1]){g=ac(x[n>>2],h);e=cd(x[g>>2],x[x[g+48>>2]+12>>2],m,o)}if(i&32){x[23604]=0;R(245,f+48|0,l|0);g=x[23604];x[23604]=0;if((g|0)==1){break g}g=y[f+48|0];v[e|0]=g;B=e,C=y[hd(f+48|0)|0],v[B+1|0]=C;o:{p:{if((g|0)==160){d=255;break p}if((g|0)==255){d=0;break p}d=0;g=(D(g>>>4|0,12)+(g&15)|0)+13|0;if(gT(g)){break o}}g=d}v[e|0]=g}g=i&192;q:{if(!g){break q}if((g|0)==192){x[23604]=0;R(333,f+48|0,l|0);g=x[23604];x[23604]=0;if((g|0)!=1){g=f+48|0;i=hd(g);j=Re(g);g=wi(g);t=y[f+48|0];r:{s:{if((t|0)==12){v[f|0]=64;B=e,C=y[Wb(i,f)|0],v[B+4|0]=C;d=1;break s}d=y[j|0];t:{if((d|0)==12){v[f|0]=64;B=e,C=y[Wb(g,f)|0],v[B+4|0]=C;j=f+48|0;d=1;break t}if((t|0)==10){v[e+4|0]=(y[i|0]<<6>>>0)/255;d=2;break s}if((d|0)!=10){break r}v[e+4|0]=(y[g|0]<<6>>>0)/255;j=f+48|0;d=2}g=i}v[e+2|0]=d;d=y[j|0]}v[e+3|0]=d;v[e+5|0]=y[g|0];break q}break g}x[23604]=0;R(245,f+48|0,l|0);g=x[23604];x[23604]=0;if((g|0)==1){break g}v[e+3|0]=y[f+48|0];B=e,C=y[hd(f+48|0)|0],v[B+5|0]=C}if(y[e+3|0]){g=e+3|0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{d=y[e+3|0];switch(d-14|0){case 19:break A;case 17:break B;case 9:break C;case 8:break D;case 6:case 7:break E;case 1:break F;case 0:break G;default:break z}}g=y[e+5|0];if(!g){g=14;break w}if((g|0)==15){break y}if((g|0)==240){v[e+5|0]=239;break x}if(g>>>0>=16){v[e+5|0]=g|15;break x}v[e+5|0]=g|240;break x}v[e+5|0]=y[e+5|0]^128;break x}g=y[e+5|0];if(g>>>0>=16){v[e+5|0]=g>>>4|240;break x}v[e+5|0]=g|224;break x}v[e+5|0]=((y[e+5|0]^-1)&254)>>>1;break x}v[e+5|0]=y[e+5|0]&15|128;break x}B=e,C=ri(y[e+5|0]<<1),v[B+5|0]=C;break x}j=32;g=0;H:{I:{J:{K:{L:{M:{N:{i=y[e+5|0];switch(i>>>4|0){case 0:break x;case 3:break H;case 5:break I;case 14:break J;case 12:case 13:break K;case 11:break L;case 10:break M;case 8:break N;default:break w}}j=64;break H}j=176;break H}j=224;break H}if(i){break x}break w}O:{switch(i&15){case 0:v[e+5|0]=119;break x;case 1:v[e+5|0]=119;break x;case 2:v[e+5|0]=121;break x;case 3:break O;default:break x}}v[e+5|0]=123;break x}j=48}v[e+5|0]=i&15|j;break x}if(d>>>0<=35){break x}break v}v[e+5|0]=254}g=d}v[e+3|0]=y[g+26976|0];if(y[e+2|0]|(g|0)!=12){break u}v[e+2|0]=1;v[e+3|0]=0;v[e+4|0]=y[e+5|0];g=e+5|0}v[g|0]=0}}zl(f+48|0,r,o);if(!Mb(x[x[f+48>>2]>>2],x[f+52>>2])){continue}if(!qB(y[e+3|0],y[e+5|0])){continue}v[e+3|0]=0;continue}}yb(l);h=h+1|0;continue}}break}a=P()|0;yb(l)}T(a|0);p()}e=e>>>0>31}hb=f+1344|0;return e|0}function Eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-304|0;hb=d;xc(b);a:{b:{c:{d:{if(!tt(b,d+208|0)){break d}if(!YQ(d+208|0)){break d}if(!Qb(x[b>>2],x[b+8>>2],Uc(XQ(d+208|0),lb))){break d}if(!c){g=1;break d}if(!Yc(b,y[d+212|0])){break d}Cd(a,268435456);Ag(a);x[a+480208>>2]=4;Nb(a+1074312|0,114,1);f=d+88|0;i=Xb(f,15118);Ab(a+1298344|0,i);xb(i);i=Xb(f,10174);Ab(a+1298356|0,i);xb(i);x[a+1298404>>2]=5;i=d+16|0;df(i,d+208|6,48,3);Dc(f,i);Ab(a+1298308|0,f);xb(f);f=y[d+262|0];w[a+480188>>1]=f+1;x[a+480228>>2]=y[d+265|0];x[a+480204>>2]=D(y[d+266|0],1e4);x[a+480196>>2]=y[d+267|0];while(1){if((e|0)==(f|0)){e:{w[a+480190>>1]=y[d+300|0];f=z[d+302>>1];i=d+192|0;x[i>>2]=0;x[i+4>>2]=0;zc(i+8|0);if(f){bk(i,f);sA(i,f)}x[23604]=0;U(582,b|0,i|0,z[d+302>>1]);f=x[23604];x[23604]=0;if((f|0)==1){break b}A=Sb(d+176|0);s=Sb(d+160|0);x[23604]=0;W(353,b|0,A|0,y[d+301|0])|0;f=x[23604];x[23604]=0;if((f|0)==1){break c}x[23604]=0;W(353,b|0,s|0,y[d+300|0])|0;f=x[23604];x[23604]=0;if((f|0)==1){break c}q=c&2;t=d+126|0;n=d+88|6;f=0;f:{while(1){e=f;if(e>>>0>=y[d+300|0]){g=1;if(!(c&1)){break e}x[d+68>>2]=0;r=a+484376|0;Fc(_b(x[a+484360>>2],y[r|0]));G=d,H=Bb(x[i>>2]),x[G+64>>2]=H;u=a+484344|0;C=Bb(x[i+4>>2]);E=a+484348|0;break f}x[23604]=0;f=e+1|0;h=D(f,104)+a|0;k=h+484380|0;R(262,k|0,0);g=x[23604];x[23604]=0;g:{if((g|0)!=1){g=zb(x[s>>2],e);g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);if(!g){continue}x[23604]=0;g=Q(141,b|0,g|0)|0;j=x[23604];x[23604]=0;h:{if((j|0)==1){break h}if(!g){continue}x[23604]=0;g=Q(583,b|0,d+88|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break h}if(!g){continue}g=d+72|0;We(g,2,n);x[23604]=0;R(208,d+16|0,g|0);g=x[23604];x[23604]=0;if((g|0)==1){break c}g=d+16|0;Bc(((f<<5)+a|0)+946304|0,g);xb(g);j=d+72|0;Wj(j,2,t);x[23604]=0;R(208,g|0,j|0);g=x[23604];x[23604]=0;if((g|0)==1){break c}g=d+16|0;ze(h+484423|0,g);xb(g);g=y[d+138|0];if(g>>>0<=15){w[h+484408>>1]=D(g,17);g=h+484414|0;w[g>>1]=z[g>>1]|32}v[d+16|0]=y[d+139|0];v[d+72|0]=64;G=h+484412|0,H=y[Wb(d+16|0,d+72|0)|0],w[G>>1]=H;x[h+484404>>2]=y[d+141|0]|y[d+142|0]<<8;m=h+484384|0;g=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[m>>2]=g;r=h+484388|0;j=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[r>>2]=j;u=y[d+155|0]|y[d+156|0]<<8|(y[d+157|0]<<16|y[d+158|0]<<24);x[k>>2]=u;l=y[d+140|0];if(l&1){j=j>>>1|0;x[r>>2]=j;g=g>>>1|0;x[m>>2]=g;x[k>>2]=u>>>1}i:{if(g>>>0>=j>>>0){break i}h=h+484414|0;g=z[h>>1];w[h>>1]=g|2;if(!(l&2)){break i}w[h>>1]=g|6}ek(k);if(!q){continue}e=zb(x[s>>2],e);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[23604]=0;Q(141,b|0,e+y[d+92|0]|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break g}}break c}break c}e=Xc(d+16|0,v[d+140|0]&1?16:8,1,0,1);x[23604]=0;W(205,e|0,k|0,b|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){continue}break}break c}while(1){j:{k:{k=x[d+64>>2];if(!Ob(k,C)){b=x[d+68>>2];c=b&63;if(!c){break k}f=y[a+484376|0];e=x[a+484360>>2];x[23604]=0;b=b>>>6|0;f=Q(295,_b(e,f)|0,b&65535)|0;e=x[23604];x[23604]=0;if((e|0)!=1){if(!f){break k}b=z[cc(x[_b(x[a+484360>>2],y[a+484376|0])>>2],b&65535)>>1];f=x[a+484344>>2];x[23604]=0;R(584,ac(f,b)|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break k}}break c}c=y[k+3|0];if(y[k+2|0]>y[d+262|0]|c>>>0>=y[d+301|0]){break j}c=zb(x[A>>2],c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23604]=0;c=Q(141,b|0,c|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break c}if(!c){break j}x[23604]=0;R(585,b|0,d+88|0);c=x[23604];x[23604]=0;if((c|0)==1){break c}e=y[d+92|0];if(!e){break j}f=y[k|0]|y[k+1|0]<<8;v[d+16|0]=y[d+93|0];v[d+72|0]=y[d+262|0]-y[k+2|0];j=y[Wb(d+16|0,d+72|0)|0];x[d+60>>2]=e+f;G=d,H=x[_c(d+68|0,d+60|0)>>2],x[G+68>>2]=H;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;c=f&63;q=f>>>6|0;t=0;while(1){if((e&255)>>>0<=t>>>0){break j}e=_b(x[a+484360>>2],y[r|0]);h=c>>>0>63;q=h+q|0;f=q&65535;if(Kc(x[e>>2],x[e+4>>2])>>>0<=f>>>0){x[23604]=0;R(308,e|0,q+1&65535);e=x[23604];x[23604]=0;if((e|0)==1){break c}x[23604]=0;n=Q(343,u|0,64)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}e=_b(x[a+484360>>2],y[r|0]);G=cc(x[e>>2],f),H=n,w[G>>1]=H}m=x[a+484344>>2];o=x[E>>2];n=z[cc(x[e>>2],f)>>1];if(!pe(m,o,n)){break j}f=0;e=ac(m,n);m=h?0:c;e=cd(x[e>>2],x[x[e+48>>2]+12>>2],m,y[k+2|0]);l:{while(1){if((f|0)==(j|0)){c=y[d+93|0];if(c>>>0<=j>>>0){break l}x[23604]=0;Q(174,b|0,D(c-j|0,5)|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break l}break c}x[23604]=0;R(586,d+72|0,b|0);c=x[23604];x[23604]=0;if((c|0)!=1){c=d+72|0;h=hd(c);F=Re(c);l=wi(c);o=jc(c);c=y[d+72|0];B=c-1&255;m:{if(B>>>0<=142){c=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[e|0]=c;v[(d+16|0)+f|0]=c;break m}v[e|0]=0}c=y[h|0];v[e+2|0]=1;v[e+1|0]=c;c=y[F|0];n:{if((c|0)!=255){v[e+4|0]=c;break n}v[e+2|0]=0}c=y[l|0];o:{if(c>>>0>22){break o}v[e+3|0]=y[c+27360|0];h=y[o|0];v[e+5|0]=h;c=e+5|0;p:{switch(y[l|0]-4|0){case 3:v[c|0]=h&3|64;break o;case 4:v[c|0]=h&3|48;break o;case 7:l=x[i>>2];if(rc(l,x[i+4>>2])>>>0<=h>>>0){break o}o=c;c=zb(l,h);c=y[c|0]|y[c+1|0]<<8;v[o|0]=c>>>6;h=ac(x[a+484344>>2],n);h=cd(x[h>>2],x[x[h+48>>2]+12>>2],m,z[a+480188>>1]-1&65535);v[h+5|0]=c&63;v[h+3|0]=14;break o;case 8:o=c;c=x[d+60>>2];v[o|0]=c>>>6;h=ac(x[a+484344>>2],n);h=cd(x[h>>2],x[x[h+48>>2]+12>>2],m,z[a+480188>>1]-1&65535);v[h+5|0]=c&63;v[h+3|0]=14;break o;case 10:v[c|0]=h&15|128;break o;case 12:v[d+15|0]=15;G=c,H=y[Wb(c,d+15|0)|0]|208,v[G|0]=H;break o;case 13:v[d+15|0]=15;G=c,H=y[Wb(c,d+15|0)|0]|192,v[G|0]=H;break o;case 14:v[d+15|0]=15;G=c,H=y[Wb(c,d+15|0)|0]|224,v[G|0]=H;break o;case 0:case 16:case 17:if(!(h&15)){break o}l=h&240;if(!l|(l|0)==240){break o}v[c|0]=h|15;break o;case 9:case 18:break p;default:break o}}if(B>>>0<143){break o}v[e|0]=y[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}c=m+1|0;t=t+1|0;e=y[d+92|0];continue}}a=_b(x[a+484360>>2],y[a+484376|0]);G=d,H=Bb(x[a>>2]),x[G+88>>2]=H;b=Bb(x[a+4>>2]);c=65535;while(1){a=x[d+88>>2];if(!Ob(a,b)){break e}if(z[a>>1]==65535){q:{if((c&65535)!=65535){break q}x[23604]=0;c=Q(343,u|0,64)|0;f=x[23604];x[23604]=0;if((f|0)!=1){break q}break c}w[a>>1]=c}Pe(d+88|0);continue}}Fe(d- -64|0);continue}}}else{w[((e<<5)+a|0)+480284>>1]=D(y[(d+e|0)+268|0],17);e=e+1|0;continue}break}sc(s);sc(A);sc(i)}hb=d+304|0;return g|0}a=P()|0;sc(s);sc(A);break a}a=P()|0}sc(i);T(a|0);p()}function vI(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;h=hb-272|0;hb=h;a:{b:{if(g){Ue(h+256|0,f,32);x[23604]=0;W(475,h+240|0,f|0,32)|0;i=x[23604];x[23604]=0;if((i|0)!=1){break b}f=P()|0;break a}Kb(h+256|0);Kb(h+240|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(Xr(c)){i=x[b+24>>2];j=x[i+484344>>2];if(pe(j,x[i+484348>>2],c&65535)){break j}}x[23604]=0;U(1033,a|0,h+256|0,h+240|0);a=x[23604];x[23604]=0;if((a|0)!=1){break i}f=P()|0;break c}c=ac(j,c);if(!(!((e|0)<0|x[c+12>>2]<=(d|0)|(d|0)<0)&z[i+480188>>1]>e>>>0)){x[23604]=0;U(1033,a|0,h+256|0,h+240|0);a=x[23604];x[23604]=0;if((a|0)!=1){break i}f=P()|0;break c}c=cd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);Ve(h+256|0);Ve(h+240|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=y[c|0];if(!Tc(d)){if(!kp(d)){break A}}e=y[c+1|0];i=x[b+24>>2];x[23604]=0;X(1034,h+208|0,i|0,d|0,e|0);d=x[23604];x[23604]=0;e=1;if((d|0)==1){break y}x[23604]=0;R(962,h+224|0,h+208|0);d=x[23604];x[23604]=0;if((d|0)!=1){break z}f=P()|0;break v}e=0;x[23604]=0;Q(54,h+224|0,16613)|0;d=x[23604];x[23604]=0;if((d|0)==1){break x}}x[23604]=0;d=Q(753,h+256|0,h+224|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break w}xb(h+224|0);if(e){xb(h+208|0)}e=9860;i=y[c|0];if(!Tc(i)){e=kp(i)?10170:16613}x[23604]=0;i=Q(54,h+224|0,e|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break u}x[23604]=0;e=Q(753,h+240|0,i|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break t}xb(i);if(f-6>>>0>4294967290){break l}x[23604]=0;i=Q(54,h+192|0,17673)|0;j=x[23604];x[23604]=0;if((j|0)==1){break s}x[23604]=0;j=Q(753,d|0,i|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break r}xb(i);x[23604]=0;i=Q(54,h+176|0,17673)|0;l=x[23604];x[23604]=0;if((l|0)==1){break q}x[23604]=0;l=Q(753,e|0,i|0)|0;k=x[23604];x[23604]=0;if((k|0)==1){break p}xb(i);i=c+1|0;B:{if(y[c+1|0]){x[23604]=0;R(493,h+160|0,i|0);k=x[23604];x[23604]=0;if((k|0)!=1){break B}break d}x[23604]=0;Q(54,h+160|0,16618)|0;k=x[23604];x[23604]=0;if((k|0)==1){break d}}x[23604]=0;k=Q(753,j|0,h+160|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break o}j=h+160|0;xb(j);i=y[i|0];x[23604]=0;i=Q(54,j|0,(i?10660:16618)|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break n}x[23604]=0;l=Q(753,l|0,i|0)|0;j=x[23604];x[23604]=0;if((j|0)!=1){break m}f=P()|0;xb(i);break c}f=P()|0;break c}f=P()|0;break c}f=P()|0;xb(h+224|0);if(!e){break c}}xb(h+208|0);break c}f=P()|0;break c}f=P()|0;xb(i);break c}f=P()|0;break c}f=P()|0;xb(i);break c}f=P()|0;break c}f=P()|0;xb(i);break c}f=P()|0;xb(h+160|0);break c}f=P()|0;break c}xb(i);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{j=Pg(y[c|0]);O:{if(j){x[23604]=0;m=Q(54,h+128|0,17673)|0;i=x[23604];x[23604]=0;if((i|0)==1){break N}i=y[c+4|0];n=y[c+2|0];x[23604]=0;o=h,q=Jj(n,i)&255,x[o+96>>2]=q;R(492,h+112|0,h+96|0);i=x[23604];x[23604]=0;if((i|0)==1){break M}i=0;x[23604]=0;U(919,h+144|0,m|0,h+112|0);m=x[23604];x[23604]=0;if((m|0)!=1){break O}f=P()|0;break G}i=y[c+2|0];if(i){i=tL(x[x[x[b+24>>2]+8>>2]+88>>2],i);x[23604]=0;i=W(475,h+128|0,1,i|0)|0;m=x[23604];x[23604]=0;if((m|0)==1){break E}x[23604]=0;R(493,h+112|0,c+4|0);m=x[23604];x[23604]=0;if((m|0)==1){break L}x[23604]=0;U(919,h+144|0,i|0,h+112|0);m=x[23604];x[23604]=0;i=1;if((m|0)!=1){break O}f=P()|0;break J}i=0;x[23604]=0;Q(54,h+144|0,16617)|0;m=x[23604];x[23604]=0;if((m|0)==1){break e}}x[23604]=0;k=Q(753,k|0,h+144|0)|0;m=x[23604];x[23604]=0;if((m|0)==1){break K}xb(h+144|0);if(i){xb(h+112|0);xb(h+128|0)}if(j){xb(h+112|0);xb(h+128|0)}i=5449;if(!Pg(y[c|0])){i=y[c+2|0]?5445:16617}x[23604]=0;i=Q(54,h+144|0,i|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break D}x[23604]=0;j=Q(753,l|0,i|0)|0;l=x[23604];x[23604]=0;if((l|0)!=1){break C}f=P()|0;xb(i);break c}f=P()|0;break c}f=P()|0;break F}f=P()|0;break I}f=P()|0;xb(h+144|0);if(!i){break H}}xb(h+112|0)}xb(h+128|0)}if(!j){break c}}xb(h+112|0)}xb(h+128|0);break c}f=P()|0;break c}f=P()|0;break c}xb(i);if(f-13>>>0>4294967283){break l}x[23604]=0;i=Q(54,h+96|0,17673)|0;l=x[23604];x[23604]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){x[23604]=0;l=Q(753,k|0,i|0)|0;k=x[23604];x[23604]=0;if((k|0)==1){break Z}xb(i);x[23604]=0;i=Q(54,h+80|0,17673)|0;k=x[23604];x[23604]=0;if((k|0)==1){break Y}x[23604]=0;j=Q(753,j|0,i|0)|0;k=x[23604];x[23604]=0;if((k|0)==1){break X}xb(i);_:{if(Pg(y[c|0])){i=y[c+5|0];k=y[c+3|0];b=0;x[23604]=0;o=h,q=Jj(k,i)&4095,x[o+16>>2]=q;R(1035,h- -64|0,h+16|0);i=x[23604];x[23604]=0;if((i|0)!=1){break _}f=P()|0;break c}i=y[c+3|0];if(i){b=sL(x[x[x[b+24>>2]+8>>2]+84>>2],i);x[23604]=0;b=W(475,h+48|0,1,b|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break W}x[23604]=0;R(493,h+32|0,c+5|0);i=x[23604];x[23604]=0;if((i|0)==1){break V}x[23604]=0;U(919,h- -64|0,b|0,h+32|0);i=x[23604];x[23604]=0;b=1;if((i|0)!=1){break _}f=P()|0;break S}b=0;x[23604]=0;Q(54,h- -64|0,16613)|0;i=x[23604];x[23604]=0;if((i|0)==1){break U}}x[23604]=0;Q(753,l|0,h- -64|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break T}xb(h- -64|0);if(b){xb(h+32|0);xb(h+48|0)}b=11024;if(!Pg(y[c|0])){b=y[c+3|0]?11024:16613}x[23604]=0;b=Q(54,h- -64|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break Q}x[23604]=0;Q(753,j|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break P}f=P()|0;xb(b);break c}f=P()|0;break c}f=P()|0;xb(i);break c}f=P()|0;break c}f=P()|0;xb(i);break c}f=P()|0;break c}f=P()|0;break R}f=P()|0;break c}f=P()|0;xb(h- -64|0);if(!b){break c}}xb(h+32|0)}xb(h+48|0);break c}f=P()|0;break c}xb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Qc(x[d+4>>2],y[d+11|0]);da:{if(b>>>0>f>>>0){x[23604]=0;X(116,h+16|0,d|0,0,f|0);b=x[23604];x[23604]=0;if((b|0)!=1){b=h+16|0;Ab(d,b);xb(b);break da}f=P()|0;break c}if(!g){break da}x[23604]=0;b=W(475,h+16|0,f-b|0,32)|0;c=x[23604];x[23604]=0;if((c|0)==1){break ca}x[23604]=0;Q(753,d|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break ba}xb(b)}b=Qc(x[e+4>>2],y[e+11|0]);if(b>>>0<=f>>>0){break $}x[23604]=0;X(116,h|0,e|0,0,f|0);b=x[23604];x[23604]=0;if((b|0)==1){break aa}Ab(e,h);xb(h);break k}f=P()|0;break c}f=P()|0;xb(b);break c}f=P()|0;break c}if(!g){break k}x[23604]=0;b=W(475,h|0,f-b|0,32)|0;c=x[23604];x[23604]=0;if((c|0)==1){break h}x[23604]=0;Q(753,e|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break g}xb(b)}x[23604]=0;U(1033,a|0,d|0,e|0);a=x[23604];x[23604]=0;if((a|0)==1){break f}}xb(h+240|0);xb(h+256|0);hb=h+272|0;return}f=P()|0;break c}f=P()|0;xb(b);break c}f=P()|0;break c}f=P()|0;break c}f=P()|0}xb(h+240|0)}xb(h+256|0);T(f|0);p()}function f_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0;l=hb-560|0;hb=l;x[l+548>>2]=k;x[l+552>>2]=b;a:{b:{if(Fh(a,l+552|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+96>>2]=1104;b=l+96|0;s=le(l+136|0,l+144|0,b);m=x[s>>2];x[l+132>>2]=m;x[l+128>>2]=m+400;u=Kb(b);q=Kb(l+80|0);o=Kb(l- -64|0);n=Kb(l+48|0);r=Kb(l+32|0);b=x[d>>2];x[23604]=0;la(1114,c|0,b|0,l+120|0,l+116|0,l+112|0,u|0,q|0,o|0,n|0,l+28|0);b=x[23604];x[23604]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;B=A>>>9|0;w=x[l+28>>2];e=0;k=0;while(1){c:{d:{e:{f:{g:{if((e|0)==4){break g}x[23604]=0;b=Q(1088,a|0,l+552|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}if(b){break g}h:{i:{j:{k:{l:{switch(v[(l+120|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[23604]=0;b=S(1089,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=W(1115,h|0,1,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}if(b){x[23604]=0;R(1116,l+16|0,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){x[23604]=0;R(48,r|0,x[l+16>>2]);b=x[23604];x[23604]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((e|0)==3){break c}}while(1){x[23604]=0;b=Q(1088,a|0,l+552|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[23604]=0;b=S(1089,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=W(1115,h|0,1,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}if(!b){break c}x[23604]=0;R(1116,l+16|0,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){x[23604]=0;R(48,r|0,x[l+16>>2]);b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Eb(x[o+4>>2],y[o+11|0])){break m}b=x[a>>2];x[23604]=0;b=S(1089,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}if((b|0)!=x[Pb(o)>>2]){break m}x[23604]=0;S(1091,a|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}v[g|0]=0;k=Eb(x[o+4>>2],y[o+11|0])>>>0>1?o:k;break c}n:{if(!Eb(x[n+4>>2],y[n+11|0])){break n}b=x[a>>2];x[23604]=0;b=S(1089,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}if((b|0)!=x[Pb(n)>>2]){break n}x[23604]=0;S(1091,a|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}v[g|0]=1;k=Eb(x[n+4>>2],y[n+11|0])>>>0>1?n:k;break c}o:{b=Eb(x[o+4>>2],y[o+11|0]);if(!b){break o}if(!Eb(x[n+4>>2],y[n+11|0])){break o}x[f>>2]=x[f>>2]|4;a=0;break d}c=b;b=Eb(x[n+4>>2],y[n+11|0]);if(!(c|b)){break c}v[g|0]=!b;break c}if(!(e>>>0<2|k|((e|0)==2&y[l+123|0]!=0|B))){k=0;break c}c=Ib(l+16|0,pd(q));p:{if(!e|y[(e+l|0)+119|0]>1){break p}q:{while(1){b=uk(q);d=x[c>>2];if(!Ob(d,b)){break q}b=x[d>>2];x[23604]=0;b=W(1115,h|0,1,b|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){if(!b){break q}Fe(c);continue}break}break a}b=pd(q);b=Ht(x[c>>2],b);if(Eb(x[r+4>>2],y[r+11|0])>>>0>=b>>>0){d=Pj(uk(r),0-b|0);t=uk(r);z=pd(q);b=hb-16|0;hb=b;x[b>>2]=z;x[b+8>>2]=d;while(1){r:{z=Ob(d,t);if(!z){break r}if(!tc(x[d>>2],x[x[b>>2]>>2])){break r}d=Fe(b+8|0);Fe(b);d=x[d>>2];continue}break}hb=b+16|0;if(z^1){break p}}D=c,E=x[Ib(l+8|0,pd(q))>>2],x[D>>2]=E}x[l+8>>2]=x[c>>2];s:{while(1){b=uk(q);if(!Ob(x[l+8>>2],b)){break s}x[23604]=0;b=Q(1088,a|0,l+552|0)|0;c=x[23604];x[23604]=0;t:{if((c|0)==1){break t}if(b){break s}b=x[a>>2];x[23604]=0;b=S(1089,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break t}if((b|0)!=x[x[l+8>>2]>>2]){break s}x[23604]=0;S(1091,a|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}Fe(l+8|0);continue}break}break a}if(!A){break c}b=uk(q);if(!Ob(x[l+8>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;z=x[l+112>>2];c=m;u:{while(1){v:{x[23604]=0;d=Q(1088,a|0,l+552|0)|0;t=x[23604];x[23604]=0;if((t|0)==1){break v}if(d){break u}d=x[a>>2];x[23604]=0;t=S(1089,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}x[23604]=0;d=W(1115,h|0,64,t|0)|0;C=x[23604];x[23604]=0;if((C|0)==1){break a}w:{if(d){d=x[j>>2];if((d|0)==x[l+548>>2]){x[23604]=0;U(1117,i|0,j|0,l+548|0);d=x[23604];x[23604]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+4;x[d>>2]=t;b=b+1|0;break w}if(!Eb(x[u+4>>2],y[u+11|0])|!b|(t|0)!=(z|0)){break u}if(x[l+128>>2]==(m|0)){x[23604]=0;U(1110,s|0,l+132|0,l+128|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}m=x[l+132>>2]}c=m+4|0;x[l+132>>2]=c;x[m>>2]=b;m=c;b=0}x[23604]=0;S(1091,a|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){continue}}break}break a}if(!b|x[s>>2]==(c|0)){break f}if(x[l+128>>2]==(c|0)){x[23604]=0;U(1110,s|0,l+132|0,l+128|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}c=x[l+132>>2]}m=c+4|0;x[l+132>>2]=m;x[c>>2]=b;break e}x[l+28>>2]=w;x:{if(!k){break x}b=k;k=1;while(1){if(Eb(x[b+4>>2],y[b+11|0])>>>0<=k>>>0){break x}x[23604]=0;c=Q(1088,a|0,l+552|0)|0;d=x[23604];x[23604]=0;y:{if((d|0)==1){break y}z:{if(!c){c=x[a>>2];x[23604]=0;c=S(1089,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break y}if((c|0)==x[Wi(b,k)>>2]){break z}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23604]=0;S(1091,a|0)|0;c=x[23604];x[23604]=0;k=k+1|0;if((c|0)!=1){continue}}break}break a}a=1;b=x[s>>2];if((b|0)==(m|0)){break d}a=0;x[l+16>>2]=0;rf(u,b,m,l+16|0);if(x[l+16>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=c}A:{if((w|0)<=0){break A}x[23604]=0;b=Q(1088,a|0,l+552|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}B:{if(!b){b=x[a>>2];x[23604]=0;b=S(1089,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}if((b|0)==x[l+116>>2]){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23604]=0;b=S(1091,a|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break A}x[23604]=0;c=Q(1088,b|0,l+552|0)|0;d=x[23604];x[23604]=0;C:{if((d|0)==1){break C}D:{if(!c){c=x[b>>2];x[23604]=0;c=S(1089,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break C}x[23604]=0;c=W(1115,h|0,64,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break C}if(c){break D}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+548>>2]){x[23604]=0;U(1117,i|0,j|0,l+548|0);c=x[23604];x[23604]=0;if((c|0)==1){break C}}c=x[b>>2];x[23604]=0;c=S(1089,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break C}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=c;x[23604]=0;S(1091,b|0)|0;c=x[23604];x[23604]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}Gc(r);Gc(n);Gc(o);Gc(q);xb(u);Mc(s);break b}e=e+1|0;continue}}break a}hb=l+560|0;return a|0}a=P()|0;Gc(r);Gc(n);Gc(o);Gc(q);xb(u);Mc(s);T(a|0);p()}function Hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;e=hb-272|0;hb=e;xc(b);d=hb-16|0;hb=d;h=e+112|0;nT(d+8|0,h);g=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(g|0)){bc(b,x[d+12>>2])}hb=d+16|0;d=(g|0)==(i|0);if(!d){mT(h)}a:{if(!d){break a}if(!oT(e+112|0)){break a}if(!c){f=1;break a}Cd(a,x[(z[e+228>>1]<<2)+26768>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;d=e+48|0;f=Xb(d,12978);Ab(a+1298344|0,f);xb(f);f=Xb(d,10205);Ab(a+1298356|0,f);xb(f);f=hb-16|0;hb=f;g=e+8|0;h=Xb(f,4350);dd(g,h);xb(h);hb=f+16|0;x[23604]=0;X(215,d|0,g|0,y[e+191|0],e+188|0);d=x[23604];x[23604]=0;b:{if((d|0)!=1){d=e+48|0;Ab(a+1298368|0,d);xb(d);f=e+8|0;Db(f);Zc(a+1298392|0,(z[e+228>>1]<<2)+26816|0);Zc(a+1298380|0,x[(z[e+228>>1]<<2)+26864>>2]);x[a+1298404>>2]=5;We(f,2,e+112|4);Dc(d,f);Ab(a+1298308|0,d);xb(d);We(f,2,e+148|0);Dc(d,f);c:{if($p(d,9642)){x[23604]=0;U(11,e+8|0,5,e+48|0);d=x[23604];x[23604]=0;if((d|0)==1){break c}d=e+8|0;Ab(a+1298320|0,d);xb(d)}xb(e+48|0);w[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;h=g+480280|0;Qe(h);f=y[(d+e|0)+193|0];e:{if(f>>>0<=15){x[e+48>>2]=f<<4|8;x[e+8>>2]=256;u=g+480284|0,A=x[rd(e+48|0,e+8|0)>>2],w[u>>1]=A;break e}if((f|0)!=16){if((f|0)!=255){break e}w[a+480188>>1]=d;break d}x[h>>2]=256;w[g+480284>>1]=128}d=d+1|0;continue}break}d=z[a+480188>>1]}f=0;if(!(d&65535)){break a}x[e+48>>2]=y[e+225|0]<<2;x[e+8>>2]=256;u=a,A=x[Fb(e+48|0,e+8|0)>>2],x[u+480200>>2]=A;x[a+480196>>2]=y[e+226|0];x[a+480204>>2]=D(y[e+227|0],1e4);if(Yc(b,z[e+230>>1]|z[e+232>>1]<<16)){go(_b(x[a+484360>>2],y[a+484376|0]),b,y[e+234|0]+1|0,255,254)}if(!Yc(b,x[e+240>>2])){break a}l=a+480190|0;d=y[e+248|0]+1|0;w[l>>1]=d;m=e+80|0;n=a+480180|0;h=1;while(1){f:{g:{j=h&65535;if(j>>>0>(d&65535)>>>0){break g}d=hb-16|0;hb=d;g=e+48|0;hc(d+8|0,g,62);f=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(f|0)){bc(b,x[d+12>>2])}hb=d+16|0;d=(f|0)==(i|0);if(!d){Zb(g,0,62)}if(!d){break g}d=0;f=D(j,104)+a|0;k=f+484380|0;od(k,0);i=e+32|0;We(i,2,e+48|0);g=e+8|0;Dc(g,i);Bc(((j<<5)+a|0)+946304|0,g);xb(g);Wj(i,2,m);Dc(g,i);ze(f+484423|0,g);xb(g);g=z[e+106>>1];x[f+484404>>2]=g;if(!lm(x[n>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==z[(d<<1)+26912>>1]){v[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!Yc(b,x[e+244>>2])){break h}d=1;f=a+480190|0;while(1){g=d&65535;if(g>>>0>z[f>>1]){break h}g=D(g,104)+a|0;fg(Xc(e+48|0,w[g+484414>>1]&1?16:8,1,0,1),g+484380|0,b);d=d+1|0;continue}}n=a+484344|0;gg(n,y[e+239|0]+1|0);f=_p(a);d=hb-16|0;hb=d;x[d+12>>2]=0;Ds(d+12|0,f);k=x[d+12>>2];hb=d+16|0;Yc(b,y[e+235|0]|y[e+236|0]<<8|(y[e+237|0]<<16|y[e+238|0]<<24));q=c&1;r=a+480188|0;s=a+480180|0;j=0;m=1;i:{j:{k:{while(1){if(y[e+239|0]<j>>>0){if(x[a+480180>>2]==1){break k}c=x[a+480208>>2]&-8454145;break j}l:{d=Cg(b);if(d>>>0>=3){c=e+8|0;Ud(c,b,d-2|0);i=kc(e+48|0,c);yb(c);m:{if(!q){break m}c=x[i>>2];x[23604]=0;c=S(164,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break l}if(!c){break m}x[23604]=0;c=W(212,n|0,j&65535,64)|0;d=x[23604];x[23604]=0;if((d|0)==1){break l}l=0;if(!c){break m}while(1){if((l|0)==64){break m}c=ac(x[n>>2],j);t=of(x[c>>2],x[x[c+48>>2]+12>>2],l);n:{o:while(1){x[23604]=0;c=S(192,i|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=z[r>>1]){break n}f=D(d,6)+t|0;if(c&32){x[23604]=0;R(245,e+8|0,i|0);d=x[23604];x[23604]=0;if((d|0)==1){break i}g=hd(e+8|0);d=y[e+8|0];if(d){d=(d&127)-1|0;v[e+8|0]=d;d=(D((d&240)>>>4|0,12)+(d&15)|0)+13|0;v[f|0]=d;m=LA(d)&m}v[f+1|0]=y[g|0]}if(!(c&64)){continue}v[f+2|0]=0;v[f+3|0]=0;g=f+5|0;while(1){c=x[i>>2];x[23604]=0;c=W(142,c|0,x[e+56>>2],2)|0;d=x[23604];x[23604]=0;if((d|0)==1){break i}if(!c){continue o}o=y[f+5|0];c=y[f+3|0];x[23604]=0;R(245,e+8|0,i|0);d=x[23604];x[23604]=0;if((d|0)!=1){h=y[hd(e+8|0)|0];v[g|0]=h;d=y[(y[e+8|0]&31)+26944|0];v[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(h>>>0<224){break r}d=223;if(x[s>>2]!=1){break s}break r;case 11:v[e+32|0]=64;u=g,A=y[Wb(g,e+32|0)|0],v[u|0]=A;if(!lT(x[k+88>>2])){break r}v[f+2|0]=1;v[f+4|0]=y[g|0];v[f+3|0]=c;v[g|0]=o;d=c;break q;case 17:u:{switch(((h&240)>>>4|0)-8|0){case 0:v[f+3|0]=2;v[g|0]=h&15|224;break p;case 1:v[f+3|0]=3;v[g|0]=h&15|224;break p;default:break u}}if(Rt(x[k+84>>2],19)){break r}vu(f);break r;case 13:d=x[k+84>>2];if(Rt(d,15)){break r}if(!Rt(d,19)){break r}v[f+3|0]=19;v[g|0]=h&15|144;break p;case 18:d=145;if((h|0)==1){break s}if((h&240)==128){if(Rt(x[k+84>>2],20)){break r}v[f+3|0]=19;break p}v[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=h&240;if(!d){break r}}v[g|0]=d}d=y[f+3|0]}if((d&255)!=20){break p}d=y[g|0];if(y[f+2|0]|(d&240)!=128){break p}v[f+2|0]=2;v[f+4|0]=(((d&15)<<6|8)>>>0)/15;v[f+3|0]=c;v[g|0]=o}if(!(y[e+8|0]&32)){continue o}continue}break}break}break i}l=l+1|0;continue}}yb(i)}j=j+1|0;continue}break}break i}c=x[a+480208>>2]&-8454145|(z[a+480188>>1]==4?m&1?8454144:0:0)}x[a+480208>>2]=c;f=1;if(!(y[e+253|0]|y[e+254|0]<<8|(y[e+255|0]<<16|y[e+256|0]<<24))){break a}if(!Yc(b,y[e+249|0]|y[e+250|0]<<8|(y[e+251|0]<<16|y[e+252|0]<<24))){break a}XA(a+1298332|0,b,y[e+253|0]|y[e+254|0]<<8|(y[e+255|0]<<16|y[e+256|0]<<24),4);break a}d=P()|0;yb(i);break b}w[f+484412>>1]=64;g=y[e+93|0]|y[e+94|0]<<8|(y[e+95|0]<<16|y[e+96|0]<<24);x[k>>2]=g;d=y[e+105|0];if(d&2){x[k>>2]=g>>>1;g=f+484414|0;w[g>>1]=z[g>>1]|1}x[f+484384>>2]=y[e+97|0]|y[e+98|0]<<8|(y[e+99|0]<<16|y[e+100|0]<<24);x[f+484388>>2]=(y[e+101|0]|y[e+102|0]<<8|(y[e+103|0]<<16|y[e+104|0]<<24))-1;if(d&1){g=f+484414|0;w[g>>1]=z[g>>1]|2}v:{w:{if(!(d&4)){break w}g=y[e+108|0];if((g|0)==255){break w}v[e+8|0]=g;v[e+32|0]=64;u=f+484410|0,A=y[Wb(e+8|0,e+32|0)|0]<<2,w[u>>1]=A;break v}g=f+484414|0;w[g>>1]=z[g>>1]|32768}x:{if(d&8){d=f+484414|0;g=z[d>>1]|32;w[d>>1]=g;j=f+484408|0;f=y[e+109|0];if(f>>>0<=15){x[e+32>>2]=256;x[e+8>>2]=f<<4|8;i=x[rd(e+8|0,e+32|0)>>2]}else{i=128}w[j>>1]=i;w[d>>1]=g&65279|((f|0)==16)<<8;break x}w[f+484408>>1]=128}h=h+1|0;d=z[l>>1];continue}}d=P()|0;xb(e+48|0);break b}d=P()|0;Db(e+8|0)}T(d|0);p()}hb=e+272|0;return f|0}function EV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-224|0;hb=e;xc(b);a:{b:{c:{d:{if(!fC(b,e+176|0)){break d}if(!iC(e+176|0)){break d}if(!c){n=1;break d}Cd(a,2048);Ag(a);d=hb-16|0;hb=d;f=e+8|0;h=Xb(d,3927);dd(f,h);xb(h);hb=d+16|0;x[23604]=0;U(199,e+80|0,f|0,y[e+179|0]);d=x[23604];x[23604]=0;e:{f:{g:{h:{i:{j:{k:{if((d|0)!=1){d=e+80|0;Ab(a+1298344|0,d);xb(d);f=e+8|0;Db(f);h=Xb(d,11008);Ab(a+1298356|0,h);xb(h);x[a+1298404>>2]=5;h=a+480188|0;w[h>>1]=y[e+216|0];w[a+480190>>1]=y[e+212|0];We(f,2,e+176|4);Dc(d,f);Ab(a+1298308|0,d);xb(d);d=y[e+179|0];l:{if(d>>>0>=9){if(d>>>0>=11){f=(d|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break l}h=Lu(b);m:{if((h|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break m}x[e+80>>2]=(h<<1)+128;x[e+8>>2]=0;x[e+160>>2]=256;t=((d<<5)+a|0)+480284|0,u=x[nj(e+80|0,e+8|0,e+160|0)>>2],w[t>>1]=u}d=d+1|0;continue}}f=e+80|0;d=hb-16|0;hb=d;n:{if(!Qb(x[b>>2],x[b+8>>2],16)){XB(f);break n}Bu(d+8|0,f);qd(d,b,x[d+8>>2],x[d+12>>2])}hb=d+16|0;d=0;while(1){if((d|0)==16){break l}w[((d<<5)+a|0)+480284>>1]=v[(e+80|0)+d|0]&1?64:192;d=d+1|0;continue}}w[h>>1]=4;hg(b,1);uh(a,1)}o:{if(y[e+179|0]>=13){d=e+80|0;Fu(d,b);f=hd(d);d=y[e+80|0];if(d>>>0<=31){v[e+80|0]=125;d=125}x[a+480204>>2]=D(d,1e4);x[a+480196>>2]=y[f|0];break o}x[a+480196>>2]=6;x[a+480204>>2]=125e4}eg(_b(x[a+484360>>2],y[a+484376|0]),y[e+213|0]);l=Sb(e+160|0);f=y[e+179|0];r=x[b+8>>2]+((f>>>0>13)<<1)|0;d=0;p:{if(f>>>0<14){break p}x[23604]=0;R(200,l|0,y[e+213|0]);f=x[23604];x[23604]=0;if((f|0)!=1){break p}d=P()|0;break b}q:{r:{s:{while(1){t:{if(y[e+213|0]<=d>>>0){d=0;if(y[e+179|0]!=10){break s}m=x[b+8>>2];k=a+480190|0;d=1;while(1){j=z[k>>1];if(j>>>0<(d&65535)>>>0){break t}x[23604]=0;f=Q(201,b|0,e+80|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break r}if(f){f=0;u:{if(y[e+212|0]<(y[e+126|0]|y[e+127|0]<<8|(y[e+128|0]<<16|y[e+129|0]<<24))>>>0|y[e+80|0]>1){break u}h=y[e+130|0]|y[e+131|0]<<8|(y[e+132|0]<<16|y[e+133|0]<<24);if(h>>>0>1048576|y[e+136|0]>64|h>>>0<(y[e+137|0]|y[e+138|0]<<8|(y[e+139|0]<<16|y[e+140|0]<<24))>>>0){break u}f=h>>>0>=(y[e+141|0]|y[e+142|0]<<8|(y[e+143|0]<<16|y[e+144|0]<<24))>>>0}if(!f){break t}}d=d+1|0;continue}}t=cc(x[_b(x[a+484360>>2],y[a+484376|0])>>2],d),u=d,w[t>>1]=u;if(y[e+179|0]>=14){x[23604]=0;f=S(180,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break q}t=cc(x[l>>2],d),u=f,w[t>>1]=u}f=z[a+480188>>1];x[23604]=0;Q(174,b|0,f<<1)|0;f=x[23604];x[23604]=0;if((f|0)==1){break q}d=d+1|0;continue}break}x[23604]=0;Q(141,b|0,m|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break c}d=j>>>0>=(d&65535)>>>0}j=a+480190|0;f=z[j>>1];x[23604]=0;x[e+80>>2]=0;m=W(202,e- -64|0,f|0,e+80|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break k}n=d?59:65;k=e+80|1;f=1;v:{while(1){h=f&65535;if(h>>>0>z[j>>1]){h=Sb(e+48|0);x[23604]=0;n=W(203,b|0,h|0,z[e+214>>1])|0;d=x[23604];x[23604]=0;w:{if((d|0)!=1){if(!n){break e}d=0;k=0;f=x[h>>2];if(!tc(f,x[h+4>>2])){f=Bb(f);g=Bb(x[h+4>>2]);k=hb-16|0;hb=k;x:{if(!Ob(f,g)){break x}x[k+8>>2]=f;while(1){j=x[Pe(k+8|0)>>2];if(!Ob(j,g)){break x}f=rl(y[f|0]|y[f+1|0]<<8,y[j|0]|y[j+1|0]<<8)?j:f;continue}}hb=k+16|0;k=y[f|0]|y[f+1|0]<<8}x[23604]=0;j=Q(204,e+32|0,k|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break w}y:{while(1){if((d|0)==(k|0)){if(!(c&2)){break j}i=Xc(e+80|0,8,1,0,1);o=a+480190|0;f=z[o>>1];g=1;z:{A:while(1){q=g&65535;if(q>>>0>(f&65535)>>>0){break j}d=x[b+8>>2];f=x[b>>2];x[23604]=0;d=W(142,f|0,d|0,1)|0;f=x[23604];x[23604]=0;if((f|0)==1){break z}if(!d){break j}s=x[b+8>>2];d=0;while(1){f=z[o>>1];if(f>>>0<=d>>>0){g=g+1|0;continue A}if((q|0)!=x[zb(x[m>>2],d)>>2]){d=d+1|0;continue}x[23604]=0;Q(141,b|0,s|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){x[23604]=0;d=d+1|0;W(205,i|0,(D(d,104)+a|0)+484380|0,b|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){continue}}break}break}d=P()|0;break i}d=P()|0;break i}x[23604]=0;f=S(180,b|0)|0;g=x[23604];x[23604]=0;B:{if((g|0)==1){break B}x[23604]=0;Q(174,b|0,1)|0;g=x[23604];x[23604]=0;if((g|0)==1){break B}if(f){x[23604]=0;U(176,e+8|0,b|0,D(f,3)+(y[e+179|0]==1?3:0)|0);f=x[23604];x[23604]=0;if((f|0)==1){break y}g=e+8|0;f=kc(e+80|0,g);$c(zg(x[j>>2],d),f);yb(f);yb(g)}d=d+1|0;continue}break}d=P()|0;break i}d=P()|0;break i}d=P()|0;break h}d=P()|0;break h}C:{D:{if(y[e+179|0]<=9){x[23604]=0;R(206,b|0,e+80|0);g=x[23604];x[23604]=0;E:{F:{if((g|0)==1){break F}x[23604]=0;R(207,e+80|0,(D(h,104)+a|0)+484380|0);g=x[23604];x[23604]=0;if((g|0)==1){break F}g=e+48|0;We(g,2,k);x[23604]=0;R(208,e+8|0,g|0);g=x[23604];x[23604]=0;if((g|0)==1){break E}break D}d=P()|0;break g}d=P()|0;break g}x[23604]=0;U(209,b|0,e+80|0,n|0);g=x[23604];x[23604]=0;if((g|0)==1){break C}x[23604]=0;U(210,e+80|0,(D(h,104)+a|0)+484380|0,d|0);g=x[23604];x[23604]=0;if((g|0)==1){break C}g=e+48|0;We(g,2,k);x[23604]=0;R(208,e+8|0,g|0);g=x[23604];x[23604]=0;if((g|0)==1){break v}}g=e+8|0;Bc(((h<<5)+a|0)+946304|0,g);xb(g);t=zb(x[m>>2],h-1|0),u=z[e+126>>1]|z[e+128>>1]<<16,x[t>>2]=u;f=f+1|0;continue}break}d=P()|0;break g}d=P()|0;break g}d=P()|0;break b}d=P()|0;break b}d=P()|0;Db(e+8|0);break a}d=P()|0;break b}if(!(c&1)){break f}x[23604]=0;g=a+484344|0;R(211,g|0,y[e+213|0]);c=x[23604];x[23604]=0;G:{if((c|0)!=1){f=a+480188|0;a=0;while(1){H:{if(y[e+213|0]<=a>>>0){break f}d=64;c=x[l>>2];if(Kc(c,x[l+4>>2])>>>0>a>>>0){d=z[cc(c,a)>>1]}x[23604]=0;c=W(212,g|0,a&65535,d&65535)|0;d=x[23604];x[23604]=0;if((d|0)==1){break G}I:{if(c){c=z[f>>1];x[23604]=0;Q(141,b|0,D(((y[e+179|0]>13)<<1)+(c<<1)|0,a)+r|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break G}c=Sb(e+80|0);d=z[f>>1];x[23604]=0;i=W(203,b|0,c|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break I}d=0;J:{if(!i){break J}while(1){if(z[f>>1]<=d>>>0){break J}K:{i=cc(x[c>>2],d);i=y[i|0]|y[i+1|0]<<8;if(!i|i>>>0>z[e+214>>1]){break K}i=cc(x[h>>2],i-1|0);i=(y[i|0]|y[i+1|0]<<8)-1&65535;if(i>>>0>=k>>>0){break K}o=x[g>>2];q=x[j>>2];x[23604]=0;U(213,ac(o,a)|0,d&65535,zg(q,i)|0);i=x[23604];x[23604]=0;if((i|0)!=1){break K}break H}d=d+1|0;continue}}nd(c)}a=a+1|0;continue}}break}d=P()|0;nd(c);break i}d=P()|0;break i}d=P()|0}jd(j)}nd(h)}sc(m);break b}jd(j)}nd(h);sc(m);nd(l)}hb=e+224|0;return n|0}d=P()|0}nd(l)}T(d|0);p()}function Ps(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;m=hb-16|0;hb=m;x[m+12>>2]=c;a:{if((c|0)<=0){break a}h=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{i=x[b+656>>2];j:{if(!(!i|x[a+480180>>2]!=16777216)){n=x[i+44>>2]!=0;break j}if(!i){break i}}if((c|0)>128){break h}l=c-1|0;k=z[cc(i+236|0,l)>>1];k:{if((k-1&65535)>>>0<=3998){h=(D(k,104)+a|0)+484380|0;break k}if(!Tb(a+1074312|0,43)){break k}if(!Ij(x[b+656>>2])){break a}}k=y[Gb(i+108|0,l)|0];x[m+12>>2]=k;if(k>>>0<=120){break g}c=k;break h}k=c;l=0;if(c>>>0<121){break f}}l:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){Kn(a,b);if(d){break l}if(!Tb(a+1074312|0,100)|!(y[a+480208|0]&4)|!y[b+789|0]){break l}x[b+88>>2]=x[b+88>>2]&-6145;break l}if(!z[a+480192>>1]){break l}x[b+88>>2]=x[b+88>>2]|4096}m:{if((c|0)!=254){break m}c=x[b+88>>2];d=a+480180|0;if(!(!(c&512)|x[d>>2]!=2)){x[b+88>>2]=c|2048;break m}x[b+88>>2]=c|2101248;n:{if(x[d>>2]&16777248){if(!z[a+480192>>1]){break n}if(Tb(a+1074312|0,50)){break n}}x[b+688>>2]=0}if(Tb(a+1074312|0,50)){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}if(!Tb(a+1074312|0,20)){break a}v[b+797|0]=0;v[b+802|0]=0;break a}l=0;if(!n){break f}if(d){l=y[b+797|0];if(l){break e}}x[b+708>>2]=0;l=1}if(d){break d}if(!(!(x[a+480180>>2]&1048588)|!h)){w[b+770>>1]=v[h+36|0];w[b+772>>1]=v[h+37|0];break c}if(h){break c}h=0;n=0;break b}l=D((x[x[i+44>>2]+36>>2]<<16>>16)+1|0,(k<<16>>16)-(l<<16>>16)|0)-x[b+852>>2]|0;x[b+708>>2]=l;x[b+852>>2]=0-l;l=1}o=(h|0)!=0;n=1;if(ki(x[b+8>>2],x[b+12>>2])){break b}p=a+1074312|0;if(Tb(p,54)){x[b+700>>2]=0;break a}n=(Tb(p,39)^-1)&d;break b}n=0;o=1;if(!Tb(a+1074312|0,24)){break b}x[b+704>>2]=x[h+24>>2]}o:{if(lm(x[a+480180>>2])){x[m+12>>2]=w[b+770>>1]+k;fe(m+12|0,12,131);break o}jR(m+12|0)}j=a+1074312|0;p:{if(Tb(j,34)){d=nm(c);break p}d=x[m+12>>2]}v[b+797|0]=d;v[b+851|0]=y[b+851|0]&183|64;if(!(x[a+480180>>2]&16777250?0:n)){v[b+803|0]=0}p=Og(a,x[m+12>>2],w[b+772>>1],x[b+704>>2]);v[b+831|0]=0;if(Tb(j,48)){cN(a,b,i,h)}q:{if(!Tb(j,115)|!i){break q}d=y[i+26|0];if(!d){break q}if(!z[b+784>>1]){w[b+784>>1]=z[b+692>>1]+1}bN(b+692|0,c,d,y[i+27|0])}r:{if(e^1|n){break r}x[b+776>>2]=0;x[b+780>>2]=0;if(!i){break r}if(Tb(j,29)){v[b+798|0]=y[i+16|0]}if(!(y[i+60|0]&8)){Yi(b+724|0)}if(!(y[i+80|0]&8)){Yi(b+732|0)}if(!(y[i+100|0]&8)){Yi(b+740|0)}if(y[i+20|0]){c=((D(Ns(Jn(a)),y[i+20|0])<<16>>16)/64|0)+1<<16>>16;s:{if(Tb(j,28)){d=x[b+752>>2];break s}d=(x[b+688>>2]+1|0)/2|0}w[b+776>>1]=(D(d,c)|0)/199}t:{if(!y[i+19|0]){break t}r=b,s=(D(Ns(Jn(a)),y[i+19|0])<<16>>16)/32|0,w[r+778>>1]=s;if(Tb(j,28)|z[b+784>>1]){break t}w[b+784>>1]=z[b+692>>1]+1}k=y[i+23|0];if(k){d=Ns(Jn(a));c=y[b+837|0];v[b+796|0]=c+1;w[b+780>>1]=(D(c,(D(k,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}k=y[i+24|0];if(!k){break r}d=Ns(Jn(a));c=y[b+838|0];v[b+795|0]=c+1;w[b+782>>1]=(D(c,(D(k,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!o){break a}o=0;u:{v:{if(!p){break v}if(!(x[b+700>>2]?n:0)){x[b+700>>2]=p}w:{x:{if(!l){if(!n){if(Tb(j,69)){break x}if(Tb(j,46)|x[a+480180>>2]==1){break x}}x[b+708>>2]=p;v[b+851|0]=y[b+851|0]&239}if(!n){break x}if(x[b+76>>2]|y[a+480180|0]&2){break w}}x[b+104>>2]=h;c=x[h>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;y:{z:{A:{if(!(y[a+480210|0]&32)){if(!Tb(j,96)|y[b+789|0]){break z}q=x[b>>2];c=x[b+76>>2];break A}if(y[b+789|0]){break z}}x[m+8>>2]=c-1;c=x[Fb(b+660|0,m+8|0)>>2];x[b>>2]=q;x[b+4>>2]=c;break y}x[b+660>>2]=0}c=z[h+34>>1];q=c&1023;d=q|x[b+88>>2]&-525056;x[b+88>>2]=d;B:{C:{if(c&8){x[b+80>>2]=x[h+12>>2];c=x[h+16>>2];x[b+88>>2]=(q&16?d|4:d&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break C}break B}if(!(q&2)){break B}x[b+80>>2]=x[h+4>>2];c=x[h+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break B}}x[b+76>>2]=c}D:{if(!(r=0,s=Tb(j,83),t=x[b+80>>2],t?r:s)){c=x[b+76>>2];break D}c=x[h>>2];x[b+84>>2]=c;x[b+76>>2]=c}d=x[b+88>>2];if(!(!(d&128)|!c)){x[b+4>>2]=c-1;x[b+88>>2]=d|128}E:{if(y[b+822|0]>3){break E}c=Tb(j,21);d=x[a+480180>>2];F:{G:{if(!(c|!(d&16777248))){h=16;if(y[a+480208|0]&4){break G}break F}h=32;if((d|0)==16){break F}}if(d&67633152){break E}h=0}v[b+819|0]=h}if(Tb(j,21)|y[b+825|0]>3){break w}v[b+820|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}if(!n){break v}o=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break v}d=1;if(!(y[a+480208|0]&8)){break u}d=1;if(!y[b+789|0]){break u}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){Xl(b);if(!Tb(j,21)){v[b+818|0]=0;x[b+756>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}H:{if(!o){h=y[b+789|0];break H}h=y[b+789|0];if(!(y[a+480208|0]&8)){break H}d=1;if(!(h&255)){break u}}if(!(h&255?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}d=o}I:{if(!(!d|!Tb(j,40)|(y[b+789|0]?y[a+480208|0]&8:0))){c=x[b+88>>2]&-4194305;break I}c=x[b+88>>2]&-4196353}x[b+88>>2]=c;J:{if(d){break J}w[b+842>>1]=65535;x[b+88>>2]=c&-6324225|2097152;K:{if(Tb(j,23)){break K}if(Tb(j,22)){break K}if(Tb(j,52)){break K}if(Tb(j,71)){break K}v[b+839|0]=0;v[b+808|0]=0}if(e){v[b+818|0]=0;x[b+756>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;k=x[a+480208>>2]&8192;L:{M:{if(i){e=1;c=y[i+22|0];N:{if(!re(c)){e=!(k>>>13|0);break N}r=b,s=mj(c),v[r+838|0]=s}c=y[i+21|0];if(re(c)){r=b,s=mj(c),v[r+837|0]=s;break M}if(e){break M}h=(e|0)!=0;break L}x[b+776>>2]=0;x[b+780>>2]=0;h=!k;break L}h=1;c=y[i+25|0];if((c|0)==255){break L}v[b+845|0]=c}O:{P:{if(y[b+837|0]>=127){if(Tb(j,36)&h){break P}break O}if(!h){break O}}if((up(a,b,1,256)|0)<0|!(y[b+89|0]&2)){break O}c=x[a+1298300>>2];if(!td(c)|(g|0)==65535){break O}yp(c,g,y[b+837|0]>>>1|0,1)}if(!(y[b+89|0]&2)){break J}if(!td(x[a+1298300>>2])|(g|0)==65535){break J}if(Tb(j,111)){Kj(x[a+1298300>>2],g);break J}if(!Tb(j,110)){break J}_y(x[a+1298300>>2],g,0,1,0)}c=x[b+88>>2];Q:{R:{S:{if(f){x[b+88>>2]=c&-1025;break S}if(!(c&1024)){break S}if(y[a+24618|0]&16){break R}}a=x[b+104>>2];if(!(!a|!(y[a+35|0]&4)|f)){break R}a=x[b+656>>2];if(!a|(!(y[a+15|0]&2)|f)){break Q}}x[b+700>>2]=0}if(d){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}hb=m+16|0}function hN(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,C=E(0),F=E(0),G=0,H=0,I=E(0),J=0;k=hb-48|0;hb=k;l=b+223848|0;Fi(l,ji(e,gi(e,Vn(e),0))+1|0);ke(k+40|0,x[l>>2],x[b+223852>>2]);ec(k+32|0,e,ji(e,gi(e,Vn(e),0)));o=x[k+32>>2];p=x[k+36>>2];l=0;m=hb-16|0;hb=m;t=a+1074312|0;e=D(c,872)+b|0;C=E(y[e+1466|0]);F=E(f>>>0);i=e+616|0;j=x[e+1272>>2];u=a+480188|0;q=1;g=255;while(1){if((n|0)!=(p|0)&A[k+44>>2]>l>>>0){h=y[Gb(o,n)|0];e=h-48|0;a:{b:{if((e&255)>>>0<=9){break b}if((h-65&255)>>>0<=5){e=h-55|0;break b}c:{d:{e:{switch(h-97|0){case 2:f:{e=sl(a,b,c,3,0);if((e-1&255)>>>0>249){break f}e=x[(D(e,160)+a|0)+906140>>2];if(!e){break f}e=uy(e,47968,45068);if(!e){break f}e=mb[x[x[e>>2]+188>>2]](e,i,c)|0;h=(e|0)!=255;e=h?e:0;if(h|!j){break b}break c}if(j){break c}e=0;break b;case 21:g:{if(!Tb(t,28)){e=0;if(!Tb(t,1)){break g}}e=w[i+776>>1]}h=D(x[i+752>>2],x[i+748>>2]);e=D(x[a+1074456>>2],e+x[i+688>>2]|0);e=Yb((Ec(Kia(Jia(h,h>>31,e,e>>31),lb,1048576,0),lb)|0)/2|0,1,127);break d;case 20:e=D(x[i+752>>2],x[i+748>>2]);h=e;s=e>>31;e=D(x[a+1074456>>2],x[i+720>>2]);e=Yb((Ec(Kia(Jia(h,s,e,e>>31),lb,67108864,0),lb)|0)/2|0,1,127);break d;case 23:x[m>>2]=x[i+692>>2]/2;x[m+12>>2]=127;e=x[rd(m,m+12|0)>>2];break d;case 24:x[m>>2]=x[i+684>>2]/2;x[m+12>>2]=127;e=x[rd(m,m+12|0)>>2];break d;case 0:e=0;if(!j){break d}h=z[j+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!j){break d}h=z[j+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=x[i+664>>2]>>>8|0;break d;case 7:e=(z[u>>1]<=c>>>0?y[i+786|0]-1|0:c)&127;break d;case 12:e=y[i+88|0]>>>7|0;break d;case 15:e=0;if(!j){break d}h=y[j+30|0];if(!h){break d}e=h-1&127;break d;case 25:h:{if(!d|v[i+850|0]<0){break h}i:{if(l>>>0<3){break i}e=x[k+40>>2];if(y[Gb(e,l-3|0)|0]!=240){break i}if(y[Gb(e,l-2|0)|0]>239){break h}}r=op(b,C,F);j:{if(r<E(4294967296)&r>=E(0)){e=~~r>>>0;break j}e=0}v[i+850|0]=e;g=128;break d}g=(g&255)==255?f:g;e=f;break d;case 18:k:{if(!l){e=0;break k}h=x[k+40>>2];e=l;while(1){e=e-1|0;s=Gb(h,e);if(!e){break k}if(y[s|0]!=240){continue}break}}if(l-e>>>0<5){break a}s=x[k+40>>2];if(y[Gb(s,e)|0]!=240){break a}e=e+5|0;h=0;while(1){if((e|0)!=(l|0)){h=y[Gb(s,e)|0]+h|0;e=e+1|0;continue}break};e=0-h&127;break d;case 13:break e;default:break a}}e=y[i+799|0];e=Tc(e)?e-1|0:0}h=q^-1;q=1;l=(h&1)+l|0;G=Gb(x[k+40>>2],l),H=e,v[G|0]=H;l=l+1|0;break a}e=z[i+786>>1];h=y[j+31|0];e=(e?e-1|0:c)&15;l:{if((h|0)==17){break l}e=bj(h)?h-1&15:0}}h=Gb(x[k+40>>2],l);m:{if(q&1){v[h|0]=e;break m}v[h|0]=y[h|0]<<4|e;l=l+1|0}q=q^1}n=n+1|0;continue}else{if(g<<24>>24>=0){v[i+850|0]=g}hc(m,x[k+40>>2],((q^-1)&1)+l|0);e=x[m+4>>2];x[k+40>>2]=x[m>>2];x[k+44>>2]=e;hb=m+16|0}break}m=x[k+44>>2];l=0;n:while(1){q=0;while(1){e=l;o:{p:{q:{r:{while(1){if(A[k+44>>2]<=e>>>0){break o}f=x[k+40>>2];g=Gb(f,e);i=v[g|0];if((i|0)==-16){i=e;if(m-e>>>0>=4){l=4;if((y[Gb(f,e+1|0)|0]&254)==240){break p}}s:{while(1){i=i+1|0;if(m>>>0<=i>>>0){break s}if(y[Gb(f,i)|0]!=247){continue}break}l=(i-e|0)+1|0;if(l){break p}}G=Gb(f,m),H=247,v[G|0]=H;m=m+1|0;l=m-e|0;break q}if((i|0)<0){break r}if(q&255){e=e-1|0;G=Gb(f,e),H=q,v[G|0]=H;continue}break}l=l+1|0;continue n}G=k,H=kP(i&255),x[G+16>>2]=H;x[k+28>>2]=m-e;l=x[Fb(k+16|0,k+28|0)>>2]}if(!l){break o}f=x[k+40>>2];g=Gb(f,e)}t=y[g|0];eq(k+16|0,f,x[k+44>>2],e,l);f=ec(k+8|0,x[k+16>>2],x[k+20>>2]);i=x[f+4>>2];x[k>>2]=x[f>>2];x[k+4>>2]=i;i=hb-32|0;hb=i;o=x[k+4>>2];t:{if(!o){break t}h=ud(y[b+223884|0]);u:{n=x[k>>2];p=Gb(n,0);f=y[p|0]-250|0;if(f>>>0>5|!(1<<f&37)){break u}g=z[a+480188>>1];f=0;while(1){if((f|0)==(g|0)){break u}j=(D(f,872)+b|0)+1453|0;v[j|0]=127;v[j+1|0]=0;f=f+1|0;continue}}f=(D(c,872)+b|0)+616|0;v:{if((o|0)!=4|y[p|0]!=240){break v}j=y[Gb(n,1)|0];if((j&254)!=240){break v}o=Gb(n,2);p=y[Gb(n,3)|0];g=p<<24>>24;w:{x:{y:{z:{A:{B:{n=y[o|0];switch(n|0){case 3:break y;case 2:break z;case 1:break A;case 0:break B;default:break x}}if((j|0)==241|(g|0)<0){break x}if(d){g=Rg(op(b,E(y[f+837|0]),E((g&255)>>>0)))}v[f+796|0]=0;v[f+837|0]=g;g=up(a,f,!(x[f+88>>2]&32768),256);if((g|0)<0|!(y[f+89|0]&2)){break t}f=x[a+1298300>>2];if(h|td(f)^1){break t}yp(f,c,g>>>2&255,1);break t}if((j|0)==241|(g|0)<0){break x}if(d){g=Rg(op(b,E(y[f+838|0]),E((g&255)>>>0)))}v[f+795|0]=0;v[f+838|0]=g;up(a,f,!(x[f+88>>2]&32768),256);break t}if((j|0)==241){break w}if(g>>>0>31){break t}v[f+845|0]=(g&240)>>>4;up(a,f,!(x[f+88>>2]&32768),256);break t}if((j|0)==241){break w}f=sl(a,b,c,3,0)-1|0;if((g|0)<0|(f&255)>>>0>249){break t}v[i+24|0]=f;g=D(f&255,160)+a|0;f=x[g+906300>>2];if(!f){break t}r=E(E(127-p|0)/E(127));if(h){g=0;j=hb-16|0;hb=j;G=j,H=Sj(i+24|0),x[G>>2]=H;f=hb-16|0;hb=f;n=b+223860|0;o=ty(n,f+12|0,y[i+24|0]);h=x[o>>2];if(!h){g=hb-16|0;hb=g;h=jc(n);p=ph(f,Jc(24),qh(g+8|0,h));h=x[p>>2];u=y[x[j>>2]];x[h+20>>2]=0;v[h+16|0]=u;G=jc(p),H=1,v[G+4|0]=H;hb=g+16|0;Vg(n,x[f+12>>2],o,x[f>>2]);h=Wd(f);cl(f);g=1}Ug(j+8|0,x[Ib(f,h)>>2],g);hb=f+16|0;f=sd(x[j+8>>2]);hb=j+16|0;B[f+4>>2]=r;break t}if(!d){Js(x[f+20>>2],r);break t}Js(x[f+20>>2],op(b,B[g+906444>>2],r));break t}if(n<<24>>24<0){break w}if((j|0)!=241){break t}}o=sl(a,b,c,3,0)-1|0;if((g|0)<0|(o&255)>>>0>249){break t}f=x[(D(o&255,160)+a|0)+906300>>2];if(!f){break t}j=(j|0)==241?n+128|0:n&127;r=E(E((g&255)>>>0)/E(127));if(h){G=yN(b+223872|0,SM(i+24|0,o,j)),I=r,B[G>>2]=I;break t}g=x[f>>2];if(!d){mb[x[g+44>>2]](f,j,r);break t}H=f,J=j,I=op(b,E(mb[x[g+48>>2]](f,j)),r),G=x[x[f>>2]+44>>2],mb[G](H|0,J|0,E(I));break t}if(h){break t}j=z[a+480188>>1];C:{if(j>>>0>c>>>0){g=c+1|0;break C}g=z[f+786>>1];if(!g){break t}}if(y[f+91|0]&4|j>>>0<(g&65535)>>>0){break t}f=sl(a,b,c,3,0);if((f-1&255)>>>0>249){break t}f=x[(D(f,160)+a|0)+906140>>2];if(!f){break t}g=y[p|0];if((g|0)==240){Kg(i+16|0,x[k>>2],x[k+4>>2]);g=x[x[f>>2]+72>>2];j=x[i+20>>2];x[i>>2]=x[i+16>>2];x[i+4>>2]=j;mb[g|0](f,i)|0;break t}G=i,J=kP(g),x[G+24>>2]=J;x[i+12>>2]=o;g=i+24|0;j=x[Fb(g,i+12|0)>>2];x[i+24>>2]=0;vc(g,n,j);mb[x[x[f>>2]+68>>2]](f,x[i+24>>2])|0}hb=i+32|0;q=t>>>0<240?t:q;l=e+l|0;continue}break}break}hb=k+48|0}function m_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;l=hb-544|0;hb=l;x[l+532>>2]=k;x[l+536>>2]=b;a:{b:{if(Lg(a,l+536|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+88>>2]=1104;b=l+88|0;t=le(l+120|0,l+128|0,b);m=x[t>>2];x[l+116>>2]=m;x[l+112>>2]=m+400;u=Kb(b);r=Kb(l+72|0);q=Kb(l+56|0);o=Kb(l+40|0);s=Kb(l+24|0);b=x[d>>2];x[23604]=0;la(1107,c|0,b|0,l+104|0,l+103|0,l+102|0,u|0,r|0,q|0,o|0,l+20|0);b=x[23604];x[23604]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;B=A>>>9|0;w=x[l+20>>2];k=h;C=y[l+107|0];D=y[l+103|0];E=y[l+102|0];c=m;e=0;d=0;while(1){c:{d:{e:{f:{if((e|0)==4){break f}x[23604]=0;b=Q(1073,a|0,l+536|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+104|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[23604]=0;b=S(1074,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}if(fh(x[k+8>>2],1,b)){x[23604]=0;R(1108,l+8|0,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){x[23604]=0;R(46,s|0,v[l+8|0]);b=x[23604];x[23604]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break c}}while(1){x[23604]=0;b=Q(1073,a|0,l+536|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}if(b){break c}b=x[a>>2];x[23604]=0;b=S(1074,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}if(!fh(x[k+8>>2],1,b)){break c}x[23604]=0;R(1108,l+8|0,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){x[23604]=0;R(46,s|0,v[l+8|0]);b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Eb(x[q+4>>2],y[q+11|0])){break l}b=x[a>>2];x[23604]=0;b=S(1074,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}if(y[uc(q,0)|0]!=(b&255)){break l}x[23604]=0;S(1076,a|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}v[g|0]=0;d=Eb(x[q+4>>2],y[q+11|0])>>>0>1?q:d;break c}m:{if(!Eb(x[o+4>>2],y[o+11|0])){break m}b=x[a>>2];x[23604]=0;b=S(1074,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}if(y[uc(o,0)|0]!=(b&255)){break m}x[23604]=0;S(1076,a|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}v[g|0]=1;d=Eb(x[o+4>>2],y[o+11|0])>>>0>1?o:d;break c}n:{b=Eb(x[q+4>>2],y[q+11|0]);if(!b){break n}if(!Eb(x[o+4>>2],y[o+11|0])){break n}x[f>>2]=x[f>>2]|4;a=0;break d}h=b;b=Eb(x[o+4>>2],y[o+11|0]);if(!(h|b)){break c}v[g|0]=!b;break c}if(!(e>>>0<2|d|((e|0)==2&(C|0)!=0|B))){d=0;break c}h=Ib(l+8|0,pd(r));o:{if(!e|y[(e+l|0)+103|0]>1){break o}while(1){p:{b=pf(r);n=x[h>>2];if(!Ob(n,b)){break p}if(!fh(x[k+8>>2],1,v[n|0])){break p}Le(h);continue}break}b=pd(r);b=de(x[h>>2],b);if(Eb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){n=dA(pf(s),b);F=pf(s);z=pd(r);b=hb-16|0;hb=b;x[b>>2]=z;x[b+8>>2]=n;while(1){z=Ob(n,F);if(!(!z|y[n|0]!=y[x[b>>2]])){n=Le(b+8|0);Le(b);n=x[n>>2];continue}break}hb=b+16|0;if(z^1){break o}}G=h,H=x[Ib(l,pd(r))>>2],x[G>>2]=H}x[l>>2]=x[h>>2];q:{while(1){b=pf(r);if(!Ob(x[l>>2],b)){break q}x[23604]=0;b=Q(1073,a|0,l+536|0)|0;h=x[23604];x[23604]=0;r:{if((h|0)==1){break r}if(b){break q}b=x[a>>2];x[23604]=0;b=S(1074,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break r}if(y[x[l>>2]]!=(b&255)){break q}x[23604]=0;S(1076,a|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}Le(l);continue}break}break a}if(!A){break c}b=pf(r);if(!Ob(x[l>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}s:{while(1){t:{x[23604]=0;h=Q(1073,a|0,l+536|0)|0;n=x[23604];x[23604]=0;if((n|0)==1){break t}if(h){break s}h=x[a>>2];x[23604]=0;n=S(1074,h|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}u:{if(fh(x[k+8>>2],64,n)){h=x[j>>2];if((h|0)==x[l+532>>2]){x[23604]=0;U(1109,i|0,j|0,l+532|0);h=x[23604];x[23604]=0;if((h|0)==1){break a}h=x[j>>2]}x[j>>2]=h+1;v[h|0]=n;b=b+1|0;break u}if(!Eb(x[u+4>>2],y[u+11|0])|!b|(n&255)!=(E|0)){break s}if(x[l+112>>2]==(c|0)){x[23604]=0;U(1110,t|0,l+116|0,l+112|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}c=x[l+116>>2]}m=c+4|0;x[l+116>>2]=m;x[c>>2]=b;c=m;b=0}x[23604]=0;S(1076,a|0)|0;h=x[23604];x[23604]=0;if((h|0)!=1){continue}}break}break a}if(!(!b|x[t>>2]==(m|0))){if(x[l+112>>2]==(m|0)){x[23604]=0;U(1110,t|0,l+116|0,l+112|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}m=x[l+116>>2]}c=m+4|0;x[l+116>>2]=c;x[m>>2]=b;m=c}if((w|0)<=0){break e}x[23604]=0;b=Q(1073,a|0,l+536|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}v:{if(!b){b=x[a>>2];x[23604]=0;b=S(1074,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}if((b&255)==(D|0)){break v}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23604]=0;b=S(1076,a|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break e}x[23604]=0;c=Q(1073,b|0,l+536|0)|0;h=x[23604];x[23604]=0;w:{if((h|0)==1){break w}x:{if(!c){c=x[b>>2];x[23604]=0;c=S(1074,c|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break w}if(fh(x[k+8>>2],64,c)){break x}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+532>>2]){x[23604]=0;U(1109,i|0,j|0,l+532|0);c=x[23604];x[23604]=0;if((c|0)==1){break w}}c=x[b>>2];x[23604]=0;c=S(1074,c|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break w}h=x[j>>2];x[j>>2]=h+1;v[h|0]=c;x[23604]=0;S(1076,b|0)|0;c=x[23604];x[23604]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}x[l+20>>2]=w;y:{if(!d){break y}k=1;while(1){if(Eb(x[d+4>>2],y[d+11|0])>>>0<=k>>>0){break y}x[23604]=0;b=Q(1073,a|0,l+536|0)|0;c=x[23604];x[23604]=0;z:{if((c|0)==1){break z}A:{if(!b){b=x[a>>2];x[23604]=0;b=S(1074,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break z}if(y[uc(d,k)|0]==(b&255)){break A}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23604]=0;S(1076,a|0)|0;b=x[23604];x[23604]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+8>>2]=0;rf(u,b,m,l+8|0);if(x[l+8>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}c=m;if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}xb(s);xb(o);xb(q);xb(r);xb(u);Mc(t);break b}e=e+1|0;continue}}break a}hb=l+544|0;return a|0}a=P()|0;xb(s);xb(o);xb(q);xb(r);xb(u);Mc(t);T(a|0);p()}function L9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb+-64|0;hb=g;d=x[b>>2];x[23604]=0;e=S(164,d|0)|0;d=x[23604];x[23604]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(e){h=Sb(g+48|0);x[23604]=0;f=(c|0)!=0;e=W(775,h|0,b|0,f|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break e}d=4;g:{h:{i:{j:{if(e){break j}x[23604]=0;e=W(776,h|0,b|0,f|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break e}d=5;if(e){break j}x[23604]=0;e=W(777,h|0,b|0,f|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break e}d=6;if(e){break j}e=0;x[23604]=0;f=W(778,h|0,b|0,f|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break e}d=3;if(!f){break i}}if(!c){d=1;e=0;break h}e=x[h>>2];if(!tc(e,x[h+4>>2])){Xu(b,e+12|0)}e=d}d=31920;k:{while(1){f=d;if((f|0)!=32436){k=x[f+8>>2];j=(k>>1)+a|0;d=x[f+4>>2];d=k&1?x[x[j>>2]+d>>2]:d;x[23604]=0;k=W(d|0,j|0,b|0,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}d=f+12|0;if(!k){continue}break k}break}x[a+480180>>2]=0;x[a+480184>>2]=0}if(!c){d=(f|0)!=32436;e=0;break h}if(!(x[a+480184>>2]|!e)){x[a+480184>>2]=e}x[23604]=0;e=1;R(718,a+1298264|0,1);f=x[23604];x[23604]=0;d=1;if((f|0)==1){break g}}hM(h);if(e){break f}break a}break c}x[23604]=0;R(232,a|0,0);d=x[23604];x[23604]=0;if((d|0)==1){break d}x[23604]=0;R(718,a+1298264|0,1);d=x[23604];x[23604]=0;if((d|0)==1){break d}x[a+1074304>>2]=19924993}d=0;while(1){if((d|0)==127){d=1;while(1){e=d&65535;if(e>>>0>z[a+480190>>1]){e=0;j=a+480180|0;d=0;l:{while(1){f=d&65535;if(f>>>0>z[a+480192>>1]){m:{w[a+480192>>1]=e;d=a+480204|0;if(A[a+480204>>2]>=1e4){break m}x[d>>2]=125e4;break l}}else{f=x[((f<<2)+a|0)+900380>>2];if(f){k=x[j>>2];wc(f,65536);wc(f+4|0,64);wc(f+8|0,256);pg(f+28|0,16384);mf(f+30|0,128);mf(f+31|0,17);if(y[f+16|0]>=4){v[f+16|0]=0}if(y[f+17|0]>=5){v[f+17|0]=0}if(y[f+18|0]>=3){v[f+18|0]=0}mf(f+19|0,64);mf(f+20|0,100);i=224;e=v[f+26|0];n:{if((e|0)>=-32){i=32;if((e|0)<33){break n}}v[f+26|0]=i}mf(f+23|0,64);mf(f+24|0,64);mz(f+48|0,64);mz(f+68|0,64);mz(f+88|0,(k|0)==4096?255:64);e=f+108|0;i=0;while(1){if((i|0)==128){if(!ro(y[f+14|0])){v[f+14|0]=5}if(y[f+34|0]>=251){v[f+34|0]=0}}else{o:{if(y[Gb(e,i)|0]){if(y[Gb(e,i)|0]<121){break o}}n=Gb(e,i),o=i+1|0,v[n|0]=o}i=i+1|0;continue}break}e=d}d=d+1|0;continue}break}wc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}e=a+480220|0;d=x[a+480216>>2];if(d>>>0>A[a+480220>>2]){x[e>>2]=d}d=a+480216|0;wc(d,65536);wc(e,65536);wc(a+480200|0,256);p:{e=a+480248|0;if(!tc(x[e>>2],x[a+480252>>2])){d=x[d>>2];x[23604]=0;R(779,e|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break p}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];d=x[a+480220>>2];e=a+1074408|0;x[e>>2]=x[a+480216>>2];x[e+4>>2]=d;x[a+1074456>>2]=x[a+480200>>2];Ay(a+1074376|0);d=a+1074446|0;w[d>>1]=0;w[d+2>>1]=0;w[d+4>>1]=0;w[d+6>>1]=65535;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074432>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;if(lm(x[a+480180>>2])){x[23604]=0;Q(250,a+1074312|0,7)|0;d=x[23604];x[23604]=0;if((d|0)==1){break p}}w[a+480276>>1]=0;lp(a);n=g,o=Bb(x[a+484360>>2]),x[n+48>>2]=o;e=Bb(x[a+484364>>2]);while(1){f=x[g+48>>2];if(!Ob(f,e)){q:{r:{j=x[a+480180>>2];if(j){Ds(a+8|0,_p(a));if(x[a+1074308>>2]){x[23604]=0;Y(780,a|0);d=x[23604];x[23604]=0;if((d|0)==1){break p}}m=Sb(g+48|0);s:{if((c&12)!=12){break s}k=a+1298464|0;d=0;t:{u:{v:{w:{x:{y:{while(1){if((d|0)==250){break s}z:{e=D(d,160)+a|0;f=e+906316|0;A:{if(!(x[f>>2]|x[e+906320>>2])){break A}x[23604]=0;l=e+906300|0;R(781,l|0,a|0);c=x[23604];x[23604]=0;B:{if((c|0)!=1){h=x[l>>2];if(!h){break B}e=x[e+906448>>2];c=x[x[h>>2]+56>>2];x[23604]=0;R(c|0,h|0,e|0);c=x[23604];x[23604]=0;if((c|0)!=1){break A}}a=P()|0;break q}i=Bb(x[m>>2]);e=Bb(x[m+4>>2]);h=hb-16|0;hb=h;x[h+8>>2]=i;while(1){C:{if(!Ob(i,e)){break C}c=x[i>>2];if((y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))==(y[l+20|0]|y[l+21|0]<<8|(y[l+22|0]<<16|y[l+23|0]<<24))){c=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))==(y[l+16|0]|y[l+17|0]<<8|(y[l+18|0]<<16|y[l+19|0]<<24))}else{c=0}if(c){break C}i=x[Fe(h+8|0)>>2];continue}break}hb=h+16|0;if(Ob(i,Bb(x[m+4>>2]))){break A}x[23604]=0;x[g+32>>2]=f;R(782,m|0,g+32|0);c=x[23604];x[23604]=0;if((c|0)==1){break z}x[23604]=0;e=Q(1,g+16|0,17549)|0;c=x[23604];x[23604]=0;if((c|0)==1){break y}x[23604]=0;R(783,g|0,l|0);c=x[23604];x[23604]=0;if((c|0)==1){break x}x[23604]=0;U(2,g+32|0,e|0,g|0);c=x[23604];x[23604]=0;if((c|0)==1){break w}c=x[k>>2];x[23604]=0;U(351,c|0,2,g+32|0);c=x[23604];x[23604]=0;if((c|0)==1){break v}xb(g+32|0);xb(g);xb(e)}d=d+1|0;continue}break}a=P()|0;break q}a=P()|0;break q}a=P()|0;break t}a=P()|0;break u}a=P()|0;xb(g+32|0)}xb(g)}xb(e);break q}c=y[a+1074368|0];x[23604]=0;R(784,a|0,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break r}sc(m)}d=(j|0)!=0;break a}a=P()|0}sc(m);break b}x[23604]=0;Y(785,f|0);d=x[23604];x[23604]=0;if((d|0)!=1){if(Kc(x[f>>2],x[f+4>>2])>>>0<=z[f+28>>1]){Xe(f,0)}gz(g+48|0);continue}break}a=P()|0;break b}a=P()|0;break b}k=D(e,104)+a|0;j=k+484380|0;D:{if(Qd(x[j>>2],x[k+484400>>2])){aj(j,a);break D}f=k+484414|0;e=z[f>>1];if(e&16384){break D}x[j>>2]=0;x[j+4>>2]=0;x[j+16>>2]=0;x[j+8>>2]=0;x[j+12>>2]=0;w[f>>1]=e&65505}e=k+484412|0;if(z[e>>1]>=65){w[e>>1]=64}E:{F:{if(!(y[k+484415|0]&2)){break F}if(!Lj(x[a+1298300>>2])){break F}x[23604]=0;Y(786,a|0);e=x[23604];x[23604]=0;if((e|0)==1){break E}}d=d+1|0;continue}break}a=P()|0;break b}f=(d<<5)+a|0;pg(f+480286|0,64);e=f+480284|0;if(z[e>>1]>=257){w[e>>1]=128}e=f+480288|0;if(y[e|0]>=251){v[e|0]=0}Tn((D(d,872)+a|0)+1074992|0,a,d&65535,134217728);d=d+1|0;continue}}break c}a=P()|0;break b}a=P()|0;hM(h)}yb(b);T(a|0);p()}yb(b);hb=g- -64|0;return d|0}function v0(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;n=hb-560|0;hb=n;x[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){u=1;C=5257;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){u=1;C=5260;break a}u=e&1;C=u?5263:5258;B=!u}b:{if((g&2146435072)==2146435072){g=u+3|0;sf(a,32,c,g,e&-65537);gf(a,C,u);d=f&32;gf(a,b!=b?d?9870:13653:d?10996:14015,3);sf(a,32,c,g,e^8192);t=(c|0)<(g|0)?g:c;break b}A=n+16|0;c:{d:{e:{b=tH(b,n+44|0);b=b+b;if(b!=0){g=x[n+44>>2];x[n+44>>2]=g-1;t=f|32;if((t|0)!=97){break e}break c}t=f|32;if((t|0)==97){break c}k=x[n+44>>2];m=(d|0)<0?6:d;break d}k=g-29|0;x[n+44>>2]=k;b=b*268435456;m=(d|0)<0?6:d}r=(n+48|0)+((k|0)>=0?288:0)|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((k|0)<=0){g=h;i=r;break f}i=r;while(1){p=(k|0)>=29?29:k;g=h-4|0;g:{if(i>>>0>g>>>0){break g}d=0;while(1){l=x[g>>2];k=d;d=p&31;if((p&63)>>>0>=32){q=l<<d;d=0}else{q=(1<<d)-1&l>>>32-d;d=l<<d}k=k+d|0;l=q+s|0;d=Mia(k,d>>>0>k>>>0?l+1|0:l,1e9,0);l=Jia(d,lb,-1e9,0)+k|0;x[g>>2]=l;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!d){break g}i=i-4|0;x[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}k=x[n+44>>2]-p|0;x[n+44>>2]=k;h=g;if((k|0)>0){continue}break}}if((k|0)<0){w=((m+25>>>0)/9|0)+1|0;s=(t|0)==102;while(1){d=0-k|0;q=(d|0)>=9?9:d;h:{if(g>>>0<=i>>>0){h=x[i>>2];break h}p=1e9>>>q|0;l=-1<<q^-1;k=0;h=i;while(1){d=x[h>>2];x[h>>2]=(d>>>q|0)+k;k=D(p,d&l);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[i>>2];if(!k){break h}x[g>>2]=k;g=g+4|0}k=q+x[n+44>>2]|0;x[n+44>>2]=k;i=(!h<<2)+i|0;d=s?r:i;g=g-d>>2>(w|0)?d+(w<<2)|0:g;if((k|0)<0){continue}break}}k=0;i:{if(g>>>0<=i>>>0){break i}k=D(r-i>>2,9);h=10;d=x[i>>2];if(d>>>0<10){break i}while(1){k=k+1|0;h=D(h,10);if(d>>>0>=h>>>0){continue}break}}d=(m-((t|0)!=102?k:0)|0)-((t|0)==103&(m|0)!=0)|0;if((d|0)<(D(g-r>>2,9)-9|0)){p=d+9216|0;d=(p|0)/9|0;l=r+(d<<2)|0;s=l-4096|0;h=10;d=p+D(d,-9)|0;if((d|0)<=7){while(1){h=D(h,10);d=d+1|0;if((d|0)!=8){continue}break}}d=l-4092|0;p=x[s+4>>2];l=(p>>>0)/(h>>>0)|0;q=D(l,h);w=s+8|0;j:{if((p|0)==(q|0)&(w|0)==(g|0)){break j}p=p-q|0;k:{if(!(l&1)){b=9007199254740992;if(!(v[s|0]&1)|((h|0)!=1e9|d>>>0<=i>>>0)){break k}}b=9007199254740994}l=h>>>1|0;z=l>>>0>p>>>0?.5:(l|0)==(p|0)?(g|0)==(w|0)?1:1.5:1.5;if(!(y[C|0]!=45|B)){z=-z;b=-b}x[d>>2]=q;if(b+z==b){break j}h=h+q|0;x[d>>2]=h;if(h>>>0>=1e9){while(1){x[d>>2]=0;d=d-4|0;if(i>>>0>d>>>0){i=i-4|0;x[i>>2]=0}h=x[d>>2]+1|0;x[d>>2]=h;if(h>>>0>999999999){continue}break}}k=D(r-i>>2,9);h=10;l=x[i>>2];if(l>>>0<10){break j}while(1){k=k+1|0;h=D(h,10);if(l>>>0>=h>>>0){continue}break}}d=d+4|0;g=d>>>0<g>>>0?d:g}while(1){l=g;h=g>>>0<=i>>>0;if(!h){g=l-4|0;if(!x[g>>2]){continue}}break}l:{if((t|0)!=103){q=e&8;break l}g=m?m:1;d=(g|0)>(k|0)&(k|0)>-5;m=(d?k^-1:-1)+g|0;f=(d?-1:-2)+f|0;q=e&8;if(q){break l}g=-9;m:{if(h){break m}p=x[l-4>>2];if(!p){break m}d=10;g=0;if((p>>>0)%10|0){break m}while(1){h=g;g=g+1|0;d=D(d,10);if(!((p>>>0)%(d>>>0)|0)){continue}break}g=h^-1}d=D(l-r>>2,9);if((f&-33)==70){q=0;d=(d+g|0)-9|0;d=(d|0)>0?d:0;m=(d|0)>(m|0)?m:d;break l}q=0;d=((d+k|0)+g|0)-9|0;d=(d|0)>0?d:0;m=(d|0)>(m|0)?m:d}t=-1;p=m|q;if(((p?2147483645:2147483646)|0)<(m|0)){break b}s=(((p|0)!=0)+m|0)+1|0;h=f&-33;n:{if((h|0)==70){if((s^2147483647)<(k|0)){break b}g=(k|0)>0?k:0;break n}d=k>>31;g=on((d^k)-d|0,0,A);if((A-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((A-g|0)<2){continue}break}}w=g-2|0;v[w|0]=f;v[g-1|0]=(k|0)<0?45:43;g=A-w|0;if((g|0)>(s^2147483647)){break b}}d=g+s|0;if((d|0)>(u^2147483647)){break b}B=d+u|0;sf(a,32,c,B,e);gf(a,C,u);sf(a,48,c,B,e^65536);o:{p:{q:{if((h|0)==70){f=n+16|0;d=f|8;s=f|9;h=i>>>0>r>>>0?r:i;i=h;while(1){g=on(x[i>>2],0,s);r:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(s|0)){break r}v[n+24|0]=48;g=d}gf(a,g,s-g|0);i=i+4|0;if(r>>>0>=i>>>0){continue}break}if(p){gf(a,16619,1)}if((m|0)<=0|i>>>0>=l>>>0){break q}while(1){g=on(x[i>>2],0,s);if(g>>>0>n+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}gf(a,g,(m|0)>=9?9:m);g=m-9|0;i=i+4|0;if(l>>>0<=i>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}r=i>>>0<l>>>0?l:i+4|0;f=n+16|0;d=f|8;l=f|9;h=i;while(1){g=on(x[h>>2],0,l);if((l|0)==(g|0)){v[n+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}gf(a,g,1);g=g+1|0;if(!(m|q)){break t}gf(a,16619,1)}f=l-g|0;gf(a,g,(f|0)>(m|0)?m:f);m=m-f|0;h=h+4|0;if(r>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}sf(a,48,m+18|0,18,0);gf(a,w,A-w|0);break o}g=m}sf(a,48,g+9|0,9,0)}sf(a,32,c,B,e^8192);t=(c|0)<(B|0)?B:c;break b}l=(f<<26>>31&9)+C|0;u:{if(d>>>0>11){break u}g=12-d|0;z=16;while(1){z=z*16;g=g-1|0;if(g){continue}break}if(y[l|0]==45){b=-(z+(-b-z));break u}b=b+z-z}r=u|2;i=f&32;h=x[n+44>>2];g=h>>31;g=on((g^h)-g|0,0,A);if((A|0)==(g|0)){v[n+15|0]=48;g=n+15|0}m=g-2|0;v[m|0]=f+15;v[g-1|0]=(h|0)<0?45:43;g=e&8;h=n+16|0;while(1){f=h;if(F(b)<2147483648){p=~~b}else{p=-2147483648}v[h|0]=i|y[p+76448|0];b=(b-+(p|0))*16;h=f+1|0;if(!(!(g|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}t=-1;g=A-m|0;f=g+r|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}i=h-(n+16|0)|0;if((i-2|0)>=(d|0)){break w}d=d+2|0;break v}i=h-(n+16|0)|0;d=i}f=d+f|0;sf(a,32,c,f,e);gf(a,l,r);sf(a,48,c,f,e^65536);gf(a,n+16|0,i);sf(a,48,d-i|0,0,0);gf(a,m,g);sf(a,32,c,f,e^8192);t=(c|0)<(f|0)?f:c}hb=n+560|0;return t|0}function kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-272|0;hb=e;xc(b);d=hb-16|0;hb=d;f=e+120|0;HQ(d+8|0,f);g=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){bc(b,x[d+12>>2])}hb=d+16|0;d=(g|0)==(h|0);if(!d){GQ(f)}a:{b:{c:{d:{if(!d){break d}if(!IQ(e+120|0)){break d}if(!c){i=1;break d}Cd(a,4194304);d=e+32|0;g=Xb(d,16886);Ab(a+1298344|0,g);xb(g);g=Xb(d,10029);Ab(a+1298356|0,g);xb(g);x[a+1298404>>2]=5;n=a,o=Td(z[e+198>>1],z[e+200>>1],127),w[n+480188>>1]=o;g=y[e+189|0];x[a+480228>>2]=(g|0)==255?48:g;x[a+480196>>2]=y[e+187|0];x[a+480204>>2]=D(y[e+188|0],1e4);g=e+96|0;df(g,e+120|4,59,3);Dc(d,g);Ab(a+1298308|0,d);xb(d);d=z[e+202>>1]|z[e+204>>1]<<16;e:{if(d>>>0<5){break e}if(!Yc(b,d-4|0)){break e}if(!wh(b,14115)){break e}go(_b(x[a+484360>>2],y[a+484376|0]),b,z[e+192>>1],65535,65535)}f:{d=z[e+206>>1]|z[e+208>>1]<<16;if(d>>>0<5){break f}if(!Yc(b,d-4|0)){break f}if(!wh(b,13648)){break f}d=0;while(1){if((d|0)==32){break f}g=(d<<5)+a|0;Qe(g+480280|0);n=g+480284|0,o=((((Be(b)^-1)&15)<<8|8)>>>0)/15|0,w[n>>1]=o;d=d+1|0;continue}}d=z[e+214>>1]|z[e+216>>1]<<16;g:{if(d>>>0<5){break g}if(!Yc(b,d-4|0)){break g}if(!wh(b,13972)){break g}d=e+32|0;Ud(d,b,z[e+196>>1]<<6);k=c&2;h=a+480190|0;g=kc(e+96|0,d);yb(d);j=e+45|0;d=0;h:{while(1){if(z[e+196>>1]<=(d&65535)>>>0){break h}x[23604]=0;f=Q(612,g|0,e+32|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break b}if(!f){break h}f=y[e+77|0]|y[e+78|0]<<8;w[e+30>>1]=f;i:{j:{if((f-1&65535)>>>0>3998){break j}f=D(f,104)+a|0;i=f+484380|0;if(Qd(x[i>>2],x[f+484400>>2])){break j}n=h,o=z[Se(h,e+30|0)>>1],w[n>>1]=o;x[23604]=0;R(613,e+32|0,i|0);f=x[23604];x[23604]=0;if((f|0)==1){break i}df(e,j,24,1);x[23604]=0;R(208,e+16|0,e|0);f=x[23604];x[23604]=0;if((f|0)==1){break b}f=e+16|0;Bc(((z[e+30>>1]<<5)+a|0)+946304|0,f);xb(f);if(!k){break j}x[23604]=0;Q(141,b|0,y[e+69|0]|y[e+70|0]<<8|(y[e+71|0]<<16|y[e+72|0]<<24))|0;f=x[23604];x[23604]=0;if((f|0)==1){break i}i=1;l=e+16|0;f=y[e+79|0];m=Xc(l,f&4?16:8,1,0,0);k:{l:{if(f&8){break l}i=2;if(f&16){break l}if(f&127){break k}}Lf(m,i)}x[23604]=0;W(205,l|0,(D(z[e+30>>1],104)+a|0)+484380|0,b|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){break j}break b}d=d+1|0;continue}break}break b}yb(g)}i=1;if(!(c&1)){break d}m:{c=z[e+210>>1]|z[e+212>>1]<<16;if(c>>>0<5){break m}if(!Yc(b,c-4|0)){break m}if(!wh(b,13498)){break m}k=a+484344|0;gg(k,z[e+194>>1]);f=0;while(1){if(z[e+194>>1]<=f>>>0){break m}if(!kA(b,e+16|0)){break m}n:{d=z[e+16>>1];if(d>>>0>3){c=e+96|0;Ud(c,b,(d+15&131056)-4|0);g=kc(e+32|0,c);yb(c);x[23604]=0;c=W(212,k|0,f&65535,y[e+18|0])|0;d=x[23604];x[23604]=0;if((d|0)==1){break n}h=0;o:{if(!c){break o}while(1){p:{c=x[g>>2];x[23604]=0;d=W(142,c|0,x[e+40>>2],1)|0;c=x[23604];x[23604]=0;q:{if((c|0)!=1){c=y[e+18|0];if(!(d&c>>>0>(h&255)>>>0)){break p}x[23604]=0;c=S(192,g|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}d=c<<24>>24;if(d){break q}h=h+1|0;continue}break c}c=x[a+484344>>2];w[e+96>>1]=d&31;w[e>>1]=z[a+480188>>1]-1;c=ac(c,f);c=cd(x[c>>2],x[x[c+48>>2]+12>>2],h,z[Wc(e+96|0,e)>>1]);if((d|0)<0){x[23604]=0;R(245,e+96|0,g|0);j=x[23604];x[23604]=0;if((j|0)==1){break c}v[c|0]=y[e+96|0]+36;n=c,o=y[hd(e+96|0)|0],v[n+1|0]=o}d=d&255;if(d&64){v[c+2|0]=1;x[23604]=0;j=S(192,g|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break c}v[e+96|0]=j;v[e|0]=64;n=c,o=y[Wb(e+96|0,e)|0],v[n+4|0]=o}if(!(d&32)){continue}x[23604]=0;R(245,e+96|0,g|0);d=x[23604];x[23604]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((d|0)!=1){d=y[hd(e+96|0)|0];v[c+5|0]=d;switch(y[e+96|0]-1|0){case 71:break s;case 70:break t;case 69:break u;case 60:break v;case 59:break w;case 52:break x;case 51:break y;case 50:break z;case 49:break A;case 42:break B;case 41:break C;case 40:break D;case 39:break E;case 30:break F;case 29:break G;case 22:break H;case 21:break I;case 20:break J;case 19:break K;case 16:break L;case 15:break M;case 14:break N;case 13:break O;case 12:break P;case 11:break Q;case 10:break R;case 9:break S;case 3:break T;case 2:break U;case 1:break V;case 0:break W;default:break r}}break c}v[c+3|0]=11;v[c+5|0]=d<<4|15;continue}v[c+3|0]=11;v[c+5|0]=d<<4;continue}v[c+3|0]=11;v[c+5|0]=d|240;continue}v[c+3|0]=11;v[c+5|0]=d&15;continue}v[c+3|0]=2;v[c+5|0]=d|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=d|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=d|16;continue}v[c+3|0]=6;v[c+5|0]=d<<4;continue}v[c+3|0]=6;v[c+5|0]=d&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=d|48;continue}v[c+3|0]=7;v[c+5|0]=d<<4;continue}v[c+3|0]=7;v[c+5|0]=d&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=d|64;continue}v[c+3|0]=10;x[23604]=0;d=S(192,g|0)|0;j=x[23604];x[23604]=0;if((j|0)!=1){v[c+5|0]=d;x[23604]=0;Q(174,g|0,1)|0;c=x[23604];x[23604]=0;if((c|0)!=1){continue}}break c}v[c+3|0]=15;v[c+5|0]=d&15;continue}v[c+3|0]=20;v[c+5|0]=d|192;continue}v[c+3|0]=20;v[c+5|0]=d|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=d|176;continue}v[c+3|0]=20;v[c+5|0]=d|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=d&15|32;continue}v[c+3|0]=20;v[c+5|0]=d&15|128;continue}v[c+3|0]=0;continue}break}if((c|0)==64){break o}he(ac(x[k>>2],f),vh(Ce(ye(e+96|0,14,0),c-1|0)))}yb(g)}f=f+1|0;continue}break}break c}c=z[e+218>>1]|z[e+220>>1]<<16;if(!c){break d}Yc(b,c);XA(a+1298332|0,b,Cg(b),4)}hb=e+272|0;return i|0}a=P()|0;break a}a=P()|0}yb(g);T(a|0);p()}function sp(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:h;r=x[b+752>>2];a:{j=y[b+802|0];b:{if(!j){if(Tb(a+1074312|0,11)){break b}}c:{d:{if(!h){break d}if(!Tc(j)){break d}e:{g=h+236|0;j=j-1|0;if(z[cc(g,j)>>1]){break e}if(!Tb(a+1074312|0,43)){break e}if(bj(y[h+31|0])){break e}x[b+656>>2]=h;return}if(y[Gb(h+108|0,j)|0]>120){break b}j=z[cc(g,j)>>1];n=(j-1&65535)>>>0<3999?(D(j,104)+a|0)+484380|0:0;break c}if(!z[a+480192>>1]){n=(D(c,104)+a|0)+484380|0;break c}if(j>>>0>250){break b}if(!Tb(a+1074312|0,43)){break c}if(h){if(bj(y[h+31|0])){break c}}v[b+803|0]=0;x[b+656>>2]=0;return}j=x[b+104>>2];l=(j|0)!=0&(j|0)!=(n|0);g=x[b+656>>2];o=!h|x[a+480180>>2]!=16777216?o:x[h+44>>2]!=0;p=d^1;j=(g|0)!=(h|0);if((p|j|l)==1){w[b+774>>1]=0}q=!l;if(!(q|(j|!(d&o)))){break b}f:{if(!(d&l)){break f}m=a+1074312|0;if(!(!Tb(m,32)|!(y[a+480208|0]&8))){n=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:n}i=x[a+480180>>2];g:{if(!(h?j|!(i&1048580):1)|(i|0)==268435456){break g}if((i|0)==1){if(ki(x[b+8>>2],x[b+12>>2])){break g}}if(!Tb(m,79)){break f}if(!ki(x[b+8>>2],x[b+12>>2])){break f}}k=1}h:{if(!x[b+16>>2]|(j|!z[a+480192>>1]|q)){break h}if(!Tb(a+1074312|0,87)){break h}k=Tc(y[b+788|0])^1|k}m=(g|0)!=(h|0);i:{if(ki(x[b+8>>2],x[b+12>>2])|!(x[a+480180>>2]&16777248)){break i}if(h){if(bj(y[h+31|0])){break i}}m=1}j:{k:{if(!(l|m)|!d){break k}if(!Tb(a+1074312|0,61)){break k}i=x[b+656>>2];g=x[b+104>>2];j=0;if(i|g){break j}}x[b+656>>2]=h;g=n;i=h;j=m}l:{m:{n:{if(!e){break n}o:{if(y[a+480180|0]&3){if(g){if(Qd(x[g>>2],x[g+20>>2])){break o}}if(!Ij(i)){break n}}if(!g){break m}}if(w[g+34>>1]<0){break n}x[b+688>>2]=z[g+30>>1]}h=(g|0)!=0;if(!(k&l)|!g){break l}if(Tb(a+1074312|0,85)){w[b+772>>1]=v[g+37|0]}h=1;if(x[a+480180>>2]!=2){break l}if(!Qd(x[g>>2],x[g+20>>2])){break l}x[b+704>>2]=x[g+24>>2];break l}if(!(!i|!y[i+34|0])){h=x[b+688>>2];if(i){h=x[i+4>>2]<<2}x[b+688>>2]=h;h=0;break l}h=0;x[b+688>>2]=0}if(k){break b}v[b+803|0]=0;p:{if(!i){break p}if(!((Tb(a+1074312|0,29)^-1)&h)&(j|y[i+34|0]!=0)!=1){break p}v[b+798|0]=y[i+16|0]}k=64;x[b+752>>2]=64;if(g){k=z[g+32>>1];x[b+752>>2]=k}if(i){x[b+752>>2]=D(x[i+4>>2],k)>>>6}q:{if(!(x[a+480180>>2]&1048580?e:1)){break q}if(Tb(a+1074312|0,48)){break q}cN(a,b,i,g)}r:{s:{t:{if(!f){break t}u:{v:{w:{x:{y:{z:{A:{B:{f=a+1074312|0;if(Tb(f,19)){if(!x[b+76>>2]){e=1;break A}if(!(!c|p)){e=(y[a+480208|0]&8)>>>3|0;if(e){break A}break B}e=0;if(c){break B}break A}C:{c=x[a+480180>>2]&17301536;e=1;D:{if(!d|!c){break D}c=1;e=1;if(y[a+480208|0]&8){break D}e=1;if(!x[b+76>>2]){break D}if(!(y[b+89|0]&16)){break C}e=!x[b+696>>2]}if(!i|(j|!c)){break y}if(!e){break u}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break x}break z}if((j|!i)!=1){break u}break v}if(d){break A}if(!(y[b+89|0]&24)){e=0;break A}e=(y[a+480208|0]&4)>>>2|0}if(j|!x[b+696>>2]){break y}if(!e){break v}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(!i){break w}if(c&2048){break x}}if(!(y[i+60|0]&8)){Yi(b+724|0)}if(!(y[i+80|0]&8)){Yi(b+732|0)}if(y[i+100|0]&8){break w}Yi(b+740|0);break w}if(!e){break v}x[b+88>>2]=x[b+88>>2]|2097152;if(!i){break w}}Xl(b)}if(Tb(f,21)){break t}v[b+818|0]=0;x[b+756>>2]=0;break t}if(!i){break s}}if(v[i+60|0]&1){break t}if(Tb(f,32)){Yi(b+724|0);break t}Xl(b)}c=0;if(g){break r}if(!i){break a}c=1;if(bj(y[i+31|0])){break r}break a}c=0;if(!g){break a}}E:{if(!(!d|(h^1|x[b+104>>2]!=(g|0)))){e=x[a+480180>>2];if(x[b+76>>2]?e&16777250:0){break b}F:{G:{if((e|0)!=4){break G}if(!Tb(a+1074312|0,40)|y[b+789|0]){break G}e=x[b+88>>2];break F}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break E}x[b+88>>2]=x[b+88>>2]&-6145;e=a+1074312|0;H:{I:{if(!Tb(e,18)){h=-640;if(j|(x[a+480180>>2]&16777248|x[b+104>>2]!=(g|0))){break I}break H}h=-640;if((j|x[b+104>>2]!=(g|0))!=1){break H}}h=-768}x[b+88>>2]=x[b+88>>2]&h;if(!i){break E}v[b+730|0]=y[i+60|0];v[b+738|0]=y[i+80|0];v[b+746|0]=y[i+100|0];J:{if((y[i+100|0]&17)!=17){break J}if(Tb(e,36)|y[b+837|0]){break J}v[b+837|0]=127}e=y[i+21|0];if(re(e)){s=b,t=mj(e),v[s+837|0]=t}e=y[i+22|0];if(!re(e)){break E}s=b,t=mj(e),v[s+838|0]=t}if(c){x[b+76>>2]=0;x[b+104>>2]=0;return}K:{if(x[b+76>>2]|!d){break K}c=a+1074312|0;if(!Tb(c,54)){if(!Tb(c,39)){break K}}x[b+8>>2]=0;x[b+12>>2]=0}L:{if(y[b+788|0]!=255){break L}if(!Tb(a+1074312|0,100)|(!(y[a+480208|0]&4)|q)){break L}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+752>>2]=r;x[b+688>>2]=z[g+30>>1];if(!(y[g+34|0]&32)){break b}Bp(b,z[g+28>>1],a);return}x[b+104>>2]=g;x[b+76>>2]=x[g>>2];x[b+80>>2]=x[g+4>>2];x[b+84>>2]=x[g+8>>2];c=a+1074312|0;if(!(!Tb(c,83)|x[b+80>>2])){x[b+84>>2]=x[g>>2]}x[b+88>>2]=x[b+88>>2]|z[g+34>>1]&1023;if(Tb(c,21)){v[b+818|0]=0;x[b+756>>2]=0}M:{N:{if(o){x[b+704>>2]=x[g+24>>2];v[b+851|0]=y[b+851|0]|64;d=0;break N}if(!(l|p)){d=x[a+480180>>2];if(d&5){break M}}x[b+704>>2]=x[g+24>>2];d=v[g+37|0]}w[b+772>>1]=d;d=x[a+480180>>2]}if(lm(d)){d=v[g+36|0]}else{d=0}w[b+770>>1]=d;if(!(Tb(c,69)|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+852>>2]=0;h=x[b+88>>2];if(h&8){x[b+80>>2]=x[g+12>>2];x[b+84>>2]=x[g+16>>2];h=h>>>2&4|h|2;x[b+88>>2]=h}O:{if(!(h&2)){h=x[b+76>>2];break O}h=x[b+76>>2];c=x[b+84>>2];if(h>>>0<=c>>>0){break O}x[b+76>>2]=c;h=c}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<h>>>0){break b}x[b>>2]=0;x[b+4>>2]=0}return}x[b+752>>2]=0;x[b+104>>2]=0}function Wda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;e=hb-224|0;hb=e;xc(b);a:{if(!xt(b,e+160|0)){break a}if(!jQ(e+160|0)){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(iQ(e+160|0),lb))){break a}if(!c){d=1;break a}Cd(a,256);f=e+144|0;jj(f,2,e+160|0);d=e+48|0;Dc(d,f);Ab(a+1298308|0,d);xb(d);f=z[e+210>>1];x[a+480260>>2]=64;x[a+480264>>2]=32767;w[a+480188>>1]=4;w[a+480190>>1]=f;Nb(a+1074312|0,107,1);f=y[e+203|0];f=f?f:96;k=Fz(f);x[a+480196>>2]=f>>>4;x[a+480204>>2]=k;v[e+48|0]=64;E=a,F=y[Wb(e+202|0,d)|0]<<2,x[E+480200>>2]=F;d=0;b:{c:{d:{e:{f:{g:{while(1){if((d|0)==4){h:{k=Sb(e+144|0);m=Sb(e+128|0);x[23604]=0;Q(141,b|0,z[e+192>>1]<<4)|0;d=x[23604];x[23604]=0;i:{if((d|0)==1){break i}x[23604]=0;W(203,b|0,k|0,z[e+208>>1])|0;d=x[23604];x[23604]=0;if((d|0)==1){break i}x[23604]=0;Q(141,b|0,z[e+194>>1]<<4)|0;d=x[23604];x[23604]=0;if((d|0)==1){break i}x[23604]=0;W(203,b|0,m|0,z[e+210>>1])|0;d=x[23604];x[23604]=0;if((d|0)==1){break i}x[23604]=0;Q(141,b|0,(z[e+196>>1]<<4)+32|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break i}d=a+484376|0;f=y[d|0];g=x[a+484360>>2];x[23604]=0;R(308,_b(g,f)|0,z[e+212>>1]);f=x[23604];x[23604]=0;if((f|0)==1){break i}d=_b(x[a+484360>>2],y[d|0]);E=e,F=Bb(x[d>>2]),x[E+48>>2]=F;d=Bb(x[d+4>>2]);j:{while(1){f=x[e+48>>2];if(!Ob(f,d)){d=0;if(!lQ(_b(x[a+484360>>2],y[a+484376|0]))){break b}g=c&2;j=e+48|1;d=1;break j}x[23604]=0;g=S(192,b|0)|0;j=x[23604];x[23604]=0;k:{if((j|0)==1){break k}w[f>>1]=g;x[23604]=0;Q(174,b|0,4)|0;f=x[23604];x[23604]=0;if((f|0)==1){break k}Pe(e+48|0);continue}break}b=P()|0;break c}l:{m:{n:{o:{while(1){f=d&65535;if(f>>>0>z[e+210>>1]){break l}i=cc(x[m>>2],f-1|0);i=y[i|0]|y[i+1|0]<<8;x[23604]=0;i=Q(141,b|0,i<<4)|0;h=x[23604];x[23604]=0;p:{if((h|0)!=1){if(i){break p}d=0;break b}b=P()|0;break c}x[23604]=0;Q(621,b|0,e+48|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break o}x[23604]=0;i=(D(f,104)+a|0)+484380|0;U(622,e+48|0,i|0,0);h=x[23604];x[23604]=0;if((h|0)==1){break o}h=e+16|0;Wj(h,2,j);x[23604]=0;R(208,e+32|0,h|0);h=x[23604];x[23604]=0;if((h|0)==1){break n}h=((f<<5)+a|0)+946304|0;f=e+32|0;Bc(h,f);xb(f);q:{r:{if(!g|!x[e+64>>2]){break r}f=yQ(e+48|0);x[23604]=0;f=Q(141,b|0,f|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break m}if(!f){break r}f=e+32|0;xQ(f,y[e+78|0],y[e+79|0],1);x[23604]=0;W(205,f|0,i|0,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break q}}d=d+1|0;continue}break}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}v[e+15|0]=1;d=x[k>>2];s:{if(tc(d,x[k+4>>2])|z[e+188>>1]==26){break s}f=y[d|0]|y[d+1|0]<<8;d=0;x[23604]=0;f=Q(141,b|0,f<<4)|0;g=x[23604];x[23604]=0;if((g|0)==1){break h}if(!f){break b}x[23604]=0;d=S(180,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break h}if((d|0)!=z[e+188>>1]){break s}v[e+15|0]=0}n=c&1;if(n){x[23604]=0;R(211,a+484344|0,z[e+208>>1]);c=x[23604];x[23604]=0;if((c|0)==1){break h}}i=a+484344|0;c=e+48|0;q=c|5;r=c|3;s=c|4;t=c|2;u=c|1;A=a+480188|0;f=0;while(1){t:{if(!n|z[e+208>>1]<=f>>>0){break t}x[23604]=0;c=W(212,i|0,f&65535,64)|0;d=x[23604];x[23604]=0;if((d|0)==1){break g}if(!c){break t}c=cc(x[k>>2],f);c=y[c|0]|y[c+1|0]<<8;x[23604]=0;c=Q(141,b|0,c<<4)|0;d=x[23604];x[23604]=0;if((d|0)==1){break g}d=0;if(!c){break b}if(!y[e+15|0]){x[23604]=0;c=S(180,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}w[e+16>>1]=65535;x[e+32>>2]=63;u:while(1){c=ac(x[i>>2],f);B=of(x[c>>2],x[x[c+48>>2]+12>>2],d);v:while(1){c=d;while(1){if(c>>>0<=63){x[23604]=0;d=S(192,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break f}h=d<<24>>24;if(!h){d=64;if(c>>>0>62){continue v}d=c+1|0;continue u}d=h&31;g=D(d,6)+B|0;l=Oh(e+48|0);j=d>>>0<z[A>>1];o=j?g:l;l=h&255;if(l&32){x[23604]=0;R(245,e|0,b|0);d=x[23604];x[23604]=0;w:{x:{y:{if((d|0)!=1){C=hd(e);d=y[e|0];if(d>>>0>239){break y}d=wQ((D(d>>>4|0,12)+(d&15)|0)+37|0);break x}b=P()|0;break c}z:{switch(d-254|0){case 0:break x;case 1:break z;default:break w}}d=0}v[o|0]=d}v[(j?g+1|0:u)|0]=y[C|0]}if(l&64){x[23604]=0;d=S(192,b|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break e}v[e|0]=d;v[(j?g+2|0:t)|0]=1;v[e+14|0]=64;E=j?g+4|0:s,F=y[Wb(e,e+14|0)|0],v[E|0]=F}if((h|0)>=0){continue}x[23604]=0;R(245,e|0,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break d}v[(j?g+3|0:r)|0]=y[e|0];E=j?g+5|0:q,F=y[hd(e)|0],v[E|0]=F;kQ(o,c,255,e+16|0,e+32|0);continue}break}break}break}c=z[e+16>>1];if((c|0)!=65535){he(ac(x[i>>2],f),om(Ce(ye(e+48|0,12,c&255),x[e+32>>2])))}f=f+1|0;continue}break}x[23604]=0;b=Q(1,e+48|0,6049)|0;c=x[23604];x[23604]=0;A:{B:{C:{if((c|0)!=1){Ab(a+1298344|0,b);xb(b);x[23604]=0;b=Q(1,e+32|0,5235)|0;c=x[23604];x[23604]=0;if((c|0)==1){break C}Ab(a+1298356|0,b);xb(b);x[a+1298404>>2]=5;x[23604]=0;R(624,e|0,4366);b=x[23604];x[23604]=0;if((b|0)==1){break B}x[23604]=0;U(289,e+16|0,e|0,e+15|0);b=x[23604];x[23604]=0;if((b|0)==1){break A}b=a+1298368|0;a=e+16|0;Ab(b,a);xb(a);Db(e);d=1;break b}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;Db(e);break c}b=P()|0;break c}}else{f=(d<<5)+a|0;Qe(f+480280|0);w[f+480284>>1]=d&1?64:192;d=d+1|0;continue}break}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0}nd(m);nd(k);T(b|0);p()}nd(m);nd(k)}hb=e+224|0;return d|0}function tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=hb-208|0;hb=d;xc(c);a:{if(!ho(c,d+192|0)){break a}if(Rb(d+192|0,13679,4)){break a}f=d+200|0;if(Rb(f,14048,4)){if(Rb(f,14152,4)){break a}}e=hb-32|0;hb=e;i=d+176|0;g=Sb(i);b:{c:{d:{e:{f:{while(1){h=x[c+8>>2];j=x[c>>2];x[23604]=0;h=W(142,j|0,h|0,8)|0;j=x[23604];x[23604]=0;if((j|0)==1){break d}if(!h){break e}x[23604]=0;R(740,e|0,c|0);h=x[23604];x[23604]=0;if((h|0)!=1){x[23604]=0;R(741,g|0,e|0);h=x[23604];x[23604]=0;if((h|0)==1){break f}Md(e);continue}break}a=P()|0;break c}a=P()|0;Md(e);break c}hb=e+32|0;break b}a=P()|0}Xd(g);T(a|0);p()}x[23604]=0;U(668,d+152|0,i|0,1129270605);c=x[23604];x[23604]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){x[23604]=0;c=Q(669,d+152|0,d+128|0)|0;e=x[23604];x[23604]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!dc(z[d+130>>1]|z[d+132>>1]<<16)){break g}if((Lb(z[d+128>>1])-3&65535)>>>0<65534){break g}if((Lb(z[d+134>>1])-65&65535)>>>0<65472){break g}x[d+124>>2]=1162760014;c=1;if(!Rb(f,14152,4)){x[23604]=0;c=Q(557,d+152|0,d+124|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break o}if(!c){break g}c=x[d+124>>2]!=1936684916}x[23604]=0;U(668,d+104|0,d+176|0,1397968452);e=x[23604];x[23604]=0;p:{q:{if((e|0)!=1){x[23604]=0;k=Q(670,d+104|0,d+96|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break p}if(k){break q}break h}c=P()|0;break j}e=(Lb(z[d+134>>1])-1|0)/8|0;g=e<<3;f=g&31;g=Xc(d+88|0,(e>>>0>=8?8:(g&63)>>>0>=32?1074268168>>>f|0:((1<<f)-1&1074268168)<<32-f|538447880>>>f)&255,(Lb(z[d+128>>1])|0)==2?2:1,c,0);c=x[d+124>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}Lf(g,3);break r}Lf(g,17);id(g,16);break r}Lf(g,16);id(g,16);break r}Lf(g,1)}c=x[d+96>>2];x[23604]=0;c=W(142,x[d+104>>2],x[d+112>>2],dc(c)|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}if(c){c=x[d+96>>2];x[23604]=0;Q(174,d+104|0,dc(c)|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break l}}Ss(a,b);x[23604]=0;i=D(b,104)+a|0;h=i+484380|0;R(262,h|0,0);c=x[23604];x[23604]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((c|0)==1){break D}s=h,t=dc(z[d+130>>1]|z[d+132>>1]<<16),x[s>>2]=t;c=y[d+138|0]|y[d+139|0]<<8|(y[d+140|0]<<16|y[d+141|0]<<24);f=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);j=30-y[d+137|0]|0;e=0;while(1){c=f;if(j&255){f=c>>>1|0;j=j-1|0;e=c;continue}break}x[i+484404>>2]=c+(e&1);x[23604]=0;W(205,g|0,h|0,d+104|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break D}x[23604]=0;U(668,d- -64|0,d+176|0,1296126539);c=x[23604];x[23604]=0;if((c|0)==1){break C}x[23604]=0;c=S(164,x[d+64>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break B}if(!c){break u}x[23604]=0;U(668,d+16|0,d+176|0,1229869908);c=x[23604];x[23604]=0;if((c|0)==1){break A}x[23604]=0;c=Q(671,d+16|0,d+40|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break z}yb(d+16|0);if(!c){break u}x[23604]=0;f=S(256,d- -64|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break y}e=Sb(d+16|0);x[23604]=0;R(672,e|0,f|0);c=x[23604];x[23604]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}x[23604]=0;g=Q(673,d- -64|0,d|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break w}if(!g){break x}x[23604]=0;R(674,e|0,d|0);g=x[23604];x[23604]=0;if((g|0)==1){break w}x[23604]=0;Q(174,d- -64|0,y[d+6|0]|1)|0;g=x[23604];x[23604]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=P()|0;break k}c=P()|0;break k}c=P()|0;break m}c=P()|0;break m}c=P()|0;yb(d+16|0);break m}c=P()|0;break m}c=Lb(z[d+48>>1]);if(c){f=i+484414|0;w[f>>1]=z[f>>1]&65511|((c|0)==2)<<4|8}c=Lb(z[d+54>>1]);if(c){f=i+484414|0;w[f>>1]=z[f>>1]&65529|((c|0)==2?4:2)|2}s=d,t=Bb(x[e>>2]),x[s>>2]=t;g=Bb(x[e+4>>2]);j=z[d+50>>1];l=i+484392|0;m=z[d+52>>1];n=i+484396|0;o=z[d+56>>1];q=i+484384|0;r=z[d+58>>1];i=i+484388|0;while(1){c=x[d>>2];if(!Ob(c,g)){break v}f=Lb(y[c|0]|y[c+1|0]<<8);if((f|0)==(Lb(j)|0)){s=l,t=dc(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Lb(y[c|0]|y[c+1|0]<<8)}if((Lb(m)|0)==(f|0)){s=n,t=dc(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Lb(y[c|0]|y[c+1|0]<<8)}if((Lb(o)|0)==(f|0)){s=q,t=dc(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Lb(y[c|0]|y[c+1|0]<<8)}if((f|0)==(Lb(r)|0)){s=i,t=dc(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t}x[d>>2]=x[d>>2]+7;continue}}c=P()|0;NN(e);break m}ek(h);NN(e)}x[23604]=0;U(668,d+16|0,d+176|0,1312902469);c=x[23604];x[23604]=0;if((c|0)==1){break n}x[23604]=0;c=S(164,x[d+16>>2])|0;e=x[23604];x[23604]=0;E:{if((e|0)==1){break E}F:{if(c){x[23604]=0;c=S(146,x[d+16>>2])|0;e=x[23604];x[23604]=0;if((e|0)==1){break E}x[23604]=0;U(298,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break F}break E}x[23604]=0;c=Q(54,d|0,21502)|0;e=x[23604];x[23604]=0;if((e|0)==1){break E}Bc(((b<<5)+a|0)+946304|0,c);xb(c)}kz(h,x[a+480180>>2]);aj(h,a);yb(d+16|0);yb(d- -64|0);break h}c=P()|0;yb(d+16|0);break m}c=P()|0;break k}c=P()|0;break j}c=P()|0;break j}c=P()|0;break m}c=P()|0;break i}yb(d- -64|0);break k}c=P()|0}yb(d+104|0)}yb(d+152|0)}Xd(d+176|0);T(c|0);p()}yb(d+104|0)}yb(d+152|0);Xd(d+176|0)}hb=d+208|0;return k|0}function rH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0;j=hb-80|0;hb=j;x[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((p^2147483647)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=y[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(y[i+1|0]!=37){b=i;break j}h=h+1|0;m=y[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;B=p^2147483647;if((h|0)>(B|0)){break d}if(a){gf(a,k,h)}if(h){continue e}x[j+76>>2]=b;h=b+1|0;q=-1;i=v[b+1|0];if(!(!Dj(i)|y[b+2|0]!=36)){q=i-48|0;u=1;h=b+3|0}x[j+76>>2]=h;n=0;i=v[h|0];b=i-32|0;k:{if(b>>>0>31){o=h;break k}o=h;b=1<<b;if(!(b&75913)){break k}while(1){o=h+1|0;x[j+76>>2]=o;n=b|n;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=o;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){b=v[o+1|0];m:{if(!(!Dj(b)|y[o+2|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;i=o+3|0;u=1;b=x[((v[o+1|0]<<3)+d|0)-384>>2];break m}if(u){break h}i=o+1|0;if(!a){x[j+76>>2]=i;u=0;r=0;break l}b=x[c>>2];x[c>>2]=b+4;u=0;b=x[b>>2]}x[j+76>>2]=i;r=b;if((b|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=qH(j+76|0);if((r|0)<0){break d}i=x[j+76>>2]}h=0;l=-1;n:{if(y[i|0]!=46){b=i;A=0;break n}if(y[i+1|0]==42){b=v[i+2|0];o:{if(!(!Dj(b)|y[i+3|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;b=i+4|0;l=x[((v[i+2|0]<<3)+d|0)-384>>2];break o}if(u){break h}b=i+2|0;l=0;if(!a){break o}i=x[c>>2];x[c>>2]=i+4;l=x[i>>2]}x[j+76>>2]=b;A=(l^-1)>>>31|0;break n}x[j+76>>2]=i+1;l=qH(j+76|0);b=x[j+76>>2];A=1}while(1){t=h;o=28;m=b;h=v[b|0];if(h-123>>>0<4294967238){break c}b=m+1|0;h=y[(h+D(t,58)|0)+75919|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){x[(q<<2)+e>>2]=h;i=(q<<3)+d|0;h=x[i+4>>2];x[j+64>>2]=x[i>>2];x[j+68>>2]=h;break q}if(!a){break f}pH(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=5247;o=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=v[m|0];h=t?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}i=x[j+64>>2];m=x[j+68>>2];z=5247;break z}h=0;I:{switch(t&255){case 0:x[x[j+64>>2]>>2]=p;continue e;case 1:x[x[j+64>>2]>>2]=p;continue e;case 2:k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e;case 3:w[x[j+64>>2]>>1]=p;continue e;case 4:v[x[j+64>>2]]=p;continue e;case 6:x[x[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e}l=l>>>0<=8?8:l;n=n|8;h=120}k=s;F=h&32;i=x[j+64>>2];m=x[j+68>>2];if(i|m){while(1){k=k-1|0;v[k|0]=F|y[(i&15)+76448|0];G=!m&i>>>0>15|(m|0)!=0;t=m;m=m>>>4|0;i=(t&15)<<28|i>>>4;if(G){continue}break}}if(!(n&8)|!(x[j+64>>2]|x[j+68>>2])){break y}z=(h>>>4|0)+5247|0;q=2;break y}h=s;k=x[j+68>>2];m=k;i=x[j+64>>2];if(k|i){while(1){h=h-1|0;v[h|0]=i&7|48;t=!m&i>>>0>7|(m|0)!=0;k=m;m=k>>>3|0;i=(k&7)<<29|i>>>3;if(t){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}i=x[j+64>>2];h=x[j+68>>2];m=h;if((h|0)<0){k=0-(m+((i|0)!=0)|0)|0;m=k;i=0-i|0;x[j+64>>2]=i;x[j+68>>2]=k;q=1;z=5247;break z}if(n&2048){q=1;z=5248;break z}q=n&1;z=q?5249:5247}k=on(i,m,s)}if((l|0)<0?A:0){break d}n=A?n&-65537:n;h=x[j+64>>2];i=x[j+68>>2];if(!((h|i)!=0|l)){k=s;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=x[j+64>>2];k=h?h:16920;m=l>>>0>=2147483647?2147483647:l;h=Ct(k,0,m);h=h?h-k|0:m;o=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(y[o|0]){break d}break g}if(l){i=x[j+64>>2];break u}h=0;sf(a,32,r,0,n);break t}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;J:{while(1){k=x[i>>2];if(!k){break J}m=oH(j+4|0,k);k=(m|0)<0;if(!(k|m>>>0>l-h>>>0)){i=i+4|0;h=h+m|0;if(l>>>0>h>>>0){continue}break J}break}if(k){break b}}o=61;if((h|0)<0){break c}sf(a,32,r,h,n);if(!h){h=0;break t}o=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break t}k=oH(j+4|0,k);o=k+o|0;if(o>>>0>h>>>0){break t}gf(a,j+4|0,k);i=i+4|0;if(h>>>0>o>>>0){continue}break}}sf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?A:0){break d}o=61;h=mb[f|0](a,C[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}v[j+55|0]=x[j+64>>2];l=1;k=E;n=i;break g}i=y[h+1|0];h=h+1|0;continue}}if(a){break a}if(!u){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){pH((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}o=28;break c}m=o-k|0;i=(l|0)>(m|0)?l:m;if((i|0)>(q^2147483647)){break d}o=61;l=i+q|0;h=(l|0)<(r|0)?r:l;if((B|0)<(h|0)){break c}sf(a,32,h,l,n);gf(a,z,q);sf(a,48,h,l,n^65536);sf(a,48,i,m,0);gf(a,k,m);sf(a,32,h,l,n^8192);continue}break}p=0;break a}o=61}x[116080]=o}p=-1}hb=j+80|0;return p}function hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;f=hb-224|0;hb=f;if(wh(b,13694)){if(d){v[d|0]=1}k=a+480204|0;n=a+480216|0;o=a+480220|0;q=a+480224|0;l=a+1074368|0;t=a+480228|0;u=a+480232|0;r=a+480200|0;m=a+480268|0;B=a+1298320|0;C=a+480248|0;E=Qt(a+1074312|0);F=a+480180|0;G=a+484376|0;H=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Qb(x[b>>2],x[b+8>>2],7)){break a}e=kg(b);g=Cg(b);if((e|0)==(y[21478]|y[21479]<<8|(y[21480]<<16|y[21481]<<24))){hg(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Qb(x[b>>2],x[b+8>>2],g)){break a}d=f+176|0;Ud(d,b,g);h=kc(f+200|0,d);yb(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=u;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=n;if((e|0)==1380991534){break s}d=o;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=t;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}x[23604]=0;U(385,h|0,g|0,f+176|0);d=x[23604];x[23604]=0;if((d|0)==1){break i}x[k>>2]=D(x[f+176>>2],1e4)+(A[k>>2]%1e4|0);break j}x[23604]=0;U(385,h|0,g|0,f+176|0);d=x[23604];x[23604]=0;if((d|0)!=1){d=x[k>>2];x[k>>2]=d-((d>>>0)%1e4|0)+A[f+176>>2]%1e4;break j}e=P()|0;break b}if(c){break j}x[23604]=0;w[f+176>>1]=0;U(386,h|0,g|0,f+176|0);d=x[23604];x[23604]=0;if((d|0)!=1){I=a,J=Td(z[f+176>>1],z[a+480188>>1],127),w[I+480188>>1]=J;break j}e=P()|0;break b}x[23604]=0;U(387,h|0,g|0,l|0);d=x[23604];x[23604]=0;if((d|0)!=1){break j}break c}x[23604]=0;x[f+176>>2]=0;U(385,h|0,g|0,f+176|0);d=x[23604];x[23604]=0;if((d|0)!=1){x[a+1074304>>2]=x[f+176>>2];break j}e=P()|0;break b}x[23604]=0;x[f+176>>2]=0;U(385,h|0,g|0,f+176|0);d=x[23604];x[23604]=0;if((d|0)==1){break h}d=x[f+176>>2];if(!d){break j}x[a+1074308>>2]=d;break j}d=r}x[23604]=0;U(385,h|0,g|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break c}break j}if(x[F>>2]==4){break j}x[23604]=0;U(386,h|0,g|0,f+176|0);d=x[23604];x[23604]=0;if((d|0)!=1){Xe(_b(x[a+484360>>2],y[G|0]),z[f+176>>1]);break j}e=P()|0;break b}x[23604]=0;U(388,h|0,g|0,m|0);d=x[23604];x[23604]=0;if((d|0)==1){break c}if(ro(y[m|0])){break j}v[m|0]=5;break j}d=Kb(f+176|0);e=x[h>>2];x[23604]=0;e=S(146,e|0)|0;g=x[23604];x[23604]=0;x:{if((g|0)==1){break x}x[23604]=0;U(389,h|0,d|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break x}x[23604]=0;U(11,f+160|0,0,d|0);e=x[23604];x[23604]=0;if((e|0)==1){break x}e=f+160|0;Ab(B,e);xb(e);xb(d);break j}e=P()|0;xb(d);break b}if(g&1|g>>>0>126){break j}d=64;w[f+176>>1]=(g>>>1|0)- -64;w[f+160>>1]=127;e=z[Wc(f+176|0,f+160|0)>>1];i=e>>>0<=64?64:e;while(1){if((d|0)==(i|0)){break j}x[23604]=0;R(245,f+176|0,h|0);e=x[23604];x[23604]=0;if((e|0)==1){break g}e=y[f+176|0];y:{if((e|0)==255){break y}j=y[hd(f+176|0)|0];g=(d<<5)+a|0;s=g+480284|0;w[s>>1]=128;w[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;x[g>>2]=j;e=e&127;if(e>>>0<65){w[s>>1]=e<<2;break y}if((e|0)!=100){break y}x[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}x[23604]=0;d=S(180,h|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break f}if(!d|d>>>0>z[H>>1]){break j}d=(D(d,104)+a|0)+484448|0;g=$S(d);while(1){if((d|0)==(g|0)){break j}e=x[h>>2];x[23604]=0;i=W(142,e|0,x[f+208>>2],4)|0;e=x[23604];x[23604]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}x[23604]=0;e=S(143,h|0)|0;i=x[23604];x[23604]=0;if((i|0)!=1){break z}}e=P()|0;break b}x[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}x[23604]=0;R(390,f|0,h|0);d=x[23604];x[23604]=0;A:{B:{C:{D:{if((d|0)!=1){x[23604]=0;U(391,f+176|0,x[f>>2],x[f+4>>2]);d=x[23604];x[23604]=0;if((d|0)==1){break D}x[23604]=0;d=Q(78,f+16|0,f+176|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break C}xb(f+176|0);fc(f);e=x[h>>2];x[23604]=0;S(146,e|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break A}x[23604]=0;R(392,d|0,C|0);e=x[23604];x[23604]=0;if((e|0)==1){break A}hf(d);break j}e=P()|0;break b}e=P()|0;break B}e=P()|0;xb(f+176|0)}fc(f);break b}e=P()|0;hf(d);break b}e=0;g=Qt(E);E:while(1){d=x[h>>2];x[23604]=0;d=W(142,d|0,x[f+208>>2],1)|0;i=x[23604];x[23604]=0;if((i|0)==1){break d}if(!(d&e>>>0<117)){break j}x[23604]=0;i=S(192,h|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>116){break F}x[23604]=0;W(249,g|0,e|0,1)|0;j=x[23604];x[23604]=0;if((j|0)!=1){break F}e=P()|0;break b}e=e+1|0;d=d+1|0;continue}}}x[23604]=0;U(393,h|0,g|0,q|0);d=x[23604];x[23604]=0;if((d|0)==1){break c}}yb(h);continue}break}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0}yb(h);T(e|0);p()}b=x[a+8>>2];yo(k,D(x[b+20>>2],1e4),D(x[b+24>>2],1e4));if(y[a+480224|0]>=3){v[q|0]=0}if(y[l|0]>=6){v[l|0]=0}wc(r,256);wc(n,65536);wc(o,65536)}hb=f+224|0}function pfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=hb-1824|0;hb=d;xc(b);e=hb-16|0;hb=e;h=d+1224|0;vR(e+8|0,h);i=x[e+12>>2];k=b;mc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);b=x[e+4>>2];if((b|0)==(i|0)){bc(k,x[e+12>>2])}hb=e+16|0;b=(b|0)==(i|0);if(!b){uR(h)}a:{if(!b){break a}if(!wR(d+1224|0)){break a}if(!_z(k,16,0)){break a}x[d+1216>>2]=x[d+1240>>2];b=x[d+1228>>2];x[d+1200>>2]=x[d+1224>>2];x[d+1204>>2]=b;b=d+1232|0;e=x[b+4>>2];x[d+1208>>2]=x[b>>2];x[d+1212>>2]=e;Cd(a,1);Nb(Nb(zf(a+1074312|0,83),84,1),85,1);w[a+480188>>1]=4;x[d+1196>>2]=0;w[a+480190>>1]=15;Yc(k,20);m=a+480188|0;f=1;i=1;while(1){b:{if((f|0)==16){b=d+1064|0;ER(k,b);e=a+484360|0;h=a+484376|0;mq(_b(x[e>>2],y[h|0]),b|2,128);f=0;m=DR(k,_b(x[e>>2],y[h|0]),y[d+1064|0],g,m,0,1);if(!(y[d+1065|0]|m>>>0>1|y[d+1064|0])){break a}if(cf(k)+65536>>>0<(m<<10)+g>>>0){break a}if(c){break b}f=1;break a}e=D(f,104)+a|0;h=e+484380|0;b=((f<<5)+a|0)+946304|0;$z(k,d+24|0,h,b,1);j=x[h>>2];c:{if(!y[Gb(b,0)|0]){break c}d:{if(Rb(b,16621,3)){if(Rb(b,16625,3)){break d}}if(y[Gb(b,5)|0]==58){break c}}i=0}b=Lb(z[d+52>>1]);if(b>>>0>=2){l=Lb(z[d+50>>1]);x[e+484384>>2]=l;x[e+484388>>2]=l+(b<<1);ek(h)}e:{if(Lb(z[d+46>>1])>>>0<=4999){if(Lb(z[d+50>>1])>>>0<1e4){break e}}x[d+1064>>2]=5;t=d,u=x[Je(d+1196|0,d+1064|0)>>2],x[t+1196>>2]=u}g=g+j|0;f=f+1|0;continue}break}f=y[d+1065|0];if(!f){v[d+1065|0]=120;f=120}f:{if(!Rb(d+1200|0,14798,6)){v[d+1065|0]=120;x[a+480204>>2]=125e4;break f}x[a+480204>>2]=125e4;if((f|0)==120){break f}t=a,u=Ge(1773447.5/(+(240-f|0)*122)*1e4),x[t+480204>>2]=u;if(x[d+1196>>2]>=2){x[d+24>>2]=i&1?4:5;t=d,u=x[Je(d+1196|0,d+24|0)>>2],x[t+1196>>2]=u;break f}x[d+24>>2]=i&1?1:2;t=d,u=x[Je(d+1196|0,d+24|0)>>2],x[t+1196>>2]=u}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;g=d+1048|0;jj(g,3,d+1200|0);b=d+24|0;Dc(b,g);Ab(a+1298308|0,b);xb(b);uh(a,0);q=i&1;r=x[k+8>>2];s=a+484376|0;g=0;while(1){g:{h:{if(m>>>0>(p&65535)>>>0){b=_b(x[a+484360>>2],y[s|0]);b=Ob(Uz(Bb(x[b>>2]),Bb(x[b+4>>2]),p),Bb(x[b+4>>2]));tR(k,d+24|0);if(b){g=Yz(d+24|0,0)+g|0;if(g>>>0>512){break h}}i=0;b=0;h=0;i:while(1){if((h|0)==64){break g}f=0;while(1)if((f|0)==4){h=h+1|0;continue i}else{e=b;o=zb(bd(d+24|0,h),f);l=y[Gb(o,2)|0]&15;j=y[Gb(o,3)|0];b=0;j:{if(!(e&255)){break j}if(Rb(o,27252,4)){break j}b=e+1|0;if((b&255)>>>0<33){break j}x[d+1196>>2]=6}k:{l:{m:{switch(l-1|0){case 0:case 1:e=x[d+1196>>2];if((e|0)==1&j>>>0>=32){break l}l=(l|0)!=1;if(!(l|!j|j>>>0>2)){x[d+1048>>2]=2;t=d,u=x[Je(d+1196|0,d+1048|0)>>2],x[t+1196>>2]=u;break k}if(l|(j|0)!=55&(j|0)!=71){break k}if((e|0)<=2){break l}break k;case 10:x[d+1196>>2]=6;break k;case 11:case 12:case 13:x[d+1048>>2]=2;t=d,u=x[Je(d+1196|0,d+1048|0)>>2],x[t+1196>>2]=u;if((l|0)!=13){break k}i=((h|j)!=0)+i|0;b=1;break k;case 14:break m;default:break k}}x[d+1048>>2]=3;t=d,u=x[Je(d+1196|0,d+1048|0)>>2],x[t+1196>>2]=u;break k}x[d+1196>>2]=q}f=f+1|0;continue}}}if(!(x[d+1196>>2]!=6|m+32>>>0>=n>>>0)){x[d+1196>>2]=5}Yc(k,r);o=c&1;if(o){gg(a+484344|0,m)}l=a+484344|0;n=0;while(1)if((m|0)==(n|0)){f=21502;b=x[d+1196>>2];if(b>>>0<7){f=x[(b<<2)+27264>>2]}b=d+24|0;g=Xb(b,8222);Ab(a+1298344|0,g);xb(g);b=Xb(b,10648);Ab(a+1298356|0,b);xb(b);Zc(a+1298368|0,f);x[a+1298404>>2]=13;if(!(c&2)){break h}f=1;while(1){if((f|0)==16){break h}b=D(f,104)+a|0;c=b+484384|0;bc(k,x[c>>2]);g=x[c>>2];x[c>>2]=0;c=b+484380|0;x[c>>2]=x[c>>2]-g;b=b+484388|0;x[b>>2]=x[b>>2]-g;b=d+24|0;Xc(b,8,1,1,0);fg(b,c,k);f=f+1|0;continue}}else{tR(k,d+24|0);n:{if(!o){break n}if(!Yg(l,n&65535,64)){break n}j=0;x[d+1048>>2]=0;o:while(1){if((j|0)==64){break n}f=0;b=ac(x[l>>2],n);q=cd(x[b>>2],x[x[b+48>>2]+12>>2],j,0);while(1)if((f|0)==4){j=j+1|0;continue o}else{b=zb(bd(d+24|0,j),f);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[d+12>>2]=b;x[d+16>>2]=b;e=q+D(f,6)|0;Tt(d+12|0,e);i=y[e+3|0];b=i;p:{q:{r:{g=y[e+5|0];if(g){b=14;if((i|0)!=14){break r}}v[(d+1048|0)+f|0]=0;if((b|g)&255){break q}break p}b=i;h=y[(d+1048|0)+f|0];if(!h){break q}s:{if(h>>>0>=16){v[e+2|0]=3;h=h>>>4|0;break s}v[e+2|0]=4}v[e+4|0]=h}t:{u:{v:{w:{x:{y:{switch((b&255)-12|0){case 1:b=x[d+1196>>2];if((b|0)==6){break u}i=10;v[e+3|0]=10;break v;case 0:g=g&127;break x;case 2:if(g>>>0<=1&x[d+1196>>2]>3){break t}i=10;v[e+3|0]=10;v[(d+1048|0)+f|0]=g;break w;case 3:break y;default:break w}}g=g&15}v[e+5|0]=g}b=x[d+1196>>2]}if((b|0)>1){break t}z:{A:{B:{switch(i|0){case 0:if(g>>>0>2){break A}break;case 2:break z;case 1:break A;default:break B}}v[e+3|0]=0;break p}v[e+3|0]=1;break p}b=g&15;if(b){v[e+3|0]=2;v[e+5|0]=b;break p}if(g>>>0<16){break p}v[e+3|0]=3;v[e+5|0]=g>>>4;break p}v[e+5|0]=0}Hf(e)}f=f+1|0;continue}}}n=n+1|0;continue}}f=m>>>0<=(p&65535)>>>0;break a}if((i-1&255)>>>0<2){x[d+1196>>2]=6}p=p+1|0;n=(i&255)+n|0;continue}}hb=d+1824|0;return f|0}function _da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-352|0;hb=d;Yc(b,60);h=15;a:{if(!wh(b,14e3)){Yc(b,124);h=31;if(!wh(b,15169)){break a}}Cd(a,536870912);w[a+480190>>1]=h;xc(b);b:{while(1){if(z[a+480190>>1]>f>>>0){e=rm(b);x[(d+224|0)+(f<<2)>>2]=e;f=f+1|0;if(e>>>0<=131072){continue}break b}break}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;f=0;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;uh(a,1);bc(b,4);e=pq(b);if(e>>>0<178){break a}q=a,r=Ge(1776930/+(e>>>0)*1e4),x[q+480204>>2]=r;bc(b,14);h=0;k=1;c:while(1){n=k&65535;if(n>>>0<=z[a+480190>>1]){zR(b,d+56|0);e=x[((n<<2)+d|0)+220>>2];l=hb-16|0;hb=l;g=(D(n,104)+a|0)+484380|0;od(g,1);x[g>>2]=e;v[g+37|0]=y[d+80|0]<<4;v[l+15|0]=y[d+81|0];v[l+14|0]=64;q=g,r=y[Wb(l+15|0,l+14|0)|0]<<2,w[q+30>>1]=r;d:{if(!e){break d}f=Lb(y[d+84|0]|y[d+85|0]<<8);j=Lb(y[d+82|0]|y[d+83|0]<<8);x[g+4>>2]=j;f=(f<<1)+j|0;x[g+8>>2]=f;if(e>>>0<=j>>>0){j=e-1|0;x[g+4>>2]=j}if(e>>>0<f>>>0){x[g+8>>2]=e;f=e}if(!(!(f>>>0<4|f>>>0<j>>>0)&f-j>>>0>3)){x[g+4>>2]=0;x[g+8>>2]=0;break d}if(f>>>0<=j>>>0){break d}w[g+34>>1]=z[g+34>>1]|2}hb=l+16|0;f=0;while(1)if((f|0)==22){if(h>>>0>127){break b}e=d+192|0;ml(e,3,d+56|0);f=d+208|0;Dc(f,e);Bc(((n<<5)+a|0)+946304|0,f);k=k+1|0;xb(f);continue c}else{e=(d+56|0)+f|0;if((y[e|0]-1&255)>>>0<=30){v[e|0]=32;h=h+1|0}f=f+1|0;continue}}break}j=1;e:{f:{g:{h=a+946336|0;f=Xb(d+56|0,13867);if(!rQ(h,f)){x[23604]=0;e=Q(54,d+208|0,13878)|0;g=x[23604];x[23604]=0;if((g|0)==1){break g}j=rQ(h,e);xb(e)}xb(f);f=0;e=d+56|0;h=yR(b,e);if(!h){Wz(e)}if(!h){break a}e=y[d+56|0];if(!uQ(e)){break a}if(!c){break e}w[d+54>>1]=0;while(1)if((e|0)==(f|0)){f=a+484360|0;h=a+484376|0;i=_b(x[f>>2],y[h|0]);g=y[d+57|0];Xe(i,e>>>0>g>>>0?g:0);mq(_b(x[f>>2],y[h|0]),d+56|2,y[d+56|0]);if(z[a+480190>>1]==31){bc(b,4)}x[d+48>>2]=0;x[d+44>>2]=0;x[d+40>>2]=0;v[d+39|0]=0;n=c&1;if(n){gg(a+484344|0,z[d+54>>1])}l=a+484344|0;k=0;while(1){h:{i:{j:{if(z[d+54>>1]<=k>>>0){if(!(c&2)){break j}f=1;while(1){h=z[a+480190>>1];c=f&65535;if(h>>>0<c>>>0){break i}c=(D(c,104)+a|0)+484380|0;if(x[c>>2]){fg(Xc(d+192|0,8,1,0,0),c,b)}f=f+1|0;continue}}k:{if(n){h=0;if(Yg(l,k&65535,64)){break k}}bc(b,1024);break h}l:while(1){if((h|0)==64){break h}f=0;e=ac(x[l>>2],k);o=cd(x[e>>2],x[x[e+48>>2]+12>>2],h,0);while(1)if((f|0)==4){h=h+1|0;continue l}else{g=d+192|0;xm(g,b);e=D(f,6)+o|0;m:{n:{o:{p:{if(y[Gb(g,0)|0]!=255){break p}v[(d+48|0)+f|0]=0;v[(d+40|0)+f|0]=0;g=Gb(d+192|0,1);i=y[g|0];if((i|0)==252&j){v[g|0]=254;break n}switch(i-252|0){case 1:break m;case 2:break n;case 0:break o;default:break p}}g=x[d+192>>2];x[d+32>>2]=g;x[d+12>>2]=g;Tt(d+12|0,e);g=y[e|0];q:{if(!g){break q}v[(d+40|0)+f|0]=0;v[(d+48|0)+f|0]=g;if(g>>>0>48){break q}v[d+16|0]=8;q=d,r=y[Ye(d+39|0,d+16|0)|0],v[q+39|0]=r}r:{s:{t:{u:{v:{w:{switch(y[e+3|0]){case 1:v[e+3|0]=1;break m;case 2:g=y[e+5|0];if(g>>>0>=16){v[e+3|0]=3;v[e+5|0]=g>>>4;break m}if(g){v[e+3|0]=2;v[e+5|0]=g;break m}v[e+5|0]=0;break s;case 3:if(y[(d+40|0)+f|0]){break t}v[e+3|0]=19;v[e+5|0]=0;break m;case 4:if(y[(d+40|0)+f|0]){break t}v[e+3|0]=19;v[e+5|0]=1;break m;case 5:if(!y[e+1|0]){break t}v[e+3|0]=13;v[d+16|0]=63;v[d+31|0]=y[e+5|0]+(z[(D(y[e+1|0],104)+a|0)+484410>>1]>>>2|0);q=e,r=y[Wb(d+16|0,d+31|0)|0],v[q+5|0]=r;if(!y[(d+40|0)+f|0]){break v}v[e+2|0]=1;v[e+4|0]=y[e+5|0];v[e+5|0]=0;break s;case 6:g=y[e+1|0];if(!g){break t}v[e+3|0]=13;g=z[(D(g,104)+a|0)+484410>>1]>>>2|0;i=y[e+5|0];g=g>>>0>=i>>>0?g-i|0:0;v[e+5|0]=g;if(!y[(d+40|0)+f|0]){break m}v[e+4|0]=g;v[e+2|0]=1;v[e+5|0]=0;break s;case 7:g=y[(d+48|0)+f|0];i=y[e+5|0];m=g-(i>>>4|0)|0;v[(d+44|0)+f|0]=m;v[e+3|0]=3;i=i&15;v[(d+40|0)+f|0]=i;q=e,r=qQ(i,m&255,g),v[q+5|0]=r;break m;case 8:i=y[(d+48|0)+f|0];g=y[e+5|0];m=i+(g>>>4|0)|0;v[(d+44|0)+f|0]=m;v[e+3|0]=2;g=g&15;v[(d+40|0)+f|0]=g;q=e,r=qQ(g,i,m&255),v[q+5|0]=r;break m;case 0:break u;case 9:break w;default:break s}}v[d+16|0]=8;q=d,r=y[Ye(d+39|0,d+16|0)|0],v[q+39|0]=r;break s}if(!y[e+3|0]){break r}break m}if(!y[e+5|0]){break r}break s}v[e+5|0]=0}v[e+3|0]=0}i=y[(d+40|0)+f|0];if(!i){break m}m=(d+44|0)+f|0;g=y[m|0];if(g){v[(d+48|0)+f|0]=g;v[e|0]=g;v[e+5|0]=i;v[m|0]=0}v[e+3|0]=4;break m}v[e+3|0]=14;v[d+39|0]=9;break m}v[e+3|0]=13}f=f+1|0;continue}}}h=z[a+480190>>1]}x:{y:{if((h&65535)==15){b=d+16|0;ef(b,4379);x[23604]=0;U(289,d+192|0,b|0,d+39|0);b=x[23604];x[23604]=0;if((b|0)!=1){break y}h=P()|0;Db(d+16|0);break f}x[23604]=0;Q(1,d+192|0,12197)|0;b=x[23604];x[23604]=0;if((b|0)==1){break x}}b=d+192|0;Ab(a+1298344|0,b);xb(b);if((h&65535)==15){Db(d+16|0)}Zc(a+1298356|0,z[a+480190>>1]==15?5243:14986);x[a+1298404>>2]=13;break e}h=P()|0;break f}k=k+1|0;continue}}else{w[d+192>>1]=y[(d+f|0)+58|0]+1;q=d,r=z[Se(d+54|0,d+192|0)>>1],w[q+54>>1]=r;f=f+1|0;continue}}h=P()|0;xb(f)}T(h|0);p()}f=1;break a}f=0}hb=d+352|0;return f|0}function UH(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=0,k=E(0),l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=E(0),A=E(0),C=0,F=E(0),G=E(0),H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=0,O=0,P=0,Q=0;y=(d|0)>0?d:0;while(1){if((s|0)!=(y|0)){C=D(s,2304)+b|0;u=0;o=hb-128|0;g=(c|0)>0?c:0;while(1){if((g|0)!=(u|0)){n=C+(u<<2)|0;x=0;i=o;p=i;j=0;while(1){if((j|0)!=8){k=B[D(15-j|0,72)+n>>2];v=D(j,72)+n|0;h=B[v+1152>>2];l=E(k+h);m=B[v>>2];z=B[D(31-j|0,72)+n>>2];A=E(m+z);B[p>>2]=l+A;v=D(j,12);k=E(E(k-h)*B[v+70640>>2]);h=E(E(m-z)*B[v+70644>>2]);B[p+64>>2]=k+h;m=E(A-l);l=B[v+70648>>2];B[p+32>>2]=m*l;B[p+96>>2]=l*E(h-k);p=p+4|0;j=j+1|0;continue}break}while(1){if((x|0)!=4){l=B[i+8>>2];m=B[i+20>>2];h=E(l+m);z=B[i+4>>2];A=B[i+24>>2];F=E(z+A);k=E(h+F);G=B[i+12>>2];H=B[i+16>>2];I=E(G+H);J=B[i>>2];K=B[i+28>>2];L=E(J+K);M=E(I+L);B[i>>2]=k+M;B[i+16>>2]=E(M-k)*E(.7071067690849304);k=E(L-I);h=E(E(k+E(F-h))*E(.7071067690849304));B[i+24>>2]=E(k-h)*E(1.3065630197525024);B[i+8>>2]=E(k+h)*E(.5411961078643799);k=E(J-K);h=E(l-m);l=E(z-A);m=E(E(h+l)*E(.7071067690849304));z=E(k+m);A=E(E(G-H)+h);h=E(l+k);l=E(A-E(h*E(.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[i+28>>2]=E(z-h)*E(2.562915563583374);B[i+4>>2]=E(z+h)*E(.509795606136322);k=E(k-m);h=E(l-E(h*E(.1989123672246933)));B[i+20>>2]=E(k+h)*E(.8999761939048767);B[i+12>>2]=E(k-h)*E(.601344883441925);i=i+32|0;x=x+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=o+(i<<2)|0;B[n>>2]=B[p>>2];k=B[p+96>>2];i=i+1|0;j=o+(i<<2)|0;h=B[j+96>>2];B[n+72>>2]=E(B[p- -64>>2]+k)+h;B[n+144>>2]=B[p+32>>2]+B[j+32>>2];B[n+216>>2]=h+E(k+B[j- -64>>2]);n=n+288|0;continue}break}B[n>>2]=B[o+28>>2];k=B[o+124>>2];B[n+72>>2]=B[o+92>>2]+k;h=B[o+60>>2];B[n+216>>2]=k;B[n+144>>2]=h;u=u+1|0;continue}break}s=s+1|0;continue}break}C=vc(f,a,3840);O=d<<5;s=0;while(1){if((c|0)>(s|0)){i=hb-32|0;hb=i;n=C+(s<<8)|0;u=(s<<2)+b|0;B[n+4080>>2]=B[u+1152>>2];f=d-1|0;x=u+D(f,2304)|0;B[n+4084>>2]=B[x+1152>>2];B[n+4088>>2]=B[u>>2];B[n+4092>>2]=B[x>>2];B[n+4336>>2]=B[u+1156>>2];B[n+4340>>2]=B[x+1156>>2];B[n+4344>>2]=B[u+4>>2];B[n+4348>>2]=B[x+4>>2];v=(D(s,O)<<1)+e|0;y=v+(f<<1)|0;Vr(y,d,n+244|0);f=d<<6;Vr(f+y|0,d,n+500|0);Vr(v,d,n+240|0);Vr(f+v|0,d,n+496|0);N=n+3840|0;p=14;o=70736;while(1){if((p|0)>=0){g=p<<4;j=g+N|0;f=D(31-p|0,72);B[j>>2]=B[f+u>>2];B[j+4>>2]=B[f+x>>2];f=f|4;B[j+8>>2]=B[f+u>>2];B[j+12>>2]=B[f+x>>2];f=D(p,72);q=f+76|0;B[j+256>>2]=B[q+u>>2];B[j+260>>2]=B[q+x>>2];f=f+72|0;B[j-248>>2]=B[f+u>>2];B[j-244>>2]=B[f+x>>2];q=p<<2;t=g+n|0;k=B[o+4>>2];h=B[o>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=B[g+j>>2];m=B[g+t>>2];B[g+(i+16|0)>>2]=E(l*h)-E(k*m);B[i+g>>2]=E(l*k)+E(h*m);f=f+1|0;continue}break}j=(q<<2)+N|0;q=j-3584|0;t=j-256|0;k=B[o+12>>2];h=B[o+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=B[o+20>>2];h=B[o+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=B[o+28>>2];h=B[o+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=B[o+36>>2];h=B[o+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=B[o+44>>2];h=B[o+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=B[o+52>>2];h=B[o+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=B[o+60>>2];h=B[o+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=B[j+q>>2];m=B[g+j>>2];B[t>>2]=B[t>>2]+E(E(l*k)+E(h*m));j=j+(i+16|0)|0;B[j>>2]=E(E(m*k)-E(h*l))+B[j>>2];f=f+1|0;continue}break}f=D(15-p|0,d)<<1;P=f+y|0,Q=Ri(B[i+20>>2]),w[P>>1]=Q;j=D(p+17|0,d)<<1;P=j+y|0,Q=Ri(B[i+4>>2]),w[P>>1]=Q;P=f+v|0,Q=Ri(B[i+16>>2]),w[P>>1]=Q;P=j+v|0,Q=Ri(B[i>>2]),w[P>>1]=Q;f=D(47-p|0,d)<<1;P=f+y|0,Q=Ri(B[i+28>>2]),w[P>>1]=Q;j=D(p+49|0,d)<<1;P=j+y|0,Q=Ri(B[i+12>>2]),w[P>>1]=Q;P=f+v|0,Q=Ri(B[i+24>>2]),w[P>>1]=Q;P=j+v|0,Q=Ri(B[i+8>>2]),w[P>>1]=Q;p=p-1|0;o=o- -64|0;continue}break}hb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}B[(s<<2)+a>>2]=B[C+(b+s<<2)>>2];s=s+2|0;continue}}vc(a,C+(b<<2)|0,3840)}}function Tea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;f=hb-256|0;hb=f;xc(b);a:{if(!oU(b,f+184|0)){break a}if(!hR(f+184|0)){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(gR(f+184|0),lb))){break a}b:{if(!c){break b}Cd(a,16);e=f+24|0;jj(e,2,f+184|4);d=f+48|0;Dc(d,e);Ab(a+1298308|0,d);xb(d);m=a+480190|0;w[m>>1]=y[f+214|0];w[a+480188>>1]=y[f+217|0];h=Xb(d,8283);Ab(a+1298344|0,h);xb(h);h=Xb(d,10021);Ab(a+1298356|0,h);xb(h);ef(e,4172);h=y[f+187|0];x[f>>2]=h>>>4;x[23604]=0;x[f+176>>2]=h&15;X(286,d|0,e|0,f|0,f+176|0);d=x[23604];x[23604]=0;c:{d:{if((d|0)!=1){d=f+48|0;Ab(a+1298368|0,d);xb(d);Db(f+24|0);x[a+1298404>>2]=5;g=1;while(1){l=g&65535;if(l>>>0>z[m>>1]){g=0;d=a+480188|0;while(1)if(z[d>>1]<=g>>>0){e=f+48|0;d=hb-16|0;hb=d;l=b;e:{if(!Qb(x[b>>2],x[b+8>>2],128)){b=0;while(1){if((b|0)!=128){qg(b+e|0);b=b+1|0;continue}break}break e}zS(d+8|0,e);qd(d,l,x[d+8>>2],x[d+12>>2])}hb=d+16|0;Iu(_b(x[a+484360>>2],y[a+484376|0]),e,y[f+211|0]+1|0);b=y[f+216|0];Ud(f,l,D(z[f+208>>1],192));m=kc(f+24|0,f);yb(f);f:{r=c&1;if(!r){break f}x[23604]=0;R(211,a+484344|0,y[f+210|0]+1|0);d=x[23604];x[23604]=0;if((d|0)!=1){break f}break d}o=b?b:64;q=a+484344|0;s=a+480188|0;b=0;while(1){g:{h:{i:{if(y[f+210|0]<k>>>0){if(!(b&u)){break h}B=f,C=Bb(x[a+484344>>2]),x[B>>2]=C;i=Bb(x[a+484348>>2]);j=z[a+480188>>1];break i}j:{if(r){x[23604]=0;d=W(212,q|0,k&65535,o|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break d}n=0;if(d){break j}}x[23604]=0;Q(174,l|0,64)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break g}break d}while(1){e=n&65535;if(e>>>0>31){break g}x[23604]=0;d=S(180,l|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}k:{if(!d|d>>>0>z[f+208>>1]|e>>>0>=z[s>>1]){break k}x[23604]=0;Q(141,m|0,D(d,192)-192|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break d}d=0;h=ac(x[q>>2],k);g=cd(x[h>>2],x[x[h+48>>2]+12>>2],0,e);while(1){if((d|0)==(o|0)){break k}i=b;x[23604]=0;R(482,f|0,m|0);b=x[23604];x[23604]=0;l:{m:{n:{o:{p:{if((b|0)!=1){j=hd(f);e=Re(f);b=y[f|0];if(b>>>0>=4){v[g|0]=(b>>>2|0)+37;b=y[f|0]}v[g+1|0]=b<<4&48|y[j|0]>>>4;b=y[e|0];h=0;e=0;q:{r:{j=y[j|0]&15;switch(j-8|0){case 0:break o;case 2:break q;case 6:break r;default:break p}}j=14;t=(b&240)<<24>>24;if((t|0)<=-17|!(435>>>((t+16&255)>>>4)&1)){break n}break o}b=(b&240?-16:15)&b;j=10;break n}break d}h=j;e=b}j=h;b=e;if(!((h|e)&255)){break m}}v[g+5|0]=b;v[g+3|0]=j;Hf(g);b=1;s:{switch(y[g+3|0]-16|0){case 0:break l;case 1:break s;default:break m}}u=1}b=i}d=d+1|0;g=D(z[s>>1],6)+g|0;continue}}n=n+1|0;continue}}while(1){t:{b=x[f>>2];if(Ob(b,i)){k=x[b+48>>2];n=x[b+12>>2];o=x[b>>2];e=0;u:while(1){if((e|0)==(n|0)){break t}g=0;q=of(o,x[k+12>>2],e);d=0;h=0;while(1)if((g|0)==(j|0)){e=e+1|0;if(!(d&h&1)){continue u}break h}else{b=1;v:{switch(y[(q+D(g,6)|0)+3|0]-16|0){case 1:h=1;default:b=d;break;case 0:break v}}g=g+1|0;d=b;continue}}}B=f,C=Bb(x[a+484344>>2]),x[B+176>>2]=C;d=Bb(x[a+484348>>2]);h=a+480188|0;w:while(1){b=x[f+176>>2];if(!Ob(b,d)){break h}e=0;while(1)if(A[b+12>>2]<=e>>>0){vt(f+176|0);continue w}else{i=of(x[b>>2],x[x[b+48>>2]+12>>2],e);j=z[h>>1];g=0;x:{while(1){if((g|0)==(j|0)){break x}k=D(g,6);g=g+1|0;k=y[(i+k|0)+3|0];if((k&254)!=16){continue}break}i=(k|0)==16;he(b,Ce(ye(f,i?17:16,i?125:6),e))}e=e+1|0;continue}}}vt(f);continue}}y:{b=z[f+212>>1];if(!b){break y}x[23604]=0;ea(297,a+1298332|0,l|0,b|0,39,1);b=x[23604];x[23604]=0;if((b|0)!=1){break y}break d}z:{if(!(c&2)){break z}g=1;b=a+480190|0;while(1){c=g&65535;if(c>>>0>z[b>>1]){break z}c=D(c,104)+a|0;d=Xc(f,w[c+484414>>1]&1?16:8,1,0,1);x[23604]=0;W(205,d|0,c+484380|0,l|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){g=g+1|0;continue}break}break d}x[a+480260>>2]=64;x[a+480264>>2]=32767;yb(m);break b}k=k+1|0;continue}}else{e=(g<<5)+a|0;Qe(e+480280|0);w[e+480284>>1]=(y[(f+g|0)+218|0]<<4|8)&248;g=g+1|0;continue}}else{e=f+48|0;jC(b,e);i=hb-16|0;hb=i;d=(D(l,104)+a|0)+484380|0;od(d,0);w[i+14>>1]=y[e+35|0]<<2;w[i+12>>1]=256;B=d,C=z[Wc(i+14|0,i+12|0)>>1],w[B+30>>1]=C;h=y[e+22|0]|y[e+23|0]<<8|(y[e+24|0]<<16|y[e+25|0]<<24);A:{if(h>>>0<3){break A}x[d>>2]=h;x[d+4>>2]=y[e+26|0]|y[e+27|0]<<8|(y[e+28|0]<<16|y[e+29|0]<<24);x[i+8>>2]=y[e+30|0]|y[e+31|0]<<8|(y[e+32|0]<<16|y[e+33|0]<<24);x[i+4>>2]=1;B=d,C=x[_c(i+8|0,i+4|0)>>2]-1|0,x[B+8>>2]=C;wc(d+8|0,h);h=x[d+8>>2];j=x[d+4>>2];B:{if(h>>>0<=j+4>>>0){x[d+4>>2]=0;x[d+8>>2]=0;h=0;j=0;break B}if(h>>>0<3){break B}w[d+34>>1]=z[d+34>>1]|2}v[d+37|0]=y[e+34|0];B=d,C=xu(0,v[e+34|0]<<4),x[B+24>>2]=C;if(!(v[e+36|0]&1)){break A}x[d+8>>2]=h>>>1;x[d+4>>2]=j>>>1;w[d+34>>1]=z[d+34>>1]|1;x[d>>2]=x[d>>2]>>>1}hb=i+16|0;ml(f,2,e);d=f+24|0;Dc(d,f);Bc(((l<<5)+a|0)+946304|0,d);g=g+1|0;xb(d);continue}}}g=P()|0;Db(f+24|0);break c}g=P()|0;yb(m)}T(g|0);p()}g=1}hb=f+256|0;return g|0}function kda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;i=hb-208|0;hb=i;xc(b);a:{if(!OA(b,i+160|0)){break a}if(!AP(i+160|0)){break a}b:{if(!c){break b}if(!Qb(x[b>>2],x[b+8>>2],Uc(zP(y[i+207|0]),lb))){break a}Cd(a,128);e=i+144|0;We(e,2,i+175|0);d=i+72|0;Dc(d,e);Ab(a+1298308|0,d);xb(d);h=Xb(d,8371);Ab(a+1298344|0,h);xb(h);h=Xb(d,6017);Ab(a+1298356|0,h);xb(h);h=Xb(e,17388);x[23604]=0;U(675,d|0,h|0,x[(y[i+174|0]<<2)+27228>>2]);d=x[23604];x[23604]=0;c:{if((d|0)!=1){d=i+72|0;Ab(a+1298368|0,d);xb(d);xb(h);x[a+480208>>2]=12;x[a+1298404>>2]=5;dB(a+1298332|0,b,y[i+207|0]<<5,32,0);n=a+480190|0;e=Be(b);w[n>>1]=e;h=1;while(1){m=h&65535;if(m>>>0>(e&65535)>>>0){go(_b(x[a+484360>>2],y[a+484376|0]),b,256,255,254);h=0;d=Be(b);if(d>>>0>=127){break a}e=a+480188|0;w[e>>1]=d+1;d=Be(b);while(1)if(z[e>>1]<=h>>>0){n=a+484344|0;r=d+1|0;gg(n,r);e=0;while(1){d:{f=e&65535;if(f>>>0>d>>>0){l=0;s=a+480188|0;e:while(1){t=l&65535;e=z[s>>1];if(t>>>0>=e>>>0){d=Wn(i+8|0);v[d+16|0]=0;w[d+14>>1]=0;w[d+12>>1]=e;x[23604]=0;R(677,d|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){a=P()|0;He(d);T(a|0);p()}x[23604]=0;U(676,i+32|0,n|0,d|0);e=x[23604];x[23604]=0;h=1;if((e|0)==1){break d}He(i+32|0);He(d);if(!(c&2)){break a}c=a+480190|0;while(1){d=h&65535;if(d>>>0>z[c>>1]){break b}d=D(d,104)+a|0;fg(Xc(i+72|0,w[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);h=h+1|0;continue}}m=0;f=Oh(i+72|0);f:while(1){g:{if((m|0)!=(r|0)){if(Qb(x[b>>2],x[b+8>>2],5)){break g}}l=l+1|0;continue e}e=0;d=ac(x[n>>2],m);h=cd(x[d>>2],x[x[d+48>>2]+12>>2],0,t);while(1){h:{i:{if(e>>>0>63){break i}j=y[i+174|0];d=hb-16|0;hb=d;o=1;g=Be(b);if((g|0)==252){o=Be(b);g=Be(b)}v[f|0]=(g-1&255)>>>0<60?g+36|0:0;g=d+8|0;xm(g,b);v[f+1|0]=y[d+8|0];k=y[hd(g)|0];v[d+7|0]=k&15;v[d+6|0]=k>>>4;u=d,A=y[Re(g)|0],v[u+5|0]=A;u=d,A=y[wi(g)|0],v[u+4|0]=A;xP(d+7|0,d+5|0,j);xP(d+6|0,d+4|0,j);j=y[d+7|0];k=(j|0)!=10;g=y[d+6|0];j:{if(!(k|(g|0)!=10)){j=y[d+5|0];g=y[d+4|0];v[f+3|0]=10;j=j|g<<8;v[f+5|0]=j>>>6;if(j>>>0<16384){break j}v[f+2|0]=15;v[f+4|0]=g>>>6;break j}k:{l:{m:{n:{if(!k){k=y[d+5|0];q=k<<2;u=d,A=zm(q),v[u+5|0]=A;if(k>>>0<64){break n}if(vi(g)>>>0>=qz(10)>>>0){break n}v[f+5|0]=q;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=k>>>6;break j}if((g|0)==10){g=y[d+4|0];k=g<<2;u=d,A=zm(k),v[u+4|0]=A;if(g>>>0<64){break k}if(vi(j)>>>0>=qz(10)>>>0){break k}v[f+5|0]=k;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=g>>>6;break j}if((g|0)!=(j|0)){break n}g=0;v[d+6|0]=0;break m}if((g|0)==13){break l}}if((j|0)==13|g){break k}}Xg(d+7|0,d+6|0);Xg(d+5|0,d+4|0)}g=d+6|0;j=d+4|0;k=d+7|0;q=d+5|0;uu(g,j,k,q);oo(d,k,q,g,j);v[f+2|0]=y[d+7|0];v[f+4|0]=y[d+5|0];v[f+3|0]=y[d+6|0];v[f+5|0]=y[d+4|0]}hb=d+16|0;g=e+o|0;e=g>>>0>64?64-e|0:o;if(!e){break i}while(1){if(!e){break h}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[h|0]=d;v[h+1|0]=d>>>8;v[h+2|0]=d>>>16;v[h+3|0]=d>>>24;d=y[f+4|0]|y[f+5|0]<<8;v[h+4|0]=d;v[h+5|0]=d>>>8;e=e-1|0;h=D(z[s>>1],6)+h|0;continue}}m=m+1|0;continue f}e=g>>>0>=64?64:g;continue}}}}e=e+1|0;h=0;if(Yg(n,f,64)){continue}break a}break}e=P()|0;He(d);break c}else{f=(h<<5)+a|0;Qe(f+480280|0);g=f+480284|0;o:{if(y[i+174|0]>=51){f=(Be(b)<<4|8)&248;break o}f=h&1?192:64}w[g>>1]=f;h=h+1|0;continue}}else{p:{if(y[i+174|0]>=52){d=i+72|0;if(!VT(b,d)){fB(d)}break p}d=hb-32|0;hb=d;x[d+28>>2]=64;x[d+8>>2]=66;f=x[b>>2];g=x[b+8>>2];e=x[Fb(d+28|0,d+8|0)>>2];if(!Qb(f,g,e)){e=cf(b)}f=d+8|0;g=i+72|0;cu(f,g);l=ec(d+16|0,x[d+8>>2],e);o=x[l>>2];mc(d,x[b>>2],x[b+8>>2],o,x[l+4>>2]);cu(f,g);Zb(x[d+8>>2]+e|0,0,66-e|0);bc(b,x[d+28>>2]);hb=d+32|0;w[i+136>>1]=z[i+134>>1];w[i+134>>1]=8363}g=hb-32|0;hb=g;f=(D(m,104)+a|0)+484380|0;od(f,0);YA(f);d=i+72|0;Wj(g,2,d+32|0);e=g+16|0;Dc(e,g);ze(f+43|0,e);xb(e);e=y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24);l=y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24);q:{if(e>>>0<=l>>>0){break q}x[f>>2]=e-l;x[f+12>>2]=y[d+44|0]|y[d+45|0]<<8|(y[d+46|0]<<16|y[d+47|0]<<24);x[g+16>>2]=y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24);u=f,A=x[Fb(g+16|0,f)>>2],x[u+16>>2]=A;w[f+30>>1]=y[d+60|0];x[f+24>>2]=y[d+62|0]|y[d+63|0]<<8;e=y[d+64|0]|y[d+65|0]<<8;if(e){bq(f,+(e<<16>>16)/393216)}e=y[d+61|0];if(e&8){w[f+34>>1]=z[f+34>>1]|8;e=y[d+61|0]}if(e&16){w[f+34>>1]=z[f+34>>1]|16;e=y[d+61|0]}if(!(e&4)){break q}w[f+34>>1]=z[f+34>>1]|1;x[f+12>>2]=x[f+12>>2]>>>1;x[f+16>>2]=x[f+16>>2]>>>1}hb=g+32|0;e=i+56|0;We(e,2,d);d=i+144|0;Dc(d,e);Bc(((m<<5)+a|0)+946304|0,d);h=h+1|0;xb(d);e=z[n>>1];continue}}}e=P()|0;xb(h)}T(e|0);p()}h=1}hb=i+208|0;return h|0}function LM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=hb-16|0;hb=g;a:{if(!Tc(d&255)){break a}n=a+1074376|0;j=(n+D(b,872)|0)+616|0;b:{h=z[a+480192>>1];if(!(!(x[a+480180>>2]&17825824)|!h|e)){break b}if(Ij(x[j+656>>2])){break b}c=D(b,872)+a|0;e=c+1075068|0;if(!x[e>>2]){break a}c=x[c+1075080>>2];if(c&1024){break a}d=D(b,872)+a|0;h=d+1075012|0;f=d+1075016|0;if(!(x[h>>2]|x[f>>2])){break a}c:{if(!(c&512)){break c}c=x[a+1298300>>2];if(!td(c)){break c}Zi(c,b,0);break a}c=ry(a,b);if((c|0)==65535){break a}c=D(c,872)+a|0;qp(c+1074992|0,j);v[c+1075823|0]=0;v[c+1075797|0]=0;w[c+1075778>>1]=b+1;d=c+1075080|0;x[d>>2]=x[d>>2]&-918529;Zn(c+1075780|0);x[c+1075688>>2]=0;x[d>>2]=x[d>>2]|2101248;x[e>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=(D(b,872)+a|0)+1075084|0;x[a>>2]=0;x[a+4>>2]=0;x[h>>2]=0;x[f>>2]=0;break a}e=D(b,872)+a|0;m=x[e+1075096>>2];c=c>>>0<=h>>>0?c:0;h=x[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!h){break d}k=d-1|0;c=z[cc(h+236|0,k)>>1];f=a+1074312|0;Jb(g+8|0,f,104);e:{if(Mb(x[x[g+8>>2]>>2],x[g+12>>2])){Jb(g,f,34);if(Mb(x[x[g>>2]>>2],x[g+4>>2])){break e}}d=y[Gb(h+108|0,k)|0]}if((c-1&65535)>>>0<=3998){m=(D(c,104)+a|0)+484380|0;break d}Jb(g+8|0,f,43);if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break d}if(!bj(y[h+31|0])){break a}}if(y[e+1075081|0]&4){break a}p=b>>>0<=256?256:b;k=a+1074312|0;q=b+1|0;r=a+480188|0;c=b;f:{while(1){if((c|0)==(p|0)){g:{e=0;c=0;if(!Ij(x[j+656>>2])){break f}c=0;if(!Tc(y[(D(b,872)+a|0)+1075789|0])){break f}d=sl(a,n,b,2,1);c=0;if((d-1&255)>>>0>249){break f}e=x[(D(d,160)+a|0)+906140>>2];if(e){break g}e=0;c=0;break f}}else{h:{if((b|0)!=(c|0)&z[r>>1]>c>>>0){break h}e=D(c,872)+a|0;if(z[e+1075778>>1]!=(q|0)&(b|0)!=(c|0)){break h}o=e+1075648|0;f=x[o>>2];if(!f){break h}l=e+1074992|0;i:{j:{k:{l:{m:{n:{o:{switch(y[f+17|0]-1|0){case 0:if(!d){break h}i=y[e+1075789|0]==(d|0)&(f|0)==(h|0);if(!h){break n}if(i){break k}break h;case 1:if(!m|x[e+1075096>>2]!=(m|0)){break h}if((f|0)==(h|0)){break i}Jb(g+8|0,k,104);if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(h){break l}i=(f|0)==(h|0)}if(i){break i}break h}if(!h){break h}i=y[h+34|0];if(!i){break h}if((i|0)==y[f+34|0]){break j}break h}if((f|0)!=(h|0)){break h}}if(!y[h+34|0]){break i}}i=e+1075789|0;if(!y[i|0]|y[f+18|0]>2){break i}Jb(g+8|0,k,34);f=gP(l,Mb(x[x[g+8>>2]>>2],x[g+12>>2]));if(!f){break i}Wl(a,c&65535,f+255|0,0);v[e+1075792|0]=0;v[i|0]=0}p:{q:{switch(y[x[o>>2]+18|0]){case 0:Kn(a,l);x[e+1075680>>2]=0;if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!td(f)){break p}Zi(f,c&65535,1);break p;case 1:Kn(a,l);if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!td(f)){break p}Kj(f,c&65535);break p;case 2:break q;default:break p}}l=e+1075080|0;f=x[l>>2];x[l>>2]=f|4096;if(!(f&512)){break p}if(!td(x[a+1298300>>2])){break p}Jb(g+8|0,k,105);if(Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break p}Kj(x[a+1298300>>2],c&65535)}if(x[e+1075680>>2]){break h}x[e+1075688>>2]=0;e=e+1075080|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;continue}break}Jb(g+8|0,k,34);d=gP(j,Mb(x[x[g+8>>2]>>2],x[g+12>>2]));c=0;if(!d){break f}c=mb[x[x[e>>2]+100>>2]](e,d,b)|0}if(!(ki(x[j+8>>2],x[j+12>>2])|c)){break a}r:{if(!(c&(e|0)!=0)){break r}c=y[(D(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break r}Wl(a,b,255,0);v[(D(b,872)+a|0)+1075792|0]=0}c=ry(a,b);if((c|0)==65535){break a}f=D(c,872);e=f+a|0;d=e+1075080|0;h=e+1074992|0;s:{if(!(y[e+1075081|0]&2)){break s}e=x[a+1298300>>2];if(!td(e)){break s}Zi(e,c,1)}m=qp(h,j);e=x[d>>2];h=e&-917505;x[d>>2]=h;l=a+1074992|0;f=l+f|0;v[f+831|0]=0;i=z[a+480188>>1];v[f+805|0]=0;w[f+786>>1]=b>>>0<i>>>0?b+1|0:0;t:{u:{switch(y[(l+D(b,872)|0)+798|0]){case 2:Kn(a,m);if(!(y[d+1|0]&2)){break t}e=x[a+1298300>>2];if(!td(e)){break t}Kj(e,b);Jb(g+8|0,k,105);if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break t}$y(x[a+1298300>>2],b,c);break t;case 0:x[(D(c,872)+a|0)+1075688>>2]=0;x[d>>2]=h|4096;if(!(e&512)){break t}e=x[a+1298300>>2];if(!td(e)){break t}Zi(e,b,1);break t;case 3:x[d>>2]=h|4096;if(!(e&512)){break t}if(!td(x[a+1298300>>2])){break t}Jb(g+8|0,k,105);e=x[a+1298300>>2];if(Mb(x[x[g+8>>2]>>2],x[g+12>>2])){$y(e,b,c);break t}Kj(e,b);break t;case 1:break u;default:break t}}if(!(e&512)){break t}e=x[a+1298300>>2];if(!td(e)){break t}$y(e,b,c)}c=D(c,872)+a|0;if(!x[c+1075680>>2]){x[c+1075688>>2]=0;x[d>>2]=x[d>>2]|2101248}a=D(b,872)+a|0;x[a+1075068>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075084|0;x[a>>2]=0;x[a+4>>2]=0}hb=g+16|0}function Ed(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=hb-96|0;hb=k;u=i&65535;o=(e^i)&-2147483648;q=e&65535;A=q;R=i>>>16&32767;S=e>>>16&32767;a:{b:{if(R-32767>>>0>4294934529&S-32767>>>0>=4294934530){break b}s=e&2147483647;r=s;j=d;if(!(!d&(r|0)==2147418112?!(b|c):r>>>0<2147418112)){m=d;o=e|32768;break a}s=i&2147483647;p=s;e=h;if(!(!e&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){m=h;o=i|32768;b=f;c=g;break a}if(!(b|j|(r^2147418112|c))){if(!(e|f|(g|p))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(e|f|(p^2147418112|g))){e=b|j;d=c|r;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|r))){b=0;c=0;break a}if(!(e|f|(g|p))){b=0;c=0;break a}if((r|0)==65535|r>>>0<65535){j=!(d|q);i=j?b:d;s=j<<6;e=G(i)+32|0;i=G(j?c:q);i=s+((i|0)==32?e:i)|0;vf(k+80|0,b,c,d,q,i-15|0);t=16-i|0;d=x[k+88>>2];A=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(p>>>0>65535){break b}i=!(h|u);e=i?f:h;q=i<<6;j=G(e)+32|0;e=G(i?g:u);e=q+((e|0)==32?j:e)|0;vf(k- -64|0,f,g,h,u,e-15|0);t=(t-e|0)+16|0;h=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;f=g<<15|f>>>17;i=e<<15;e=0;v=i&-32768;L=c;s=Jia(v,e,c,0);e=lb;z=e;M=f;r=b;b=Jia(f,0,b,0);i=b+s|0;f=lb+e|0;c=b>>>0>i>>>0?f+1|0:f;j=0;b=Jia(r,l,v,l);p=j+b|0;f=i;e=f+lb|0;e=b>>>0>p>>>0?e+1|0:e;q=e;N=(f|0)==(e|0)&j>>>0>p>>>0|e>>>0<f>>>0;O=d;w=Jia(v,l,d,0);P=lb;b=Jia(L,l,M,l);y=b+w|0;j=lb+P|0;j=b>>>0>y>>>0?j+1|0:j;b=u<<15|h>>>17;B=h<<15|g>>>17;d=Jia(B,0,r,l);C=d+y|0;f=lb+j|0;f=d>>>0>C>>>0?f+1|0:f;D=f;d=(c|0)==(z|0)&i>>>0<s>>>0|c>>>0<z>>>0;E=c+C|0;f=d+f|0;f=c>>>0>E>>>0?f+1|0:f;u=f;g=E;c=f;F=A|65536;A=Jia(v,l,F,n);Q=lb;d=Jia(O,m,M,l);H=d+A|0;e=lb+Q|0;e=d>>>0>H>>>0?e+1|0:e;i=e;I=b|-2147483648;b=Jia(I,0,r,l);J=b+H|0;f=lb+e|0;f=b>>>0>J>>>0?f+1|0:f;b=Jia(B,m,L,l);z=b+J|0;K=f;f=f+lb|0;s=b>>>0>z>>>0?f+1|0:f;b=0;r=b+g|0;e=c+z|0;v=b>>>0>r>>>0?e+1|0:e;f=v;b=r+N|0;c=b>>>0<r>>>0?f+1|0:f;t=((S+R|0)+t|0)-16383|0;d=Jia(I,m,L,l);h=lb;e=Jia(F,m,M,l);g=e+d|0;f=lb+h|0;f=e>>>0>g>>>0?f+1|0:f;n=(h|0)==(f|0)&d>>>0>g>>>0|f>>>0<h>>>0;h=f;e=Jia(B,m,O,m);d=e+g|0;f=lb+f|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(f|0)==(h|0)&d>>>0<g>>>0|f>>>0<h>>>0;f=0;h=g;g=g+n|0;f=h>>>0>g>>>0?1:f;h=g;g=Jia(I,m,F,m);h=h+g|0;f=lb+f|0;N=h;g=g>>>0>h>>>0?f+1|0:f;h=d;l=e;e=(j|0)==(P|0)&w>>>0>y>>>0|j>>>0<P>>>0;f=0;j=(j|0)==(D|0)&y>>>0>C>>>0|j>>>0>D>>>0;n=j;j=e+j|0;e=(n>>>0>j>>>0?1:f)+l|0;f=g;d=d+j|0;e=d>>>0<j>>>0?e+1|0:e;n=e;w=d;d=(e|0)==(l|0)&d>>>0<h>>>0|e>>>0<l>>>0;e=d;d=d+N|0;f=e>>>0>d>>>0?f+1|0:f;j=d;g=f;e=Jia(B,m,F,m);l=lb;d=Jia(I,m,O,m);h=d+e|0;f=lb+l|0;f=d>>>0>h>>>0?f+1|0:f;d=f;f=(l|0)==(f|0)&e>>>0>h>>>0|f>>>0<l>>>0;y=d+j|0;e=f+g|0;e=d>>>0>y>>>0?e+1|0:e;l=y;g=e;e=0;d=e+w|0;f=h+n|0;f=d>>>0<e>>>0?f+1|0:f;e=f;h=(n|0)==(f|0)&d>>>0<w>>>0|f>>>0<n>>>0;f=g;g=h+l|0;f=g>>>0<h>>>0?f+1|0:f;w=g;g=f;h=d;j=e;e=(s|0)==(K|0)&z>>>0<J>>>0|s>>>0<K>>>0;d=(i|0)==(Q|0)&A>>>0>H>>>0|i>>>0<Q>>>0;i=(i|0)==(K|0)&H>>>0>J>>>0|i>>>0>K>>>0;d=d+i|0;d=d+e|0;n=s;i=n+h|0;e=d+j|0;f=g;d=i;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0<j>>>0;g=h+w|0;f=h>>>0>g>>>0?f+1|0:f;j=g;g=f;h=d;f=0;i=e;n=(u|0)==(v|0)&r>>>0<E>>>0|u>>>0>v>>>0;l=n;n=n+((u|0)==(D|0)&C>>>0>E>>>0|u>>>0<D>>>0)|0;e=e+(l>>>0>n>>>0?1:f)|0;f=g;d=d+n|0;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(i|0)&d>>>0<h>>>0|e>>>0<i>>>0;g=h;h=h+j|0;f=g>>>0>h>>>0?f+1|0:f;i=f;c:{if(f&65536){t=t+1|0;break c}j=q>>>31|0;g=0;f=i<<1|h>>>31;h=h<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;f=q<<1|p>>>31;p=p<<1;q=f;f=c<<1|b>>>31;b=b<<1|j;c=f|g}if((t|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){g=1-t|0;if(g>>>0>=128){b=0;c=0;break a}f=t+127|0;vf(k+48|0,p,q,b,c,f);vf(k+32|0,d,e,h,i,f);Ul(k+16|0,p,q,b,c,g);Ul(k,d,e,h,i,g);p=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;q=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];g=x[k+8>>2];f=x[k+12>>2];break d}g=h;f=i&65535|t<<16}m=g|m;o=f|o;if(!(!b&(c|0)==-2147483648?!(p|q):(c|0)>0|(c|0)>=0)){b=d+1|0;c=b?e:e+1|0;d=(e|0)==(c|0)&b>>>0<d>>>0|c>>>0<e>>>0;e=o;m=d+m|0;o=m>>>0<d>>>0?e+1|0:e;break a}if(b|p|(c^-2147483648|q)){b=d;c=e;break a}j=o;f=e;b=d&1;c=b;b=b+d|0;f=c>>>0>b>>>0?f+1|0:f;c=f;d=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;m=d+m|0;o=d>>>0>m>>>0?j+1|0:j}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=m;x[a+12>>2]=o;hb=k+96|0}function vda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-144|0;hb=d;xc(c);a:{b:{c:{d:{if(!ho(c,d+128|0)){break d}if(Rb(d+128|0,13679,4)){break d}k=d+136|0;e:{if(!Rb(k,13377,4)){break e}if(!Rb(k,13435,4)){break e}if(Rb(k,14110,4)){break d}}j=hb-32|0;hb=j;g=Sb(d+112|0);f:{g:{h:{i:{j:{while(1){f=x[c+8>>2];e=x[c>>2];x[23604]=0;f=W(142,e|0,f|0,8)|0;e=x[23604];x[23604]=0;if((e|0)==1){break h}if(!f){break i}x[23604]=0;R(744,j|0,c|0);e=x[23604];x[23604]=0;if((e|0)!=1){x[23604]=0;R(745,g|0,j|0);e=x[23604];x[23604]=0;if((e|0)==1){break j}Md(j);continue}break}a=P()|0;break g}a=P()|0;Md(j);break g}hb=j+32|0;break f}a=P()|0}Xd(g);T(a|0);p()}x[23604]=0;j=S(160,d+88|0)|0;c=x[23604];x[23604]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c|0)!=1){l=Xc(d+80|0,8,1,1,0);if(Rb(k,14110,4)){break t}x[23604]=0;U(662,d+56|0,d+112|0,1296581714);c=x[23604];x[23604]=0;if((c|0)==1){break q}x[23604]=0;U(662,d+32|0,d+112|0,1296318804);c=x[23604];x[23604]=0;if((c|0)==1){break c}c=d+32|0;f=$c(j,c);yb(c);c=0;x[23604]=0;i=S(663,d+56|0)|0;e=x[23604];x[23604]=0;h=1;if((e|0)==1){break c}if(!i){break u}e=x[f>>2];x[23604]=0;i=S(164,e|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}if(!i){break u}x[23604]=0;m=S(264,d+56|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break c}x[23604]=0;g=S(256,d+56|0)|0;c=x[23604];x[23604]=0;w:{if((c|0)==1){break w}x[23604]=0;Q(174,d+56|0,2)|0;c=x[23604];x[23604]=0;if((c|0)==1){break w}x[23604]=0;c=S(264,d+56|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break v}}break c}h=P()|0;break a}x[23604]=0;R(578,d+32|0,d+56|0);e=x[23604];x[23604]=0;if((e|0)==1){break c}e=Lb(z[d+32>>1]);if(!e){break u}c=(c>>>0)/(e>>>0)|0;e=d+32|0;f=jc(e);i=Re(e);e=Lb(y[f|0]|y[f+1|0]<<8);if((e|0)!=(Lb(y[i|0]|y[i+1|0]<<8)+1|0)){break u}if((e|0)==2){to(l,2)}x:{if((g|0)!=16){if((g|0)!=8){break u}y:{switch(Lb(y[d+38|0]|y[d+39|0]<<8)|0){case 0:Lf(l,1);break x;case 2:Lf(l,17);break x;case 3:break y;default:break u}}Lf(l,16);break x}if(Lb(y[d+38|0]|y[d+39|0]<<8)){break u}id(l,16)}h=0}yb(d+56|0);if(!h){break s}h=0;break k}x[23604]=0;U(662,d+56|0,d+112|0,1447576658);c=x[23604];x[23604]=0;z:{A:{if((c|0)!=1){x[23604]=0;U(662,d+32|0,d+112|0,1128808782);c=x[23604];x[23604]=0;if((c|0)==1){break A}x[23604]=0;U(662,d+8|0,d+112|0,1112491097);c=x[23604];x[23604]=0;if((c|0)==1){break m}c=d+8|0;g=$c(j,c);yb(c);c=x[g>>2];x[23604]=0;f=S(164,c|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break z}c=0;e=0;B:{if(!f){break B}x[23604]=0;f=S(164,x[d+56>>2])|0;c=x[23604];x[23604]=0;if((c|0)==1){break z}c=0;e=0;if(!f){break B}x[23604]=0;f=Q(664,d+56|0,d+8|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break z}c=0;e=0;if(!f){break B}m=Rb(k,13377,4);x[23604]=0;k=S(264,d+32|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break m}if(m){q=l,r=x[Xc(d,16,1,0,0)>>2],x[q>>2]=r}if((k|0)==6){to(l,3)}c=x[g>>2];x[23604]=0;n=x[d+24>>2];g=z[d+20>>1];o=x[d+12>>2];f=x[d+8>>2];e=S(146,c|0)|0;c=x[23604];x[23604]=0;i=1;if((c|0)==1){break m}c=e;e=D((k|0)==6?2:1,m?2:1);m=(c>>>0)/(e>>>0)|0;n=dc(n);c=Lb(g);o=(dc(o)>>>0)/(e>>>0)|0;e=(dc(f)>>>0)/(e>>>0)|0}yb(d+32|0);yb(d+56|0);if(i){break r}break k}h=P()|0;break b}h=P()|0;break l}break m}e=0}Ss(a,b);x[23604]=0;g=D(b,104)+a|0;f=g+484380|0;R(262,f|0,0);i=x[23604];x[23604]=0;if((i|0)==1){break p}i=e+o|0;x[g+484388>>2]=i;x[g+484384>>2]=e;x[f>>2]=m;if(!(i>>>0<=e+4>>>0|i>>>0>m>>>0)){e=g+484414|0;w[e>>1]=z[e>>1]|2}x[g+484404>>2]=c?c:22050;c=n>>>8|0;w[g+484410>>1]=(n&16776960)>>>0>65536?256:c&65535?c:256;kz(f,x[a+480180>>2]);x[23604]=0;U(662,d+56|0,d+112|0,1312902469);c=x[23604];x[23604]=0;if((c|0)==1){break o}x[23604]=0;e=S(164,x[d+56>>2])|0;c=x[23604];x[23604]=0;if((c|0)==1){break n}C:{D:{if(e){x[23604]=0;e=S(146,x[d+56>>2])|0;c=x[23604];x[23604]=0;if((c|0)==1){break n}x[23604]=0;U(309,d+56|0,((b<<5)+a|0)+946304|0,e|0);b=x[23604];x[23604]=0;if((b|0)!=1){break D}break n}x[23604]=0;e=Q(54,d+32|0,21502)|0;c=x[23604];x[23604]=0;if((c|0)==1){break C}Bc(((b<<5)+a|0)+946304|0,e);xb(e)}x[23604]=0;W(205,l|0,f|0,j|0)|0;b=x[23604];x[23604]=0;h=1;if((b|0)==1){break n}aj(f,a);yb(d+56|0);break k}break n}h=P()|0;break b}h=P()|0;break b}h=P()|0;break b}h=P()|0;yb(d+56|0);break b}h=P()|0;yb(d+32|0)}yb(d+56|0);break b}yb(j);Xd(d+112|0)}hb=d+144|0;return h|0}h=P()|0;yb(d+56|0)}yb(j)}Xd(d+112|0);T(h|0);p()}function Kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=hb-144|0;hb=f;xc(b);a:{b:{c:{d:{e:{if(!$Q(b,13996)){break e}j=Sb(f+128|0);i=Sb(f+112|0);x[23604]=0;x[f+104>>2]=0;x[f+108>>2]=0;R(232,a|0,32768);d=x[23604];x[23604]=0;if((d|0)==1){break b}x[23604]=0;d=Q(1,f+88|0,8087)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}Ab(a+1298344|0,d);xb(d);x[23604]=0;d=Q(1,f+72|0,6021)|0;e=x[23604];x[23604]=0;if((e|0)==1){break d}Ab(a+1298356|0,d);xb(d);x[a+1298404>>2]=13;k=a+484376|0;while(1){d=x[b+8>>2];e=x[b>>2];x[23604]=0;d=W(142,e|0,d|0,8)|0;e=x[23604];x[23604]=0;f:{g:{h:{if((e|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}x[23604]=0;d=Q(577,b|0,f- -64|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break m}if(!d){break n}d=x[f+68>>2];x[23604]=0;U(176,f+16|0,b|0,dc(d)|0);d=x[23604];x[23604]=0;if((d|0)==1){break l}d=f+16|0;h=kc(f+40|0,d);yb(d);d=x[h>>2];x[23604]=0;d=S(164,d|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break j}if(d){break k}yb(h)}if(z[a+480188>>1]){break i}e=0;break g}a=P()|0;break a}a=P()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=dc(x[f+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(z[a+480188>>1]){break f}d=x[h>>2];x[23604]=0;d=S(146,d|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;x[23604]=0;R(578,f+16|0,h|0);e=x[23604];x[23604]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}e=1;break o}else{g=cc(f+16|0,d);e=z[a+480188>>1];v:{if(!Lb(y[g|0]|y[g+1|0]<<8)){g=(d&3)-1|0;break v}g=f+104|0;n=Gb(g,e),o=1,v[n|0]=o;n=Gb(g,z[a+480188>>1]+1|0),o=255,v[n|0]=o;Qe(((z[a+480188>>1]<<5)+a|0)+480280|0);g=z[a+480188>>1];e=g+1|0;w[a+480188>>1]=e;l=((g<<5)+a|0)+480284|0;g=(d&3)-1|0;w[l>>1]=g>>>0<2?192:64}Qe((((e&65535)<<5)+a|0)+480280|0);e=z[a+480188>>1];w[a+480188>>1]=e+1;w[((e<<5)+a|0)+480284>>1]=g>>>0<2?192:64;d=d+1|0;continue}}if(z[a+480190>>1]){break f}x[23604]=0;R(579,h|0,a|0);d=x[23604];x[23604]=0;if((d|0)!=1){break f}break j}d=x[h>>2];x[23604]=0;d=S(146,d|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[23604]=0;d=S(256,h|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break j}n=a,o=Td(d,1,255),x[n+480196>>2]=o;break f}d=x[h>>2];x[23604]=0;d=S(146,d|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[23604]=0;m=S(256,h|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break f}break j}d=y[k|0];e=x[a+484360>>2];g=x[h>>2];x[23604]=0;g=S(146,g|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break j}x[23604]=0;ea(324,_b(e,d)|0,h|0,g|0,255,254);d=x[23604];x[23604]=0;if((d|0)==1){break j}break f}d=j;if(Bf(x[d>>2],x[d+4>>2])>>>0>=256){break f}break q}if(Bf(x[i>>2],x[i+4>>2])>>>0>3998){break f}d=x[h>>2];x[23604]=0;e=S(146,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break j}d=i;if(!e){break f}}x[23604]=0;R(580,d|0,h|0);d=x[23604];x[23604]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}e=0}yb(h);break g}a=P()|0;yb(h);break a}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=y[a+484376|0];d=x[a+484360>>2];x[23604]=0;R(308,_b(d,b)|0,m&65535);b=x[23604];x[23604]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=x[j+4>>2];e=x[j>>2];d=0;x[23604]=0;R(211,a+484344|0,Bf(e,b)&65535);b=x[23604];x[23604]=0;if((b|0)==1){break b}while(1){g=x[j>>2];b=d&65535;if(Bf(g,x[j+4>>2])>>>0<=b>>>0){break w}x[23604]=0;e=x[f+108>>2];h=x[f+104>>2];x[f+8>>2]=h;x[f+12>>2]=e;x[f>>2]=h;x[f+4>>2]=e;X(581,zg(g,b)|0,b|0,a|0,f|0);b=x[23604];x[23604]=0;if((b|0)!=1){d=d+1|0;continue}break}a=P()|0;break a}h=c&2;e=1;d=1;b=0;while(1){if(z[a+480190>>1]<=d>>>0){break g}if(!h|Bf(x[i>>2],x[i+4>>2])>>>0<=b>>>0){break g}c=(D(d,104)+a|0)+484380|0;uo(c);x:{if(x[c>>2]){g=x[zg(x[i>>2],b)>>2];x[23604]=0;g=S(146,g|0)|0;k=x[23604];x[23604]=0;if((k|0)==1){break h}wc(c,g);g=Xc(f+40|0,8,1,1,0);k=x[i>>2];x[23604]=0;W(205,g|0,c|0,zg(k,b)|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}jd(i);jd(j);break e}yb(h);continue}}hb=f+144|0;return e|0}a=P()|0;break a}a=P()|0;break a}a=P()|0}jd(i);jd(j);T(a|0);p()}function sV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-112|0;hb=f;xc(b);a:{if(!yq(b,11649)){break a}if(!zu(b,f+96|0)){break a}if(!VB(y[f+97|0])){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(UB(f+96|0),lb))){break a}if(!bc(b,y[f+105|0]|y[f+106|0]<<8)){break a}b:{if(!c){break b}Cd(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[f+98|0]&31)+1;e=a+480190|0;w[e>>1]=y[f+99|0];uh(a,1);d=f+32|0;j=Xb(d,8394);Ab(a+1298344|0,j);xb(j);j=Xb(d,7011);Ab(a+1298356|0,j);xb(j);j=hb-16|0;hb=j;g=f+8|0;h=Xb(j,4208);dd(g,h);xb(h);hb=j+16|0;x[23604]=0;X(215,d|0,g|0,y[f+97|0],f+96|0);d=x[23604];x[23604]=0;c:{if((d|0)!=1){d=f+32|0;Ab(a+1298368|0,d);xb(d);Db(f+8|0);x[a+1298404>>2]=5;d=y[f+99|0];j=f+80|0;x[j>>2]=0;x[j+4>>2]=0;Oj(j+8|0,0);if(d){Fq(j,d);IC(j,d,0)}d=1;d:{while(1){g=d&65535;if(g>>>0>z[e>>1]){x[23604]=0;Q(216,b|0,a+1298308|0)|0;g=x[23604];x[23604]=0;d=1;e:{if((g|0)==1){break e}g=a+480190|0;while(1){e=d&65535;if(e>>>0>z[g>>1]){d=0;g=a+480188|0;f:{while(1){if(z[g>>1]<=d>>>0){d=0;x[23604]=0;g=a+484344|0;R(211,g|0,z[f+100>>1]);e=x[23604];x[23604]=0;if((e|0)==1){break e}break f}e=(d<<5)+a|0;Qe(e+480280|0);x[23604]=0;R(217,b|0,e+480289|0);e=x[23604];x[23604]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}g:{h:{i:{j:{while(1){if(z[f+100>>1]<=d>>>0){x[23604]=0;e=S(180,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break h}if(!e){break i}d=x[b+8>>2];g=x[b>>2];x[23604]=0;d=W(142,g|0,d|0,e|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break h}if(d){break j}break i}x[23604]=0;e=Q(218,b|0,f+32|0)|0;h=x[23604];x[23604]=0;k:{if((h|0)==1){break k}x[23604]=0;h=W(212,g|0,d&65535,64)|0;i=x[23604];x[23604]=0;if((i|0)==1){break k}if((e&h)==1){e=x[g>>2];x[23604]=0;R(219,ac(e,d)|0,f+32|0);e=x[23604];x[23604]=0;if((e|0)==1){break k}}d=d+1|0;continue}break}b=P()|0;break d}g=Sb(f+32|0);x[23604]=0;U(220,b|0,g|0,e|0);d=x[23604];x[23604]=0;l:{if((d|0)!=1){d=Kb(f+8|0);x[23604]=0;R(45,d|0,e|0);e=x[23604];x[23604]=0;m:{if((e|0)==1){break m}l=f,m=Bb(x[g>>2]),x[l+56>>2]=m;h=Bb(x[g+4>>2]);while(1){n:{e=x[f+56>>2];if(!Ob(e,h)){x[23604]=0;X(221,f+56|0,5,6,d|0);e=x[23604];x[23604]=0;if((e|0)==1){break n}h=f+56|0;e=Ab(d,h);xb(h);h=Pb(e);i=y[e+11|0];k=x[e+4>>2];x[23604]=0;ea(222,a+1298332|0,h|0,Qc(k,i)|0,76,0);h=x[23604];x[23604]=0;if((h|0)==1){break m}xb(e);fc(g);break i}o:{e=v[e|0];if((e|0)<0){i=x[Ib(f+72|0,pf(d))>>2];x[23604]=0;X(223,d|0,i|0,e&127,32);e=x[23604];x[23604]=0;if((e|0)!=1){break o}break m}x[23604]=0;R(46,d|0,e|0);e=x[23604];x[23604]=0;if((e|0)!=1){break o}break m}Le(f+56|0);continue}break}}b=P()|0;xb(d);break l}b=P()|0}fc(g);break d}d=y[a+484376|0];g=x[a+484360>>2];x[23604]=0;U(224,_b(g,d)|0,b|0,z[f+102>>1]);d=x[23604];x[23604]=0;if((d|0)==1){break h}e=c&1;h=a+484348|0;d=0;while(1){p:{q:{if(z[f+100>>1]>d>>>0){g=x[b+8>>2];i=x[b>>2];x[23604]=0;g=W(142,i|0,g|0,4)|0;i=x[23604];x[23604]=0;if((i|0)==1){break p}if(g){break q}}if(!(c&2)){break g}g=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>z[g>>1]){break g}e=D(c,104)+a|0;h=z[e+484414>>1];Jb(f+32|0,x[j>>2],c-1|0);c=Xc(f+8|0,h&1?16:8,1,0,Mb(x[x[f+32>>2]>>2],x[f+36>>2])?6:0);x[23604]=0;W(205,c|0,e+484380|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}x[23604]=0;g=S(143,b|0)|0;i=x[23604];x[23604]=0;r:{s:{if((i|0)!=1){x[23604]=0;U(176,f+8|0,b|0,g|0);g=x[23604];x[23604]=0;if((g|0)==1){break s}i=f+8|0;g=kc(f+32|0,i);yb(i);if(!e){break r}i=x[a+484344>>2];if(!pe(i,x[h>>2],d&65535)){break r}x[23604]=0;U(225,ac(i,d)|0,0,g|0);i=x[23604];x[23604]=0;if((i|0)!=1){break r}b=P()|0;yb(g);break d}b=P()|0;break d}b=P()|0;break d}yb(g);d=d+1|0;continue}break}b=P()|0;break d}b=P()|0;break d}He(j);break b}x[23604]=0;Q(226,b|0,((e<<5)+a|0)+946304|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}b=P()|0;break d}x[23604]=0;R(227,b|0,f+32|0);h=x[23604];x[23604]=0;t:{if((h|0)==1){break t}x[23604]=0;R(228,f+32|0,(D(g,104)+a|0)+484380|0);h=x[23604];x[23604]=0;if((h|0)==1){break t}h=y[f+48|0];i=f+8|0;Jb(i,x[j>>2],g-1|0);sg(i,(h&3)!=0);d=d+1|0;continue}break}b=P()|0}He(j);break c}b=P()|0;Db(f+8|0)}T(b|0);p()}d=1}hb=f+112|0;return d|0}function F8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;e=hb-320|0;hb=e;d=-1;a:{b:{c:{if(!Ck(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){b=Dl(e+216|0,b);x[23604]=0;d=Q(394,e+200|0,13827)|0;f=x[23604];x[23604]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){x[23604]=0;x[e+184>>2]=83886084;x[e+188>>2]=0;U(395,b|0,d|0,e+184|0);f=x[23604];x[23604]=0;if((f|0)==1){break A}Db(d);v[e+199|0]=0;x[23604]=0;d=Q(394,e+184|0,14605)|0;f=x[23604];x[23604]=0;if((f|0)==1){break z}x[23604]=0;U(396,b|0,e+199|0,d|0);f=x[23604];x[23604]=0;if((f|0)==1){break y}Db(d);x[23604]=0;f=y[e+199|0];d=Q(394,e+168|0,15654)|0;g=x[23604];x[23604]=0;if((g|0)==1){break x}x[23604]=0;f=f?0:c;X(833,b|0,a+40|0,d|0,f|0);c=x[23604];x[23604]=0;if((c|0)==1){break w}Db(d);w[e+166>>1]=65535;x[23604]=0;c=Q(394,e+152|0,15256)|0;d=x[23604];x[23604]=0;if((d|0)==1){break v}x[23604]=0;W(424,b|0,e+166|0,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break u}Db(c);w[e+150>>1]=0;x[23604]=0;c=Q(394,e+136|0,15152)|0;d=x[23604];x[23604]=0;if((d|0)==1){break t}x[23604]=0;W(424,b|0,e+150|0,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break s}Db(c);w[a>>1]=z[e+150>>1];x[23604]=0;c=Q(394,e+120|0,14917)|0;d=x[23604];x[23604]=0;if((d|0)==1){break r}x[23604]=0;X(834,b|0,a+52|0,c|0,f|0);d=x[23604];x[23604]=0;if((d|0)==1){break q}Db(c);x[23604]=0;c=Q(394,e+104|0,14854)|0;d=x[23604];x[23604]=0;if((d|0)==1){break p}x[23604]=0;U(825,b|0,a+36|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break o}Db(c);x[23604]=0;c=Q(394,e+88|0,15263)|0;d=x[23604];x[23604]=0;if((d|0)==1){break n}x[23604]=0;h=a+4|0;U(835,b|0,h|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break m}Db(c);x[23604]=0;c=Q(394,e+72|0,15154)|0;d=x[23604];x[23604]=0;if((d|0)==1){break l}x[23604]=0;f=a+28|0;U(836,b|0,f|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break k}Db(c);x[23604]=0;c=Q(394,e+56|0,15031)|0;d=x[23604];x[23604]=0;if((d|0)==1){break j}x[23604]=0;U(836,b|0,a+30|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break i}Db(c);x[23604]=0;c=Q(394,e+40|0,14883)|0;d=x[23604];x[23604]=0;if((d|0)==1){break h}x[23604]=0;U(837,b|0,a+32|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break g}Db(c);w[e+38>>1]=0;x[23604]=0;c=Q(394,e+24|0,14833)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}x[23604]=0;W(424,b|0,e+38|0,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break f}Db(c);i=_K(B[a+32>>2]);B[a+32>>2]=i;d=-1;if(!Sl(i)){break d}k=e,l=Bb(x[a+4>>2]),x[k+16>>2]=l;c=Bb(x[a+8>>2]);while(1){g=x[e+16>>2];if(!Ob(g,c)){break e}if(!Sl(B[g>>2])){break d}Fe(e+16|0);continue}}a=P()|0;break a}a=P()|0;Db(d);break a}a=P()|0;break a}a=P()|0;Db(d);break a}a=P()|0;break a}a=P()|0;Db(d);break a}a=P()|0;break a}a=P()|0;Db(c);break a}a=P()|0;break a}a=P()|0;Db(c);break a}a=P()|0;break a}a=P()|0;Db(c);break a}a=P()|0;break a}a=P()|0;Db(c);break a}a=P()|0;break a}a=P()|0;Db(c);break a}a=P()|0;break a}a=P()|0;Db(c);break a}a=P()|0;break a}a=P()|0;Db(c);break a}a=P()|0;break a}a=P()|0;Db(c);break a}a=P()|0;Db(c);break a}if(y[b+3|0]&64){break d}c=z[f>>1];if((c+300&65535)>>>0>600){break d}g=z[a>>1];if(g>>>0>3|(g|0)==2){break d}j=w[a+30>>1];if((j|0)<0){break d}k=e,l=oi(x[a+36>>2]),x[k+16>>2]=l;x[e+8>>2]=0;k=a,l=x[nj(e+16|0,e+8|0,44352)>>2],x[k+36>>2]=l;if(rc(x[a+4>>2],x[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=w[e+38>>1];if((f|0)<=0){break d}w[e+6>>1]=j;B[e+16>>2]=B[a+32>>2];x[23604]=0;w[e+8>>1]=c;w[e+10>>1]=(c+f|0)-1;a=fa(838,a|0,e+6|0,e+16|0,e+8|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;break a;case 0:g=w[e+38>>1];if((g|0)<=0){break d}B[e+16>>2]=B[a+32>>2];x[23604]=0;w[e+8>>1]=c;w[e+10>>1]=(c+g|0)-1;a=ja(839,a|0,h|0,e+16|0,e+8|0,f|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;break a;default:break C}}x[23604]=0;Y(840,a|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}}d=1}Wg(b)}hb=e+320|0;return d|0}a=P()|0;break a}a=P()|0}Wg(b);T(a|0);p()}function uH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;i=hb-560|0;hb=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;k=g+D(s,-24)|0;o=x[(e<<2)+73136>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){C[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+x[(c<<2)+73152>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;t=(o|0)>0?o:0;h=(d|0)<=0;while(1){a:{if(h){f=0;break a}n=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(n-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;c=(g|0)==(t|0);g=g+1|0;if(!c){continue}break}z=47-k|0;u=48-k|0;A=k-25|0;g=o;b:{while(1){f=C[(g<<3)+i>>3];c=0;h=g;l=(g|0)<=0;if(!l){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(F(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(F(f)<2147483648){j=~~f;break d}j=-2147483648}x[n>>2]=j;h=h-1|0;f=C[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=uj(f,q);f=f+J(f*.125)*-8;e:{if(F(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{v=(q|0)<=0;i:{if(!v){h=(g<<2)+i|0;j=x[h+476>>2];c=j>>u;r=h;h=j-(c<<u)|0;x[r+476>>2]=h;n=c+n|0;j=h>>z;break i}if(q){break h}j=x[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;h=0;if(!l){while(1){r=(i+480|0)+(c<<2)|0;w=x[r>>2];l=16777215;j:{k:{if(h){break k}l=16777216;if(w){break k}h=0;break j}x[r>>2]=l-w;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(v){break l}c=8388607;m:{switch(A|0){case 1:c=4194303;break;case 0:break m;default:break l}}l=(g<<2)+i|0;x[l+476>>2]=x[l+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!h){break f}f=f-uj(1,q)}if(f==0){c=1;l=0;h=g;n:{if((g|0)<=(o|0)){break n}while(1){h=h-1|0;l=x[(i+480|0)+(h<<2)>>2]|l;if((h|0)>(o|0)){continue}break}if(!l){break n}k=q;while(1){k=k-24|0;g=g-1|0;if(!x[(i+480|0)+(g<<2)>>2]){continue}break}break b}while(1){h=c;c=c+1|0;if(!x[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;C[(i+320|0)+(j<<3)>>3]=x[(s+g<<2)+73152>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=uj(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(F(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}k=q}x[(i+480|0)+(g<<2)>>2]=c}f=uj(1,k);if((g|0)>=0){d=g;while(1){a=d;C[(a<<3)+i>>3]=f*+x[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}a=0;h=g;while(1){d=a>>>0>t>>>0?t:a;c=0;f=0;while(1){f=C[(c<<3)+75920>>3]*C[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}C[(i+160|0)+(g-h<<3)>>3]=f;h=h-1|0;c=(a|0)!=(g|0);a=a+1|0;if(c){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=C[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;y=C[h>>3];f=y+f;C[e+(c<<3)>>3]=m+(y-f);C[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=C[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=m+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+C[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[i+160>>3];if(j){break s}C[b>>3]=f;f=C[i+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break r}C[b>>3]=-f;f=C[i+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}hb=i+560|0;return n&7}function q_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=hb+-64|0;hb=h;x[h+56>>2]=b;x[e>>2]=0;Pc(h,x[d+28>>2]);x[23604]=0;i=S(1083,x[h>>2])|0;j=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){$b(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;$b(h);T(a|0);p()}TF(a,f+24|0,h+56|0,c,e,i);break b}SF(a,f+16|0,h+56|0,c,e,i);break b}g=a;i=b;a=mb[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Pb(a);k=h,l=Aj(g,i,c,d,e,f,b,b+(Eb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+56>>2]=l;break b}a=Ii(h+56|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[20555];x[h+24>>2]=x[20554];x[h+28>>2]=g;g=x[20553];x[h+16>>2]=x[20552];x[h+20>>2]=g;g=x[20551];x[h+8>>2]=x[20550];x[h+12>>2]=g;g=x[20549];x[h>>2]=x[20548];x[h+4>>2]=g;k=h,l=Aj(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}g=x[20563];x[h+24>>2]=x[20562];x[h+28>>2]=g;g=x[20561];x[h+16>>2]=x[20560];x[h+20>>2]=g;g=x[20559];x[h+8>>2]=x[20558];x[h+12>>2]=g;g=x[20557];x[h>>2]=x[20556];x[h+4>>2]=g;k=h,l=Aj(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}a=Ii(h+56|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=Ii(h+56|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=Ii(h+56|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=Ii(h+56|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=Ii(h+56|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+56|0;b=hb-16|0;hb=b;x[b+8>>2]=c;while(1){H:{if(Fh(a,b+8|0)){break H}if(!wk(i,1,xk(x[a>>2]))){break H}kn(a);continue}break}if(Fh(a,b+8|0)){x[e>>2]=x[e>>2]|2}hb=b+16|0;break b}b=h+56|0;a=mb[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Eb(x[a+4>>2],y[a+11|0])|0)==(0-Eb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=yr(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=vc(h,82256,44);k=g,l=Aj(a,b,c,d,e,f,g,g+44|0),x[k+56>>2]=l;break b}x[h+16>>2]=x[20580];g=x[20579];x[h+8>>2]=x[20578];x[h+12>>2]=g;g=x[20577];x[h>>2]=x[20576];x[h+4>>2]=g;k=h,l=Aj(a,b,c,d,e,f,h,h+20|0),x[k+56>>2]=l;break b}a=Ii(h+56|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[20591];x[h+24>>2]=x[20590];x[h+28>>2]=g;g=x[20589];x[h+16>>2]=x[20588];x[h+20>>2]=g;g=x[20587];x[h+8>>2]=x[20586];x[h+12>>2]=g;g=x[20585];x[h>>2]=x[20584];x[h+4>>2]=g;k=h,l=Aj(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}a=Ii(h+56|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=mb[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Pb(a);k=h,l=Aj(g,i,c,d,e,f,b,b+(Eb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+56>>2]=l;break b}RF(f+20|0,h+56|0,c,e,i);break b}a=Ii(h+56|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=hb-16|0;hb=a;x[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(Fh(c,a+8|0)){break M}b=4;if((_m(i,xk(x[c>>2]))|0)!=37){break M}b=2;if(!Fh(kn(c),a+8|0)){break L}}x[e>>2]=x[e>>2]|b}hb=a+16|0}a=x[h+56>>2]}hb=h- -64|0;return a|0}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-352|0;hb=e;xc(b);f=hb-16|0;hb=f;qT(f+8|0,e+128|0);h=x[f+12>>2];mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(h|0)){bc(b,x[f+12>>2])}hb=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((h|0)!=(i|0)){break g}if(!sT(e+128|0)){break g}if(!Qb(x[b>>2],x[b+8>>2],Uc(rT(y[e+344|0],y[e+345|0]),lb))){break g}if(!c){d=1;break g}Cd(a,2);Ag(a);x[a+480188>>2]=524296;t=a,u=Ge(455e3),x[t+480204>>2]=u;Nb(a+1074312|0,110,1);x[a+480208>>2]=x[a+480208>>2]|16777216;f=e+96|0;We(f,2,e+159|0);d=e+112|0;Dc(d,f);Ab(a+1298308|0,d);xb(d);d=0;h:{i:{while(1){if((d|0)==8){j:{d=_b(x[a+484360>>2],y[a+484376|0]);o=y[e+344|0];n=o+1|0;go(d,b,n,65535,65535);f=Sb(e+112|0);x[23604]=0;U(220,b|0,f|0,n|0);d=x[23604];x[23604]=0;if((d|0)==1){break j}t=e,u=Bb(x[f>>2]),x[t+96>>2]=u;d=Bb(x[f+4>>2]);while(1){h=x[e+96>>2];q=Ob(h,d);if(q){if((y[h|0]-9&255)>>>0<248){break h}Le(e+96|0);continue}break}t=a,u=y[Gb(x[f>>2],0)|0],x[t+480196>>2]=u;d=y[e+343|0];i=y[e+345|0];h=Sb(e+96|0);x[23604]=0;m=i+1|0;U(220,b|0,h|0,m|0);i=x[23604];x[23604]=0;k:{if((i|0)==1){break k}x[23604]=0;i=a+484344|0;R(211,i|0,m|0);g=x[23604];x[23604]=0;if((g|0)==1){break k}r=d+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(m|0)){break i}d=y[Gb(x[h>>2],c)|0];x[23604]=0;d=W(212,i|0,d|0,r|0)|0;g=x[23604];x[23604]=0;l:{if((g|0)!=1){if(!d){break i}g=0;k=ac(x[i>>2],y[Gb(x[h>>2],c)|0]);m:while(1){s=g&65535;if(s>>>0>7){break l}g=g+1|0;d=0;while(1){if(A[k+12>>2]<=d>>>0){continue m}x[23604]=0;j=S(192,b|0)|0;l=x[23604];x[23604]=0;n:{o:{if((l|0)!=1){j=j<<24>>24;if((j|0)>=0){break o}d=(j&127)+d|0;break n}d=P()|0;break b}l=cd(x[k>>2],x[x[k+48>>2]+12>>2],d,s);if((j|0)==1){v[l|0]=254;break n}if((j-1&255)>>>0>96){break n}v[l+1|0]=g;v[l|0]=j+12}d=d+1|0;continue}}}d=P()|0;break b}c=c+1|0;continue}}d=P()|0;break b}}else{i=e+112|0;f=(e+128|0)+D(d,19)|0;NA(i,f+63|0);h=e+96|0;Dc(h,i);vm(((d<<5)+a|0)+480289|0,h);xb(h);d=d+1|0;g=D(d,104)+a|0;j=g+484380|0;od(j,2);v[e+107|0]=0;h=y[f+78|0]|y[f+79|0]<<8|(y[f+80|0]<<16|y[f+81|0]<<24);v[e+103|0]=h;v[e+104|0]=h>>>8;v[e+105|0]=h>>>16;v[e+106|0]=h>>>24;h=y[f+75|0]|y[f+76|0]<<8|(y[f+77|0]<<16|y[f+78|0]<<24);f=y[f+71|0]|y[f+72|0]<<8|(y[f+73|0]<<16|y[f+74|0]<<24);x[e+8>>2]=x[e+104>>2];x[e+96>>2]=f;x[e+100>>2]=h;f=x[e+100>>2];x[e>>2]=x[e+96>>2];x[e+4>>2]=f;kl(j,1,e);x[g+484404>>2]=8215;f=e+80|0;Dc(f,i);Bc(((d<<5)+a|0)+946304|0,f);xb(f);continue}break}d=P()|0;break a}j=o+1|0;c=a+484376|0;d=0;p:{q:{while(1){if((d|0)==(j|0)){x[23604]=0;b=Q(1,e+80|0,8518)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break p}d=P()|0;break b}b=y[c|0];g=x[a+484360>>2];x[23604]=0;k=d&65535;b=Q(295,_b(g,b)|0,k|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){r:{s:{if(b){b=_b(x[a+484360>>2],y[c|0]);break s}x[23604]=0;g=Q(343,i|0,r|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break q}if((g|0)==65535){break r}b=_b(x[a+484360>>2],y[c|0]);t=cc(x[b>>2],d),u=g,w[t>>1]=u}b=MA(Bb(x[ac(x[i>>2],z[cc(x[b>>2],d)>>1])+4>>2]),1);g=y[b+5|0];l=y[Gb(x[f>>2],(d+1>>>0)%(n>>>0)|0)|0];if((g|0)==(l|0)){break r}t:{if(y[b+3|0]!=16){break t}g=y[c|0];m=x[a+484360>>2];x[23604]=0;g=Q(344,_b(m,g)|0,k|0)|0;k=x[23604];x[23604]=0;if((k|0)==1){break c}if((g|0)==65535){break t}b=MA(Bb(x[ac(x[i>>2],g)+4>>2]),1)}v[b+5|0]=l;v[b+3|0]=16}d=d+1|0;continue}break}d=P()|0;break b}d=P()|0;break b}Ab(a+1298344|0,b);xb(b);x[23604]=0;b=Q(1,e- -64|0,6010)|0;c=x[23604];x[23604]=0;if((c|0)==1){break f}Ab(a+1298356|0,b);xb(b);b=e+16|0;jj(b,2,e+139|0);x[23604]=0;R(208,e+32|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break e}x[23604]=0;U(11,e+48|0,5,e+32|0);b=x[23604];x[23604]=0;if((b|0)==1){break d}b=e+48|0;Ab(a+1298368|0,b);xb(b);xb(e+32|0);x[a+1298404>>2]=5;fc(h)}fc(f);d=q^1}hb=e+352|0;return d|0}d=P()|0;break b}d=P()|0;break b}d=P()|0;xb(e+32|0);break b}d=P()|0}fc(h)}fc(f);T(d|0);p()}function hx(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=hb-48|0;hb=l;x[l+44>>2]=0;a:{if(!(d|g|h)){j=3;if(!i){break a}}k=g?l+44|0:0;b:{if(!k){break b}j=x[k>>2];if(!j){break b}Hb(j);x[k>>2]=0}x[23604]=0;Z(91);j=x[23604];x[23604]=0;c:{d:{if((j|0)==1){m=Ua(92520,49424,49480,62120,92708,92812,92760,92652,92640,92956,92924,92892,92880,93104,0)|0;e:{f:{n=ib;if((n|0)==(da(92520)|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=277;if((k|0)==1){break f}break c}if((da(49424)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=358;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(49480)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=359;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(62120)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=357;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(92708)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=300;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(92812)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=299;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(92760)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=298;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(92652)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=297;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(92640)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=296;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(92956)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=289;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(92924)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=288;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(92892)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=287;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}if((da(92880)|0)==(n|0)){j=_(m|0)|0;x[23604]=0;R(1e3,k|0,j|0);k=x[23604];x[23604]=0;j=286;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break e}o=da(93104)|0;j=257;m=_(m|0)|0;if((n|0)!=(o|0)){break c}x[23604]=0;R(1e3,k|0,m|0);k=x[23604];x[23604]=0;j=267;if((k|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break e}break d}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break d}}V(0)|0;Vb()}p()}T(a|0);p()}$();k=j;m=!g;if(d){j=mb[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){x[g+16>>2]=k;m=g;g=x[l+44>>2];q=m,r=Qf(g?g:21502),x[q+20>>2]=r}if(h){x[h>>2]=k}if(!i){break a}g=x[l+44>>2];q=i,r=Qf(g?g:21502),x[q>>2]=r}g=x[l+44>>2];if(g){Hb(g);x[l+44>>2]=0}g:{if(!(j&1)){break g}x[23604]=0;R(998,l+32|0,a|0);g=x[23604];x[23604]=0;h:{i:{if((g|0)!=1){j:{if(f){g=x[f+24>>2];x[23604]=0;R(999,g|0,l+32|0);g=x[23604];x[23604]=0;if((g|0)!=1){break j}break i}g=Pb(l+32|0);if(b){x[23604]=0;R(b|0,g|0,c|0);g=x[23604];x[23604]=0;if((g|0)==1){break i}break j}os(g,l)}xb(l+32|0);break g}g=V(0)|0;break h}g=V(0)|0;xb(l+32|0)}_(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+8>>2]=a?a:21502;x[l+4>>2]=250;x[l>>2]=9076;LJ(17718,l);ns(93456);$()}hb=l+48|0}function wI(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=hb-48|0;hb=g;a:{b:{if(Xr(c)){j=x[b+484344>>2];if(pe(j,x[b+484348>>2],c&65535)){break b}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);ai(c,a,b);xb(b);xb(a);break a}c=ac(j,c);if(!(x[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);ai(c,a,b);xb(b);xb(a);break a}if(!(z[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);ai(c,a,b);xb(b);xb(a);break a}if(f>>>0>=6){c=a;a=Kb(g+32|0);b=Kb(g+16|0);ai(c,a,b);xb(b);xb(a);break a}c=cd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=y[c|0];if(!Tc(d)){if(!kp(d)){break k}}e=g+16|0;VL(e,b,d,y[c+1|0]);x[23604]=0;R(962,g+32|0,e|0);b=x[23604];x[23604]=0;d=1;if((b|0)!=1){break j}c=P()|0;break g}d=0;x[23604]=0;Q(54,g+32|0,16613)|0;b=x[23604];x[23604]=0;if((b|0)==1){break i}}b=9860;c=y[c|0];if(!Tc(c)){b=kp(c)?10170:16613}x[23604]=0;b=Q(54,g|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break h}c=a;a=g+32|0;ai(c,a,b);xb(b);xb(a);if(!d){break a}xb(g+16|0);break a}c=P()|0;break d}c=P()|0;xb(g+32|0);if(!d){break d}}xb(g+16|0);break d;case 1:b=c+1|0;l:{if(y[c+1|0]){Dt(g+32|0,b);break l}Xb(g+32|0,16618)}b=y[b|0];x[23604]=0;b=Q(54,g+16|0,(b?10660:16618)|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break e}c=a;a=g+32|0;ai(c,a,b);xb(b);xb(a);break a;case 2:m:{if(Pg(y[c|0])){Xb(g+32|0,17673);break m}d=y[c+2|0];if(d){Ue(g+32|0,1,tL(x[x[b+8>>2]+88>>2],d));break m}Xb(g+32|0,17673)}b=17673;if(!Pg(y[c|0])){b=y[c+2|0]?5466:17673}x[23604]=0;b=Q(54,g+16|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){c=a;a=g+32|0;ai(c,a,b);xb(b);xb(a);break a}c=P()|0;xb(g+32|0);break d;case 4:n:{if(Pg(y[c|0])){k=g,l=Jj(y[c+2|0],y[c+4|0])&255,x[k>>2]=l;fA(g+32|0,g);break n}if(y[c+2|0]){Dt(g+32|0,c+4|0);break n}Xb(g+32|0,16618)}b=5450;if(!Pg(y[c|0])){b=y[c+2|0]?5450:16618}x[23604]=0;b=Q(54,g+16|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){c=a;a=g+32|0;ai(c,a,b);xb(b);xb(a);break a}c=P()|0;xb(g+32|0);break d;case 3:o:{if(Pg(y[c|0])){k=g,l=(Jj(y[c+3|0],y[c+5|0])&3840)!=0,v[k|0]=l;d=hb-32|0;hb=d;v[d+24|0]=44;x[d+16>>2]=-1;x[d+20>>2]=0;x[d+8>>2]=1058;x[d+12>>2]=1;j=g+32|0;b=hb+-64|0;hb=b;h=x[d+8>>2]&2?16:10;f=hb-32|0;hb=f;e=Ue(f+16|0,1,0);p:{q:{r:{while(1){i=Pb(e);$I(f+8|0,i,Eb(x[e+4>>2],y[e+11|0])+i|0,y[g|0],h);if(!x[f+12>>2]){break r}i=Rf(Eb(x[e+4>>2],y[e+11|0]));x[23604]=0;R(58,e|0,i|0);i=x[23604];x[23604]=0;if((i|0)!=1){continue}break}break q}h=x[f+8>>2];i=Pb(e);x[23604]=0;R(59,e|0,h-i|0);h=x[23604];x[23604]=0;s:{if((h|0)!=1){x[23604]=0;R(60,b|0,e|0);h=x[23604];x[23604]=0;if((h|0)!=1){break s}break q}break q}xb(e);hb=f+32|0;break p}a=P()|0;xb(e);T(a|0);p()}e=b+16|0;Ll(e,b,x[d+8>>2]);f=x[d+12>>2];h=x[d+8>>2];x[23604]=0;X(73,b+32|0,e|0,h|0,f|0);e=x[23604];x[23604]=0;t:{u:{v:{w:{x:{if((e|0)!=1){e=y[d+24|0];f=x[d+20>>2];x[23604]=0;X(74,b+48|0,b+32|0,f|0,e|0);e=x[23604];x[23604]=0;if((e|0)==1){break x}x[23604]=0;R(57,j|0,b+48|0);e=x[23604];x[23604]=0;if((e|0)==1){break w}xb(b+48|0);xb(b+32|0);xb(b+16|0);xb(b);hb=b- -64|0;break t}a=P()|0;break u}a=P()|0;break v}a=P()|0;xb(b+48|0)}xb(b+32|0)}xb(b+16|0);xb(b);T(a|0);p()}hb=d+32|0;break o}d=y[c+3|0];if(d){Ue(g+32|0,1,sL(x[x[b+8>>2]+84>>2],d));break o}Xb(g+32|0,16619)}b=12182;if(!Pg(y[c|0])){b=y[c+3|0]?12182:16619}x[23604]=0;b=Q(54,g+16|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){c=a;a=g+32|0;ai(c,a,b);xb(b);xb(a);break a}c=P()|0;xb(g+32|0);break d;case 5:break f;default:break c}}y:{if(Pg(y[c|0])){k=g,l=Jj(y[c+3|0],y[c+5|0])&255,x[k>>2]=l;fA(g+32|0,g);break y}if(y[c+3|0]){Dt(g+32|0,c+5|0);break y}Xb(g+32|0,16618)}b=11025;if(!Pg(y[c|0])){b=y[c+3|0]?11025:16618}x[23604]=0;b=Q(54,g+16|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){c=a;a=g+32|0;ai(c,a,b);xb(b);xb(a);break a}c=P()|0;xb(g+32|0);break d}c=P()|0;xb(g+32|0)}T(c|0);p()}c=a;a=Kb(g+32|0);b=Kb(g+16|0);ai(c,a,b);xb(b);xb(a)}hb=g+48|0}function hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=hb-752|0;hb=d;xc(b);e=hb-16|0;hb=e;g=d+144|0;DQ(e+8|0,g);f=x[e+12>>2];mc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(f|0)){bc(b,x[e+12>>2])}hb=e+16|0;e=(f|0)==(h|0);if(!e){CQ(g)}a:{if(!e){break a}if(!FQ(d+144|0)){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(EQ(z[d+178>>1]),lb))){break a}if(!c){o=1;break a}Cd(a,262144);f=d+104|0;hl(f,2,d+144|0);e=d+24|0;Dc(e,f);Ab(a+1298308|0,e);xb(e);g=Xb(e,8235);Ab(a+1298344|0,g);xb(g);e=Xb(e,10017);Ab(a+1298356|0,e);xb(e);e=hb-16|0;hb=e;i=f;f=Xb(e,4154);dd(i,f);xb(f);hb=e+16|0;v[d+8|0]=y[d+174|0];x[23604]=0;v[d+127|0]=y[d+173|0];R(614,d+128|0,d+127|0);e=x[23604];x[23604]=0;b:{c:{d:{if((e|0)!=1){x[23604]=0;X(236,d+24|0,d+104|0,d+8|0,d+128|0);e=x[23604];x[23604]=0;if((e|0)!=1){e=d+24|0;Ab(a+1298368|0,e);xb(e);xb(d+128|0);f=d+104|0;Db(f);x[a+480208>>2]=12;x[a+1298404>>2]=5;g=a+480188|0;w[g>>1]=z[d+182>>1];w[d+24>>1]=z[d+178>>1];w[d+104>>1]=3999;B=a,C=z[Wc(e,f)>>1],w[B+480190>>1]=C;vT(_b(x[a+484360>>2],y[a+484376|0]),d+240|0,z[d+176>>1]);e=0;while(1)if(z[g>>1]<=e>>>0){e=d+24|0;Ud(e,b,D(z[d+178>>1],80));g=c&2;l=kc(d+104|0,e);yb(e);h=d+72|0;e=0;e:{f:{while(1){if(z[a+480190>>1]<=e>>>0){o=1;if(c&1){break f}break b}x[23604]=0;R(615,l|0,d+24|0);f=x[23604];x[23604]=0;if((f|0)==1){break e}f=d+8|0;hl(f,2,h);x[23604]=0;R(208,d+128|0,f|0);f=x[23604];x[23604]=0;if((f|0)==1){break e}e=e+1|0;f=d+128|0;Bc(((e<<5)+a|0)+946304|0,f);xb(f);x[23604]=0;i=f;f=(D(e,104)+a|0)+484380|0;U(616,i|0,d+24|0,f|0);i=x[23604];x[23604]=0;g:{if((i|0)==1){break g}if(!g|!x[f>>2]){continue}x[23604]=0;i=Q(141,b|0,z[d+42>>1]|z[d+44>>1]<<16)|0;j=x[23604];x[23604]=0;if((j|0)==1){break g}if(!i){continue}x[23604]=0;W(205,d+128|0,f|0,b|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){continue}}break}break e}x[23604]=0;m=a+484344|0;R(211,m|0,z[d+180>>1]);c=x[23604];x[23604]=0;if((c|0)==1){break e}c=d+24|0;r=c|4;s=c|2;t=c|5;u=c|3;A=c|1;q=a+480188|0;e=0;while(1){if(z[d+180>>1]<=e>>>0){break b}x[23604]=0;a=W(212,m|0,e&65535,64)|0;c=x[23604];x[23604]=0;if((c|0)==1){break e}h:{if(!a){break h}a=(e<<1)+d|0;a=y[a+496|0]|y[a+497|0]<<8;if(!a){break h}x[23604]=0;a=Q(141,b|0,a<<4)|0;c=x[23604];x[23604]=0;if((c|0)==1){break e}if(!a){break h}c=0;a=ac(x[m>>2],e);j=cd(x[a>>2],x[x[a+48>>2]+12>>2],0,0);while(1){if(c>>>0>63){break h}a=x[b+8>>2];f=x[b>>2];x[23604]=0;a=W(142,f|0,a|0,1)|0;f=x[23604];x[23604]=0;i:{if((f|0)!=1){if(!a){break h}x[23604]=0;a=S(192,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break e}k=a<<24>>24;if(k){break i}c=c+1|0;j=D(z[q>>1],6)+j|0;continue}break e}w[d+28>>1]=0;x[d+24>>2]=0;a=k&31;f=D(a,6)+j|0;i=Oh(d+24|0);g=a>>>0<z[q>>1];n=g?f:i;h=k&255;j:{if(!(h&32)){break j}x[23604]=0;R(245,d+128|0,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break e}a=y[d+128|0];v[n|0]=a;B=g?f+1|0:A,C=y[hd(d+128|0)|0],v[B|0]=C;k:{if(a){if((a|0)==254){break k}if(a>>>0<121){break j}}a=0}v[n|0]=a}l:{if(!(h&64)){break l}x[23604]=0;R(245,d+128|0,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break e}h=g?f+3|0:u;a=y[d+128|0];v[h|0]=a;i=g?f+5|0:t;B=i,C=y[hd(d+128|0)|0],v[B|0]=C;m:{if(a>>>0>=16){if(a>>>0<=23){a=y[a+27367|0];v[h|0]=a;break m}v[h|0]=0;break l}Hf(n);a=y[h|0]}if((a|0)!=23){if((a|0)!=9){break l}v[h|0]=20;v[d+8|0]=y[i|0]>>>3;v[d+127|0]=1;B=i,C=y[Ye(d+8|0,d+127|0)|0]-1&15|128,v[B|0]=C;break l}v[d+8|0]=64;B=i,C=y[Wb(i,d+8|0)|0]<<1,v[B|0]=C}if((k|0)>=0){continue}v[(g?f+2|0:s)|0]=1;x[23604]=0;a=S(192,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break e}v[(g?f+4|0:r)|0]=a;continue}}e=e+1|0;continue}}b=P()|0;yb(l);break c}else{f=(e<<5)+a|0;Qe(f+480280|0);w[f+480284>>1]=(y[(d+e|0)+208|0]<<4|4)&244;e=e+1|0;continue}}b=P()|0;xb(d+128|0);break d}b=P()|0}Db(d+104|0)}T(b|0);p()}yb(l)}hb=d+752|0;return o|0}function DJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-272|0;hb=f;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[Fk(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Rk(f+96|0,h,g,g-1|0);g=x[f+100>>2];x[b>>2]=x[f+96>>2];x[b+4>>2]=g}g=f+96|0;Pd(g);h=x[f+96>>2];Pd(f+248|0);i=Ek(h,x[f+252>>2],b);Pd(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{if((i|0)==x[f+100>>2]){a=oc(f+264|0,21502);i=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=i;if(Ic(h,g,f+8|0)){e=ba(8)|0;x[23604]=0;c=Ah(f+248|0,c,d);a=x[23604];x[23604]=0;f:{g:{h:{if((a|0)!=1){x[23604]=0;U(915,f+96|0,17481,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}a=0;b=pc(e,f+96|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(f+96|0);break g}b=P()|0;break f}b=P()|0;a=1}xb(c);if(!a){break c}}ca(e|0);break c}if(!e){break e}e=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[23604]=0;g=Ah(f+216|0,b,a);a=x[23604];x[23604]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23604]=0;U(915,f+232|0,17517,g|0);a=x[23604];x[23604]=0;if((a|0)==1){break q}x[23604]=0;R(917,f+248|0,f+232|0);b=x[23604];x[23604]=0;a=1;if((b|0)==1){break p}x[23604]=0;c=Ah(f+200|0,c,d);a=x[23604];x[23604]=0;if((a|0)==1){break o}x[23604]=0;U(919,f+96|0,f+248|0,c|0);b=x[23604];x[23604]=0;a=1;if((b|0)==1){break n}a=pc(e,f+96|0);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(f+96|0);a=0;break m}b=P()|0;break i}b=P()|0;a=1;break j}b=P()|0;break k}b=P()|0;a=1;break l}b=P()|0}xb(c)}xb(f+248|0)}xb(f+232|0)}xb(g);if(!a){break c}}ca(e|0);break c}b=oc(f+192|0,21502);e=x[b+4>>2];x[f+88>>2]=x[b>>2];x[f+92>>2]=e;if(Ic(h,g,f+88|0)){e=ba(8)|0;x[23604]=0;c=Ah(f+248|0,c,d);a=x[23604];x[23604]=0;r:{s:{t:{if((a|0)!=1){x[23604]=0;U(915,f+96|0,17481,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break t}a=0;b=pc(e,f+96|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(f+96|0);break s}b=P()|0;break r}b=P()|0;a=1}xb(c);if(!a){break c}}ca(e|0);break c}b=oc(f+184|0,12228);e=x[b+4>>2];x[f+80>>2]=x[b>>2];x[f+84>>2]=e;if(Ic(h,g,f+80|0)){b=oc(f+176|0,5562);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;if(Ic(c,d,f+32|0)){x[a+52>>2]=0;break e}b=oc(f+168|0,11160);e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(Ic(c,d,f+24|0)){x[a+52>>2]=1;break e}b=oc(f+160|0,9108);e=x[b+4>>2];x[f+16>>2]=x[b>>2];x[f+20>>2]=e;if(Ic(c,d,f+16|0)){x[a+52>>2]=2;break e}e=ba(8)|0;x[23604]=0;c=Ah(f+248|0,c,d);a=x[23604];x[23604]=0;u:{v:{w:{if((a|0)!=1){x[23604]=0;U(915,f+96|0,14483,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break w}a=0;b=pc(e,f+96|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(f+96|0);break v}b=P()|0;break u}b=P()|0;a=1}xb(c);if(!a){break c}}ca(e|0);break c}b=oc(f+152|0,11397);e=x[b+4>>2];x[f+72>>2]=x[b>>2];x[f+76>>2]=e;if(!Ic(h,g,f+72|0)){break e}b=oc(f+144|0,15437);e=x[b+4>>2];x[f+64>>2]=x[b>>2];x[f+68>>2]=e;b=0;x:{if(Ic(c,d,f- -64|0)){break x}b=oc(f+136|0,15442);e=x[b+4>>2];x[f+56>>2]=x[b>>2];x[f+60>>2]=e;b=1;if(Ic(c,d,f+56|0)){break x}b=oc(f+128|0,12502);e=x[b+4>>2];x[f+48>>2]=x[b>>2];x[f+52>>2]=e;b=2;if(Ic(c,d,f+48|0)){break x}b=oc(f+120|0,9172);e=x[b+4>>2];x[f+40>>2]=x[b>>2];x[f+44>>2]=e;b=3;if(Ic(c,d,f+40|0)){break x}a=ba(8)|0;x[23604]=0;c=Q(54,f+96|0,11433)|0;b=x[23604];x[23604]=0;if((b|0)==1){break d}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}x[a+56>>2]=b;a=x[a+24>>2];if(!x[a+24668>>2]){break e}c=a+24664|0;d=x[c+4>>2];x[f+112>>2]=x[c>>2];x[f+116>>2]=d;c=a+24656|0;d=x[c+4>>2];x[f+104>>2]=x[c>>2];x[f+108>>2]=d;c=x[a+24652>>2];x[f+96>>2]=x[a+24648>>2];x[f+100>>2]=c;j=f,k=jJ(b),x[j+116>>2]=k;if(!bx(f+96|0,a+24648|0)){break e}$x(a,f+96|0)}hb=f+272|0;return}b=P()|0;ca(a|0)}T(b|0)}p()}function z8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0;d=hb-128|0;hb=d;g=-1;a:{b:{c:{d:{if(x[(x[x[b>>2]-12>>2]+b|0)+16>>2]){break d}_d(d+112|0,b);e=x[d+120>>2];k=x[d+124>>2];f=d+104|0;tl(f);b=yk(b,f,8);if(Rb(f,16589,8)){a=dh(d+88|0,e,k);c=x[a+12>>2];x[d+16>>2]=x[a+8>>2];x[d+20>>2]=c;c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;zj(b,d+8|0);break d}w[d+86>>1]=0;Ff(b,d+86|0);k=w[d+86>>1];if((k-4&65535)>>>0<65534){break d}f=d+78|0;tl(f);e=yk(b,f,8);if(Rb(f,14157,8)){break d}w[d+76>>1]=0;Ff(e,d+76|0);f=w[d+76>>1];if((f-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(f>>>0<=3){b=Kb(d+112|0);x[23604]=0;h=W(428,e|0,b|0,65535)|0;l=x[23604];x[23604]=0;if((l|0)==1){break b}if(!h){break i}x[23604]=0;U(11,d- -64|0,c|0,b|0);h=x[23604];x[23604]=0;if((h|0)!=1){break j}break b}b=Kb(d+112|0);x[23604]=0;h=Q(430,e|0,b|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break c}if(!h){break h}x[23604]=0;U(11,d- -64|0,c|0,b|0);h=x[23604];x[23604]=0;if((h|0)==1){break c}}h=d- -64|0;Ab(a+40|0,h);xb(h);xb(b);w[d+62>>1]=0;Ff(e,d+62|0);w[d+60>>1]=0;Ff(e,d+60|0);w[a>>1]=z[d+60>>1];w[d+58>>1]=0;k:{if((f|0)<=3){x[d+112>>2]=0;Uj(e,d+112|0);b=x[d+112>>2];if(b>>>0>65535){break d}b=bu(b);w[d+58>>1]=b;break k}Ff(e,d+58|0);b=z[d+58>>1]}h=a+52|0;l=b&65535;n=(f|0)>3;b=0;l:{m:{while(1){if(l>>>0<=(b&65535)>>>0){break l}f=Kb(d+112|0);x[23604]=0;w[d+40>>1]=0;R(844,e|0,d+40|0);i=x[23604];x[23604]=0;if((i|0)==1){break g}n:{if(!n){x[23604]=0;i=W(428,e|0,f|0,65535)|0;j=x[23604];x[23604]=0;if((j|0)==1){break g}if(i){break n}break e}x[23604]=0;i=Q(430,e|0,f|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break g}if(!i){break e}}x[23604]=0;U(11,d- -64|0,c|0,f|0);i=x[23604];x[23604]=0;if((i|0)!=1){x[23604]=0;i=Q(841,h|0,d+40|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break m}j=i;i=d- -64|0;Ab(j,i);xb(i);xb(f);b=b+1|0;continue}break}g=P()|0;break f}g=P()|0;xb(d- -64|0);break f}c=d- -64|0;tl(c);b=yk(e,c,8);if(Rb(c,14101,8)){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;o:{if((k|0)<=2){if(YK(b,c)){break o}break d}if(!XK(b,c)){break d}}o=d,q=Bb(x[a+4>>2]),x[o+112>>2]=q;c=Bb(x[a+8>>2]);while(1){e=x[d+112>>2];if(Ob(e,c)){if(!Sl(B[e>>2])){break d}Fe(d+112|0);continue}break}c=a+16|0;p:{if((k|0)<=2){if(YK(b,c)){break p}break d}if(!XK(b,c)){break d}}o=d,q=Bb(x[a+16>>2]),x[o+112>>2]=q;c=Bb(x[a+20>>2]);while(1){e=x[d+112>>2];if(Ob(e,c)){if(!Sl(B[e>>2])){break d}Fe(d+112|0);continue}break}o=a,q=rc(x[a+16>>2],x[a+20>>2]),x[o+36>>2]=q;w[d+56>>1]=0;Ff(b,d+56|0);c=z[d+56>>1];w[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}w[d+54>>1]=0;Ff(b,d+54|0);c=w[d+54>>1];w[a+30>>1]=c;if((c|0)<0){break d}x[d+48>>2]=0;ep(b,d+48|0);m=_K(B[d+48>>2]);B[a+32>>2]=m;if(!Sl(m)){break d}c=d+40|0;tl(c);yk(b,c,8);if(Rb(c,16580,8)){break d}b=rc(x[a+4>>2],x[a+8>>2]);if(b>>>0>32767){break d}c=w[a+30>>1];e=z[a>>1];if(!(e?!(B[a+32>>2]<=E(0))&(c|0)>0:1)){break d}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break q}}b=0;c=x[a+36>>2];if(c){b=c-1|0;x[a+36>>2]=b}o=d,q=oi(b),x[o+112>>2]=q;x[d+32>>2]=0;o=a,q=x[nj(d+112|0,d+32|0,44352)>>2],x[o+36>>2]=q;fp(a);g=1;if(z[a>>1]!=3){break d}c=w[a+30>>1];if((c-w[a+28>>1]|0)>(gL(rc(x[a+4>>2],x[a+8>>2]))|0)){break d}g=a+32|0;e=Sb(d+112|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=z[a+28>>1];w[d+32>>1]=b;o=d,q=(rc(x[a+4>>2],x[a+8>>2])+b|0)-1|0,w[o+34>>1]=q;x[23604]=0;w[d+30>>1]=0;ja(839,a|0,e|0,g|0,d+32|0,d+30|0)|0;a=x[23604];x[23604]=0;g=1;if((a|0)==1){break r}sc(e);break d}c=w[a+28>>1];f=x[a+4>>2];x[23604]=0;R(845,e|0,zb(f,b-c|0)|0);c=x[23604];x[23604]=0;if((c|0)!=1){b=b+1|0;c=z[a+30>>1];continue}}break}g=P()|0;sc(e);break a}xb(b);break d}xb(b);break d}g=P()|0}xb(f);break a}xb(f)}hb=d+128|0;return g|0}g=P()|0;xb(b);break a}g=P()|0;xb(b)}T(g|0);p()}function XU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-3056|0;hb=e;xc(b);f=hb-16|0;hb=f;h=e+1096|0;yB(f+8|0,h);i=x[f+12>>2];j=b;mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(i|0)){bc(j,x[f+12>>2])}hb=f+16|0;b=(b|0)==(i|0);if(!b){xB(h)}a:{if(!b){break a}if(!zB(e+1096|0)){break a}b:{if(!c){break b}if(!Qb(x[j>>2],x[j+8>>2],Uc(1024,0))){break a}wB(j,e+576|0);wB(j,e- -64|0);while(1){if((g|0)!=128){b=g<<2;f=x[b+(e+576|0)>>2];if(f>>>0>16777215){break a}b=x[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}g=g+1|0;if(_q(x[j>>2],(b+f|0)+2978|0)){continue}break a}break}Cd(a,2);Ag(a);b=e+40|0;d=Xb(b,13704);Ab(a+1298344|0,d);xb(d);d=Xb(b,14622);Ab(a+1298356|0,d);xb(d);b=Xb(b,15279);Ab(a+1298368|0,b);xb(b);x[a+1298404>>2]=5;b=y[e+1096|0];x[a+480204>>2]=143e4;x[a+480196>>2]=b;Xe(_b(x[a+484360>>2],y[a+484376|0]),y[e+1097|0]);x[a+480188>>2]=4194317;Nb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;g=0;while(1){if((g|0)==4){c:{while(1){d:{if((d|0)==32){g=0;break d}b=d+1|0;g=D(b,104)+a|0;i=g+484380|0;od(i,2);h=e+16|0;Ph(h,1,(D(d,13)+e|0)+1098|0);f=e+40|0;Dc(f,h);Bc(((b<<5)+a|0)+946304|0,f);xb(f);d=(e+1096|0)+(d<<4)|0;f=y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24);x[i>>2]=f;h=f;f=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);if(h>>>0>=f>>>0){d=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);w[g+484414>>1]=2;x[g+484388>>2]=f;x[g+484384>>2]=d}x[g+484404>>2]=8287;d=b;continue}break}while(1){if((g|0)!=32){d=g+33|0;f=(D(d,104)+a|0)+484380|0;od(f,2);i=e+16|0;Ph(i,1,(D(g,13)+e|0)+2026|0);b=e+40|0;Dc(b,i);Bc(((d<<5)+a|0)+946304|0,b);xb(b);x[e+48>>2]=0;x[e+40>>2]=0;x[e+44>>2]=0;d=(e+1096|0)+D(g,11)|0;o=Gb(b,0),q=y[d+1347|0],v[o|0]=q;o=Gb(b,1),q=y[d+1352|0],v[o|0]=q;o=Gb(b,2),q=y[d+1348|0],v[o|0]=q;o=Gb(b,3),q=y[d+1353|0],v[o|0]=q;o=Gb(b,4),q=y[d+1349|0],v[o|0]=q;o=Gb(b,5),q=y[d+1354|0],v[o|0]=q;o=Gb(b,6),q=y[d+1350|0],v[o|0]=q;o=Gb(b,7),q=y[d+1355|0],v[o|0]=q;o=Gb(b,8),q=y[d+1351|0],v[o|0]=q;o=Gb(b,9),q=y[d+1356|0],v[o|0]=q;o=Gb(b,10),q=y[d+1346|0],v[o|0]=q;x[e+8>>2]=x[e+48>>2];b=x[e+44>>2];x[e>>2]=x[e+40>>2];x[e+4>>2]=b;kl(f,1,e);g=g+1|0;continue}break}Bq(_b(x[a+484360>>2],y[a+484376|0]),e+2794|0,256,255,65535);l=a+484344|0;gg(l,128);m=c&1;f=0;while(1){e:{f:{if((f|0)!=128){b=f<<2;Yc(j,x[b+(e+576|0)>>2]+2978|0);d=e+16|0;Ud(d,j,x[b+(e- -64|0)>>2]);b=kc(e+40|0,d);yb(d);if(!m){break e}x[23604]=0;d=W(212,l|0,f&65535,64)|0;g=x[23604];x[23604]=0;if((g|0)==1){break c}if(!d){break e}g=0;i=ac(x[l>>2],f);while(1){if(g>>>0>63){break e}d=x[b>>2];x[23604]=0;d=W(142,d|0,x[e+48>>2],1)|0;h=x[23604];x[23604]=0;g:{if((h|0)!=1){if(!d){break e}x[23604]=0;d=S(192,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break c}if(d>>>0>12){break g}h=cd(x[i>>2],x[x[i+48>>2]+12>>2],g,d);x[23604]=0;R(245,e+16|0,b|0);k=x[23604];x[23604]=0;if((k|0)==1){break c}k=y[e+16|0];d=d>>>0>3;v[h|0]=((k&15)+(d?13:37)|0)+D(k>>>4&7,12);k=hd(e+16|0);v[h+1|0]=((y[k|0]>>>4|0)+(d?33:1)|0)+(y[e+16|0]>>>3&16);vB(h,y[k|0],d);continue}break c}h=d-32|0;if((h&255)>>>0<=12){h=cd(x[i>>2],x[x[i+48>>2]+12>>2],g,h&65535);x[23604]=0;k=S(192,b|0)|0;n=x[23604];x[23604]=0;if((n|0)==1){break c}vB(h,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!g){break e}o=cd(x[i>>2],x[x[i+48>>2]+12>>2],g-1|0,0),q=14,v[o+3|0]=q;break e}x[23604]=0;d=S(192,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break c}g=d+g|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}fg(Xc(e+40|0,8,1,0,1),(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}yb(b);d=0;break a}yb(b);f=f+1|0;continue}}}else{w[((g<<5)+a|0)+480284>>1]=g&1?192:64;g=g+1|0;continue}break}a=P()|0;yb(b);T(a|0);p()}d=1}hb=e+3056|0;return d|0}function w_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=hb-32|0;hb=h;x[h+24>>2]=b;x[e>>2]=0;Pc(h+8|0,x[d+28>>2]);x[23604]=0;i=S(18,x[h+8>>2])|0;j=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){$b(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;$b(h+8|0);T(a|0);p()}XF(a,f+24|0,h+24|0,c,e,i);break b}WF(a,f+16|0,h+24|0,c,e,i);break b}g=a;i=b;a=mb[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Pb(a);k=h,l=Bj(g,i,c,d,e,f,b,Eb(x[a+4>>2],y[a+11|0])+b|0),x[k+24>>2]=l;break b}a=Ji(h+24|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h+8>>2]=623865125;x[h+12>>2]=2032480100;k=h,l=Bj(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}x[h+8>>2]=623728933;x[h+12>>2]=1680158061;k=h,l=Bj(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}a=Ji(h+24|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=Ji(h+24|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=Ji(h+24|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=Ji(h+24|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=Ji(h+24|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+24|0;b=hb-16|0;hb=b;x[b+8>>2]=c;while(1){H:{if(Lg(a,b+8|0)){break H}c=zk(x[a>>2]);if(!fh(x[i+8>>2],1,c)){break H}Hl(a);continue}break}if(Lg(a,b+8|0)){x[e>>2]=x[e>>2]|2}hb=b+16|0;break b}b=h+24|0;a=mb[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Eb(x[a+4>>2],y[a+11|0])|0)==(0-Eb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=Br(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[82168]|y[82169]<<8|(y[82170]<<16|y[82171]<<24);v[h+15|0]=g;v[h+16|0]=g>>>8;v[h+17|0]=g>>>16;v[h+18|0]=g>>>24;g=y[82165]|y[82166]<<8|(y[82167]<<16|y[82168]<<24);x[h+8>>2]=y[82161]|y[82162]<<8|(y[82163]<<16|y[82164]<<24);x[h+12>>2]=g;k=h,l=Bj(a,b,c,d,e,f,h+8|0,h+19|0),x[k+24>>2]=l;break b}v[h+12|0]=y[82176];x[h+8>>2]=y[82172]|y[82173]<<8|(y[82174]<<16|y[82175]<<24);k=h,l=Bj(a,b,c,d,e,f,h+8|0,h+13|0),x[k+24>>2]=l;break b}a=Ji(h+24|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h+8>>2]=624576549;x[h+12>>2]=1394948685;k=h,l=Bj(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}a=Ji(h+24|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=mb[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Pb(a);k=h,l=Bj(g,i,c,d,e,f,b,Eb(x[a+4>>2],y[a+11|0])+b|0),x[k+24>>2]=l;break b}VF(f+20|0,h+24|0,c,e,i);break b}a=Ji(h+24|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=hb-16|0;hb=a;x[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(Lg(c,a+8|0)){break M}b=4;if(($m(i,zk(x[c>>2]))|0)!=37){break M}b=2;if(!Lg(Hl(c),a+8|0)){break L}}x[e>>2]=x[e>>2]|b}hb=a+16|0}a=x[h+24>>2]}hb=h+32|0;return a|0}function lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=hb-224|0;hb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!ho(b,d+208|0)){break l}if(!rR(d+208|0)){break l}g=xh(d+184|0);h=Kb(d+168|0);Zt(d+104|0);x[23604]=0;f=Q(546,b|0,d+96|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=dc(dc(x[d+100>>2])-4|0),x[m+100>>2]=n;while(1){f=dc(dc(x[d+100>>2])-8|0);x[d+100>>2]=f;n:{if(c){break n}if((dc(x[d+96>>2])|0)!=1347699796){break n}j=1;break m}x[23604]=0;U(176,d+72|0,b|0,dc(f)|0);f=x[23604];x[23604]=0;if((f|0)==1){break d}e=d+72|0;f=kc(d+8|0,e);yb(e);e=x[f>>2];x[23604]=0;i=S(164,e|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=dc(x[d+96>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}x[23604]=0;Q(174,f|0,4)|0;e=x[23604];x[23604]=0;if((e|0)==1){break b}x[23604]=0;e=S(547,f|0)|0;k=x[23604];x[23604]=0;if((k|0)==1){break b}if(!e){break o}e=dc(x[d+100>>2]);if(e>>>0<7){break o}x[23604]=0;U(548,f|0,h|0,e-6|0);e=x[23604];x[23604]=0;if((e|0)==1){break b}break o}x[23604]=0;l=Q(549,f|0,d+104|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break o}break b}Xu(g,f);break o}x[23604]=0;j=W(550,a|0,f|0,c|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break b}}yb(f);if(i){x[23604]=0;f=Q(546,b|0,d+96|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break i}if(f){continue}}break}if(wd(x[h+4>>2],y[h+11|0])){x[23604]=0;b=Q(1,d+72|0,14750)|0;c=x[23604];x[23604]=0;if((c|0)==1){break g}Ab(h,b);xb(b)}q:{if(!(j&l&1)){break q}b=z[d+146>>1];x[23604]=0;b=Lb(b)&256;W(249,a+1074312|0,5,!b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break f}c=Lb(z[d+142>>1]);if(c){w[d+8>>1]=64;w[d+56>>1]=c;m=a,n=z[Wc(d+8|0,d+56|0)>>1],x[m+480228>>2]=n}c=!b;b=Lb(z[d+144>>1]);if(!(c|!b)){x[a+480204>>2]=D(b,1e4)}if(y[d+104|0]){b=d+56|0;We(b,2,d+104|0);x[23604]=0;R(208,d+8|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break e}b=d+8|0;Ab(a+1298308|0,b);xb(b)}c=z[d+150>>1];if(!Ip(c,1,12)){break q}f=z[d+148>>1];if(!Ip(f,1,31)){break q}e=z[d+154>>1];if(!Ip(e,0,23)){break q}i=z[d+156>>1];if(!Ip(i,0,59)){break q}k=z[d+158>>1];if(!Ip(k,0,59)){break q}b=kq(d+8|0);m=b,n=Lb(z[d+152>>1]),x[m+20>>2]=n;m=b,n=Lb(c)-1|0,x[m+16>>2]=n;m=b,n=Lb(f),x[m+12>>2]=n;m=b,n=Lb(e),x[m+8>>2]=n;m=b,n=Lb(i),x[m+4>>2]=n;m=b,n=Lb(k),x[m>>2]=n;x[23604]=0;R(379,a+1298408|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break q}a=P()|0;break a}if(j&1){b=x[g>>2];x[23604]=0;b=S(164,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break h}if(b){b=Kb(d+8|0);x[23604]=0;U(253,g|0,b|0,32);c=x[23604];x[23604]=0;if((c|0)==1){break c}if($p(b,13597)){x[23604]=0;U(11,d+56|0,13,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break c}c=d+56|0;Ab(a+1298320|0,c);xb(c)}c=x[g+8>>2];f=x[g>>2];x[23604]=0;c=Q(551,f|0,c|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break c}if(!c){x[23604]=0;c=S(188,g|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break c}x[23604]=0;ea(297,a+1298332|0,g|0,c|0,40,0);c=x[23604];x[23604]=0;if((c|0)==1){break c}}xb(b)}x[23604]=0;b=Q(1,d+56|0,17376)|0;c=x[23604];x[23604]=0;if((c|0)==1){break k}x[23604]=0;U(422,d+8|0,b|0,h|0);c=x[23604];x[23604]=0;if((c|0)==1){break j}c=d+8|0;Ab(a+1298368|0,c);xb(c);xb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[23604]=0;a=W(249,a+1074312|0,84,1)|0;b=x[23604];x[23604]=0;if((b|0)==1){break h}x[23604]=0;a=W(249,a|0,83,1)|0;b=x[23604];x[23604]=0;if((b|0)==1){break h}x[23604]=0;Q(250,a|0,85)|0;a=x[23604];x[23604]=0;if((a|0)==1){break h}}xb(h);yb(g)}hb=d+224|0;return j&1}a=P()|0;break a}a=P()|0;xb(b);break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;xb(b);break a}a=P()|0;yb(f)}xb(h);yb(g);T(a|0);p()}function xj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;i=1;o(+b);c=j(1)|0;e=j(0)|0;a:{b:{g=c;p=c&2147483647;c:{if(!(p|e)){break c}o(+a);c=j(1)|0;f=j(0)|0;if(!f&(c|0)==1072693248){break c}q=c&2147483647;t=f;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(f|0)!=0|p>>>0>2146435072)&(!e|(p|0)!=2146435072))){return a+b}d:{e:{f:{g:{h:{r=0;i:{if((c|0)>0|(c|0)>=0){break i}r=2;if(p>>>0>1128267775){break i}r=0;if(p>>>0<1072693248){break i}f=p>>>20|0;if(p>>>0<1094713344){break h}m=1075-f|0;f=e>>>m|0;r=0;if((e|0)!=f<<m){break i}r=2-(f&1)|0}m=r;if(e){break f}if((p|0)!=2146435072){break g}if(!(q-1072693248|t)){break c}if(q>>>0<1072693248){break e}return(g|0)>0|(g|0)>=0?b:0}if(e){break f}f=1043-f|0;e=p>>>f|0;if((p|0)!=e<<f){break g}m=2-(e&1)|0}if((p|0)==1072693248){if((g|0)>0|(g|0)>=0){return a}return 1/a}if((g|0)==1073741824){return a*a}if((g|0)!=1071644672|(c|0)<0){break f}return M(a)}d=F(a);if(t){break d}j:{if((c|0)<0){if((c|0)==-2147483648|(c|0)==-1074790400|(c|0)==-1048576){break j}break d}if(!c|(c|0)==2146435072){break j}if((c|0)!=1072693248){break d}}i=(g|0)<0?1/d:d;if((c|0)>0|(c|0)>=0){break c}if(!(q-1072693248|m)){a=i-i;return a/a}return(m|0)==1?-i:i}return(g|0)>0|(g|0)>=0?0:-b}k:{if((c|0)>0|(c|0)>=0){break k}l:{switch(m|0){case 0:a=a-a;return a/a;case 1:break l;default:break k}}i=-1}m:{if(p>>>0>=1105199105){if(p>>>0>=1139802113){if(q>>>0<=1072693247){return(g|0)<0?O:0}return(g|0)>0?O:0}if(q>>>0<=1072693246){return(g|0)<0?i*1e300*1e300:i*1e-300*1e-300}if(q>>>0>=1072693249){return(g|0)>0?i*1e300*1e300:i*1e-300*1e-300}a=d+-1;d=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;h=d;d=a*1.4426950216293335;o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-d);break m}a=d*9007199254740992;e=q>>>0<1048576;d=e?a:d;o(+a);c=j(1)|0;j(0)|0;m=e?c:q;f=m&1048575;c=f|1072693248;m=(m>>20)+(e?-1076:-1023)|0;e=0;n:{if(f>>>0<235663){break n}if(f>>>0<767610){e=1;break n}c=f|1071644672;m=m+1|0}f=((e<<18)+(c>>>1|0)|0)+537395200|0;e=e<<3;w=C[e+3536>>3];o(+d);j(1)|0;t=0;l(0,j(0)|t);l(1,c|0);k=+n();s=C[e+3520>>3];h=k-s;u=1/(s+k);d=h*u;o(+d);c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();x=a;l(0,t|0);l(1,f|0);v=a*a;y=h;h=+n();k=u*(y-a*h-a*(k-(h-s)));h=k*(d+a);a=d*d;s=h+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();h=x*a;d=k*a+d*(s-(a+-3-v));o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=w+(a*-7.028461650952758e-9+(d-(a-h))*.9617966939259756);h=d;k=C[e+3552>>3];d=a*.9617967009544373;s=+(m|0);o(+(k+(h+d)+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-s-k-d)}l(0,0);l(1,g|0);k=+n();d=(b-k)*a+d*b;b=a*k;a=d+b;o(+a);c=j(1)|0;g=j(0)|0;o:{if((c|0)>=1083179008){if(g|c-1083179008){break b}if(!(d+8008566259537294e-32>a-b)){break o}break b}if((c&2147482624)>>>0<1083231232){break o}if(g|c+1064252416){break a}if(!(d<=a-b)){break o}break a}e=0;f=c&2147483647;if(f>>>0>=1071644673){g=c+(1048576>>>(f>>>20|0)-1022|0)|0;f=g>>>20&2047;e=(g&1048575|1048576)>>>1043-f|0;e=(c|0)<0?0-e|0:e;l(0,0);l(1,g&-1048576>>f-1023);b=b-+n();o(+(d+b));c=j(1)|0;j(0)|0}l(0,0);l(1,c|0);a=+n();k=a*.6931471824645996;d=(d-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=k+d;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);h=a*b/(b+-2);b=a;a=d-(a-k);a=b-(h-(b*a+a))+1;o(+a);c=j(1)|0;g=j(0)|0;c=(e<<20)+c|0;p:{if((c|0)<=1048575){a=uj(a,e);break p}l(0,g|0);l(1,c|0);a=+n()}i=i*a}return i}return i*1e300*1e300}return i*1e-300*1e-300}function Cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;i=hb-736|0;hb=i;a:{b:{if(d>>>0<=511){a=hb-16|0;hb=a;e=i+56|0;hc(a+8|0,e,554);d=x[a+12>>2];mc(a,x[b>>2],x[b+8>>2],x[a+8>>2],x[a+12>>2]);f=x[a+4>>2];if((f|0)==(d|0)){bc(b,x[a+12>>2])}hb=a+16|0;a=(d|0)==(f|0);if(!a){Zb(e,0,554)}if(!a){break b}d=hb-32|0;hb=d;c:{a=i+56|0;if(Rb(a,13857,4)){break c}Hq(d,a+32|0);b=d+16|0;Dc(b,d);Bc(c+492|0,b);xb(b);Ph(d,1,a+4|0);Dc(b,d);Bc(c+524|0,b);xb(b);b=y[a+24|0]|y[a+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[a+26|0];v[c+17|0]=y[a+27|0];f=c+108|0;k=c+236|0;b=0;while(1)if((b|0)==120){b=y[c+60|0]&-2|v[a+17|0]&1;v[c+60|0]=b;b=b&-3|y[a+17|0]&2;v[c+60|0]=b;v[c+60|0]=b&251|y[a+17|0]&4;k=c+61|0;v[k|0]=y[a+18|0];g=c+62|0;v[g|0]=y[a+19|0];j=c+63|0;v[j|0]=y[a+20|0];h=c- -64|0;v[h|0]=y[a+21|0];f=c+48|0;Zg(f,25);e=x[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=zb(e,b);m=b<<1;n=y[(a+m|0)+504|0];w[l>>1]=n;if((n|0)!=255){break d}Zg(f,b);e=x[f>>2]}b=Ye(k,g);a=ie(e,x[c+52>>2]);if(a>>>0<=y[b|0]){v[c+60|0]=y[c+60|0]&253}if(a>>>0>y[Ye(j,h)|0]){break c}v[c+60|0]=y[c+60|0]&251;break c}v[l+2|0]=y[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{g=a+(b<<1)|0;e=y[g- -64|0];g=y[g+65|0];o=cc(k,b),q=g,w[o>>1]=q;o=Gb(f,b),q=(e>>>0<120?e:b)+1|0,v[o|0]=q;b=b+1|0;continue}}hb=d+32|0;break b}k=x[b+8>>2];d=hb-32|0;hb=d;x[d+28>>2]=674;x[d+8>>2]=674;e=x[b>>2];g=x[b+8>>2];f=x[Fb(d+28|0,d+8|0)>>2];if(!Qb(e,g,f)){f=cf(b)}g=d+8|0;e=i+56|0;fT(g,e);j=ec(d+16|0,x[d+8>>2],f);h=x[j>>2];mc(d,x[b>>2],x[b+8>>2],h,x[j+4>>2]);fT(g,e);Zb(x[d+8>>2]+f|0,0,674-f|0);bc(b,x[d+28>>2]);hb=d+32|0;f=x[a+480180>>2];a=0;d=hb-32|0;hb=d;if(!Rb(e,13857,4)){Hq(d,e+32|0);a=d+16|0;Dc(a,d);Bc(c+492|0,a);xb(a);Ph(d,1,e+4|0);Dc(a,d);Bc(c+524|0,a);xb(a);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;wc(c+4|0,64);g=y[e+25|0]&127;x[c+8>>2]=g>>>0>64?128:g<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[d+16|0]=y[e+26|0];v[d|0]=100;o=c,q=y[Wb(a,d)|0],v[o+20|0]=q;v[d+16|0]=y[e+27|0];v[d|0]=64;o=c,q=y[Wb(a,d)|0],v[o+19|0]=q;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];a=y[e+58|0];Bm(c,a&127,a>>>7|0);a=y[e+59|0];Am(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=y[e+28|0]|y[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=y[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){v[c+30|0]=a}a=y[e+62|0]|y[e+63|0]<<8;if(a>>>0<129){break f}break e}a=v[e+61|0];if((a|0)<0){break g}v[c+30|0]=a+1}a=y[e+62|0];a=a<<24>>24>=0?a+1|0:0;g=v[e+63|0];if((g|0)<0){break f}a=((g&255)<<7)+a|0}w[c+28>>1]=a}a=v[e+60|0];v[c+31|0]=a;if((a|0)<0){v[c+31|0]=0;v[c+34|0]=a^128}a=0;f=f&16777216?240:25;Su(e+304|0,c+48|0,0,f);Su(e+386|0,c+68|0,32,f);Su(e+468|0,c+88|0,32,f);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;g=c+108|0;j=c+236|0;while(1){if((a|0)!=120){h=e+(a<<1)|0;f=y[h- -64|0];h=y[h+65|0];o=cc(j,a),q=h,w[o>>1]=q;o=Gb(g,a),q=(f>>>0<120?f:a)+1|0,v[o|0]=q;a=a+1|0;continue}break}a=554}hb=d+32|0;d=0;k:{if(!a){break k}d=e+550|0;l:{if(Rb(d,13382,4)){if(Rb(d,13689,4)){break l}}a=c+236|0;f=0;while(1){if((f|0)!=120){d=y[(e+f|0)+554|0];g=cc(a,f);w[g>>1]=z[g>>1]|d<<8;f=f+1|0;continue}break}a=674}d=a}Yc(b,d+k|0);if(!wh(b,13862)){break b}d=i+8|0;Ud(d,b,kg(b));a=kc(i+32|0,d);yb(d);b=x[a>>2];x[23604]=0;S(146,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}x[23604]=0;b=Q(346,a|0,13612)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}if(b){x[23604]=0;b=S(192,a|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}v[c+34|0]=b>>>0<=250?b:0}yb(a)}hb=i+736|0;return}b=P()|0;yb(a);T(b|0);p()}function MJ(){var a=0,b=0,c=0,d=0,e=0,f=0;if(y[467872]){return x[116967]}b=Nd(469512);x[b>>2]=82376;c=b+8|0;x[c>>2]=0;x[c+4>>2]=0;e=zc(c+8|0),f=0,v[e+128|0]=f;a=hb-16|0;hb=a;if(bh(1073741823)>>>0<=29){Sc();p()}vF(a+8|0,Yv(c),30);d=x[a+8>>2];x[c+4>>2]=d;x[c>>2]=d;e=Cb(c),f=d+(x[a+12>>2]<<2)|0,x[e>>2]=f;hb=a+16|0;BF(c,30);x[23604]=0;d=Q(54,b+152|0,14155)|0;a=x[23604];x[23604]=0;a:{b:{c:{if((a|0)!=1){AF(c);Nd(469184);x[117296]=84964;x[23604]=0;Y(1124,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469192);x[117298]=84996;x[23604]=0;Y(1125,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}a=Nd(469200);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=82396;x[a+8>>2]=82448;x[23604]=0;Y(1126,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469216);x[117304]=83912;x[23604]=0;Y(1127,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469224);x[117306]=84060;x[23604]=0;Y(1128,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}x[23604]=0;Z(1129);a=x[23604];x[23604]=0;if((a|0)==1){break c}x[23604]=0;Y(1130,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469248);x[117312]=84208;x[23604]=0;Y(1131,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469256);x[117314]=84440;x[23604]=0;Y(1132,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469264);x[117316]=84324;x[23604]=0;Y(1133,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469272);x[117318]=84556;x[23604]=0;Y(1134,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}a=Nd(469280);w[a+8>>1]=11310;x[a>>2]=83528;Kb(a+12|0);x[23604]=0;Y(1135,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}a=Nd(469304);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=83568;Kb(a+16|0);x[23604]=0;Y(1136,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469336);x[117334]=85028;x[23604]=0;Y(1137,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469344);x[117336]=85272;x[23604]=0;Y(1138,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469352);x[117338]=85484;x[23604]=0;Y(1139,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469360);x[117340]=85716;x[23604]=0;Y(1140,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469368);x[117342]=86700;x[23604]=0;Y(1141,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469376);x[117344]=86848;x[23604]=0;Y(1142,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469384);x[117346]=86964;x[23604]=0;Y(1143,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469392);x[117348]=87080;x[23604]=0;Y(1144,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469400);x[117350]=87196;x[23604]=0;Y(1145,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469408);x[117352]=87360;x[23604]=0;Y(1146,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469416);x[117354]=87524;x[23604]=0;Y(1147,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469424);x[117356]=87688;x[23604]=0;Y(1148,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469432);x[117360]=88944;x[117360]=85964;x[117358]=85916;x[23604]=0;Y(1149,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469448);x[117364]=88980;x[117364]=86228;x[117362]=86180;x[23604]=0;Y(1150,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}x[23604]=0;Z(1151);a=x[23604];x[23604]=0;if((a|0)==1){break c}x[23604]=0;Y(1152,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}x[23604]=0;Z(1153);a=x[23604];x[23604]=0;if((a|0)==1){break c}x[23604]=0;Y(1154,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469496);x[117374]=87852;x[23604]=0;Y(1155,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}Nd(469504);x[117376]=87972;x[23604]=0;Y(1156,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}break a}b=P()|0;break b}b=P()|0;xb(d)}CF(c);T(b|0);p()}x[116966]=469512;v[467872]=1;x[116967]=467864;return 467864}function VL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-16|0;hb=h;a:{b:{c:{d:{if(!Tc(c)|!d|x[b+480180>>2]!=16777216|z[b+480192>>1]<d>>>0){break d}d=x[((d<<2)+b|0)+900380>>2];if(!d){break d}d=x[d+44>>2];if(!d){break d}w[h+14>>1]=c-61;b=hb+-64|0;hb=b;e:{f:{e=w[d+28>>1];g=h+14|0;c=w[g>>1];if((e|0)<=(c|0)){if((c|0)<=(rc(x[d+4>>2],x[d+8>>2])+e|0)-1<<16>>16){break f}}Kb(a);break e}g:{e=z[d+30>>1];if(!e){c=d+52|0;d=Fx(c,g);if(!xg(d,xf(c))){break g}lg(a,sd(d)+4|0);break e}e=Ex(c,e<<16>>16);w[b+62>>1]=e;c=Kb(a);h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{a=d+52|0;f=Fx(a,b+62|0);u:{if(xg(f,xf(a))){x[23604]=0;R(121,c|0,sd(f)+4|0);a=x[23604];x[23604]=0;if((a|0)==1){break u}a=w[d+30>>1];d=w[g>>1];x[23604]=0;l=b,m=Dx(d,a)+5|0,x[l+32>>2]=m;R(118,b+48|0,b+32|0);a=x[23604];x[23604]=0;v:{if((a|0)!=1){x[23604]=0;Q(87,c|0,b+48|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break v}xb(b+48|0);break e}a=P()|0;break h}a=P()|0;xb(b+48|0);break h}if(w[d+30>>1]>26){break r}x[23604]=0;e=W(475,b+32|0,1,e+65<<24>>24)|0;a=x[23604];x[23604]=0;if((a|0)==1){break t}x[23604]=0;U(11,b+48|0,0,e|0);a=x[23604];x[23604]=0;if((a|0)==1){break s}a=b+48|0;f=Ab(c,a);xb(a);xb(e);x[23604]=0;Q(119,f|0,14506)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break q}}a=P()|0;break h}a=P()|0;break h}a=P()|0;xb(e);break h}x[23604]=0;a=e<<16>>16;x[b+28>>2]=(a|0)%16;R(793,b+32|0,b+28|0);e=x[23604];x[23604]=0;if((e|0)==1){break p}x[23604]=0;x[b+12>>2]=((a|0)/16<<16>>16)%16;R(793,b+16|0,b+12|0);e=x[23604];x[23604]=0;if((e|0)==1){break o}x[23604]=0;U(2,b+48|0,b+32|0,b+16|0);e=x[23604];x[23604]=0;if((e|0)==1){break n}e=b+48|0;f=Ab(c,e);xb(e);xb(b+16|0);xb(b+32|0);if((a|0)<256){break q}x[23604]=0;U(8,b|0,0,f|0);a=x[23604];x[23604]=0;if((a|0)==1){break l}i=b+32|0;e=pd(b);j=pf(b);k=pd(b);a=hb-16|0;hb=a;x[a>>2]=k;x[a+8>>2]=e;while(1){if(Ob(e,j)){l=x[a>>2],m=gp(v[e|0]),v[l|0]=m;e=Le(a+8|0);Le(a);e=x[e>>2];continue}break}hb=a+16|0;dd(i,b);x[23604]=0;U(11,b+48|0,0,i|0);a=x[23604];x[23604]=0;if((a|0)==1){break k}a=b+48|0;Ab(f,a);xb(a);xb(b+32|0);xb(b)}a=w[d+30>>1];d=w[g>>1];x[23604]=0;l=b,m=Dx(d,a)+5|0,x[l+16>>2]=m;R(118,b+48|0,b+16|0);a=x[23604];x[23604]=0;if((a|0)==1){break j}x[23604]=0;Q(87,c|0,b+48|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break i}xb(b+48|0);break e}a=P()|0;break h}a=P()|0;break m}a=P()|0;xb(b+16|0)}xb(b+32|0);break h}a=P()|0;break h}a=P()|0;xb(b+32|0);xb(b);break h}a=P()|0;break h}a=P()|0;xb(b+48|0)}break b}c=hb-16|0;hb=c;e=hb-32|0;hb=e;d=Ue(e+16|0,1,0);w:{while(1){f=Pb(d);ts(e+8|0,f,Eb(x[d+4>>2],y[d+11|0])+f|0,w[g>>1]);if(!x[e+12>>2]){break w}f=Rf(Eb(x[d+4>>2],y[d+11|0]));x[23604]=0;R(58,d|0,f|0);f=x[23604];x[23604]=0;if((f|0)!=1){continue}break}break a}g=x[e+8>>2];f=Pb(d);x[23604]=0;R(59,d|0,g-f|0);g=x[23604];x[23604]=0;x:{if((g|0)!=1){x[23604]=0;R(71,c|0,d|0);g=x[23604];x[23604]=0;if((g|0)!=1){break x}break a}break a}xb(d);hb=e+32|0;x[23604]=0;R(70,a|0,c|0);a=x[23604];x[23604]=0;y:{if((a|0)!=1){xb(c);hb=c+16|0;break y}a=P()|0;break b}}hb=b- -64|0;break c}e=x[b>>2];b=hb-32|0;hb=b;z:{if(kp(c)){x[b+16>>2]=x[8116];d=x[8115];x[b+8>>2]=x[8114];x[b+12>>2]=d;d=x[8113];x[b>>2]=x[8112];x[b+4>>2]=d;Xb(a,(b+(c<<2)|0)-1004|0);break z}if(Tc(c)){d=Kb(b);x[23604]=0;c=c-1|0;g=(c|0)/12|0;c=Q(794,d|0,e+(D(g,-12)+c<<16>>16<<2)|0)|0;e=x[23604];x[23604]=0;A:{if((e|0)==1){break A}x[23604]=0;c=Q(795,c|0,g+48<<24>>24)|0;e=x[23604];x[23604]=0;if((e|0)==1){break A}x[23604]=0;Q(3,a|0,c|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break A}xb(c);break z}break a}if(!c){Xb(a,16613);break z}Xb(a,14477)}hb=b+32|0}hb=h+16|0;return}xb(c);T(a|0);p()}a=P()|0;xb(d);T(a|0);p()}function FM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;g=a+1074376|0;h=D(b,872);f=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;x[a>>2]=x[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(cj(x[f+656>>2])){a=D(b,872)+a|0;w[a+1075764>>1]=d-8;a=a+1075843|0;v[a|0]=y[a|0]|64;break a}if(x[a+480180>>2]!=64){b=D(b,872)+a|0;c=d<<28>>24;w[b+1075764>>1]=c;f=z[(d<<1)+33808>>1];x[b+1075696>>2]=f;d=b+1075692|0;if(!x[d>>2]){break a}k=d,l=Og(a,y[b+1075789|0],c,f),x[k>>2]=l;break a}a=D(b,872)+a|0;b=x[a+1075096>>2];if(!b){break a}x[a+1075696>>2]=x[b+24>>2]+D(d,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075814|0]=c&3;break a}Jb(e+8|0,a+1074312|0,21);if(Mb(x[x[e+8>>2]>>2],x[e+12>>2])){v[(D(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075817|0]=c&3;break a}Jb(e+8|0,a+1074312|0,21);if(Mb(x[x[e+8>>2]>>2],x[e+12>>2])){v[(D(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Jb(e+8|0,a+1074312|0,21);if(Mb(x[x[e+8>>2]>>2],x[e+12>>2])){a=D(b,872)+a|0;v[a+1075813|0]=0;v[a+1075820|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+d;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(d>>>0<=2){c=z[a+480188>>1];h=c>>>0<=256?256:c;i=b+1|0;j=d-1|0;while(1){if((c|0)==(h|0)){break a}f=D(c,872)+a|0;c:{if(z[f+1075778>>1]!=(i|0)){break c}d:{e:{switch(j|0){case 0:Kn(a,f+1074992|0);if(!(y[f+1075081|0]&2)){break d}d=x[a+1298300>>2];if(!td(d)){break d}Kj(d,c&65535);break d;case 1:g=f+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!td(d)){break d}Kj(d,c&65535);break d;default:break e}}x[f+1075688>>2]=0;g=f+1075080|0;d=x[g>>2];x[g>>2]=d|4096;if(!(d&512)){break d}d=x[a+1298300>>2];if(!td(d)){break d}Zi(d,c&65535,1)}d=x[f+1075648>>2];if(!d){break c}g=y[d+34|0];if(!g){break c}g=x[(D(g,160)+a|0)+906140>>2];if(!g){break c}mb[x[x[g>>2]+92>>2]](g,d,y[f+1075789|0]+255|0,0,b)}c=c+1|0;continue}}cP(f,d,x[a+480180>>2]);break a;case 7:if(!(y[a+480209|0]&16)){break a}Zl(a,f,d,4);break a;case 8:b=f;c=x[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d|0){case 0:x[b+88>>2]=x[b+88>>2]&-257;break f;case 1:x[b+692>>2]=128;x[b+88>>2]=x[b+88>>2]|256;break f;case 8:x[b+88>>2]=x[b+88>>2]&-25165825|16777216;break f;case 9:x[b+88>>2]=x[b+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=c&-16385;break f;case 11:x[a+480208>>2]=c|16384;break f;case 12:x[a+480208>>2]=c&-8193;break f;case 13:x[a+480208>>2]=c|8192;break f;case 14:x[b+88>>2]=x[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(x[b>>2]|x[b+4>>2]){break h}a=x[b+76>>2];if(!a){break h}if(!(k=Tc(y[b+788|0]),l=1,m=y[b+88|0]&2,m?k:l)){break h}x[b>>2]=-1;x[b+4>>2]=a-1}x[b+88>>2]=x[b+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}c=D(b,872)+a|0;v[c+1075828|0]=d;Jb(e+8|0,a+1074312|0,35);if(Mb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}if(!Tc(y[c+1075780|0])){break a}b=x[(D(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}x[f+4>>2]=a;break a;case 10:if(!(y[a+480209|0]&16)){break a}Cy(a,g,b,d);break a;case 11:i:{if(d){break i}d=1;c=x[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Jb(e+8|0,a+1074312|0,30);qy(a,b,d,Mb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,872)+a|0)+1075836|0]=d}hb=e+16|0}function o5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=hb-128|0;hb=f;g=x[b+4>>2];h=y[b+11|0];a:{if(wd(g,h)){break a}e=y[mJ(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+112|0;ir(e,b,0,Qc(g,h)-1|0);Ab(b,e);xb(e)}g=f+112|0;Pd(g);e=x[f+112>>2];Pd(f+96|0);e=lJ(e,x[f+100>>2],b);Pd(g);b:{c:{d:{e:{if((e|0)==x[f+116>>2]){if(ne(b,21502)){a=ba(8)|0;x[23604]=0;U(906,f+112|0,17481,c|0);b=x[23604];x[23604]=0;if((b|0)==1){break d}a=pc(a,f+112|0);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(f+112|0);break c}if(!d){break e}a=ba(8)|0;x[23604]=0;U(906,f+80|0,17517,b|0);b=x[23604];x[23604]=0;f:{g:{h:{i:{j:{if((b|0)!=1){x[23604]=0;R(917,f+96|0,f+80|0);b=x[23604];x[23604]=0;if((b|0)==1){break j}x[23604]=0;U(477,f+112|0,f+96|0,c|0);b=x[23604];x[23604]=0;d=1;if((b|0)==1){break i}b=pc(a,f+112|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(f+112|0);d=0;break h}b=P()|0;break f}b=P()|0;d=1;break g}b=P()|0}xb(f+96|0)}xb(f+80|0);if(!d){break c}}ca(a|0);break c}k:{switch(x[e+4>>2]){case 0:ve(f+72|0,b);b=hb-192|0;hb=b;e=b+16|0;ih(e,c);x[23604]=0;R(77,b+32|0,e|0);c=x[23604];x[23604]=0;l:{m:{n:{o:{p:{if((c|0)!=1){x[23604]=0;c=Q(78,b+48|0,b+32|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break p}xb(b+32|0);xb(b+16|0);e=x[x[c>>2]-12>>2];x[23604]=0;g=ga(61)|0;h=x[23604];x[23604]=0;if((h|0)==1){break n}x[23604]=0;U(62,b+8|0,c+e|0,g|0);e=x[23604];x[23604]=0;if((e|0)==1){break n}$b(b+8|0);x[23604]=0;e=Q(1014,c|0,b+32|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break n}c=Ck(x[(e+x[x[e>>2]-12>>2]|0)+16>>2]);g=y[b+32|0];hf(e);hb=b+192|0;b=(c^-1)&(g|0)!=0;break l}a=P()|0;break o}a=P()|0;xb(b+32|0)}xb(b+16|0);break m}a=P()|0;hf(c)}T(a|0);p()}c=x[f+76>>2];x[f+8>>2]=x[f+72>>2];x[f+12>>2]=c;GJ(a,f+8|0,b,d);break e;case 1:ve(f- -64|0,b);b=hb-192|0;hb=b;e=b+16|0;ih(e,c);x[23604]=0;R(77,b+32|0,e|0);c=x[23604];x[23604]=0;q:{r:{s:{t:{u:{if((c|0)!=1){x[23604]=0;c=Q(78,b+48|0,b+32|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break u}xb(b+32|0);xb(b+16|0);e=x[x[c>>2]-12>>2];x[23604]=0;g=ga(61)|0;h=x[23604];x[23604]=0;if((h|0)==1){break s}x[23604]=0;U(62,b+8|0,c+e|0,g|0);e=x[23604];x[23604]=0;if((e|0)==1){break s}$b(b+8|0);x[23604]=0;e=Q(84,c|0,b+32|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break s}c=Ck(x[(e+x[x[e>>2]-12>>2]|0)+16>>2]);g=x[b+32>>2];h=x[b+36>>2];hf(e);hb=b+192|0;b=c?0:g;c=c?0:h;break q}a=P()|0;break t}a=P()|0;xb(b+32|0)}xb(b+16|0);break r}a=P()|0;hf(c)}T(a|0);p()}e=x[f+68>>2];x[f+16>>2]=x[f+64>>2];x[f+20>>2]=e;EJ(a,f+16|0,b,c,d);break e;case 2:ve(f+56|0,b);b=hb-192|0;hb=b;e=b+16|0;ih(e,c);x[23604]=0;R(77,b+32|0,e|0);c=x[23604];x[23604]=0;v:{w:{x:{y:{z:{if((c|0)!=1){x[23604]=0;c=Q(78,b+48|0,b+32|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break z}xb(b+32|0);xb(b+16|0);e=x[x[c>>2]-12>>2];x[23604]=0;g=ga(61)|0;h=x[23604];x[23604]=0;if((h|0)==1){break x}x[23604]=0;U(62,b+8|0,c+e|0,g|0);e=x[23604];x[23604]=0;if((e|0)==1){break x}$b(b+8|0);x[23604]=0;e=Q(85,c|0,b+32|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break x}c=Ck(x[(e+x[x[e>>2]-12>>2]|0)+16>>2]);i=C[b+32>>3];hf(e);hb=b+192|0;i=c?0:i;break v}a=P()|0;break y}a=P()|0;xb(b+32|0)}xb(b+16|0);break w}a=P()|0;hf(c)}T(a|0);p()}b=x[f+60>>2];x[f+24>>2]=x[f+56>>2];x[f+28>>2]=b;FJ(a,f+24|0,i,d);break e;case 3:break k;default:break e}}ve(f+48|0,b);ve(f+40|0,c);b=x[f+52>>2];x[f+32>>2]=x[f+48>>2];x[f+36>>2]=b;DJ(a,f+32|0,x[f+40>>2],x[f+44>>2],d)}hb=f+128|0;return}b=P()|0;ca(a|0)}T(b|0)}p()}function Qn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;f=hb-96|0;hb=f;r=Uy(x[a+24>>2],y[a+32|0]);t=$i(r);c=t;e=x[a>>2];d=Dd(e,x[a+4>>2]);a:{if(c>>>0>d>>>0){k=hb-32|0;hb=k;d=c-d|0;c=x[Cb(a)>>2];e=x[a+4>>2];b:{if(d>>>0<=(c-e|0)/12>>>0){e=hb-16|0;hb=e;c=ot(e,a,d);d=x[c+4>>2];g=x[c+8>>2];while(1){if((d|0)==(g|0)){ic(c);hb=e+16|0}else{UN(d);d=d+12|0;x[c+4>>2]=d;continue}break}break b}c=Cb(a);c=wl(k+8|0,Io(a,Dd(x[a>>2],e)+d|0),Dd(x[a>>2],x[a+4>>2]),c);g=hb-16|0;hb=g;d=YP(g,c+8|0,d);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){UN(e);e=x[d>>2]+12|0;x[d>>2]=e;continue}break}Hd(d);hb=g+16|0;e=hb-32|0;hb=e;d=Ib(e+24|0,x[a+4>>2]);j=Ib(e+16|0,x[a>>2]);h=Ib(e+8|0,x[c+4>>2]);g=x[d>>2];m=x[j>>2];d=hb-16|0;hb=d;x[d>>2]=x[h>>2];x[d+8>>2]=g;while(1){j=x[d>>2];if(og(g,m)){Kz(Bi(j),Bi(g));g=vl(d+8|0);vl(d);g=x[g>>2];continue}break}hb=d+16|0;x[c+4>>2]=j;qc(a,c+4|0);qc(a+4|0,c+8|0);qc(Cb(a),yc(c));x[c>>2]=x[c+4>>2];hb=e+32|0;d=x[c+4>>2];while(1){e=x[c+8>>2];if((e|0)!=(d|0)){e=e-12|0;x[c+8>>2]=e;He(e);continue}break}d=x[c>>2];if(d){fr(c);Hb(d)}}hb=k+32|0;break a}if(d>>>0>c>>>0){_N(a,e+D(c,12)|0)}}if(b){c=a+12|0;vp(c,Sd(c));A=Cb(c),B=0,x[A>>2]=B;i=c;c=jc(c);x[i>>2]=c;x[c>>2]=0;x[a+28>>2]=0}k=Sb(f+80|0);c=x[a+24>>2];c=Us(x[c+484344>>2],x[c+484348>>2]);x[23604]=0;j=W(555,f- -64|0,c|0,30588)|0;c=x[23604];x[23604]=0;c:{if((c|0)!=1){g=a+12|0;d:{while(1){if((l|0)==(t|0)){nd(j);fc(k);hb=f+96|0;return}c=x[a+24>>2];m=z[cc(x[r>>2],l)>>1];d=eO(c,m);x[f+60>>2]=d;c=Zd(x[a>>2],l);e:{f:{if(b){x[23604]=0;v[f+40|0]=0;U(719,c|0,d|0,f+40|0);d=x[23604];x[23604]=0;if((d|0)!=1){break f}d=P()|0;break d}x[23604]=0;R(677,c|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break e}}x[23604]=0;d=Q(295,r|0,l&65535)|0;e=x[23604];x[23604]=0;if((e|0)==1){break e}g:{if(!d){break g}x[f+40>>2]=b?0:x[c+4>>2];s=x[Fb(f+40|0,f+60|0)>>2];o=xf(g);c=z[cc(x[j>>2],m)>>1];if((c|0)!=65535){d=cO(g,z[am(f+40|0,c,s)>>1],x[f+44>>2]);h:{if(xg(d,xf(g))){c=cO(g,z[am(f+40|0,z[cc(x[j>>2],m)>>1],x[f+60>>2])>>1],x[f+44>>2]);break h}c=xf(g)}x[f+56>>2]=d;while(1){i:{if(!xg(d,c)){break g}e=Sb(f+40|0);d=Pm(sd(d)+8|0);x[23604]=0;R(720,e|0,d|0);d=x[23604];x[23604]=0;if((d|0)!=1){d=Oj(f+24|0,o);h=am(f+16|0,l,x[sd(x[f+56>>2])+4>>2]);d=x[d>>2];x[23604]=0;d=fa(721,g|0,d|0,h|0,e|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break i}x[f+32>>2]=d;o=x[Tg(f+32|0)>>2];je(e);d=x[Tg(f+56|0)>>2];continue}}break}d=P()|0;je(e);break d}q=ac(x[x[a+24>>2]+484344>>2],m);c=Bg(x[x[q+48>>2]+12>>2]);x[23604]=0;v[f+40|0]=0;U(701,k|0,c|0,f+40|0);c=x[23604];x[23604]=0;if((c|0)!=1){n=x[f+60>>2];j:while(1){k:{if((n|0)==(s|0)){if(s){break g}A=cc(x[j>>2],m),B=l,w[A>>1]=B;break g}c=1;h=0;e=x[x[q+48>>2]+12>>2];n=n-1|0;d=of(x[q>>2],e,n);while(1){if(c>>>0<16&Bg(e)>>>0>h>>>0){u=Gb(x[k>>2],h);e=y[u|0];l:{m:{n:{switch(y[d+3|0]-19|0){case 1:i=y[d+5|0];if((i&240)==176){break m}break l;case 0:break n;default:break l}}i=y[d+5|0];if((i&240)!=96){break l}}v[u|0]=i&15;i=y[Gb(x[k>>2],h)|0];e=i?i:e}i=c;c=e&255;c=D(i,c?c+1|0:1);d=d+6|0;h=h+1|0;e=x[x[q+48>>2]+12>>2];continue}else{o:{if(c>>>0<=1){continue j}e=Sb(f+40|0);x[23604]=0;R(720,e|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break o}c=Oj(f+8|0,o);d=am(f+16|0,l,n);c=x[c>>2];x[23604]=0;o=fa(721,g|0,c|0,d|0,e|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break k}je(e);continue j}}break}}break}d=P()|0;je(e);break d}d=P()|0;break d}l=l+1|0;continue}break}d=P()|0}nd(j);break c}d=P()|0}fc(k);T(d|0);p()}function Mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-976|0;hb=e;xc(b);d=hb-16|0;hb=d;h=e+872|0;zT(d+8|0,h);f=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){bc(b,x[d+12>>2])}hb=d+16|0;d=(f|0)==(g|0);if(!d){yT(h)}a:{if(!d){break a}if(!BT(e+872|0)){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(AT(y[e+919|0]|y[e+920|0]<<8),lb))){break a}if(!c){l=1;break a}Cd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[e+947|0];x[a+480208>>2]=16;x[a+480200>>2]=256;x[a+480204>>2]=8e5;Nb(a+1074312|0,7,1);d=e+96|0;f=Xb(d,8142);Ab(a+1298344|0,f);xb(f);f=Xb(d,8814);Ab(a+1298356|0,f);xb(f);x[a+1298404>>2]=5;f=e+16|0;wT(f,e+872|4);Dc(d,f);Ab(a+1298308|0,d);xb(d);d=0;while(1){if((d|0)==16){b:{d=z[e+968>>1];if(d){dB(a+1298332|0,b,d,132,0)}d=hb-16|0;hb=d;h=e+96|0;hc(d+8|0,h,771);f=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){bc(b,x[d+12>>2])}hb=d+16|0;l=(f|0)==(g|0);if(!l){Zb(h,0,771)}if(!l){break a}d=a+484360|0;f=a+484376|0;vT(_b(x[d>>2],y[f|0]),e+96|0,y[e+353|0]);Xe(_b(x[d>>2],y[f|0]),y[e+354|0]);Yc(b,y[e+919|0]|y[e+920|0]<<8);o=a+484344|0;q=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}pB(b,e- -64|0);d=0;while(1){if((d|0)==64){break a}if(!(y[e- -64+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!OA(b,e+16|0)){break a}d=d+1|0;w[a+480190>>1]=d;We(e,1,e+16|0);h=e+72|0;Dc(h,e);Bc(((z[a+480190>>1]<<5)+a|0)+946304|0,h);xb(h);c=(D(d,104)+a|0)+484380|0;od(c,0);i=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);x[c>>2]=i;f=y[e+54|0]|y[e+55|0]<<8|(y[e+56|0]<<16|y[e+57|0]<<24);x[c+4>>2]=f;g=y[e+58|0]|y[e+59|0]<<8|(y[e+60|0]<<16|y[e+61|0]<<24);x[c+24>>2]=16726;x[c+8>>2]=g;w[c+30>>1]=y[e+53|0]<<4;if(v[e+62|0]&1){g=g>>>1|0;x[c+8>>2]=g;f=f>>>1|0;x[c+4>>2]=f;x[c>>2]=i>>>1}if(!(!(y[e+63|0]&8)|f>>>0>=g>>>0)){w[c+34>>1]=z[c+34>>1]|2}Xc(h,v[e+62|0]&1?16:8,1,0,0);fg(h,c,b);continue}}d:{d=(h<<1)+e|0;g=y[d+355|0]|y[d+356|0]<<8;if(g){f=e+72|0;Ud(f,b,g);i=kc(e+16|0,f);yb(f);n=((y[d+355|0]|y[d+356|0]<<8)-2|0)/64|0;e:{if(!q){break e}x[23604]=0;d=W(212,o|0,h&65535,n|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break d}if(!d){break e}x[23604]=0;d=S(192,i|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break b}x[23604]=0;Q(174,i|0,1)|0;f=x[23604];x[23604]=0;if((f|0)==1){break b}r=d?d>>>0>=n-2>>>0?-1:d+1|0:-1;f=0;f:while(1){g:{d=ac(x[o>>2],h);if((f|0)==(n|0)){break g}m=0;s=of(x[d>>2],x[x[d+48>>2]+12>>2],f);while(1){if((m|0)==16){f=f+1|0;continue f}x[23604]=0;R(333,e+72|0,i|0);d=x[23604];x[23604]=0;if((d|0)==1){break c}d=D(m,6)+s|0;j=e+72|0;g=Re(j);j=wi(j);k=y[e+72|0];if((k-1&255)>>>0<=71){v[d|0]=k+36;t=d,u=y[hd(e+72|0)|0]+1|0,v[t+1|0]=u}if((y[g|0]-1&255)>>>0<=15){v[d+2|0]=1;v[d+4|0]=((y[g|0]<<6)+-64>>>0)/15}k=y[j|0];g=k&15;v[d+5|0]=g;h:{i:{switch((y[j|0]>>>4|0)-1|0){case 0:case 1:v[d+5|0]=k|240;break h;case 2:v[d+5|0]=g<<2;break h;case 3:v[d+5|0]=(6/(g+1>>>0)|0)+1;break h;case 5:case 6:v[d+5|0]=g<<3;break h;case 9:v[d+4|0]=(g<<2)+4;v[d+2|0]=1;break h;case 10:v[d+5|0]=g|128;break h;case 11:break i;default:break h}}v[d+5|0]=(6/(g+1>>>0)|0)+1|13}v[d+3|0]=y[(y[j|0]>>>4|0)+26752|0];m=m+1|0;continue}}break}he(d,vh(Ce(ye(e+72|0,14,0),r)))}yb(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;Qe(h);g=h;h=(e+872|0)+d|0;x[g>>2]=!y[h+50|0]<<10;w[f+480284>>1]=(y[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=P()|0;yb(i);T(a|0);p()}hb=e+976|0;return l|0}function IV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-576|0;hb=e;xc(b);d=hb-16|0;hb=d;f=e+72|0;uC(d+8|0,f);g=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(g|0)){bc(b,x[d+12>>2])}hb=d+16|0;d=(g|0)==(j|0);if(!d){tC(f)}a:{if(!d){break a}if(!xC(e+72|0)){break a}b:{if(!c){break b}if(!Qb(x[b>>2],x[b+8>>2],Uc(wC(y[e+182|0],y[e+183|0]),lb))){break a}Cd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;Nb(a+1074312|0,7,1);d=e+40|0;g=Xb(d,14519);Ab(a+1298344|0,g);xb(g);d=Xb(d,14552);Ab(a+1298356|0,d);xb(d);Zc(a+1298368|0,Rb(e+72|0,11012,2)?14547:14519);x[a+1298404>>2]=5;f=y[e+182|0];w[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=hb-16|0;hb=f;d=e+40|0;hc(f+8|0,d,25);l=x[f+12>>2];mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(l|0)){bc(b,x[f+12>>2])}hb=f+16|0;if((i|0)!=(l|0)){v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0}if((y[e+53|0]|y[e+54|0]<<8|(y[e+55|0]<<16|y[e+56|0]<<24))>>>0>67108863){break a}f=(D(j,104)+a|0)+484380|0;od(f,0);x[f+24>>2]=8363;l=e+40|0;d=l;i=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[f>>2]=i;k=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);x[f+4>>2]=k;d=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);d=d>>>0>i>>>0?k?d:0:d;x[f+8>>2]=d;if(d){w[f+34>>1]=2;ek(f)}f=e+8|0;Ph(f,2,l);d=e+24|0;Dc(d,f);Bc(((j<<5)+a|0)+946304|0,d);g=g+1|0;xb(d);f=z[a+480190>>1];continue}break}g=e+24|0;h=e+72|2;Kf(g,3,h,36);d=e+40|0;Dc(d,g);Ab(a+1298308|0,d);xb(d);g=0;sC(a+1298332|0,h,108,36,0);d=a+484360|0;h=a+484376|0;Iu(_b(x[d>>2],y[h|0]),e+185|0,128);d=_b(x[d>>2],y[h|0]);h=y[e+184|0];if(z[cc(x[d>>2],h)>>1]<y[e+183|0]){Xe(d,h)}while(1)if((g|0)==8){j=a+484344|0;gg(j,y[e+183|0]);n=c&1;f=0;while(1)if(y[e+183|0]<=f>>>0){h=1;if(!(c&2)){break a}c=Xc(e+40|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>z[a+480190>>1]){break b}fg(c,(D(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{c:{d:{if(n){if(Yg(j,f&65535,64)){break d}}bc(b,1536);break c}x[e+24>>2]=-1;x[e+28>>2]=-1;l=0;e:while(1){if((l|0)==64){d=(e+72|0)+f|0;g=y[d+369|0];if(g>>>0<63){he(ac(x[j>>2],f),vh(Ce(ye(e+40|0,14,0),g)))}he(ac(x[j>>2],f),vh(ye(e+40|0,16,y[d+241|0])));break c}g=0;d=ac(x[j>>2],f);h=of(x[d>>2],x[x[d+48>>2]+12>>2],l);while(1){if((g|0)==8){l=l+1|0;continue e}d=e+40|0;Cq(d,b);i=hd(d);k=Re(d);i=y[i|0];d=y[e+40|0];if(d>>>0<=253){v[h|0]=(d>>>2|0)+37;v[h+1|0]=(d<<4&48|i>>>4)+1;v[(e+24|0)+g|0]=255;d=y[e+40|0]}if((d&255)!=255){v[h+2|0]=1;v[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=y[k|0];if((d|0)!=255){v[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;f:{g:{if(!(d&15)&(d|0)!=48){break g}k=y[i|0];if((k|0)==255){break f}m=k<<24>>24;d=m&15;v[h+5|0]=d;h:{if((m|0)<0){break h}k=k>>>4|0;v[h+3|0]=y[k+26536|0];i:{switch(k-3|0){case 0:v[h+5|0]=d|32;break g;case 1:v[h+5|0]=d|m<<4;break f;case 2:break g;case 3:break i;default:break f}}j:{switch(d|0){case 0:v[h+5|0]=79;break f;case 1:break j;default:break h}}v[h+5|0]=244;break f}v[h+3|0]=0;break f}v[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;Qe(d+480280|0);w[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}hb=e+576|0;return h|0}function Xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-192|0;hb=f;a:{b:{if(Qb(x[c>>2],x[c+8>>2],8)){bc(c,4);while(1){if(Mt(x[c>>2],x[c+8>>2])){break b}m=hb-288|0;hb=m;e=wO(m);i=hb-384|0;hb=i;j=vc(e,wO(i+96|0),282);e=0;c:{d:{e:{f:{g:{if(wh(c,13503)){hg(c,4);h=ge(i+72|0,c);x[23604]=0;k=Q(712,h|0,j|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break g}h:{if(!k){break h}k=x[h+8>>2];g=x[h>>2];l=y[j+26|0];x[23604]=0;k=W(142,g|0,k|0,l|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break g}if(!k){break h}k=0;i:{while(1){if(y[j+26|0]<=e>>>0){g=x[h+8>>2];l=x[h>>2];e=0;x[23604]=0;k=k&65535;g=W(142,l|0,g|0,k|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break e}if(!g){break h}x[23604]=0;Q(174,h|0,k|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break e}hg(h,xO(j));e=zc(i- -64|0);g=i+96|0;Xy(g);x[23604]=0;R(713,h|0,g|0);g=x[23604];x[23604]=0;if((g|0)!=1){w[i+118>>1]=0;w[i+120>>1]=0;e=Yy(e,i+96|0,i+123|0);g=y[j+26|0];x[23604]=0;Q(174,h|0,g|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){break i}}e=P()|0;break d}x[23604]=0;g=S(184,h|0)|0;l=x[23604];x[23604]=0;if((l|0)!=1){v[(e+j|0)+27|0]=g;e=e+1|0;k=g+k|0;continue}break}e=P()|0;break d}l=e;e=j+27|0;l=Yy(l,e,e+y[j+26|0]|0);x[23604]=0;U(176,i+16|0,h|0,k|0);e=x[23604];x[23604]=0;if((e|0)==1){break f}g=i+16|0;k=kc(i+40|0,g);yb(g);e=0;x[23604]=0;R(510,g|0,k|0);g=x[23604];x[23604]=0;if((g|0)==1){e=P()|0;yb(k);break d}g=i+16|0;PB(i+8|0,g);n=l;l=x[i+8>>2];l=Yy(n,l,Gb(l,x[i+12>>2]));Lc(g);yb(k);if(x[l>>2]!=(y[j+22|0]|y[j+23|0]<<8|(y[j+24|0]<<16|y[j+25|0]<<24))){break h}e=xO(j);x[23604]=0;Q(174,c|0,e|0)|0;j=x[23604];x[23604]=0;e=1;if((j|0)==1){break e}}yb(h)}hb=i+384|0;break c}e=P()|0;break d}e=P()|0;break d}e=P()|0}yb(h);T(e|0);p()}hb=m+288|0;if(e){continue}break}}xc(c);fg(b,a,c);a=1;break a}v[d|0]=1;xc(c);e=kg(c);d=f+144|0;Ud(d,c,cf(c));i=kc(f+168|0,d);yb(d);c=z[a+34>>1]&-66|y[b|0]>15;b=y[b+1|0]!=1;c=c|b<<6;w[a+34>>1]=c;x[a>>2]=e>>>(c&1)>>>b;x[f+140>>2]=0;x[f+136>>2]=0;x[23604]=0;R(510,d|0,i|0);b=x[23604];x[23604]=0;j:{k:{l:{m:{if((b|0)!=1){c=xe(f+144|0);e=x[f+144>>2];j=eA(c,oi(e),f+140|0,f+136|0);x[23604]=0;b=x[f+140>>2];Q(174,i|0,b|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){if(!j){break j}yg(a);d=b+c|0;b=e-b|0;e=x[f+136>>2];c=0;while(1){n:{if(e){if(!b|(e|0)!=1){break k}e=x[a>>2];if(e>>>0>c>>>0){break n}break k}e=x[a>>2];if(e>>>0<=c>>>0){break k}}if(!Qd(e,x[a+20>>2])){break k}x[f+132>>2]=0;x[f+128>>2]=0;k=TR(j,d,oi(b),f+132|0,f+124|0,f+128|0);x[23604]=0;Q(174,i|0,k|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break m}Rh(f+128|0,oi(x[a>>2]-c|0));e=x[f+128>>2];o:{if((e|0)<=0){break o}h=x[f+132>>2];l=z[a+34>>1];if((Gd(l)|0)!=(h|0)){break o}m=D(c,h);g=x[a+20>>2];if(l&1){h=$f(f+112|0,g+(m<<1)|0,h,e);m=$f(f+96|0,x[f+124>>2],x[f+132>>2],e);x[23604]=0;x[f+56>>2]=x[h+8>>2];g=x[h+4>>2];x[f+48>>2]=x[h>>2];x[f+52>>2]=g;x[f+40>>2]=x[m+8>>2];h=x[m+4>>2];x[f+32>>2]=x[m>>2];x[f+36>>2]=h;R(511,f+48|0,f+32|0);h=x[23604];x[23604]=0;if((h|0)!=1){break o}break m}h=$f(f+80|0,g+m|0,h,e);m=$f(f- -64|0,x[f+124>>2],x[f+132>>2],e);x[23604]=0;x[f+24>>2]=x[h+8>>2];g=x[h+4>>2];x[f+16>>2]=x[h>>2];x[f+20>>2]=g;x[f+8>>2]=x[m+8>>2];h=x[m+4>>2];x[f>>2]=x[m>>2];x[f+4>>2]=h;R(512,f+16|0,f|0);h=x[23604];x[23604]=0;if((h|0)==1){break m}}b=b-k|0;d=d+k|0;c=c+e|0;e=SR(j);continue}}break m}c=P()|0;break l}c=P()|0;Lc(f+144|0)}yb(i);T(c|0);p()}RR(j)}Lc(f+144|0);yb(i);a=(j|0)!=0}hb=f+192|0;return a|0}function lia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=hb-336|0;hb=d;xc(b);a:{if(!ho(b,d+320|0)){break a}if(!TT(d+320|0)){break a}if(!Rb(d+320|0,14024,4)){bc(b,4)}if(!Th(b,d+312|0)){break a}if(Rb(d+312|0,14e3,4)){break a}if(!c){l=1;break a}CB(b,d+120|0,x[d+316>>2]);if(z[d+156>>1]>128|z[d+162>>1]>16|(z[d+160>>1]>256|z[d+154>>1]>128)){break a}Cd(a,8192);g=d+32|0;e=Xb(g,6500);Ab(a+1298344|0,e);xb(e);e=Xb(g,10033);Ab(a+1298356|0,e);xb(e);x[a+1298404>>2]=5;e=d+96|0;hl(e,2,d+120|0);Dc(g,e);Ab(a+1298308|0,g);xb(g);w[d+32>>1]=z[d+162>>1];w[d+96>>1]=1;f=z[Se(g,e)>>1];w[a+480188>>1]=f;x[a+480196>>2]=y[d+166|0];x[a+480204>>2]=D(y[d+167|0],1e4);v[d+32|0]=y[d+164|0];v[d+96|0]=64;e=y[Wb(g,e)|0];x[a+480200>>2]=e<<2;if(!e){x[a+480200>>2]=256}e=y[d+165|0];b:{if((e|0)==128){x[d+32>>2]=256/(f>>>0);x[d+96>>2]=128;e=x[Fb(d+32|0,d+96|0)>>2];break b}e=e&127}x[a+480228>>2]=e;g=0;while(1){if((g|0)==16){f=a+484376|0;Iu(_b(x[a+484360>>2],y[f|0]),d+184|0,z[d+156>>1]);e=z[d+154>>1];if(e>>>0<z[d+156>>1]){Xe(_b(x[a+484360>>2],y[f|0]),e)}o=c&2;m=a+484344|0;l=1;q=c&1;r=d+68|0;k=a+480190|0;s=a+480188|0;while(1){if(!Th(b,d+312|0)){break a}c=d+32|0;Ud(c,b,x[d+316>>2]);i=kc(d+96|0,c);yb(c);c:{d:{if(!(Rb(d+312|0,13445,4)|!q)){x[23604]=0;g=n&65535;e=W(212,m|0,g|0,64)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}if(!e){break c}x[23604]=0;Q(174,i|0,2)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}sh(d+32|0);j=0;e:{while(1){c=x[i>>2];x[23604]=0;e=W(142,c|0,x[d+104>>2],1)|0;c=x[23604];x[23604]=0;f:{if((c|0)!=1){if(!(e&j>>>0<64)){break e}x[23604]=0;e=S(192,i|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}f=e<<24>>24;if(f){break f}j=j+1|0;continue}break d}c=d+32|0;e=f&15;if(e>>>0<z[s>>1]){c=ac(x[m>>2],g);c=cd(x[c>>2],x[x[c+48>>2]+12>>2],j,e)}g:{if((f|0)>=0){break g}x[23604]=0;h=S(192,i|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break d}if(!h){break g}v[c|0]=h>>>0<109?h+12|0:h}h=f&255;if(h&64){x[23604]=0;f=S(192,i|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break d}v[c+1|0]=f}if(h&32){v[c+2|0]=1;x[23604]=0;f=S(192,i|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break d}v[d+16|0]=f;v[d|0]=64;t=c,u=y[Wb(d+16|0,d)|0],v[t+4|0]=u}if(!(h&16)){continue}x[23604]=0;R(245,d+16|0,i|0);e=x[23604];x[23604]=0;if((e|0)!=1){f=hd(d+16|0);h:{i:{j:{k:{l:{e=y[d+16|0];switch(e-17|0){case 2:break k;case 0:case 1:break l;default:break j}}e=e&15;break i}v[d+16|0]=33;v[f|0]=145;e=y[d+16|0];break h}if(e>>>0<17){break h}e=(e&240)==32?9:-1}v[d+16|0]=e}v[c+3|0]=e;v[c+5|0]=y[f|0];Hf(c);continue}break}break d}n=n+1|0;break c}if(Rb(d+312|0,13450,4)){break c}c=z[k>>1];if(!Nh(c)){break c}e=c+1|0;w[k>>1]=e;x[23604]=0;R(303,i|0,d+32|0);c=x[23604];x[23604]=0;m:{if((c|0)==1){break m}x[23604]=0;f=(D(e&65535,104)+a|0)+484380|0;R(304,d+32|0,f|0);c=x[23604];x[23604]=0;if((c|0)==1){break m}hl(d,2,r);x[23604]=0;R(208,d+16|0,d|0);c=x[23604];x[23604]=0;if((c|0)==1){break m}c=d+16|0;Bc(((z[k>>1]<<5)+a|0)+946304|0,c);xb(c);if(!o){break c}h=y[d+45|0]|y[d+46|0]<<8;e=2;c=d+16|0;g=Xc(c,8,1,0,1);n:{if(!(h&64)){e=0;if(!(h&2)){break n}}Lf(g,e)}if(h&4){id(g,16)}x[23604]=0;W(205,c|0,f|0,i|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break c}}}a=P()|0;yb(i);T(a|0);p()}yb(i);continue}}f=(g<<5)+a|0;Qe(f+480280|0);e=y[(d+g|0)+168|0];if(e>>>0<=128){w[f+480284>>1]=e<<1}g=g+1|0;continue}}hb=d+336|0;return l|0}function Yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-192|0;hb=e;xc(b);a:{if(!OA(b,e+144|0)){break a}if(!oQ(e+144|0)){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(nQ(y[e+175|0],y[e+177|0]),lb))){break a}b:{if(!c){break b}Cd(a,256);g=e+32|0;jj(g,2,e+144|0);d=e- -64|0;Dc(d,g);Ab(a+1298308|0,d);xb(d);f=Xb(d,15137);Ab(a+1298344|0,f);xb(f);d=Xb(d,10012);Ab(a+1298356|0,d);xb(d);ef(g,4232);x[23604]=0;R(235,e+128|0,e+175|0);d=x[23604];x[23604]=0;c:{d:{if((d|0)!=1){x[23604]=0;X(623,e- -64|0,e+32|0,e+174|0,e+128|0);d=x[23604];x[23604]=0;if((d|0)!=1){d=e- -64|0;Ab(a+1298368|0,d);xb(d);xb(e+128|0);Db(e+32|0);x[a+1298404>>2]=5;d=Nb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;Nb(d,107,1);f=y[e+176|0];d=y[e+175|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|D(g,-10)+f}g=(f&255?f:96)&255;f=Fz(g);x[a+480196>>2]=g>>>4;x[a+480204>>2]=f;f=0;if(d>>>0>=11){v[e+64|0]=64;o=a,q=y[Wb(e+178|0,e- -64|0)|0]<<2,x[o+480200>>2]=q}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){wt(b,e+32|0);d=y[e+44|0];if(d?(d|0)!=46:0){break c}h=hb-32|0;hb=h;d=(D(f,104)+a|0)+484380|0;od(d,0);k=e+32|0;g=k;Wj(h,2,g);i=h+16|0;Dc(i,h);ze(d+43|0,i);xb(i);x[d+24>>2]=y[g+24|0]|y[g+25|0]<<8;v[h+16|0]=y[g+22|0];v[h|0]=64;o=d,q=y[Wb(i,h)|0]<<2,w[o+30>>1]=q;i=y[g+16|0]|y[g+17|0]<<8;x[d>>2]=i;j=y[g+18|0]|y[g+19|0]<<8;x[d+4>>2]=j;g=y[g+20|0]|y[g+21|0]<<8;x[d+8>>2]=g;e:{if(i>>>0<=1){x[d>>2]=0;break e}if((g|0)==65535|i>>>0<=j>>>0|g>>>0<=j>>>0){break e}w[d+34>>1]=2;o=d,q=x[Fb(d+8|0,d)>>2],x[o+8>>2]=q}hb=h+32|0;g=e+16|0;Wj(g,2,k);d=e+128|0;Dc(d,g);Bc(((f<<5)+a|0)+946304|0,d);xb(d);w[((f<<1)+e|0)+62>>1]=z[e+46>>1];f=f+1|0;continue}break}d=a+484360|0;g=a+484376|0;go(_b(x[d>>2],y[g|0]),b,y[e+175|0]?128:64,65535,65535);f=0;if(!lQ(_b(x[d>>2],y[g|0]))){break a}m=c&1;if(m){gg(a+484344|0,y[e+177|0])}i=a+484344|0;while(1)if(y[e+177|0]<=l>>>0){f=1;if(!(c&2)){break a}c=Xc(e+32|0,8,1,0,0);while(1){if((f|0)==32){break b}d=D(f,104)+a|0;g=d+484380|0;f:{if(!x[g>>2]|!z[d+484410>>1]){break f}d=z[((f<<1)+e|0)+62>>1];if(d>>>0<4){break f}if(!Yc(b,d<<4)){break f}fg(c,g,b)}f=f+1|0;continue}}else{f=0;g:{h:{if(m){if(Yg(i,l&65535,64)){break h}}while(1){if((f|0)==256){break g}if((Be(b)+2&255)>>>0<=252){bc(b,3)}f=f+1|0;continue}}o=e,q=Bb(x[ac(x[i>>2],l)>>2]),x[o+128>>2]=q;w[e+14>>1]=65535;x[e+16>>2]=63;h=0;i:while(1){f=0;if((h|0)==64){d=z[e+14>>1];if((d|0)==65535){break g}he(ac(x[i>>2],l),om(Ce(ye(e+32|0,12,d&255),x[e+16>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=Be(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}v[x[e+128>>2]]=254;break j}d=e+32|0;Cq(d,b);j=y[Gb(d,0)|0];k=y[Gb(d,1)|0];n=y[Gb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(D(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=x[e+128>>2];v[d|0]=g;break k}h=h+1|0;continue i}d=x[e+128>>2]}v[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){v[d+4|0]=g;v[d+2|0]=1}v[d+5|0]=n;v[d+3|0]=k&15;kQ(d,h,y[e+175|0],e+14|0,e+16|0)}f=f+1|0;Tz(e+128|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;Qe(d+480280|0);w[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=P()|0;xb(e+128|0);break d}f=P()|0}Db(e+32|0);T(f|0);p()}f=0;break a}f=1}hb=e+192|0;return f|0}function bK(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=E(0),t=0,u=E(0);j=hb-16|0;hb=j;b=a+4208|0;i=Mj(E(B[zb(b,12)>>2]*E(3)));x[a+4264>>2]=i;d=E(x[x[a+16>>2]+24620>>2]>>>((i^-1)>>>1&1)>>>0);B[a+4268>>2]=d;t=a,u=E(E(B[zb(b,9)>>2]*E(100))*E(.0061803399585187435)),B[t+4272>>2]=u;t=j,u=me(E(10),E(E(aK(a)+E(E(B[zb(b,5)>>2]*E(11e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[j+8>>2]=1065353216;t=a,u=E(B[Pl(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[t+4280>>2]=u;c=me(E(10),E(E(E(E(B[zb(b,1)>>2]*E(1e4))+E(-1e4))/E(100))/E(10)));if(c!=E(1)){d=dp(E(E($J(a)*E(6.2831854820251465))/d));f=E(c+c);e=E(c*c);c=Iy(E(E(E(E(d*f)+E(-2))+E(M(E(E(E(E(d*E(E(d*e)*E(4)))+E(c*E(8)))-E(e*E(4)))-E(E(d*c)*E(8))))))/E(f+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=hb-16|0;hb=i;c=B[a+4268>>2];b=a+4208|0;d=E(B[zb(b,6)>>2]*E(.30000001192092896));t=i,u=E(B[zb(b,8)>>2]*E(.10000000149011612)),B[t+12>>2]=u;x[i+8>>2]=1000593162;f=B[tx(i+12|0,i+8|0)>>2];e=E(c*E(E(d+f)+E(.007000000216066837)));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){if((b|0)==12){t=i,u=E(E(E(E(B[zb(a+4208|0,10)>>2]*E(100))/E(100))+E(.10000000149011612))*E(.9090999960899353)),B[t+12>>2]=u;x[i+8>>2]=1065353216;d=B[Pl(i+12|0,i+8|0)>>2];f=E(c*E(E(d*E(75))/E(1e3)));d=E(c*E(E(d*E(67))/E(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=E(c*E(.0035299998708069324));b:{if(E(F(d))<E(2147483648)){b=~~d;break b}b=-2147483648}x[h>>2]=b;h=a+4344|0;d=E(c*E(.0032500000670552254));c:{if(E(F(d))<E(2147483648)){b=~~d;break c}b=-2147483648}x[h>>2]=b;h=a+4340|0;c=E(c*E(.009999999776482582));d:{if(E(F(c))<E(2147483648)){b=~~c;break d}b=-2147483648}x[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=me(E(.9300000071525574),E(n|0));g=E(f*e);e:{if(E(F(g))<E(2147483648)){k=~~g;break e}k=-2147483648}x[p>>2]=k;k=h+4292|0;e=E(d*e);f:{if(E(F(e))<E(2147483648)){h=~~e;break f}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){eK((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}hb=i+16|0}else{k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(c*E(E(f*B[(b<<2)+47424>>2])+d));g:{if(E(F(e))<E(2147483648)){h=~~e;break g}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=hb-16|0;hb=b;d=hh(a,5);e=hh(a,11);c=E(d*hh(a,4));d=E(E(c*E(.03999999910593033))+E(E(d*E(.02250000089406967))+E(0)));f=E(e*hh(a,10));e=E(E(f*E(.03999999910593033))+E(E(e*E(.02250000089406967))+E(0)));if(v[a+4264|0]&1){g=hh(a,3);l=hh(a,9);g=E(c*g);c=E(g*hh(a,2));d=E(E(c*E(.1444000005722046))+E(E(g*E(.12250000238418579))+d));g=E(f*l);f=E(g*hh(a,8));e=E(E(f*E(.1444000005722046))+E(E(g*E(.12250000238418579))+e))}hh(a,12);g=B[a+4496>>2];l=hh(a,1);m=hh(a,7);q=hh(a,0);r=hh(a,6);t=b,u=me(E(10),E(E(aK(a)+E(E(B[zb(a+4208|0,7)>>2]*E(12e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[b+8>>2]=1065353216;o=B[Pl(b+12|0,b+8|0)>>2];s=c;c=E(g*g);g=E(l*E(s*c));l=E(q*g);c=E(m*E(f*c));f=E(r*c);m=E(E(E(l+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(m/E(E(l*E(.1444000005722046))+E(E(c*E(.1444000005722046))+d)))));B[a+4288>>2]=o*E(M(E(m/E(E(f*E(.1444000005722046))+E(E(g*E(.1444000005722046))+e)))));hb=b+16|0;v[a+5046|0]=0;hb=j+16|0}function uaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-112|0;hb=e;g=a+140|0;ij(e+88|0,g,1296125513);x[23604]=0;f=S(164,x[e+88>>2])|0;h=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Kb(e+32|0);x[23604]=0;h=S(146,x[e+88>>2])|0;i=x[23604];x[23604]=0;if((i|0)==1){break p}x[23604]=0;U(729,e+88|0,f|0,h|0);h=x[23604];x[23604]=0;if((h|0)==1){break p}h=z[a+174>>1];x[23604]=0;U(730,e+72|0,h|0,f|0);h=x[23604];x[23604]=0;if((h|0)==1){break o}x[23604]=0;U(8,e+8|0,c|0,e+72|0);c=x[23604];x[23604]=0;if((c|0)==1){break n}c=e+8|0;Bc(d,c);xb(c);xb(e+72|0);xb(f)}if(y[a+176|0]){x[23604]=0;R(731,e+32|0,d|0);c=x[23604];x[23604]=0;if((c|0)==1){break e}c=e+32|0;ze(b+43|0,c);xb(c)}x[23604]=0;U(724,e+32|0,g|0,1413894985);c=x[23604];x[23604]=0;if((c|0)==1){break l}x[23604]=0;f=S(732,e+32|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break k}g=e+32|0;yb(g);c=a+40|0;xc(c);x[23604]=0;g=Q(733,c|0,g|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break j}if(g){q:{if(A[e+60>>2]<2){break q}x[23604]=0;g=Q(734,c|0,e+8|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break i}if(!g){break q}BL(e+8|0,b+12|0,b+16|0,x[b>>2],b+34|0,8,16,f)}x[23604]=0;c=Q(734,c|0,e+8|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break i}if(c){BL(e+8|0,b+4|0,b+8|0,x[b>>2],b+34|0,2,4,f)}c=x[e+44>>2];v[b+42|0]=c&128?0:c+1|0;ek(b)}r:{if(y[b+42|0]){break r}c=x[a+60>>2];x[23604]=0;c=Q(602,c|0,7)|0;f=x[23604];x[23604]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;xc(c);x[23604]=0;c=Q(735,c|0,e+8|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break d}if(!c){break r}c=v[e+8|0];v[b+42|0]=(c|0)>=0?c+1|0:0}c=x[a+120>>2];x[23604]=0;c=S(164,c|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break j}if(!c){break f}x[23604]=0;h=a+120|0;c=S(143,h|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break c}x[e+72>>2]=c;wc(e+72|0,9);f=b+68|0;g=x[e+72>>2];c=0;while(1){if((c|0)==(g|0)){break g}x[23604]=0;R(736,h|0,e+8|0);i=x[23604];x[23604]=0;if((i|0)==1){break h}i=x[e+12>>2];j=zb(f,c),k=i,x[j>>2]=k;c=c+1|0;continue}}a=P()|0;break a}a=P()|0;break m}a=P()|0;break m}a=P()|0;xb(e+72|0)}xb(f);break a}a=P()|0;break a}a=P()|0;yb(e+32|0);break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}rz(f+(g<<2)|0,$S(f),43208)}c=a+80|0;xc(c);x[23604]=0;f=Q(737,c|0,e+8|0)|0;g=x[23604];x[23604]=0;s:{if((g|0)==1){break s}if(!f){break b}if(y[e+8|0]&32){w[b+34>>1]=z[b+34>>1]|32}w[e+72>>1]=z[e+12>>1];w[e+6>>1]=256;j=b,k=z[Wc(e+72|0,e+6|0)>>1],w[j+28>>1]=k;w[e+72>>1]=z[e+14>>1];w[e+6>>1]=256;j=b,k=z[Wc(e+72|0,e+6|0)>>1],w[j+30>>1]=k;w[e+72>>1]=z[e+16>>1];w[e+6>>1]=64;j=b,k=z[Wc(e+72|0,e+6|0)>>1],w[j+32>>1]=k;v[b+38|0]=y[e+20|0];v[b+39|0]=y[e+21|0];v[b+40|0]=y[e+22|0];v[b+41|0]=y[e+23|0];f=x[a+88>>2];a=x[a+80>>2];x[23604]=0;a=W(142,a|0,f|0,32)|0;f=x[23604];x[23604]=0;if((f|0)==1){break s}if(!a){break b}x[23604]=0;R(738,c|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break s}x[23604]=0;a=S(188,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break s}x[23604]=0;U(739,c|0,b+43|0,a|0);a=x[23604];x[23604]=0;if((a|0)!=1){break b}}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}yb(e+88|0);hb=e+112|0;return}yb(e+88|0);T(a|0);p()}function sM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,z=0;if(b){h=a+327720|0;c=hb-400|0;hb=c;tO(c+384|0,8);x[23604]=0;ra(714,c+368|0,9);i=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){x[23604]=0;i=Q(715,c+352|0,14)|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}x[23604]=0;R(716,c+384|0,i|0);e=x[23604];x[23604]=0;if((e|0)==1){break k}x[23604]=0;R(716,c+368|0,i|0);e=x[23604];x[23604]=0;if((e|0)==1){break k}sO(c+280|0,4900);sO(c+208|0,32e3);jO(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[23604]=0;e=Q(717,c+104|0,c+384|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break j}Xs(c+120|0,c+280|0,e);je(e);x[23604]=0;e=Q(717,c+72|0,c+368|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break i}Xs(c+88|0,c+208|0,e);je(e);x[23604]=0;e=Q(717,c+40|0,c+120|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break h}Xs(c+56|0,c+136|0,e);je(e);x[23604]=0;e=Q(717,c+8|0,c+88|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break g}g=c+24|0;Xs(g,c+136|0,e);je(e);e=c+120|0;xp(e);l=c+56|0;xp(l);m=c+88|0;xp(m);xp(g);q=c+368|0;xp(q);wp(x[c+120>>2],x[c+124>>2],Rn(h,0));wp(x[c+56>>2],x[c+60>>2],Rn(h,1));wp(x[c+88>>2],x[c+92>>2],Rn(h,2));wp(x[c+24>>2],x[c+28>>2],Rn(h,3));wp(x[c+368>>2],x[c+372>>2],Rn(h,4));je(g);je(l);je(m);je(e);fl(i);je(q);je(c+384|0);hb=c+400|0;break a}a=P()|0;break b}a=P()|0;break c}a=P()|0;break d}a=P()|0;break d}a=P()|0;break e}a=P()|0;break f}a=P()|0;je(c+56|0)}je(c+88|0)}je(c+120|0)}fl(i)}je(c+368|0)}je(c+384|0);T(a|0);p()}Rx(a+131112|0,9.6377,.97);Rx(a+196648|0,8.5,.5);Rx(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(u=0,v=EL(c,a),z=b,z?u:v)){e=a+24|0;s=C[a+8>>3];g=y[a+16|0];h=hb+-64|0;hb=h;m:while(1){if((n|0)!=8193){t=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){j=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;d=J(C[h+(b<<3)>>3]*32768*j+.5);d=d<-32768?-32768:H(d,32768);n:{if(F(d)<2147483648){i=~~d;break n}i=-2147483648}w[m>>1]=i;b=b+1|0;continue}}else{j=s;f=1;d=+(b|0)-t;r=d+-3.5;if(!(F(r)<1e-8)){o:{p:{switch(g|0){case 0:f=Me(d*.8975979010256552)*-.5+.5;break o;case 1:f=Me(d*.8975979010256552)*-.46+.54;break o;case 2:f=Me(d*1.7951958020513104)*.08+(Me(d*.8975979010256552)*-.5+.42);break o;case 3:f=Me(d*1.7951958020513104)*.05677+(Me(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=Me(d*1.7951958020513104)*.07922+(Me(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=Me(d*1.7951958020513104);k=Me(d*.8975979010256552);f=Me(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=Me(d*1.7951958020513104);k=Me(d*.8975979010256552);f=Me(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=Me(d*1.7951958020513104);k=Me(d*.8975979010256552);f=Me(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=r*3.141592653589793;j=mi(d*j)/d}j=f*j;C[h+(b<<3)>>3]=j;o=o+j;b=b+1|0;continue}}break}hb=h- -64|0;b=x[a+20>>2];x[c+16>>2]=x[a+16>>2];x[c+20>>2]=b;b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b}}function GJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-256|0;hb=e;v[e+255|0]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[Fk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Rk(e+80|0,g,f,f-1|0);f=x[e+84>>2];x[b>>2]=x[e+80>>2];x[b+4>>2]=f}f=e+80|0;Pd(f);g=x[e+80>>2];Pd(e+224|0);h=Ek(g,x[e+228>>2],b);Pd(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==x[e+84>>2]){a=oc(e+240|0,21502);c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Ic(g,f,e)){d=ba(8)|0;x[23604]=0;R(908,e+224|0,e+255|0);a=x[23604];x[23604]=0;if((a|0)==1){break g}x[23604]=0;U(915,e+80|0,17481,e+224|0);a=x[23604];x[23604]=0;if((a|0)==1){break f}a=0;b=pc(d,e+80|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(e+80|0);break e}if(!d){break h}d=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[23604]=0;a=Ah(e+192|0,b,a);b=x[23604];x[23604]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[23604]=0;U(915,e+208|0,17517,a|0);b=x[23604];x[23604]=0;if((b|0)==1){break p}x[23604]=0;R(917,e+224|0,e+208|0);b=x[23604];x[23604]=0;c=1;if((b|0)==1){break o}x[23604]=0;R(908,e+176|0,e+255|0);b=x[23604];x[23604]=0;if((b|0)==1){break n}x[23604]=0;U(919,e+80|0,e+224|0,e+176|0);b=x[23604];x[23604]=0;if((b|0)==1){break m}b=pc(d,e+80|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(e+80|0);c=0;break l}b=P()|0;break d}b=P()|0;c=1;break i}b=P()|0;break j}b=P()|0;break k}b=P()|0}xb(e+176|0)}xb(e+224|0)}xb(e+208|0)}xb(a);if(c){break d}break c}b=oc(e+168|0,21502);d=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=d;if(Ic(g,f,e+72|0)){d=ba(8)|0;x[23604]=0;R(908,e+224|0,e+255|0);a=x[23604];x[23604]=0;q:{r:{if((a|0)!=1){x[23604]=0;U(915,e+80|0,17481,e+224|0);a=x[23604];x[23604]=0;if((a|0)==1){break r}a=0;b=pc(d,e+80|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(e+80|0);break q}b=P()|0;break d}b=P()|0;a=1}xb(e+224|0);if(a){break d}break c}b=oc(e+160|0,7380);d=x[b+4>>2];x[e+64>>2]=x[b>>2];x[e+68>>2]=d;s:{if(!Ic(g,f,e- -64|0)){b=oc(e+152|0,7362);d=x[b+4>>2];x[e+56>>2]=x[b>>2];x[e+60>>2]=d;if(!Ic(g,f,e+56|0)){break s}}v[a+60|0]=c;break h}b=oc(e+144|0,6895);d=x[b+4>>2];x[e+48>>2]=x[b>>2];x[e+52>>2]=d;t:{if(!Ic(g,f,e+48|0)){b=oc(e+136|0,6876);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(!Ic(g,f,e+40|0)){break t}}v[a+61|0]=c;break h}b=oc(e+128|0,6979);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Ic(g,f,e+32|0)){v[a+62|0]=c;break h}b=oc(e+120|0,6025);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Ic(g,f,e+24|0)){v[a+63|0]=c;break h}b=oc(e+112|0,7429);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(Ic(g,f,e+16|0)){v[a+64|0]=c;break h}b=oc(e+104|0,13251);d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;if(!Ic(g,f,e+8|0)){break h}b=x[a+24>>2];d=b+24664|0;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;d=b+24656|0;f=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=f;d=x[b+24652>>2];x[e+80>>2]=x[b+24648>>2];x[e+84>>2]=d;if(c){a=jJ(x[a+56>>2])}else{a=0}x[e+100>>2]=a;if(!bx(e+80|0,b+24648|0)){break h}$x(b,e+80|0)}hb=e+256|0;return}b=P()|0;break d}b=P()|0;a=1}xb(e+224|0);if(!a){break c}}ca(d|0)}T(b|0)}p()}function Nga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-224|0;hb=f;_d(f+208|0,b);g=hb-48|0;hb=g;x[g+44>>2]=0;Uj(b,g+44|0);a:{b:{c:{if(x[g+44>>2]!=(ym(13964)|0)){break c}x[g+40>>2]=0;e=hb-32|0;hb=e;x[e+24>>2]=0;wv(e+8|0,e+24|0);gn(e+16|0,b,x[e+8>>2],x[e+12>>2]);x[g+40>>2]=x[e+24>>2];hb=e+32|0;e=-1;i=x[g+40>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Kb(g+24|0);x[23604]=0;h=W(428,b|0,i|0,256)|0;j=x[23604];x[23604]=0;if((j|0)==1){break b}if(!h){break e}x[23604]=0;U(11,g+8|0,d|0,i|0);h=x[23604];x[23604]=0;if((h|0)!=1){break f}break b}i=Kb(g+24|0);x[23604]=0;h=Q(430,b|0,i|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break b}if(!h){break d}x[23604]=0;U(11,g+8|0,d|0,i|0);h=x[23604];x[23604]=0;if((h|0)==1){break b}}h=g+8|0;Ab(c,h);xb(h);xb(i);Ff(b,h);i=0;x[g+24>>2]=0;Uj(b,g+24|0);h=x[g+24>>2];if(h>>>0>50){break c}g:{while(1){if((h|0)==(i|0)){break g}i=i+1|0;if(WK(a,b,d)){continue}break}break c}x[g+24>>2]=0;Uj(b,g+24|0);e=x[g+24>>2]==(ym(14010)|0)?1:-1;break c}xb(i);break c}xb(i)}hb=g+48|0;break a}a=P()|0;xb(i);T(a|0);p()}h:{if(e){break h}Sm(x[x[b>>2]-12>>2]+b|0,0);e=x[f+220>>2];x[f+8>>2]=x[f+216>>2];x[f+12>>2]=e;e=x[f+212>>2];x[f>>2]=x[f+208>>2];x[f+4>>2]=e;b=Dl(f+104|0,zj(b,f));x[23604]=0;e=Q(394,f+88|0,14149)|0;g=x[23604];x[23604]=0;i:{if((g|0)!=1){x[23604]=0;x[f+72>>2]=3;x[f+76>>2]=0;U(395,b|0,e|0,f+72|0);g=x[23604];x[23604]=0;if((g|0)!=1){Db(e);v[f+87|0]=0;x[23604]=0;e=Q(394,f+72|0,14605)|0;g=x[23604];x[23604]=0;if((g|0)!=1){x[23604]=0;U(396,b|0,f+87|0,e|0);g=x[23604];x[23604]=0;if((g|0)!=1){Db(e);x[23604]=0;g=y[f+87|0];e=S(409,b|0)|0;i=x[23604];x[23604]=0;if((i|0)!=1){x[23604]=0;i=S(410,b|0)|0;h=x[23604];x[23604]=0;if((h|0)!=1){g=g?0:d;x[f+64>>2]=e;j:{k:{l:{m:{while(1){if(!Ob(e,i)){a=x[b>>2];Wg(b);e=a&1073741824?-1:1;break h}x[23604]=0;d=Q(394,f+48|0,15654)|0;e=x[23604];x[23604]=0;if((e|0)==1){break l}e=x[b+36>>2];h=x[b+32>>2];x[23604]=0;e=fa(411,h|0,e|0,x[f+64>>2],d|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break k}Db(d);n:{o:{if(!e){x[23604]=0;X(412,b|0,f- -64|0,c|0,g|0);d=x[23604];x[23604]=0;if((d|0)!=1){break o}break j}x[23604]=0;d=Q(394,f+32|0,15256)|0;e=x[23604];x[23604]=0;p:{q:{if((e|0)!=1){e=x[b+36>>2];h=x[b+32>>2];x[23604]=0;e=fa(411,h|0,e|0,x[f+64>>2],d|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break q}Db(d);if(e){break p}x[23604]=0;U(413,b|0,f- -64|0,f+62|0);d=x[23604];x[23604]=0;if((d|0)==1){break j}break o}a=P()|0;break i}a=P()|0;Db(d);break i}x[23604]=0;d=Q(394,f+16|0,15152)|0;e=x[23604];x[23604]=0;if((e|0)==1){break n}e=x[b+36>>2];h=x[b+32>>2];x[23604]=0;e=fa(411,h|0,e|0,x[f+64>>2],d|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break m}Db(d);if(e){break o}x[23604]=0;X(414,b|0,f- -64|0,a|0,g|0);d=x[23604];x[23604]=0;if((d|0)==1){break j}}Yn(f- -64|0);e=x[f+64>>2];continue}break}a=P()|0;break i}a=P()|0;Db(d);break i}a=P()|0;break i}a=P()|0;Db(d);break i}a=P()|0;break i}a=P()|0;break i}a=P()|0;break i}a=P()|0;Db(e);break i}a=P()|0;break i}a=P()|0;Db(e);break i}a=P()|0}Wg(b);T(a|0);p()}hb=f+224|0;return e|0}function oy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=hb-16|0;hb=g;e=D(b,872)+a|0;j=y[e+1075800|0];l=a+1074312|0;Jb(g+8|0,l,23);f=c&15;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(Mb(x[x[g+8>>2]>>2],x[g+12>>2])){if(!(x[a+1074392>>2]|!y[e+1075780|0])){v[e+1075800|0]=f;break i}i=e+1075800|0;h=y[i|0];if(h){k=h-1|0;v[i|0]=k;h=0;if(k&255){break c}}v[i|0]=f;h=1;break c}Jb(g+8|0,l,52);i=c&256;if(!(!i|!Mb(x[x[g+8>>2]>>2],x[g+12>>2]))){i=x[a+480208>>2]&4096;if(!i){break e}if(y[e+1075781|0]){j=gT(y[e+1075780|0])?1:j}if(y[e+1075784|0]?y[e+1075782|0]==1:0){break b}if(f>>>0>j>>>0){break c}if(!i){break d}if(Tc(y[e+1075780|0])){break c}break d}k=x[a+480180>>2];if(k&16777250){h=!(j?(j>>>0)%((f?f:1)>>>0)|0:1);j=j+1|0;break c}if((k|0)==16){break g}if((k|0)!=1){break f}h=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!h){if(Tc(y[e+1075780|0])){break a}}if(f){break h}}h=0;break c}h=!((h>>>0)%(f>>>0)|0);break c}h=x[a+1074392>>2]==(f|0)&(f|0)!=0;break c}f=!i|y[e+1075782|0]!=1?f:(y[e+1075785|0]>15)+f|0;j:{if(x[a+480208>>2]&4096?i:1){f=f?f:1;h=!x[a+1074416>>2]|i?h:!(A[a+1074392>>2]%(f>>>0)|0);j=j+1|0;break j}j=k&1048580?0:j}if(!(!(y[e+1075780|0]|!i?x[a+1074392>>2]:1)|(j&255)>>>0<f>>>0)){h=1}Jb(g+8|0,l,52);if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])|c){break c}h=!x[a+1074392>>2];break c}if(f>>>0>j>>>0){break c}}j=0;h=1}k:{if(x[e+1075068>>2]){break k}Jb(g+8|0,l,38);if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break k}if(!Ij(x[e+1075648>>2])){break a}}Jb(g+8|0,l,106);if(q=0,r=Mb(x[x[g+8>>2]>>2],x[g+12>>2]),s=x[e+1075688>>2],s?q:r){break a}if(h){f=x[e+1075680>>2];x[g+4>>2]=f;h=c>>>4&15;l:{if(!h){h=x[e+1075080>>2];break l}Jb(g+8|0,l,52);m:{if(q=Mb(x[x[g+8>>2]>>2],x[g+12>>2]),r=0,s=y[e+1075782|0]==1,s?q:r){break m}if(!(16191>>>h&1)){x[g+4>>2]=(D(f,v[h+34224|0])|0)/16;break m}x[g+4>>2]=f+(v[h+34240|0]<<2)}fe(g+4|0,0,256);f=e+1075080|0;h=x[f>>2]|2097152;x[f>>2]=h}m=x[e+1075692>>2];f=y[e+1075794|0];k=0;if(h&512){Jb(g+8|0,l,108);k=Mb(x[x[g+8>>2]>>2],x[g+12>>2])}if(!((k^-1)&x[a+480180>>2]==2|(!x[e+1075068>>2]|(f-1&255)>>>0>119))){LM(a,b,0,f,1)}h=e+1074992|0;n:{if(!(x[a+480180>>2]&1048580)){break n}n=(c|0)<256;if((c|0)>255){break n}i=y[e+1075781|0];if(!i){break n}n=1;sp(a,h,i,0,0,1)}i=e+1075652|0;o=x[i>>2];x[i>>2]=0;p=x[e+1075080>>2];Jb(g+8|0,l,23);i=1;o:{if(Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break o}i=0;if(x[a+480180>>2]!=2){break o}i=(k^1)&x[e+1075068>>2]!=0}Ps(a,h,f,i,n,0,b);if(!y[e+1075781|0]){x[e+1075652>>2]=o}if(!(!(p&4096)|x[a+480180>>2]!=4)){k=e+1075080|0;x[k>>2]=x[k>>2]|4096}x[e+1075680>>2]=x[g+4>>2];if(z[a+480192>>1]){v[e+1075780|0]=f;JM(a,b)}b=x[a+480180>>2];if(!(!(b&16777248)|(y[e+1075780|0]|!m))){x[e+1075692>>2]=m}if(i){x[h>>2]=0;x[h+4>>2]=0}b=b&16777250;p:{if(d-11>>>0<4294967286){break p}f=x[e+1075096>>2];if(!f){break p}q:{if((d|0)==1){f=x[e+1075656>>2];break q}f=x[zb(f+68|0,d-2|0)>>2];x[e+1075656>>2]=f}Pn(a,h,f)}j=b?j:0}a=g+8|0;Jb(a,l,52);b=x[x[g+8>>2]>>2];d=x[g+12>>2];Jb(a,l,23);if(Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break a}j=(Mb(b,d)&c>>>8)+j|0}v[e+1075800|0]=j}hb=g+16|0}function FJ(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-176|0;hb=e;C[e+168>>3]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[Fk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Rk(e+144|0,g,f,f-1|0);f=x[e+148>>2];x[b>>2]=x[e+144>>2];x[b+4>>2]=f}f=e+144|0;Pd(f);g=x[e+144>>2];Pd(e+128|0);h=Ek(g,x[e+132>>2],b);Pd(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{if((h|0)==x[e+148>>2]){a=oc(e+160|0,21502);h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;if(Ic(g,f,e+8|0)){d=ba(8)|0;x[23604]=0;R(912,e+128|0,e+168|0);a=x[23604];x[23604]=0;f:{g:{h:{if((a|0)!=1){x[23604]=0;U(915,e+144|0,17481,e+128|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}a=0;b=pc(d,e+144|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(e+144|0);break g}b=P()|0;break f}b=P()|0;a=1}xb(e+128|0);if(!a){break c}}ca(d|0);break c}if(!d){break e}d=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[23604]=0;f=Ah(e+96|0,b,a);a=x[23604];x[23604]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23604]=0;U(915,e+112|0,17517,f|0);a=x[23604];x[23604]=0;if((a|0)==1){break q}x[23604]=0;R(917,e+128|0,e+112|0);b=x[23604];x[23604]=0;a=1;if((b|0)==1){break p}x[23604]=0;R(912,e+80|0,e+168|0);a=x[23604];x[23604]=0;if((a|0)==1){break o}x[23604]=0;U(919,e+144|0,e+128|0,e+80|0);b=x[23604];x[23604]=0;a=1;if((b|0)==1){break n}a=pc(d,e+144|0);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(e+144|0);a=0;break m}b=P()|0;break i}b=P()|0;a=1;break j}b=P()|0;break k}b=P()|0;a=1;break l}b=P()|0}xb(e+80|0)}xb(e+128|0)}xb(e+112|0)}xb(f);if(!a){break c}}ca(d|0);break c}b=oc(e+72|0,21502);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(Ic(g,f,e+40|0)){d=ba(8)|0;x[23604]=0;R(912,e+128|0,e+168|0);a=x[23604];x[23604]=0;r:{s:{t:{if((a|0)!=1){x[23604]=0;U(915,e+144|0,17481,e+128|0);a=x[23604];x[23604]=0;if((a|0)==1){break t}a=0;b=pc(d,e+144|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(e+144|0);break s}b=P()|0;break r}b=P()|0;a=1}xb(e+128|0);if(!a){break c}}ca(d|0);break c}b=oc(e- -64|0,7677);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Ic(g,f,e+32|0)){if(!ud(y[a+28|0])){break e}if(c<=0|c>4){a=ba(8)|0;x[23604]=0;d=Q(54,e+144|0,7772)|0;b=x[23604];x[23604]=0;if((b|0)==1){break d}a=pc(a,d);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(d);break c}a=x[a+24>>2];i=a,j=Ge(65536/c),x[i+480244>>2]=j;lp(a);break e}b=oc(e+56|0,7729);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Ic(g,f,e+24|0)){if(!ud(y[a+28|0])){break e}if(c<=0|c>4){a=ba(8)|0;x[23604]=0;d=Q(54,e+144|0,7793)|0;b=x[23604];x[23604]=0;if((b|0)!=1){a=pc(a,d);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(d);break c}b=P()|0;ca(a|0);break c}a=x[a+24>>2];i=a,j=Ge(c*65536),x[i+480240>>2]=j;lp(a);break e}b=oc(e+48|0,7747);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(!Ic(g,f,e+16|0)){break e}i=x[a+24>>2],j=dm(c*65536),x[i+480236>>2]=j}hb=e+176|0;return}b=P()|0;ca(a|0)}T(b|0)}p()}function Dda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;h=hb-4144|0;hb=h;g=Lb(y[a+14|0]|y[a+15|0]<<8);a:{if(!g|g>>>0>20){break a}j=b+480190|0;if(z[j>>1]<=y[a+23|0]){break a}od(d,32);w[d+34>>1]=1;f=h+24|0;g=a+20|0;x[f>>2]=g;x[f+4>>2]=(g+80|0)-g>>2;PP(h+4136|0,x[h+24>>2],x[h+28>>2],Lb(y[a+14|0]|y[a+15|0]<<8));g=x[h+4136>>2];k=y[zb(g,0)+3|0];x[h+24>>2]=1;k=x[_c(Rj(b,k+1|0)+24|0,f)>>2];i=f;f=x[h+4140>>2];PP(i,g,f,c?f:1);r=1/+(k>>>0);f=x[h+24>>2];g=zb(f,x[h+28>>2]);k=x[h+4136>>2];j=z[j>>1];while(1){if((f|0)==(g|0)){b:{s=yg(d);if(!s){break b}f=x[h+4140>>2];k=h+4120|0;x[k>>2]=0;x[k+4>>2]=0;zc(k+8|0);if(f){g=hb-16|0;hb=g;j=hb-16|0;hb=j;x[j+12>>2]=4925421;x[j+8>>2]=2147483647;i=x[Fb(j+12|0,j+8|0)>>2];hb=j+16|0;if(f>>>0>i>>>0){Sc();p()}if(f>>>0>=4925422){qi();p()}j=D(f,872);i=Jc(j);x[g+12>>2]=f;x[g+8>>2]=i;f=x[g+8>>2];x[k+4>>2]=f;x[k>>2]=f;C=Cb(k),E=f+D(x[g+12>>2],872)|0,x[C>>2]=E;hb=g+16|0;f=hb-16|0;hb=f;x[f>>2]=k;g=x[k+4>>2];x[f+4>>2]=g;x[f+8>>2]=g+j;i=x[f+4>>2];g=x[f+8>>2];while(1){if((g|0)==(i|0)){ic(f);hb=f+16|0}else{EP(Zb(i,0,872));i=i+872|0;x[f+4>>2]=i;continue}break}}j=(e<<12>>>0)/1e4|0;t=x[k>>2];o=x[h+4136>>2];u=x[h+4140>>2];B=b+480190|0;f=0;i=0;while(1){if((f|0)==(u|0)){g=b+24648|0}else{g=zb(o,f);e=OP(t,f);l=y[g+3|0];c:{if(l>>>0>=z[B>>1]){break c}m=v[g+1|0];if((m|0)<0){break c}n=0;g=y[g+2|0];if((g+14&255)>>>0<=5){n=y[g+27166|0]}l=Rj(b,l+1|0);g=x[l+24>>2];q=r*(wj(+(n<<24>>24)/96+ +(m-v[zb(o,0)+1|0]|0)/12)*+(g>>>0));if(q<=0){break c}g=NP(q);x[e+8>>2]=g;n=lb;x[e+12>>2]=n;x[e+16>>2]=x[l+20>>2];m=x[l>>2];x[e+76>>2]=m;x[e+88>>2]=z[l+34>>1]&1023;d:{if(c){x[e+664>>2]=i;i=Ge(+(m>>>0)/zz(g,n))+i|0;g=j;break d}g=(j>>>0)/(Lb(y[a+14|0]|y[a+15|0]<<8)>>>0)|0}x[e+20>>2]=g;x[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){e:{a=x[d>>2];if(a>>>0>b>>>0){Zb(h+24|0,0,4096);x[h+16>>2]=512;x[h+12>>2]=a-b;c=x[Fb(h+16|0,h+12|0)>>2];C=h,E=Bb(x[k>>2]),x[C+16>>2]=E;j=Bb(x[k+4>>2]);while(1){a=x[h+16>>2];if(!Ob(a,j)){break e}f:{g:{if(!x[a+16>>2]){break g}e=x[a+664>>2];if(e>>>0>=c>>>0){x[a+664>>2]=e-c;break g}f=x[a+88>>2];x[h+12>>2]=c-e;C=h,E=Ge((+A[a+76>>2]-zz(x[a>>2],x[a+4>>2]))/zz(x[a+8>>2],x[a+12>>2])),x[C+8>>2]=E;i=x[Fb(h+12|0,h+8|0)>>2];x[23604]=0;X(x[((f&1|(f&64?18:16))<<2)+27760>>2],a|0,g|0,(h+24|0)+(e<<3)|0,i|0);e=x[23604];x[23604]=0;if((e|0)==1){break f}x[a+664>>2]=0;if(A[a+76>>2]>A[a+4>>2]){break g}x[a+16>>2]=0}x[h+16>>2]=x[h+16>>2]+872;continue}break}a=P()|0;pt(k);T(a|0);p()}pt(k);break b}e=x[d+20>>2]+(b<<1)|0;f=h+24|0;a=hb-16|0;hb=a;x[a+12>>2]=c;wc(a+12|0,512);i=x[a+12>>2];while(1){if(i){j=gd(x[f>>2]+2048|0,12);j=(j|0)>=32767?32767:j;w[e>>1]=(j|0)<=-32768?-32768:j;f=f+8|0;e=e+2|0;i=i-1|0;continue}break}hb=a+16|0;b=b+c|0;continue}}f=(s|0)!=0}else{i=y[f+3|0];h:{if(i>>>0>=j>>>0){break h}l=v[f+1|0];if((l|0)<0){break h}i=Rj(b,i+1|0);o=x[i>>2];q=wj(+(l-v[zb(k,0)+1|0]|0)/-12);C=d,E=x[d>>2]+Ge(r*(q*+(o>>>0)*+A[i+24>>2]))|0,x[C>>2]=E}f=f+4|0;continue}break}}hb=h+4144|0;return f|0}function tg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=hb-112|0;hb=j;k=i&2147483647;a:{b:{l=e&2147483647;m=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:m)){o=k-2147418112|0;if(!h&(o|0)==-2147418112?f|g:(o|0)==-2147418112&(h|0)!=0|o>>>0>2147549184){break b}}if(!(!d&(l|0)==2147418112?m:l>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(l^2147418112|c))){n=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:n;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|l))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}n=(k|0)==(l|0);r=n&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:n&d>>>0<h>>>0|k>>>0>l>>>0;m=r;l=m?f:b;o=m?g:c;n=m?i:e;s=n;m=m?h:d;q=n&65535;d=r?d:h;e=r?e:i;t=e;n=e>>>16&32767;p=s>>>16&32767;if(!p){e=!(m|q);i=e;k=e?l:m;e=e<<6;h=e;i=G(i?o:q);e=e+((i|0)==32?G(k)+32|0:i)|0;vf(j+96|0,l,o,m,q,e-15|0);m=x[j+104>>2];q=x[j+108>>2];o=x[j+100>>2];p=16-e|0;l=x[j+96>>2]}f=r?b:f;g=r?c:g;h=d;i=t&65535;if(!n){b=!(h|i);e=b;k=b?f:h;b=b<<6;c=b;e=G(e?g:i);b=b+((e|0)==32?G(k)+32|0:e)|0;vf(j+80|0,f,g,h,i,b-15|0);n=16-b|0;h=x[j+88>>2];i=x[j+92>>2];g=x[j+84>>2];f=x[j+80>>2]}c=i<<3|h>>>29;b=h<<3|g>>>29;c=c|524288;h=m<<3|o>>>29;i=q<<3|m>>>29;r=s^t;e=g<<3|f>>>29;d=f<<3;c:{if((n|0)==(p|0)){break c}f=p-n|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}vf(j- -64|0,d,e,b,c,128-f|0);Ul(j+48|0,d,e,b,c,f);b=x[j+56>>2];c=x[j+60>>2];e=x[j+52>>2];d=x[j+48>>2]|(x[j+64>>2]|x[j+72>>2]|(x[j+68>>2]|x[j+76>>2]))!=0}m=d;k=e;n=h;q=i|524288;e=o<<3|l>>>29;o=l<<3;l=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(m^o|b^n|(k^l|c^q))){break a}d=o-m|0;e=l-((m>>>0>o>>>0)+k|0)|0;f=n-b|0;g=(k|0)==(l|0)&m>>>0>o>>>0|k>>>0>l>>>0;h=f-g|0;b=(q-((b>>>0>n>>>0)+c|0)|0)-(f>>>0<g>>>0)|0;i=b;if(b>>>0>524287){break d}b=!(h|i);f=b;g=b?d:h;b=b<<6;c=b;f=G(f?e:i);b=b+((f|0)==32?G(g)+32|0:f)|0;b=b-12|0;vf(j+32|0,d,e,h,i,b);p=p-b|0;h=x[j+40>>2];i=x[j+44>>2];d=x[j+32>>2];e=x[j+36>>2];break d}e=k+l|0;d=m+o|0;e=d>>>0<o>>>0?e+1|0:e;f=(k|0)==(e|0)&d>>>0<m>>>0|e>>>0<k>>>0;k=c+q|0;b=b+n|0;k=b>>>0<n>>>0?k+1|0:k;h=b+f|0;i=h>>>0<b>>>0?k+1|0:k;if(!(i&1048576)){break d}d=m&1|((e&1)<<31|d>>>1);e=h<<31|e>>>1;p=p+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}c=0;l=s&-2147483648;if((p|0)>=32767){h=c;i=l|2147418112;f=0;g=0;break a}n=0;e:{if((p|0)>0){n=p;break e}vf(j+16|0,d,e,h,i,p+127|0);Ul(j,d,e,h,i,1-p|0);d=x[j>>2]|(x[j+16>>2]|x[j+24>>2]|(x[j+20>>2]|x[j+28>>2]))!=0;e=x[j+4>>2];h=x[j+8>>2];i=x[j+12>>2]}o=d&7;d=(e&7)<<29|d>>>3;f=(o>>>0>4)+d|0;b=h<<29|e>>>3;g=d>>>0>f>>>0?b+1|0:b;d=(b|0)==(g|0)&d>>>0>f>>>0|b>>>0>g>>>0;b=c|((i&7)<<29|h>>>3);h=d+b|0;i=l|(i>>>3&65535|n<<16);i=b>>>0>h>>>0?i+1|0:i;f:{if((o|0)==4){b=0;k=g+b|0;d=f;c=f&1;f=f+c|0;g=d>>>0>f>>>0?k+1|0:k;b=(b|0)==(g|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+h|0;i=b>>>0>h>>>0?i+1|0:i;break f}if(!o){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;hb=j+112|0}function _ga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-400|0;hb=e;g=hb-32|0;hb=g;d=g+8|0;AA(d,b);tu(g,d);x[23604]=0;U(408,e+240|0,x[g>>2],x[g+4>>2]);b=x[23604];x[23604]=0;a:{if((b|0)!=1){Lc(g+8|0);hb=g+32|0;break a}a=P()|0;Lc(g+8|0);T(a|0);p()}x[23604]=0;U(391,e+136|0,x[e+240>>2],x[e+244>>2]);b=x[23604];x[23604]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){x[23604]=0;g=Q(78,e+256|0,e+136|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break z}xb(e+136|0);fc(e+240|0);if(c>>>0<2189){break g}b=Dl(e+136|0,g);x[23604]=0;c=Q(394,e+120|0,10016)|0;d=x[23604];x[23604]=0;if((d|0)==1){break x}x[23604]=0;x[e+104>>2]=19924993;x[e+108>>2]=0;U(395,b|0,c|0,e+104|0);d=x[23604];x[23604]=0;if((d|0)==1){break w}Db(c);v[e+119|0]=0;x[23604]=0;c=Q(394,e+104|0,10906)|0;d=x[23604];x[23604]=0;if((d|0)==1){break i}x[23604]=0;U(396,b|0,e+119|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break v}Db(c);c=0;c=y[e+119|0]?c:x[a+1298404>>2];f=x[a+4>>2];x[23604]=0;d=Q(394,e+88|0,15654)|0;h=x[23604];x[23604]=0;if((h|0)==1){break u}x[23604]=0;X(397,b|0,f|0,d|0,c|0);f=x[23604];x[23604]=0;if((f|0)==1){break t}Db(d);x[23604]=0;d=Q(394,e+72|0,15256)|0;f=x[23604];x[23604]=0;if((f|0)==1){break s}x[23604]=0;X(398,b|0,a|0,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break r}Db(d);x[23604]=0;c=Q(394,e+56|0,15152)|0;d=x[23604];x[23604]=0;if((d|0)==1){break q}x[23604]=0;d=a+484360|0;U(399,b|0,d|0,c|0);f=x[23604];x[23604]=0;if((f|0)==1){break p}Db(c);x[23604]=0;c=Q(394,e+40|0,27014)|0;f=x[23604];x[23604]=0;if((f|0)==1){break o}x[23604]=0;U(400,b|0,a+484344|0,c|0);f=x[23604];x[23604]=0;if((f|0)==1){break n}Db(c);f=x[a+1298404>>2];x[23604]=0;c=Q(394,e+24|0,27020)|0;h=x[23604];x[23604]=0;if((h|0)==1){break m}x[23604]=0;X(401,b|0,d|0,c|0,f|0);d=x[23604];x[23604]=0;if((d|0)==1){break l}Db(c);if(y[b+3|0]&64){x[23604]=0;c=Q(1,e+8|0,16133)|0;d=x[23604];x[23604]=0;if((d|0)==1){break k}a=x[a+1298464>>2];x[23604]=0;U(351,a|0,1,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break j}xb(c)}Wg(b);break f}a=P()|0;break y}a=P()|0;xb(e+136|0)}fc(e+240|0);break b}a=P()|0;break h}a=P()|0;Db(c);break h}a=P()|0;Db(c);break h}a=P()|0;break h}a=P()|0;Db(d);break h}a=P()|0;break h}a=P()|0;Db(d);break h}a=P()|0;break h}a=P()|0;Db(c);break h}a=P()|0;break h}a=P()|0;Db(c);break h}a=P()|0;break h}a=P()|0;Db(c);break h}a=P()|0;break h}a=P()|0;xb(c);break h}a=P()|0}Wg(b);break c}b=Kb(e+136|0);d=x[a+1298404>>2];f=x[a+4>>2];x[23604]=0;d=fa(402,f|0,g|0,b|0,d|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break e}A:{if((d|0)!=1){x[23604]=0;c=Q(1,e+120|0,16439)|0;d=x[23604];x[23604]=0;B:{if((d|0)!=1){a=x[a+1298464>>2];x[23604]=0;U(351,a|0,1,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break B}xb(c);break A}a=P()|0;break d}a=P()|0;xb(c);break d}d=x[a+1298404>>2];x[23604]=0;X(403,g|0,a|0,d|0,c>>>0<2188|0);a=x[23604];x[23604]=0;if((a|0)==1){break e}}xb(b)}hf(g);hb=e+400|0;return}a=P()|0}xb(b)}hf(g)}T(a|0);p()}function Hb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[23484]){break a}a=a+b|0;c:{d:{if(x[23485]!=(d|0)){if(b>>>0<=255){e=b>>>3|0;b=x[d+8>>2];c=x[d+12>>2];if((c|0)==(b|0)){i=93920,j=x[23480]&Nia(-2,e),x[i>>2]=j;break b}x[b+12>>2]=c;x[c+8>>2]=b;break b}g=x[d+24>>2];b=x[d+12>>2];if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}e=d+20|0;c=x[e>>2];if(!c){c=x[d+16>>2];if(!c){break d}e=d+16|0}while(1){h=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[h>>2]=0;break c}b=x[f+4>>2];if((b&3)!=3){break b}x[23482]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[f>>2]=a;return}b=0}if(!g){break b}c=x[d+28>>2];e=(c<<2)+94224|0;e:{if(x[e>>2]==(d|0)){x[e>>2]=b;if(b){break e}i=93924,j=x[23481]&Nia(-2,c),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=g;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{g:{h:{i:{if(!(b&2)){if(x[23486]==(f|0)){x[23486]=d;a=x[23483]+a|0;x[23483]=a;x[d+4>>2]=a|1;if(x[23485]!=(d|0)){break a}x[23482]=0;x[23485]=0;return}if(x[23485]==(f|0)){x[23485]=d;a=x[23482]+a|0;x[23482]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;if(b>>>0<=255){e=b>>>3|0;b=x[f+8>>2];c=x[f+12>>2];if((c|0)==(b|0)){i=93920,j=x[23480]&Nia(-2,e),x[i>>2]=j;break g}x[b+12>>2]=c;x[c+8>>2]=b;break g}g=x[f+24>>2];b=x[f+12>>2];if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}e=f+20|0;c=x[e>>2];if(!c){c=x[f+16>>2];if(!c){break i}e=f+16|0}while(1){h=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[h>>2]=0;break h}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;break f}b=0}if(!g){break g}c=x[f+28>>2];e=(c<<2)+94224|0;j:{if(x[e>>2]==(f|0)){x[e>>2]=b;if(b){break j}i=93924,j=x[23481]&Nia(-2,c),x[i>>2]=j;break g}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=g;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[23485]!=(d|0)){break f}x[23482]=a;return}if(a>>>0<=255){b=(a&-8)+93960|0;c=x[23480];a=1<<(a>>>3);k:{if(!(c&a)){x[23480]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}c=31;if(a>>>0<=16777215){b=G(a>>>8|0);c=((a>>>38-b&1)-(b<<1)|0)+62|0}x[d+28>>2]=c;x[d+16>>2]=0;x[d+20>>2]=0;b=(c<<2)+94224|0;l:{m:{e=x[23481];h=1<<c;n:{if(!(e&h)){x[23481]=e|h;x[b>>2]=d;x[d+24>>2]=b;break n}c=a<<((c|0)!=31?25-(c>>>1|0)|0:0);b=x[b>>2];while(1){e=b;if((x[b+4>>2]&-8)==(a|0)){break m}b=c>>>29|0;c=c<<1;h=e+(b&4)|0;b=x[h+16>>2];if(b){continue}break}x[h+16>>2]=d;x[d+24>>2]=e}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[e+8>>2];x[a+12>>2]=d;x[e+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=e;x[d+8>>2]=a}a=x[23488]-1|0;x[23488]=a?a:-1}}function Bia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=hb-736|0;hb=e;xc(b);f=hb-16|0;hb=f;h=e+120|0;tU(f+8|0,h);g=x[f+12>>2];j=b;mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){bc(j,x[f+12>>2])}hb=f+16|0;b=(b|0)==(g|0);if(!b){sU(h)}a:{if(!b){break a}if(!uU(e+120|0)){break a}b:{if(!c){break b}Cd(a,67108864);Ag(a);b=y[e+145|0];w[a+480190>>1]=31;w[a+480188>>1]=b;x[a+480228>>2]=256/(b>>>0);b=Xb(e,8097);Ab(a+1298344|0,b);xb(b);b=Xb(e,10663);Ab(a+1298356|0,b);xb(b);d=e+96|0;ef(d,4135);f=y[e+144|0];x[e+72>>2]=f>>>4;b=0;x[23604]=0;x[e+116>>2]=f&15;X(286,e|0,d|0,e+72|0,e+116|0);d=x[23604];x[23604]=0;c:{d:{if((d|0)!=1){Ab(a+1298368|0,e);xb(e);Db(e+96|0);x[a+1298404>>2]=13;mq(_b(x[a+484360>>2],y[a+484376|0]),e+168|0,y[e+167|0]+1|0);while(1){e:{if((b|0)==31){ku(j,a+1298308|0,32);d=1;break e}d=b+1|0;g=D(d,104)+a|0;h=g+484380|0;od(h,1);f=(e+120|0)+(b<<2)|0;q=h,r=dc(y[f+176|0]|y[f+177|0]<<8|(y[f+178|0]<<16|y[f+179|0]<<24)),x[q>>2]=r;k=dc(y[f+300|0]|y[f+301|0]<<8|(y[f+302|0]<<16|y[f+303|0]<<24));x[g+484384>>2]=k;f=dc(y[f+424|0]|y[f+425|0]<<8|(y[f+426|0]<<16|y[f+427|0]<<24));x[g+484388>>2]=f+k;if(f){f=g+484414|0;w[f>>1]=z[f>>1]|2}ek(h);b=(e+120|0)+b|0;v[e|0]=y[b+548|0];v[e+96|0]=64;q=g+484410|0,r=y[Wb(e,e+96|0)|0]<<2,w[q>>1]=r;v[g+484417|0]=y[b+579|0]<<4;b=d;continue}break}while(1){if((d|0)!=32){rU(j,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}n=c&1;if(n){gg(a+484344|0,y[e+166|0]+1|0)}k=a+484344|0;m=a+480188|0;f=0;while(1){if(y[e+166|0]<f>>>0){d=1;if(!(c&2)){break a}b=Xc(e,8,1,1,0);while(1){if((d|0)==32){break b}fg(b,(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}g=xh(e+96|0);f:{g:{if(y[e+146|0]){x[23604]=0;b=S(256,j|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break f}x[23604]=0;U(176,e+72|0,j|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break f}break g}b=z[m>>1];x[23604]=0;U(176,e+72|0,j|0,b<<8);b=x[23604];x[23604]=0;if((b|0)==1){break d}}b=e+72|0;d=kc(e,b);$c(g,d);yb(d);yb(b);h:{if(!n){break h}x[23604]=0;b=W(212,k|0,f&65535,64)|0;d=x[23604];x[23604]=0;if((d|0)==1){break d}if(!b){break h}b=0;if(y[e+146|0]){h=0;x[23604]=0;R(287,g|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break d}i:while(1){if((h|0)==64){break h}i=e+h|0;b=128;d=0;l=ac(x[k>>2],f);l=of(x[l>>2],x[x[l+48>>2]+12>>2],h);while(1){if(z[m>>1]<=d>>>0){h=h+1|0;continue i}j:{if(!(y[i|0]&b)){break j}x[23604]=0;R(288,g|0,l+D(d,6)|0);o=x[23604];x[23604]=0;if((o|0)!=1){break j}break d}b=b>>>1|0;d=d+1|0;continue}}}k:while(1){d=0;h=b&65535;if(h>>>0>=z[m>>1]){break h}while(1){if((d|0)==64){b=b+1|0;continue k}i=ac(x[k>>2],f);i=cd(x[i>>2],x[x[i+48>>2]+12>>2],d,h);x[23604]=0;R(288,g|0,i|0);i=x[23604];x[23604]=0;if((i|0)!=1){d=d+1|0;continue}break}break}break d}yb(g);f=f+1|0;continue}break}break d}d=P()|0;Db(e+96|0);break c}d=P()|0;yb(g)}T(d|0);p()}d=1}hb=e+736|0;return d|0}function SL(a,b){var c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=E(0),t=0;if(b){ay(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;XL(a)}RL(a+24648|0);o=x[a+24620>>2];f=hb-144|0;hb=f;d=!b;e=a+397456|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}h=D(c,44)+48e3|0;if(!((h|0)==x[e+8>>2]&d)){x[e+8>>2]=h;m=E(o>>>0);c=f+8|0;d=x[h+24>>2];x[c>>2]=d;j=x[h+16>>2];x[c+4>>2]=j;x[c+8>>2]=x[h+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){i=j;j=k+600|0;x[c+4>>2]=i-j;x[c>>2]=d-j}g=E(B[h+36>>2]*E(79.30999755859375));a:{if(E(F(g))<E(2147483648)){d=~~g;break a}d=-2147483648}x[c+16>>2]=d- -8192;g=E(E(E(B[h+32>>2]*E(.0036000001709908247))+E(.15000000596046448))*E(32767));b:{if(E(F(g))<E(2147483648)){d=~~g;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;j=0;g=B[h+8>>2];l=E(E(H(B[h+20>>2],E(.10000000149011612)))*m);c:{if(E(F(l))<E(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)<=96?96:d;i=k-7500|0;n=k>>>0>=i>>>0?i:0;l=E(B[h+28>>2]*m);d:{if(E(F(l))<E(2147483648)){i=~~l;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)<=128?128:d;p=i>>>0>=3800?3800:i;x[c+24>>2]=p;n=(d|0)<128?d-128|0:0;g=E(g*m);e:{if(E(F(g))<E(2147483648)){q=~~g;break e}q=-2147483648}d=i-3800|0;i=(q+n|0)+(d>>>0<=i>>>0?d:0)|0;x[c+32>>2]=i;n=k>>>0>=7500?7500:k;while(1){if((j|0)==8){g=E(i|0);l=E(me(E(.0010000000474974513),(i|0)<4721?E(1):E(E(4720)/g))*E(32768));f:{if(E(F(l))<E(2147483648)){d=~~l;break f}d=-2147483648}x[c+12>>2]=d;g=E(B[h+12>>2]*g);r=c,s=me(E(.0010000000474974513),g<=E(4720)?E(1):E(E(4720)/g)),B[r+28>>2]=s}else{d=D(j,12);k=d+c|0;w[k+42>>1]=z[d+49290>>1];w[k+36>>1]=z[d+49284>>1];w[k+40>>1]=z[d+49288>>1];w[k+38>>1]=z[d+49286>>1];x[k+44>>2]=n+((D(x[d+49280>>2],p)+50|0)/100|0);j=j+1|0;continue}break}x[e+20>>2]=x[f+40>>2];c=SJ(TJ(x[f+16>>2]),m);w[e+86>>1]=c;w[e+84>>1]=c;c=z[f+24>>1]<<1;w[e+94>>1]=c;w[e+92>>1]=c;c=0;while(1){if((c|0)==8){x[e+49892>>2]=x[f+32>>2];c=x[f+12>>2];if((c|0)>-9e3){c=RJ(c)}else{c=0}x[e+80>>2]=c;d=e+49948|0;c=x[f+8>>2];if((c|0)>=-8999){c=RJ(c)}else{c=0}x[d>>2]=c;c=x[f+28>>2];d=e+49932|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+49906>>1]=c;w[e+49904>>1]=c;w[e+49902>>1]=c;w[e+49900>>1]=c;x[f+4>>2]=x[f+20>>2];fe(f+4|0,0,32752);c=z[f+4>>1];w[e+49914>>1]=c;w[e+49910>>1]=0;w[e+49912>>1]=0;w[e+49908>>1]=c;g=B[f+36>>2];r=f,t=SJ(E(g*g),m),x[r>>2]=t;fe(f,256,32512);c=z[f>>1];w[e+49922>>1]=c;w[e+49918>>1]=0;w[e+49920>>1]=0;w[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+8|0)+D(c,12)|0;j=x[h+44>>2];x[d+100>>2]=j;x[d+104>>2]=j;w[d+108>>1]=z[h+36>>1];w[d+110>>1]=z[h+42>>1];w[d+112>>1]=z[h+40>>1];w[d+114>>1]=z[h+38>>1];c=c+1|0;continue}break}}if(b){x[e+16>>2]=0;VJ(e,a+397448|0,a+397452|0)}b=D(o,5);if(b>>>0>A[e+20>>2]){x[e+20>>2]=b}hb=f+144|0;b=x[a+1298300>>2];if(td(b)){CO(b,x[a+24620>>2])}}function WV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=hb-32|0;hb=e;x[e+28>>2]=b;a:{if((d|0)<=0){break a}x[e+8>>2]=d;x[e+16>>2]=214748364;u=e,w=D(x[Fb(e+28|0,e+16|0)>>2],20),x[u+20>>2]=w;dn(c,x[Fb(e+8|0,e+20|0)>>2]);x[e+12>>2]=b;x[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=_g(a,b,i);h=_g(a,b,i+4|0);f=_g(a,b,i+5|0);u=e,w=_g(a,b,i+6|0)<<8|_g(a,b,i+7|0),x[u+24>>2]=w;n=f|h<<8;t=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<n>>>0){i=ba(8)|0;x[23604]=0;a=S(179,i|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(n|0)){u=e,w=_g(a,b,i+t|0),v[u+20|0]=w;cn(c,e+20|0);i=i+1|0;continue}break};s=n;break b;case 1:break g;default:break e}}Rh(e+24|0,d);s=x[e+24>>2];o=_g(a,b,i+10|0);v[e+20|0]=o;cn(c,e+20|0);j=i+11|0;n=n+3&65532;i=s-1|0;h=0;l=0;q=0;m=0;while(1){if((i|0)<=0){break c}f=jg(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;m=8;break l}g=h+1|0;m:{if(!f){if(!jg(j,g,1,e+8|0)){break i}k=2;n:{o:{f=h+2|0;if(!jg(j,f,1,e+8|0)){break o}k=3;f=h+3|0;if(!jg(j,f,1,e+8|0)){break o}k=jg(j,f,3,e+8|0);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((m<<3)+k|0)-17|0;s:{if((h|0)<0){a=ba(8)|0;x[23604]=0;b=S(179,a|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=ba(8)|0;x[23604]=0;b=S(179,a|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break q}}b=P()|0;ca(a|0);T(b|0);p()}ha(b|0,26440,154);p()}ha(b|0,26440,154);p()}m=y[h+26480|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((q|0)>19){break k}}f=0;break j}q=q+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;r=_g(x[e+8>>2],x[e+12>>2],h);o=o-gd((_g(x[e+8>>2],x[e+12>>2],h+1|0)<<8|r<<16|_g(x[e+8>>2],x[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;v[e+20|0]=o;cn(c,e+20|0);f=f-1|0;i=i-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!jg(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!jg(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!jg(j,f,1,e+8|0)){h=6;break v}f=g+5|0;if(!jg(j,g+4|0,1,e+8|0)){g=g+8|0;f=jg(j,f,3,e+8|0)+8|0;break t}g=g+10|0;h=16;f=jg(j,f,5,e+8|0);break u}g=f+2|0;f=jg(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(jg(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=jg(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}r=g+1|0;g=jg(j,r,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)<=1?1:l)-1|0}k=(g^-1)+k|0;g=Rc(x[c>>2],x[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+r|0;while(1){if((f|0)<=0|(i|0)<=0){break h}o=y[Gb(x[c>>2],g)|0];v[e+20|0]=o;cn(c,e+20|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=ba(8)|0;x[23604]=0;a=S(179,i|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break d}ha(a|0,26440,154);p()}q=q-(q>>3)|0;continue}}ha(a|0,26440,154);p()}i=tc(x[c>>2],x[c+4>>2])^1;break a}a=P()|0;ca(i|0);T(a|0);p()}x[e+24>>2]=i}d=d-s|0;i=n+t|0;continue}}hb=e+32|0;return i|0}function eR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=x[a>>2];b=c+b|0;c:{d:{e:{a=a-c|0;if((a|0)!=x[23485]){if(c>>>0<=255){e=c>>>3|0;c=x[a+8>>2];d=x[a+12>>2];if((d|0)!=(c|0)){break e}i=93920,j=x[23480]&Nia(-2,e),x[i>>2]=j;break b}g=x[a+24>>2];c=x[a+12>>2];if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break c}e=a+20|0;d=x[e>>2];if(!d){d=x[a+16>>2];if(!d){break d}e=a+16|0}while(1){h=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[h>>2]=0;break c}c=x[f+4>>2];if((c&3)!=3){break b}x[23482]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[c+12>>2]=d;x[d+8>>2]=c;break b}c=0}if(!g){break b}d=x[a+28>>2];e=(d<<2)+94224|0;f:{if(x[e>>2]==(a|0)){x[e>>2]=c;if(c){break f}i=93924,j=x[23481]&Nia(-2,d),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=g;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c}g:{h:{i:{j:{c=x[f+4>>2];if(!(c&2)){if(x[23486]==(f|0)){x[23486]=a;b=x[23483]+b|0;x[23483]=b;x[a+4>>2]=b|1;if(x[23485]!=(a|0)){break a}x[23482]=0;x[23485]=0;return}if(x[23485]==(f|0)){x[23485]=a;b=x[23482]+b|0;x[23482]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;if(c>>>0<=255){e=c>>>3|0;c=x[f+8>>2];d=x[f+12>>2];if((d|0)==(c|0)){i=93920,j=x[23480]&Nia(-2,e),x[i>>2]=j;break h}x[c+12>>2]=d;x[d+8>>2]=c;break h}g=x[f+24>>2];c=x[f+12>>2];if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}e=f+20|0;d=x[e>>2];if(!d){d=x[f+16>>2];if(!d){break j}e=f+16|0}while(1){h=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[h>>2]=0;break i}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b;break g}c=0}if(!g){break h}d=x[f+28>>2];e=(d<<2)+94224|0;k:{if(x[e>>2]==(f|0)){x[e>>2]=c;if(c){break k}i=93924,j=x[23481]&Nia(-2,d),x[i>>2]=j;break h}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=g;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[23485]!=(a|0)){break g}x[23482]=b;return}if(b>>>0<=255){c=(b&-8)+93960|0;d=x[23480];b=1<<(b>>>3);l:{if(!(d&b)){x[23480]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}d=31;if(b>>>0<=16777215){c=G(b>>>8|0);d=((b>>>38-c&1)-(c<<1)|0)+62|0}x[a+28>>2]=d;x[a+16>>2]=0;x[a+20>>2]=0;c=(d<<2)+94224|0;m:{e=x[23481];h=1<<d;n:{if(!(e&h)){x[23481]=e|h;x[c>>2]=a;x[a+24>>2]=c;break n}d=b<<((d|0)!=31?25-(d>>>1|0)|0:0);c=x[c>>2];while(1){e=c;if((x[c+4>>2]&-8)==(b|0)){break m}c=d>>>29|0;d=d<<1;h=e+(c&4)|0;c=x[h+16>>2];if(c){continue}break}x[h+16>>2]=a;x[a+24>>2]=e}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[e+8>>2];x[b+12>>2]=a;x[e+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=e;x[a+8>>2]=b}}function WS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb-176|0;hb=g;i=ag(g+160|0);a:{b:{c:{if(d){x[23604]=0;U(415,a|0,i|0,c|0);c=x[23604];x[23604]=0;if((c|0)!=1){break c}break b}x[23604]=0;U(416,a|0,i|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}}k=Sb(g+144|0);m=b+480192|0;n=b+1298464|0;c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=c&65535;if(h>>>0<=z[m>>1]){x[23604]=0;w[g+142>>1]=0;R(417,a|0,g+142|0);d=x[23604];x[23604]=0;t:{u:{v:{w:{if((d|0)!=1){j=hb-16|0;hb=j;o=z[g+142>>1];d=Sd(i);e=jc(i);f=hb-16|0;hb=f;while(1){if(d){l=eo(z[d+16>>1],o);e=l?e:d;d=x[(l?d+4|0:d)>>2];continue}break}d=x[Ib(f+8|0,e)>>2];hb=f+16|0;x:{if(Ob(d,Ef(i))){if(!eo(z[g+142>>1],z[sd(d)>>1])){break x}}d=Ef(i)}d=Ib(j+8|0,d);hb=j+16|0;j=((h<<2)+b|0)+900380|0;if(!x[j>>2]){break d}d=x[d>>2];if(!xg(d,xf(i))){break u}x[23604]=0;d=Q(3,g+128|0,sd(d)+4|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break t}x[23604]=0;e=Q(1,g+112|0,16629)|0;f=x[23604];x[23604]=0;if((f|0)==1){break v}f=Xp(d,e);xb(e);if(f){break p}e=x[b+4>>2];x[23604]=0;e=Q(418,e|0,d|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break r}x[x[j>>2]+44>>2]=e;if(!x[x[j>>2]+44>>2]){break w}break e}c=P()|0;break f}x[23604]=0;e=Q(1,g+96|0,13282)|0;f=x[23604];x[23604]=0;y:{z:{A:{if((f|0)!=1){B:{if(!Xp(d,e)){x[23604]=0;f=Q(1,g+80|0,13487)|0;h=x[23604];x[23604]=0;if((h|0)==1){break A}h=Xp(d,f);xb(f);xb(e);if(h){break B}break s}xb(e)}x[23604]=0;e=S(419,d|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break z}x[g+56>>2]=e;e=x[b+4>>2];f=x[Mf(g+72|0,g+56|0)>>2];x[23604]=0;e=Q(420,e|0,f|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break y}bg(g+56|0);if(e){break e}break s}c=P()|0;break g}c=P()|0;xb(e);break g}c=P()|0;break g}c=P()|0;bg(g+56|0);break g}c=P()|0;break g}d=x[j>>2];if(!d){break d}x[d+44>>2]=0;break d}c=P()|0;break f}Vd(k);VS(i);hb=g+176|0;return}e=Bb(x[k>>2]);h=Bb(x[k+4>>2]);f=hb-16|0;hb=f;x[f+8>>2]=e;while(1){C:{if(!Ob(e,h)){break C}if(Xp(e,d)){break C}e=x[Wp(f+8|0)>>2];continue}break}hb=f+16|0;if(Ob(e,Bb(x[k+4>>2]))){break p}x[23604]=0;R(421,k|0,d|0);e=x[23604];x[23604]=0;if((e|0)!=1){break q}}c=P()|0;break g}x[23604]=0;e=Q(1,g+24|0,17330)|0;f=x[23604];x[23604]=0;if((f|0)==1){break o}x[23604]=0;U(422,g+40|0,e|0,d|0);f=x[23604];x[23604]=0;if((f|0)==1){break n}x[23604]=0;f=Q(1,g+8|0,16182)|0;h=x[23604];x[23604]=0;if((h|0)==1){break m}x[23604]=0;U(2,g+56|0,g+40|0,f|0);h=x[23604];x[23604]=0;if((h|0)==1){break l}h=x[n>>2];x[23604]=0;U(351,h|0,2,g+56|0);h=x[23604];x[23604]=0;if((h|0)==1){break k}xb(g+56|0);xb(f);xb(g+40|0);xb(e)}x[x[j>>2]+44>>2]=0;break e}c=P()|0;break g}c=P()|0;break h}c=P()|0;break i}c=P()|0;break j}c=P()|0;xb(g+56|0)}xb(f)}xb(g+40|0)}xb(e)}xb(d)}Vd(k);break a}xb(d)}c=c+1|0;continue}}c=P()|0}VS(i);T(c|0);p()}function eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=hb-32|0;hb=j;a:{b:{if(dt(a)>>>0<b>>>0){if((b|0)<0){break b}n=Wn(j+16|0);x[23604]=0;R(681,n|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}$k(j+8|0,x[a>>2]);hm(j,x[a>>2],x[a+4>>2]);m=hb-48|0;hb=m;d=x[n+4>>2];c=ec(m+40|0,x[j+8>>2],x[j+12>>2]);e=ec(m+32|0,x[j>>2],x[j+4>>2]);b=hb-16|0;hb=b;c=ec(b+8|0,x[c>>2],x[c+4>>2]);e=ec(b,x[e>>2],x[e+4>>2]);c=KQ(x[c>>2],x[c+4>>2],x[e>>2],x[e+4>>2]);hb=b+16|0;c=c+d|0;x[n+4>>2]=c;c:{d:{if(!d){b=c-1|0;break d}b=c-1|0;if((b^d-1)>>>0<32){break c}}x[x[n>>2]+((c>>>0>=33?b>>>5|0:0)<<2)>>2]=0}e=ec(m+24|0,x[j+8>>2],x[j+12>>2]);c=ec(m+16|0,x[j>>2],x[j+4>>2]);b=m+8|0;vo(b,x[n>>2],d);d=x[e>>2];o=hb-48|0;hb=o;e=x[e+4>>2];e:{if((e|0)==x[b+4>>2]){e=ec(o+40|0,d,e);c=ec(o+32|0,x[c>>2],x[c+4>>2]);b=ec(o+24|0,x[b>>2],x[b+4>>2]);d=hb-16|0;hb=d;f=x[e>>2];g=x[e+4>>2];c=_k(x[c>>2],x[c+4>>2],f,g);x[d+12>>2]=c;f:{if((c|0)<=0){c=x[b>>2];break f}if(g){i=32-g|0;x[d+8>>2]=i;k=c;c=x[rd(d+8|0,d+12|0)>>2];x[d+12>>2]=k-c;h=x[b>>2];g=-1<<g&-1>>>i-c;x[h>>2]=x[h>>2]&(g^-1)|g&x[f>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;x[b>>2]=h+(c>>>3&536870908);f=x[e>>2]+4|0;x[e>>2]=f;c=x[d+12>>2]}k=f;f=(c|0)/32|0;JQ(k,f,x[b>>2]);g=c-(f<<5)|0;x[d+12>>2]=g;f=f<<2;c=f+x[b>>2]|0;x[b>>2]=c;if((g|0)<=0){break f}c=e;e=f+x[e>>2]|0;x[c>>2]=e;c=x[b>>2];f=-1>>>32-g|0;x[c>>2]=x[c>>2]&(f^-1)|f&x[e>>2];x[b+4>>2]=x[d+12>>2]}ec(m,c,x[b+4>>2]);hb=d+16|0;break e}g=ec(o+16|0,d,e);d=ec(o+8|0,x[c>>2],x[c+4>>2]);f=ec(o,x[b>>2],x[b+4>>2]);e=hb-16|0;hb=e;c=x[d>>2];k=x[d+4>>2];b=x[g>>2];d=x[g+4>>2];c=_k(c,k,b,d);x[e+12>>2]=c;g:{if((c|0)<=0){d=x[f+4>>2];break g}h:{if(!d){d=x[f+4>>2];break h}l=32-d|0;x[e+8>>2]=l;i=e+8|0;h=x[rd(i,e+12|0)>>2];x[e+12>>2]=c-h;c=x[f+4>>2];q=x[b>>2];x[e+8>>2]=h;k=32-c|0;x[e+4>>2]=k;b=x[f>>2];r=x[b>>2];i=x[Fb(i,e+4|0)>>2];l=q&(-1<<d&-1>>>l-h);x[b>>2]=(-1<<c&-1>>>k-i^-1)&r|(c>>>0>d>>>0?l<<c-d:l>>>d-c|0);c=c+i|0;d=c&31;x[f+4>>2]=d;c=b+(c>>>3&536870908)|0;x[f>>2]=c;b=h-i|0;if((b|0)>0){x[c>>2]=x[c>>2]&(-1>>>32-b^-1)|l>>>i+x[g+4>>2];x[f+4>>2]=b;d=b}b=x[g>>2]+4|0;x[g>>2]=b;c=x[e+12>>2]}h=32-d|0;i=-1<<d;l=i^-1;while(1){if((c|0)>=32){c=x[f>>2];b=x[b>>2];x[c>>2]=l&x[c>>2]|b<<d;x[f>>2]=c+4;x[c+4>>2]=i&x[c+4>>2]|b>>>h;c=x[e+12>>2]-32|0;x[e+12>>2]=c;b=x[g>>2]+4|0;x[g>>2]=b;continue}break}if((c|0)<=0){break g}l=x[b>>2];x[e+8>>2]=h;g=x[f>>2];b=x[g>>2];k=b;b=x[rd(e+12|0,e+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-c;x[g>>2]=k|h<<d;c=b+d|0;d=c&31;x[f+4>>2]=d;c=g+(c>>>3&536870908)|0;x[f>>2]=c;g=x[e+12>>2]-b|0;x[e+12>>2]=g;if((g|0)<=0){break g}x[c>>2]=x[c>>2]&(-1>>>32-g^-1)|h>>>b;d=x[e+12>>2];x[f+4>>2]=d}ec(m,x[f>>2],d);hb=e+16|0}hb=o+48|0;hb=m+48|0;kt(a,n);He(n)}hb=j+32|0;return}Sc();p()}a=P()|0;He(n);T(a|0);p()}function _J(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=0,k=E(0),m=E(0),p=E(0),s=E(0),t=0,u=0,v=E(0),w=E(0);d=a+4208|0;EN(zb(d,0),B[a+4272>>2]);b=E(E(B[zb(d,0)>>2]*E(15920))+E(80));s=me(E(10),E(E(E(B[zb(d,2)>>2]+E(-.5))*E(30))/E(40)));c=E(E(b/E(A[x[a+16>>2]+24620>>2]))*E(6.2831854820251465));b=rK(c);v=dp(c);w=b;f=E(E(c*E(E(E(B[zb(d,1)>>2]*E(35))+E(1))*E(.02888113260269165)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());h=(q(f),j(2))&2147483647;c=(l(2,h),r());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{i=(q(c),j(2));d=i&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((i|0)<0){break b}if(!(c>E(88.7216796875))){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((i|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));k=E(c*b);p=E(E(k*E(E(k*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(k*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-k));if(!d){break b}e=E(E(E(c*E(p-e))-e)-k);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}i=d<<23;b=(l(2,i+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}k=(l(2,1065353216-i|0),r());c=E((d>>>0<=22?E(E(E(1)-k)+E(c-e)):E(E(c-E(e+k))+E(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=Ew(b)&2047;j:{k:{if(Ew(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(Ew(E(O))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=eD(0);break j}if(!(b<E(-103.97207641601562))){break k}c=KC(0);break j}g=C[165]*+b;t=C[164];u=g+t;g=g-(u-t);g=(C[166]*g+C[167])*(g*g)+(C[168]*g+1);o(+u);j(1)|0;d=j(0)|0;i=d<<15;d=((d&31)<<3)+1024|0;h=x[d>>2];d=x[d+4>>2]+i|0;l(0,h|0);l(1,(h>>>0<h>>>0?d+1|0:d)|0);c=E(g*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/s);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*s);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function bW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-160|0;hb=d;xc(b);Fo(a);a:{if(!Zu(b,d+120|0)){break a}if(!_C(d+120|0)){break a}j=x[b+8>>2];b:{if(!Yc(b,y[d+136|0]|y[d+137|0]<<8|(y[d+138|0]<<16|y[d+139|0]<<24))){break b}while(1){c:{if((y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24))>>>0>h>>>0){if(Qb(x[b>>2],x[b+8>>2],5)){break c}}f=i&1;break b}f=0;g=1;d:{if((y[d+124|0]|y[d+125|0]<<8)>>>0>=64){if((hi(b)|0)<=0){break d}}while(1){l=Be(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(gp(l<<24>>24)&255)==y[f+12972|0]}g=e;f=f+1|0;continue}break}bc(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}Yc(b,j);if(!f){break a}if(!Qb(x[b>>2],x[b+8>>2],ZC(d+120|0))){break a}if(!c){k=1;break a}g=hb-16|0;hb=g;e=d+120|0;Yc(b,y[e+16|0]|y[e+17|0]<<8|(y[e+18|0]<<16|y[e+19|0]<<24));i=d+104|0;f=Sb(i);c=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);x[23604]=0;R(167,f|0,c|0);c=x[23604];x[23604]=0;e:{f:{g:{if((c|0)!=1){c=0;h:{i:{while(1){if((y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24))>>>0<=c>>>0){break h}h=x[b+8>>2];j=x[b>>2];x[23604]=0;h=W(142,j|0,h|0,5)|0;j=x[23604];x[23604]=0;if((j|0)==1){break g}if(!h){break h}h=y[e+4|0]|y[e+5|0]<<8;x[23604]=0;U(168,g|0,b|0,h|0);h=x[23604];x[23604]=0;if((h|0)!=1){x[23604]=0;R(169,f|0,g|0);h=x[23604];x[23604]=0;if((h|0)==1){break i}c=c+1|0;xb(g);continue}break}c=P()|0;break f}c=P()|0;xb(g);break f}hb=g+16|0;break e}c=P()|0;break f}c=P()|0}Vd(f);T(c|0);p()}x[23604]=0;X(162,d+88|0,b|0,e|0,i|0);c=x[23604];x[23604]=0;j:{if((c|0)!=1){x[23604]=0;Q(141,b|0,x[d+144>>2])|0;c=x[23604];x[23604]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if(A[d+140>>2]>k>>>0){c=x[b+8>>2];e=x[b>>2];x[23604]=0;c=W(142,e|0,c|0,8)|0;e=x[23604];x[23604]=0;if((e|0)==1){break q}if(c){break p}}k=tc(x[a>>2],x[a+4>>2])^1;sc(d+88|0);Vd(d+104|0);break a}b=P()|0;break k}x[23604]=0;ea(163,d- -64|0,b|0,d+120|0,d+88|0,d+104|0);c=x[23604];x[23604]=0;if((c|0)!=1){e=Go(d- -64|0);x[23604]=0;c=S(164,x[d+64>>2])|0;f=x[23604];x[23604]=0;if((f|0)==1){break o}if(c){x[23604]=0;c=S(165,d+24|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break n}e=x[e>>2];r:{if((e|0)<0){break r}f=x[d+104>>2];if(Dd(f,x[d+108>>2])>>>0<=e>>>0){break r}x[23604]=0;U(11,d+8|0,8,Zd(f,e)|0);e=x[23604];x[23604]=0;if((e|0)==1){break m}e=d+8|0;Ab(c,e);xb(e)}Xu(g,d- -64|0);x[23604]=0;R(166,a|0,c|0);e=x[23604];x[23604]=0;if((e|0)==1){break m}Pq(c)}k=k+1|0;yb(d- -64|0);continue}break}b=P()|0;break k}b=P()|0;break l}b=P()|0;break l}b=P()|0;Pq(c)}yb(d- -64|0);break k}b=P()|0}sc(d+88|0);break j}b=P()|0}Vd(d+104|0);T(b|0);p()}hb=d+160|0;return k|0}function EJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-160|0;hb=f;x[f+152>>2]=c;x[f+156>>2]=d;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[Fk(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Rk(f+128|0,h,g,g-1|0);g=x[f+132>>2];x[b>>2]=x[f+128>>2];x[b+4>>2]=g}g=f+128|0;Pd(g);h=x[f+128>>2];Pd(f+112|0);i=Ek(h,x[f+116>>2],b);Pd(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==x[f+132>>2]){a=oc(f+144|0,21502);c=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=c;if(Ic(h,g,f+8|0)){a=ba(8)|0;x[23604]=0;R(910,f+112|0,f+152|0);b=x[23604];x[23604]=0;if((b|0)==1){break g}x[23604]=0;U(915,f+128|0,17481,f+112|0);b=x[23604];x[23604]=0;if((b|0)==1){break f}e=0;b=pc(a,f+128|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(f+128|0);break e}if(!e){break h}a=ba(8)|0;c=x[b>>2];b=x[b+4>>2];x[23604]=0;c=Ah(f+80|0,c,b);b=x[23604];x[23604]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[23604]=0;U(915,f+96|0,17517,c|0);b=x[23604];x[23604]=0;if((b|0)==1){break p}x[23604]=0;R(917,f+112|0,f+96|0);b=x[23604];x[23604]=0;e=1;if((b|0)==1){break o}x[23604]=0;R(910,f- -64|0,f+152|0);b=x[23604];x[23604]=0;if((b|0)==1){break n}x[23604]=0;U(919,f+128|0,f+112|0,f- -64|0);b=x[23604];x[23604]=0;if((b|0)==1){break m}b=pc(a,f+128|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(f+128|0);e=0;break l}b=P()|0;break d}b=P()|0;e=1;break i}b=P()|0;break j}b=P()|0;break k}b=P()|0}xb(f- -64|0)}xb(f+112|0)}xb(f+96|0)}xb(c);if(e){break d}break c}b=oc(f+56|0,21502);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;if(Ic(h,g,f+32|0)){a=ba(8)|0;x[23604]=0;R(910,f+112|0,f+152|0);b=x[23604];x[23604]=0;q:{r:{if((b|0)!=1){x[23604]=0;U(915,f+128|0,17481,f+112|0);b=x[23604];x[23604]=0;if((b|0)==1){break r}e=0;b=pc(a,f+128|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(f+128|0);break q}b=P()|0;break d}b=P()|0;e=1}xb(f+112|0);if(e){break d}break c}b=oc(f+48|0,10833);e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(Ic(h,g,f+24|0)){zJ(a,Ec(c,d));break h}b=oc(f+40|0,8529);e=x[b+4>>2];x[f+16>>2]=x[b>>2];x[f+20>>2]=e;if(!Ic(h,g,f+16|0)){break h}a=x[a+32>>2];b=Ky(c,d);b=b>>>0>=4?1:b;c=hb-16|0;hb=c;s:{if((Ej(y[a+140|0])|0)==(b|0)){d=a+120|0;cs(y[d+20|0]);b=hb-16|0;hb=b;x[b+8>>2]=c+8;a=hb-16|0;hb=a;e=x[15458];x[a+8>>2]=x[15457];x[a+12>>2]=e;e=x[15456];x[a>>2]=x[15455];x[a+4>>2]=e;mb[x[$o(a,Ej(y[d+20|0]))>>2]](b+8|0,d);hb=a+16|0;hb=b+16|0;break s}hJ(a,b,iJ(a))}hb=c+16|0}hb=f+160|0;return}b=P()|0;break d}b=P()|0;e=1}xb(f+112|0);if(!e){break c}}ca(a|0)}T(b|0)}p()}function vD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=hb-176|0;hb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){fv(a+128|0,c);x[23604]=0;c=Q(1,a+112|0,17617)|0;d=x[23604];x[23604]=0;if((d|0)==1){break E}x[23604]=0;U(2,a+144|0,a+128|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break D}x[23604]=0;d=Q(3,a+80|0,e|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break C}x[23604]=0;e=Q(1,a- -64|0,19445)|0;f=x[23604];x[23604]=0;if((f|0)==1){break B}x[23604]=0;U(4,a+96|0,d|0,e|0);f=x[23604];x[23604]=0;if((f|0)==1){break A}x[23604]=0;U(2,a+160|0,a+144|0,a+96|0);f=x[23604];x[23604]=0;if((f|0)==1){break z}xb(a+96|0);xb(e);xb(d);d=a+144|0;xb(d);xb(c);xb(a+128|0);c=x[b>>2];x[23604]=0;U(5,d|0,1,(c?c:21502)|0);c=x[23604];x[23604]=0;if((c|0)==1){break t}c=x[b+4>>2];x[23604]=0;U(5,a+128|0,1,(c?c:21502)|0);c=x[23604];x[23604]=0;if((c|0)==1){break s}b=x[b+8>>2];x[23604]=0;x[a+48>>2]=b;R(6,a+96|0,a+48|0);b=x[23604];x[23604]=0;if((b|0)==1){break r}x[23604]=0;Y(7,17496);b=x[23604];x[23604]=0;if((b|0)==1){break q}x[23604]=0;U(8,a+48|0,0,a+144|0);b=x[23604];x[23604]=0;if((b|0)==1){break p}x[23604]=0;Y(9,a+48|0);b=x[23604];x[23604]=0;if((b|0)==1){break o}x[23604]=0;Y(7,17290);b=x[23604];x[23604]=0;if((b|0)==1){break o}x[23604]=0;U(8,a+32|0,0,a+96|0);b=x[23604];x[23604]=0;if((b|0)==1){break n}x[23604]=0;Y(9,a+32|0);b=x[23604];x[23604]=0;if((b|0)==1){break m}x[23604]=0;Y(7,17288);b=x[23604];x[23604]=0;if((b|0)==1){break m}x[23604]=0;Y(7,17617);b=x[23604];x[23604]=0;if((b|0)==1){break m}x[23604]=0;U(8,a+16|0,0,a+160|0);b=x[23604];x[23604]=0;if((b|0)==1){break l}x[23604]=0;Y(9,a+16|0);b=x[23604];x[23604]=0;if((b|0)==1){break k}x[23604]=0;Y(7,13308);b=x[23604];x[23604]=0;if((b|0)==1){break k}x[23604]=0;U(8,a|0,0,a+128|0);b=x[23604];x[23604]=0;if((b|0)==1){break j}x[23604]=0;Y(9,a|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;Y(7,13306);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;Z(10);b=x[23604];x[23604]=0;if((b|0)==1){break i}xb(a);xb(a+16|0);xb(a+32|0);xb(a+48|0);xb(a+96|0);xb(a+128|0);xb(a+144|0);xb(a+160|0)}hb=a+176|0;return}b=P()|0;break u}b=P()|0;break v}b=P()|0;break w}b=P()|0;break x}b=P()|0;break y}b=P()|0;xb(a+96|0)}xb(e)}xb(d)}xb(a+144|0)}xb(c)}xb(a+128|0);break a}b=P()|0;break b}b=P()|0;break c}b=P()|0;break d}b=P()|0;break e}b=P()|0;break e}b=P()|0;break f}b=P()|0;break f}b=P()|0;break g}b=P()|0;break g}b=P()|0;break h}b=P()|0;break h}b=P()|0;xb(a)}xb(a+16|0)}xb(a+32|0)}xb(a+48|0)}xb(a+96|0)}xb(a+128|0)}xb(a+144|0)}xb(a+160|0)}T(b|0);p()}function _E(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;h=hb-48|0;hb=h;o(+a);d=j(1)|0;i=j(0)|0;a:{b:{e=d;k=e&2147483647;c:{if(k>>>0<=1074752122){if((d&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;i=k>>>20|0;e:{if((i-(e>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;if((i-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,i|0);l(1,e&1048575|1096810496);a=+n();d=0;i=1;while(1){m=(h+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=i;i=0;if(m){continue}break}C[h+32>>3]=a;d=2;while(1){i=d;d=d-1|0;if(C[(h+16|0)+(i<<3)>>3]==0){continue}break}d=uH(h+16|0,h,(k>>>20|0)-1046|0,i+1|0,1);a=C[h>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[h+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[h+8>>3]}hb=h+48|0;return d}function Sv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-96|0;hb=e;a:{if(fd(a,11)|x[a+4>>2]){d=x[a+28>>2];b=x[a+12>>2];g=x[a+64>>2];c=g+x[a+8>>2]|0;b=dh(e+80|0,c,c>>>0<g>>>0?b+1|0:b);c=x[b+12>>2];x[e+32>>2]=x[b+8>>2];x[e+36>>2]=c;c=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=c;zj(d,e+24|0);b=x[a+28>>2];if(Ck(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){eh(a,1073741826);break a}c=x[a+92>>2];b=a+44|0;f=x[b>>2];d=ch(f,x[b+4>>2]);b:{if(c>>>0>d>>>0){g=hb-32|0;hb=g;c=c-d|0;d=x[Cb(b)>>2];f=x[b+4>>2];c:{if(c>>>0<=d-f>>4>>>0){d=hb-16|0;hb=d;b=Jo(d,b,c);c=x[b+4>>2];f=x[b+8>>2];while(1){if((c|0)==(f|0)){ic(b);hb=d+16|0}else{$D(c);c=c+16|0;x[b+4>>2]=c;continue}break}break c}d=Cb(b);d=Cv(g+8|0,Gv(b,ch(x[b>>2],f)+c|0),ch(x[b>>2],x[b+4>>2]),d);h=hb-16|0;hb=h;c=ZD(h,d+8|0,c);f=x[c>>2];while(1){if(x[c+4>>2]!=(f|0)){$D(f);f=x[c>>2]+16|0;x[c>>2]=f;continue}break}Hd(c);hb=h+16|0;xd(b,d);iE(d)}hb=g+32|0;break b}if(c>>>0<d>>>0){Id(b,f+(c<<4)|0)}}g=a+32|0;dn(g,x[a+92>>2]<<2);d=0;while(1){if(A[a+92>>2]>d>>>0){b=x[a+28>>2];if(Ck(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){eh(a,1073741828);break a}c=z[a+16>>1];w[e+78>>1]=c;if((c|0)==65535){Uv(b,e+78|0);c=z[e+78>>1]}b=Rc(x[a+32>>2],x[a+36>>2]);f=c&65535;d:{if(!f){c=0;break d}if(f>>>0>(b^-1)>>>0){break d}Fi(g,b+f|0);yk(x[a+28>>2],Gb(x[a+32>>2],b),f)}f=bd(x[a+44>>2],d);x[f>>2]=b;w[f+12>>1]=c;if(fd(a,6)){lk(x[a+28>>2],e+56|0);b=x[e+56>>2];if(x[e+60>>2]<0){eh(a,1073741829);break a}i=bd(x[a+44>>2],d),j=b,x[i+4>>2]=j}b=x[a+4>>2];e:{if(b){c=bd(x[a+44>>2],d);x[c+8>>2]=b;break e}if(!fd(a,7)){c=bd(x[a+44>>2],d);break e}lk(x[a+28>>2],e+56|0);b=x[e+56>>2];if(x[e+60>>2]<0){eh(a,1073741829);break a}c=bd(x[a+44>>2],d);x[c+8>>2]=b}f:{if(x[c+8>>2]==-1){break f}if(fd(a,6)){break f}g:{if(!d){c=0;h=bd(x[a+44>>2],0);break g}b=x[a+44>>2];c=bd(b,d-1|0);c=x[c+8>>2]+x[c+4>>2]|0;h=bd(b,d)}x[h+4>>2]=c}if(fd(a,8)){w[e+56>>1]=0;Uv(x[a+28>>2],e+56|0);b=fd(a,9);Gl(x[a+28>>2],z[e+56>>1]<<b)}d=d+1|0;continue}break}_d(e+56|0,x[a+28>>2]);b=x[e+68>>2];x[a+72>>2]=x[e+64>>2];x[a+76>>2]=b}mk(a,4,1);d=x[a+72>>2];f=x[a+76>>2];c=x[a+12>>2];b=x[a+88>>2];g=x[a+8>>2]+b|0;c=b>>>0>g>>>0?c+1|0:c;h=d;d=(b|0)==x[a+64>>2];b=d?h:g;x[a+80>>2]=b;c=d?f:c;x[a+84>>2]=c;d=x[a+28>>2];b=dh(e+40|0,b,c);c=x[b+12>>2];x[e+16>>2]=x[b+8>>2];x[e+20>>2]=c;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;zj(d,e+8|0);if(fd(a,6)){break a}if(!(fd(a,7)|x[a+4>>2])){break a}b=x[a+80>>2]-x[a+8>>2]|0;c=x[a+44>>2];d=x[a+92>>2];a=0;while(1){if((a|0)==(d|0)){break a}f=bd(c,a);x[f+4>>2]=b+x[f+4>>2];a=a+1|0;continue}}hb=e+96|0}function S9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+8>>2]=44096;x[a+4>>2]=0;x[a>>2]=32528;b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;Cp(a+24604|0);yM(a+24648|0,0);x[a+397448>>2]=0;x[a+397452>>2]=0;b=a+397456|0;x[b>>2]=8;x[b+4>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;v[b+12|0]=0;x[b+8>>2]=0;w[b+24>>1]=0;Zb(b+28|0,0,40);Zb(b+68|0,0,49824);Zb(b+49892|0,0,32832);v[a+480224|0]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;i=Sb(a+480248|0);x[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;qC(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Sb(c);x[f+12>>2]=a;x[23604]=0;j=Q(761,a+484360|0,a|0)|0;b=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){d=a+900380|0;b=a+484380|0;while(1){x[23604]=0;b=S(632,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break i}b=b+104|0;if((d|0)!=(b|0)){continue}break}x[23604]=0;S(762,a+901404|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break h}c=a+946300|0;g=a+906300|0;b=g;while(1){b=xM(b)+160|0;if((c|0)!=(b|0)){continue}break}x[a+946300>>2]=0;e=a+1074304|0;h=a+946304|0;b=h;while(1){b=at(b)+32|0;if((e|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;Oq(a+1074312|0);x[23604]=0;Z(763);b=x[23604];x[23604]=0;if((b|0)==1){break g}t=a,u=rM(),x[t+1074328>>2]=u;b=a+1074332|0;x[b+12>>2]=1065353216;iM(b,4);x[23604]=0;e=S(764,a+1074376|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break g}x[23604]=0;k=W(532,a+1298264|0,a|0,255)|0;b=x[23604];x[23604]=0;if((b|0)==1){break f}l=zc(a+1298300|0);m=zc(a+1298304|0);n=Kb(a+1298308|0);o=Kb(a+1298320|0);q=Kb(a+1298332|0);r=vM(a+1298344|0);s=Sb(a+1298408|0);v[a+1298420|0]=0;b=a+1298424|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1298464>>2]=0;mp(a+12|0);hy(a+8204|0);hy(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;Zb(d,0,1024);qM(h);x[23604]=0;b=S(765,12)|0;d=x[23604];x[23604]=0;if((d|0)==1){break e}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;t=a,u=Sb(b),x[t+4>>2]=u;return a|0}b=P()|0;break a}b=P()|0;break b}b=P()|0;break b}b=P()|0;break c}b=P()|0;break d}b=P()|0;uM(s);ky(r);xb(q);xb(o);xb(n);jy(m);iy(l);Os(k)}xy(e)}while(1){c=Gs(c-160|0);if((g|0)!=(c|0)){continue}break}}fz(j)}nM(f);sc(i);T(b|0);p()}function w5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-192|0;hb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[Fk(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Rk(d+168|0,f,e,e-1|0);e=x[d+172>>2];x[b>>2]=x[d+168>>2];x[b+4>>2]=e}f=d+168|0;Pd(f);e=x[d+168>>2];Pd(d+152|0);e=Ek(e,x[d+156>>2],b);Pd(f);b:{c:{d:{e:{if((e|0)==x[d+172>>2]){a=x[b+4>>2];e=x[b>>2];f=oc(d+184|0,21502);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Ic(e,a,d)){a=ba(8)|0;x[23604]=0;c=Q(54,d+168|0,10374)|0;b=x[23604];x[23604]=0;if((b|0)==1){break d}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}e=0;if(!c){break e}a=ba(8)|0;c=x[b+4>>2];b=x[b>>2];x[23604]=0;e=Ah(d+152|0,b,c);b=x[23604];x[23604]=0;f:{g:{h:{if((b|0)!=1){x[23604]=0;U(915,d+168|0,17517,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break h}c=0;b=pc(a,d+168|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(d+168|0);break g}b=P()|0;break f}b=P()|0;c=1}xb(e);if(!c){break c}}ca(a|0);break c}if(x[e+4>>2]){a=ba(8)|0;x[23604]=0;c=Q(54,d+168|0,11459)|0;b=x[23604];x[23604]=0;if((b|0)!=1){a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}c=x[b+4>>2];b=x[b>>2];e=oc(d+144|0,21502);f=x[e+4>>2];x[d+72>>2]=x[e>>2];x[d+76>>2]=f;if(Ic(b,c,d+72|0)){a=ba(8)|0;x[23604]=0;c=Q(54,d+168|0,10374)|0;b=x[23604];x[23604]=0;if((b|0)!=1){a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}e=oc(d+136|0,7380);f=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=f;i:{if(!Ic(b,c,d- -64|0)){e=oc(d+128|0,7362);f=x[e+4>>2];x[d+56>>2]=x[e>>2];x[d+60>>2]=f;if(!Ic(b,c,d+56|0)){break i}}e=y[a+60|0]!=0;break e}e=oc(d+120|0,6895);f=x[e+4>>2];x[d+48>>2]=x[e>>2];x[d+52>>2]=f;j:{if(!Ic(b,c,d+48|0)){e=oc(d+112|0,6876);f=x[e+4>>2];x[d+40>>2]=x[e>>2];x[d+44>>2]=f;if(!Ic(b,c,d+40|0)){break j}}e=y[a+61|0]!=0;break e}e=oc(d+104|0,6979);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Ic(b,c,d+32|0)){e=y[a+62|0]!=0;break e}e=oc(d+96|0,6025);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Ic(b,c,d+24|0)){e=y[a+63|0]!=0;break e}e=oc(d+88|0,7429);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Ic(b,c,d+16|0)){e=y[a+64|0]!=0;break e}e=oc(d+80|0,13251);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;if(!Ic(b,c,d+8|0)){break e}e=x[x[a+24>>2]+24668>>2]!=0}hb=d+192|0;return e|0}b=P()|0;ca(a|0)}T(b|0)}p()}function nfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=hb-560|0;hb=f;a:{if(!Yc(b,1464)){break a}if(!fo(b,f+556|0)){break a}Cd(a,1);Nb(Nb(zf(a+1074312|0,83),84,1),85,1);b:{if(ce(f+556|0,27257)){d=f+32|0;e=Xb(d,8348);Ab(a+1298344|0,e);xb(e);e=Xb(d,14689);Ab(a+1298356|0,e);xb(e);d=Xb(d,14754);Ab(a+1298368|0,d);break b}if(!ce(f+556|0,15373)){break a}d=f+32|0;e=Xb(d,8506);Ab(a+1298344|0,e);xb(e);e=Xb(d,12147);Ab(a+1298356|0,e);xb(e);d=Xb(d,15219);Ab(a+1298368|0,d)}xb(d);x[a+1298404>>2]=13;Yc(b,0);CA(b,a+1298308|0,20);w[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+552|0;Fu(d,b);m=hd(d);if(y[f+552|0]>128){break a}e=f+32|0;d=hb-16|0;hb=d;c:{if(!Qb(x[b>>2],x[b+8>>2],512)){sR(e);break c}lu(d+8|0,e);qd(d,b,x[d+8>>2],x[d+12>>2])}hb=d+16|0;d=0;e=y[m|0];while(1){n=(d|0)==512;if(!n){i=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=y[i|0]){continue}break a}break}if(!c){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;uh(a,0);o=a+484376|0;eg(_b(x[a+484360>>2],y[o|0]),y[f+552|0]);k=a+484344|0;gg(k,y[f+552|0]);e=0;while(1)if(y[f+552|0]<=e>>>0){if(!(c&2)){break a}Yc(b,(y[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(D(d,104)+a|0)+484380|0;if(x[c>>2]){fg(Xc(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}else{r=cc(x[_b(x[a+484360>>2],y[o|0])>>2],e),s=e,w[r>>1]=s;d:{if(!Yg(k,e&65535,64)){break d}l=e<<2;i=0;e:while(1){if((i|0)==4){r=f,s=Bb(x[ac(x[k>>2],e)>>2]),x[r+24>>2]=s;i=0;while(1){if((i|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{v[f+30|0]=p;v[f+31|0]=q;d=h&255;if(d){break g}h=0;break f}}else{g=x[f+24>>2];h:{if((y[g+3|0]&254)!=16){break h}v[g+3|0]=16;h=0;j=y[g+5|0];if(j>>>0<16){break h}h=j>>>4|0;v[g+5|0]=h;l=h;h=j&15;g=(l|0)==(h|0)|!h;p=g?p:l;q=g?q:h;h=!g}d=d+1|0;Tz(f+24|0);continue}break}he(ac(x[k>>2],e),Ce(ye(f+8|0,16,y[(d+f|0)+29|0]),i));h=h+1|0;h=(h&255)==3?1:h}i=i+1|0;continue}}Yc(b,(y[f+32+(i+l)|0]<<8)+1468|0);g=0;d=ac(x[k>>2],e);d=cd(x[d>>2],x[x[d+48>>2]+12>>2],0,i&65535);while(1)if((g|0)==64){i=i+1|0;continue e}else{eu(b,d);i:{j:{j=y[d+3|0];k:{if((j|0)!=14){if(!j){if(y[d+5|0]){break j}break k}if((j-5&255)>>>0<5){break k}break j}if(y[d+5|0]<=15){break j}}v[d+3|0]=0;break i}Hf(d)}d=d+24|0;g=g+1|0;continue}}}e=e+1|0;continue}}else{g=$z(b,f+32|0,(D(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}hb=f+560|0;return n|0}function fm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-80|0;hb=e;h=Sb(a);x[23604]=0;a=S(264,b|0)|0;c=x[23604];x[23604]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=x[b+8>>2];d=x[b>>2];x[23604]=0;c=W(142,d|0,c|0,a|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break e}if(c){break d}x[23604]=0;a=S(188,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break e}x[23604]=0;Q(174,b|0,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break c}}a=P()|0;break a}x[23604]=0;U(176,e+32|0,b|0,a|0);b=x[23604];x[23604]=0;f:{g:{h:{if((b|0)!=1){b=e+32|0;c=kc(e+56|0,b);yb(b);if(a>>>0<10){break g}x[23604]=0;b=S(658,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break b}if(!b){break g}x[23604]=0;b=S(264,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break b}x[e+28>>2]=b;a=a-10|0;wc(e+28|0,a>>>0>25264513?-1:D(a,170));x[23604]=0;d=x[e+28>>2];R(270,h|0,d|0);a=x[23604];x[23604]=0;if((a|0)!=1){break h}break b}a=P()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=x[c+8>>2];f=x[c>>2];x[23604]=0;a=Q(659,f|0,a|0)|0;f=x[23604];x[23604]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}x[23604]=0;a=S(467,c|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}x[23604]=0;a=S(192,c|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=x[c+8>>2];i=x[c>>2];x[23604]=0;g=W(142,i|0,g|0,a|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break b}if(!g){continue}ke(e+32|0,x[h>>2],x[h+4>>2]);eq(e+16|0,x[e+32>>2],x[e+36>>2],b,a);x[23604]=0;Wm(404,e+8|0,c,x[e+16>>2],x[e+20>>2]);f=x[23604];x[23604]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}x[23604]=0;a=S(192,c|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}x[23604]=0;i=Q(660,c|0,e+24|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+24|0;i=jc(f);lt(f,i,Ee(Bb(x[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}x[23604]=0;a=Q(660,c|0,e+24|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}if(!a){continue}a=e+24|0;f=jc(a);lt(a,f,Ee(Bb(x[h>>2]),b));lt(a,f,Ee(Ee(Bb(x[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}x[23604]=0;a=S(192,c|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}a=Sb(e+32|0);kt(a,h);fc(a);break f}x[23604]=0;U(311,c|0,h|0,a|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}}yb(c)}hb=e+80|0;return}a=P()|0;yb(c)}fc(h);T(a|0);p()}function Gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=hb-16|0;hb=g;a:{if(!Qb(x[a>>2],x[a+8>>2],2)){Yg(c+484344|0,b,64);break a}k=c+484344|0;l=Td(pq(a),1,1024);if(!Yg(k,b,l)){break a}o=z[c+480188>>1];p=c+480190|0;b:while(1){if((j|0)==(l|0)){break a}i=0;e=ac(x[k>>2],b);m=of(x[e>>2],x[x[e+48>>2]+12>>2],j);while(1)if((i|0)==(o|0)){j=j+1|0;continue b}else{f=g+8|0;xm(f,a);e=D(i,6)+m|0;q=Re(f);f=wi(f);h=y[g+8|0];c:{if((h-1&255)>>>0>35){break c}v[e|0]=h+48;n=y[hd(g+8|0)|0];h=n+1|0;v[e+1|0]=h;r=h;h=h&255;if((r|0)!=(h|0)|h>>>0>z[p>>1]){break c}h=Rj(c,h);if(!(!y[Gb(d,i)|0]|z[h+30>>1]>255)){v[e+4|0]=64;v[e+2|0]=1}h=h+68|0;d:{if(x[zb(h,0)>>2]==1){if(y[Gb(d,i)|0]){break d}}if(x[zb(h,0)>>2]){break c}if(y[Gb(d,i)|0]){break c}}v[e+1|0]=n+101}e:{f:{switch(y[q|0]){case 1:if(!y[f|0]){break e}v[e+3|0]=2;v[e+5|0]=y[f|0];break e;case 2:if(!y[f|0]){break e}v[e+3|0]=3;v[e+5|0]=y[f|0];break e;case 12:if(!y[f|0]){break e}v[e+3|0]=1;v[e+5|0]=y[f|0];break e;case 13:if(!y[f|0]){break e}v[e+3|0]=39;v[g+7|0]=15;s=e,t=y[Wb(g+7|0,f)|0]|16,v[s+5|0]=t;break e;case 30:if(!y[f|0]){break e}v[e+3|0]=38;v[g+6|0]=15;s=e,t=y[Wb(g+6|0,f)|0]|16,v[s+5|0]=t;break e;case 21:if(!y[f|0]){break e}v[e+3|0]=39;v[g+5|0]=15;s=e,t=y[Wb(g+5|0,f)|0]|80,v[s+5|0]=t;break e;case 17:if(!y[f|0]){break e}v[e+3|0]=38;v[g+4|0]=15;s=e,t=y[Wb(g+4|0,f)|0]|80,v[s+5|0]=t;break e;case 15:v[e+3|0]=19;v[e+5|0]=y[f|0]!=0;break e;case 25:v[e+3|0]=12;v[e+5|0]=y[f|0];break e;case 27:Zn(e);v[e|0]=255;break e;case 28:if(y[f|0]>31){break e}v[e+3|0]=16;v[e+5|0]=y[f|0];break e;case 31:h=y[f|0];if(h&15){s=e,t=y[Gb(d,i)|0]?22:11,v[s+3|0]=t;v[e+5|0]=y[f|0]&15;h=y[f|0]}g:{h:{switch(h>>>4|0){case 4:if((h|0)!=64){break g}case 0:case 1:case 2:case 3:if(y[Gb(d,i)|0]){v[e+3|0]=21;v[e+5|0]=y[f|0];break g}v[e+2|0]=1;f=y[f|0];v[e+3|0]=0;v[e+4|0]=f;break g;case 5:v[e+5|0]=y[e+5|0]<<4;break g;case 6:v[g+3|0]=y[e+5|0];v[g+2|0]=14;s=e,t=y[Wb(g+3|0,g+2|0)|0]|240,v[s+5|0]=t;break g;case 7:v[g+1|0]=y[e+5|0];v[g|0]=14;s=e,t=y[Wb(g+1|0,g)|0]<<4|15,v[s+5|0]=t;break g;default:break h}}v[e+3|0]=0}if((y[e+3|0]-21&255)>>>0>1){break e}f=D(v[Gb(d,i)|0]+i|0,6)+m|0;if(uq(f+3|0,f+5|0,1)){v[f+2|0]=y[f+3|0];v[f+4|0]=y[f+5|0]}v[f+3|0]=y[e+3|0];v[f+5|0]=y[e+5|0];break e;case 0:break e;default:break f}}v[e+3|0]=0}i=i+1|0;continue}}}hb=g+16|0}function Zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb+-64|0;hb=d;w[d+62>>1]=c;pg(d+62|0,32);j=Sb(a);x[23604]=0;o=z[d+62>>1];R(471,j|0,o|0);a=x[23604];x[23604]=0;a:{b:{if((a|0)!=1){k=b+480190|0;q=b+480192|0;c:{d:{while(1){if((r&65535)>>>0>=o>>>0){break d}e=1;c=z[k>>1];a=c+1|0;w[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){f=e&65535;if(f>>>0>c>>>0){break h}i:{g=Rj(b,f);if(!Qd(x[g>>2],x[g+20>>2])){if(!Ob(Uz(Bb(x[j>>2]),Bb(x[j+4>>2]),e),Bb(x[j+4>>2]))){break i}c=z[k>>1]}e=e+1|0;continue}break}w[d+60>>1]=e;a=1;while(1){if(z[q>>1]<a>>>0){a=e}else{j:{c=x[((a<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;g=aq(c);while(1){if((c|0)==(g|0)){break j}if((f|0)==z[c>>1]){w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}}if((a&65535)>>>0<4e3){break g}e=Wn(d+48|0);x[23604]=0;a=Q(698,b|0,e|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break b}if(!a){break e}x[23604]=0;R(699,b|0,e|0);c=x[23604];x[23604]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=z[q>>1]){k:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;f=aq(c);while(1){if((c|0)==(f|0)){break k}g=z[c>>1];l:{if(g>>>0>=A[d+52>>2]){break l}Jb(d+40|0,x[e>>2],g);if(Mb(x[x[d+40>>2]>>2],x[d+44>>2])){break l}w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}$k(d+24|0,x[e>>2]);qP(d+32|0,x[d+24>>2],x[d+28>>2],1);hm(d+16|0,x[e>>2],x[d+52>>2]);m=hb-16|0;hb=m;g=d+40|0;c=ec(m,x[d+32>>2],x[d+36>>2]);a=_k(x[d+16>>2],x[d+20>>2],x[d+32>>2],x[d+36>>2]);f=hb-16|0;hb=f;x[f+12>>2]=a;h=x[c+4>>2];m:{if(h){i=32-h|0;x[f+8>>2]=i;n=x[Fb(f+8|0,f+12|0)>>2];l=-1<<h&-1>>>i-n;i=x[c>>2];l=l&(x[i>>2]^-1);if(l){ec(g,i,Iia(l));break m}if((a|0)==(n|0)){qP(g,i,h,a);break m}a=a-n|0;x[f+12>>2]=a;x[c>>2]=i+4}while(1){if(a>>>0>=32){h=x[c>>2];i=x[h>>2];if((i|0)!=-1){ec(g,h,Iia(i^-1));break m}else{x[c>>2]=h+4;a=a-32|0;x[f+12>>2]=a;continue}}break}if(!a){ec(g,x[c>>2],0);break m}c=x[c>>2];h=(x[c>>2]^-1)&-1>>>32-a;if(!h){ec(g,c,a);break m}ec(g,c,Iia(h))}hb=f+16|0;hb=m+16|0;$k(d+8|0,x[e>>2]);a=_k(x[d+40>>2],x[d+44>>2],x[d+8>>2],x[d+12>>2]);w[d+60>>1]=a;He(e);if((a&65535)>>>0>3999){break f}}x[23604]=0;R(243,j|0,d+60|0);c=x[23604];x[23604]=0;if((c|0)==1){break c}if(z[k>>1]>=(a&65535)>>>0){break f}w[k>>1]=a}r=r+1|0;continue}break}He(e)}hb=d- -64|0;return}c=P()|0;break a}c=P()|0;break a}c=P()|0;He(e)}nd(j);T(c|0);p()}function R1(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=hb-192|0;hb=d;x[d+184>>2]=c;a:{b:{c:{if(b>=.8){x[23604]=0;e=ga(1024)|0;f=x[23604];x[23604]=0;d:{e:{f:{if((f|0)!=1){x[d+80>>2]=e;x[23604]=0;c=S(1025,c|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break e}x[d+176>>2]=c;un(e,c);a=ge(d+152|0,a);x[23604]=0;f=x[a+12>>2];c=d- -64|0;x[c>>2]=x[a+8>>2];x[c+4>>2]=f;x[d+72>>2]=x[a+16>>2];c=x[a+4>>2];x[d+56>>2]=x[a>>2];x[d+60>>2]=c;a=W(1017,e|0,d+56|0,15)|0;c=x[23604];x[23604]=0;if((c|0)==1){break f}if(a){x[23604]=0;Y(766,e|0);a=x[23604];x[23604]=0;g=1;if((a|0)==1){break f}}Si(d+176|0);Ti(d+80|0);break b}c=V(0)|0;break c}c=V(0)|0;Si(d+176|0);break d}c=V(0)|0}Ti(d+80|0);break c}if(b>=.6){x[23604]=0;e=ga(1024)|0;f=x[23604];x[23604]=0;g:{h:{i:{if((f|0)!=1){x[d+80>>2]=e;x[23604]=0;c=S(1025,c|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break h}x[d+176>>2]=c;un(e,c);a=ge(d+128|0,a);x[23604]=0;c=x[a+12>>2];x[d+40>>2]=x[a+8>>2];x[d+44>>2]=c;x[d+48>>2]=x[a+16>>2];c=x[a+4>>2];x[d+32>>2]=x[a>>2];x[d+36>>2]=c;a=W(1017,e|0,d+32|0,2)|0;c=x[23604];x[23604]=0;if((c|0)==1){break i}if(a){x[23604]=0;Y(766,e|0);a=x[23604];x[23604]=0;g=.8;if((a|0)==1){break i}}Si(d+176|0);Ti(d+80|0);break b}c=V(0)|0;break c}c=V(0)|0;Si(d+176|0);break g}c=V(0)|0}Ti(d+80|0);break c}g=.2;if(b>=.2){x[23604]=0;e=ga(1024)|0;f=x[23604];x[23604]=0;j:{k:{l:{if((f|0)!=1){x[d+80>>2]=e;x[23604]=0;c=S(1025,c|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break k}x[d+176>>2]=c;un(e,c);a=ge(d+104|0,a);x[23604]=0;c=x[a+12>>2];x[d+16>>2]=x[a+8>>2];x[d+20>>2]=c;x[d+24>>2]=x[a+16>>2];c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;a=W(1017,e|0,d+8|0,0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break l}g=0;if(a){x[23604]=0;Y(766,e|0);a=x[23604];x[23604]=0;g=.6;if((a|0)==1){break l}}Si(d+176|0);Ti(d+80|0);break b}c=V(0)|0;break c}c=V(0)|0;Si(d+176|0);break j}c=V(0)|0}Ti(d+80|0);break c}if(!(b>=.1)){break b}x[23604]=0;U(189,d+80|0,a|0,2048);c=x[23604];x[23604]=0;if((c|0)!=1){c=xe(d+80|0);a=x[a>>2];x[23604]=0;e=x[d+80>>2];a=S(146,a|0)|0;f=x[23604];x[23604]=0;m:{if((f|0)==1){break m}x[23604]=0;a=UE(1026,c,e,a,0);c=x[23604];x[23604]=0;if((c|0)==1){break m}g=C[(a<<3)+61848>>3];Lc(d+80|0);break b}c=V(0)|0;Lc(d+80|0);break c}c=V(0)|0}_(c|0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;g=0;if((a|0)==1){break a}}te(d+184|0);hb=d+192|0;return+g}a=P()|0;te(d+184|0);T(a|0);p()}function bZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-320|0;hb=d;e=hb-16|0;hb=e;x[a>>2]=0;f=a+32|0;dn(f,32);v[e+15|0]=0;cn(f,e+15|0);hb=e+16|0;e=x[a+28>>2];a:{if(x[(x[x[e>>2]-12>>2]+e|0)+16>>2]){eh(a,1073741825);break a}_d(d+56|0,e);e=x[d+68>>2];x[a+8>>2]=x[d+64>>2];x[a+12>>2]=e;x[d+56>>2]=3;g=x[a+28>>2];f=d+16|0;e=0;while(1){if(A[d+56>>2]>e>>>0){$h(g,e+f|0);e=e+1|0;continue}break}if(Rb(f,26336,3)){eh(a,1073741827);break a}v[d+319|0]=0;$h(x[a+28>>2],d+319|0);Zb(d+56|0,0,256);e=y[d+319|0];if(e){yk(x[a+28>>2],d+56|0,e)}f=b;b=Xm(d+16|0,d+56|0,e);e=Wv(f,b);Db(b);if(!e){eh(a,1073741830)}if(y[a+3|0]&64){break a}$h(x[a+28>>2],d+55|0);b=y[d+55|0];e=b&3;w[a+16>>1]=(e|0)==3?4:e;if(Gi(b,6)){mk(a,9,1)}x[d+48>>2]=0;hF(x[a+28>>2],d+48|0);e=x[d+48>>2];v[d+47|0]=0;if(e>>>0>=2){$h(x[a+28>>2],d+55|0);f=-1;if(!y[d+55|0]){$h(x[a+28>>2],d+47|0);f=-2}Gl(x[a+28>>2],e+f|0)}x[d+32>>2]=0;x[d+36>>2]=0;b:{if(!Gi(b,4)){break b}lk(x[a+28>>2],d+32|0);e=x[d+36>>2];f=x[d+32>>2];x[a+56>>2]=f;x[a+60>>2]=e;g=x[c+4>>2];if((g|0)==(e|0)&A[c>>2]>=f>>>0|e>>>0<g>>>0){break b}eh(a,536871424)}if(Gi(b,5)){$h(x[a+28>>2],d+55|0);Gl(x[a+28>>2],y[d+55|0])}e=y[d+47|0];c:{if(!Gi(e,0)){break c}$h(x[a+28>>2],d+55|0);c=y[d+55|0];c=c&1?-1:c>>>1|0;w[a+16>>1]=c;if(c){break c}eh(a,536871168)}x[a+4>>2]=0;c=1;if(Gi(e,1)){hF(x[a+28>>2],a+4|0)}mk(a,6,Gi(b,2));mk(a,7,Gi(b,3));mk(a,5,z[a+16>>1]!=0);mk(a,8,Gi(b,7));d:{if(fd(a,5)){break d}if(fd(a,6)){break d}if(fd(a,7)){break d}c=fd(a,8)}mk(a,11,c);fd(a,11);if(Gi(e,2)){w[d+16>>1]=0;Uv(x[a+28>>2],d+16|0);Gl(x[a+28>>2],D(z[d+16>>1],fd(a,9)?2:1))}if(Gi(e,3)){Gl(x[a+28>>2],5)}lk(x[a+28>>2],d+32|0);c=x[d+36>>2];b=x[d+32>>2];if(!c&b>>>0>=16001|c){eh(a,1073741831);break a}x[a+92>>2]=b;if(!b){eh(a,536871040)}e:{if(!fd(a,11)){break e}lk(x[a+28>>2],d+32|0);b=x[d+32>>2];c=x[d+36>>2];if((c|0)>0|(c|0)>=0){break e}eh(a,1073741829);break a}_d(d,x[a+28>>2]);c=x[a+8>>2];f=x[a+12>>2];e=x[d+4>>2];x[d+16>>2]=x[d>>2];x[d+20>>2]=e;e=x[d+12>>2];x[d+24>>2]=x[d+8>>2];x[d+28>>2]=e;e=x[d+24>>2];f=x[d+28>>2]-(f+(c>>>0>e>>>0)|0)|0;c=e-c|0;x[d+24>>2]=c;x[d+28>>2]=f;c=x[d+24>>2];e=x[d+28>>2];if((e|0)==1|e>>>0>1){eh(a,1073741832);break a}x[a+88>>2]=c;c=fd(a,11);x[a+64>>2]=c?b:x[a+88>>2];if(!fd(a,11)){b=x[a+12>>2];e=x[a+88>>2];c=e+x[a+8>>2]|0;x[a+72>>2]=c;x[a+76>>2]=c>>>0<e>>>0?b+1|0:b}mk(a,10,1)}hb=d+320|0}function T8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-48|0;hb=c;a:{b:{if(!Ob(x[b>>2],x[b+4>>2])){break b}l=x[b+12>>2];k=Bg(x[x[b+48>>2]+12>>2]);d=k;f=c+32|0;x[f>>2]=0;x[f+4>>2]=0;zc(f+8|0);if(d){Ot(f,d);g=hb-16|0;hb=g;e=hq(g,f,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){ic(e);hb=g+16|0}else{sh(d);d=d+6|0;x[e+4>>2]=d;continue}break}}while(1){c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!(x[(x[x[a>>2]-12>>2]+a|0)+16>>2]|j>>>0>=l>>>0)){x[23604]=0;v[c+31|0]=0;Q(828,a|0,c+31|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}d=v[c+31|0];if(!d){j=j+1|0;continue}v[c+30|0]=0;r:{if((d|0)>=0){break r}x[23604]=0;Q(828,a|0,c+30|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break r}break a}v[c+29|0]=0;sh(c+16|0);s:{d=d&127;g=(d?d-1|0:0)&65535;i=g>>>0>=k>>>0;t:{u:{if(!i){h=cd(x[b>>2],x[x[b+48>>2]+12>>2],j,g);d=y[c+30|0];if(d&1){break u}e=Bd(x[f>>2],g);break t}h=c+16|0;d=y[c+30|0];if(!(d&1)){break s}}x[23604]=0;Q(828,a|0,c+29|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break a}if(i){break s}e=Bd(x[f>>2],g);v[e|0]=y[c+29|0]}v[h|0]=y[e|0];d=y[c+30|0];if(!(d&2)){break p}break q}if(d&2){break q}break o}Zj(f);break b}x[23604]=0;Q(828,a|0,c+29|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break a}if(i){break o}e=Bd(x[f>>2],g);v[e+1|0]=y[c+29|0]}v[h+1|0]=y[e+1|0];if(d&4){break n}break m}if(!(d&4)){break l}}x[23604]=0;Q(828,a|0,c+29|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break a}if(i){break l}e=Bd(x[f>>2],g);v[e+2|0]=y[c+29|0]}v[h+2|0]=y[e+2|0];if(!(d&8)){break j}break k}if(!(d&8)){break i}}x[23604]=0;Q(828,a|0,c+29|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break a}if(i){break i}e=Bd(x[f>>2],g);v[e+4|0]=y[c+29|0]}v[h+4|0]=y[e+4|0];if(d&16){break h}break g}if(!(d&16)){break f}}x[23604]=0;Q(828,a|0,c+29|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break a}if(i){break f}e=Bd(x[f>>2],g);v[e+3|0]=y[c+29|0]}v[h+3|0]=y[e+3|0];if(!(d&32)){break d}break e}if(!(d&32)){break c}}x[23604]=0;Q(828,a|0,c+29|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break a}if(i){break c}e=Bd(x[f>>2],g);v[e+5|0]=y[c+29|0]}v[h+5|0]=y[e+5|0]}if(!(d&64)){continue}x[23604]=0;Q(828,a|0,c+15|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){x[23604]=0;Q(829,a|0,y[c+15|0])|0;d=x[23604];x[23604]=0;if((d|0)!=1){continue}}break}break a}hb=c+48|0;return}a=P()|0;Zj(f);T(a|0);p()}function $9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0;k=hb-32|0;hb=k;i=x[a+4>>2];f=Ne(x[a+8>>2],b);r=x[f>>2];a:{if(r+1>>>0<2){break a}e=(i+D(b,872)|0)+616|0;if(!(ki(x[e+8>>2],x[e+12>>2])|y[f+4|0])|!x[e+104>>2]){break a}n=x[e+88>>2]&2;f=x[(n?84:76)+e>>2];o=x[e+84>>2];g=x[e+80>>2];s=Tb(x[a>>2]+1074312|0,31);h=Ze(x[e+8>>2],x[e+12>>2],c);l=y[e+88|0]&128;i=l?0-h|0:h;m=lb;l=l?0-(m+((h|0)!=0)|0)|0:m;h=n;n=h?0:0;p=h?g:0;m=o-g|0;t=m<<1;o=f;u=(y[e+746|0]&17)!=1;b:{while(1){if((q|0)==(r|0)){break b}c:{if(d>>>0>q>>>0){f=(y[e+746|0]&17)==1;break c}v[e+851|0]=y[e+851|0]&254;f=x[a>>2];g=x[a+4>>2];h=ac(x[f+484344>>2],z[g+70>>1]);g=cd(x[h>>2],x[x[h+48>>2]+12>>2],x[g+48>>2],b);h=y[g+3|0];if(y[g+2|0]==11){j=k+8|0;Dy(j,f,h,y[g+4|0],0);j=Re(j);In(x[a>>2],e,z[k+8>>1]);f=1;if(y[j|0]){break c}}f=1;d:{switch(h-4|0){case 0:In(x[a>>2],e,y[g+5|0]);break c;case 2:break d;default:break c}}In(x[a>>2],e,0)}x[k+28>>2]=x[e+700>>2];if(s){Ms(x[a>>2],e)}if(!u){aN(x[a>>2],e,k+28|0);f=1}if(!s){Ms(x[a>>2],e)}x[k+24>>2]=0;$M(e,k+24|0);e:{f:{if(y[e+89|0]&2){break f}g:{if(!f){if(!y[Ne(x[a+8>>2],b)+4|0]){break g}}if(y[e+851|0]&96){dP(e,E(1),0,x[a>>2]);i=y[e+851|0];v[e+851|0]=(i&64?-65:-33)&i}Fy(k+8|0,x[a>>2],e,x[k+28>>2],0);i=x[k+12>>2];x[e+8>>2]=x[k+8>>2];x[e+12>>2]=i;A=Ne(x[a+8>>2],b),B=0,v[A+4|0]=B;f=Ze(x[e+8>>2],x[e+12>>2],c);g=y[e+88|0]&128;i=g?0-f|0:f;h=lb;l=g?0-(h+((f|0)!=0)|0)|0:h}Ub(e,i,l);g=x[e>>2];f=x[e+4>>2];if((g>>>0<w>>>0&(f|0)<=(o|0)|(f|0)<(o|0))&((f|0)>=(p|0)&g>>>0>=n>>>0|(f|0)>(p|0)|((l|0)>0|(l|0)>=0))){break f}j=x[e+88>>2];if(!(j&2)){break e}if(j&4){h=x[e+80>>2];if(g>>>0<n>>>0&(f|0)<=(p|0)|(f|0)<(p|0)){x[e+88>>2]=j^128;A=e,B=Dg(0,h<<1,g,f),x[A>>2]=B;f=lb;x[e+4>>2]=f;g=i;i=0-g|0;l=0-(((g|0)!=0)+l|0)|0}f=(f-h>>>0)%(t-Tb(x[a>>2]+1074312|0,33)>>>0)|0;h:{if(f>>>0<m>>>0){h=f+x[e+80>>2]|0;break h}h=x[e+84>>2]+(m-f|0)|0}x[e+4>>2]=h;g=x[e+88>>2];if((g&128)>>>7^f>>>0<m>>>0){break f}x[e+88>>2]=g^128;f=i;i=0-f|0;l=0-(((f|0)!=0)+l|0)|0;break f}j=x[e+84>>2];if(j+m>>>0<=f>>>0){f=j+((f-j>>>0)%(m>>>0)|0)|0}while(1){h=f;f=f-m|0;if(h>>>0>=j>>>0){continue}break}x[e>>2]=g;x[e+4>>2]=h}q=q+1|0;continue}break}hP(e);x[e+708>>2]=0}A=Ne(x[a+8>>2],b),B=0,x[A>>2]=B}hb=k+32|0}function p2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-192|0;hb=d;h=aJ(d+176|0);x[h>>2]=49812;Sb(h+4|0);un(x[a+24>>2],h);e=x[a+24>>2];i=y[a+62|0];f=y[a+61|0];g=y[a+60|0];b=ge(d+152|0,b);x[23604]=0;j=x[b+12>>2];x[d+16>>2]=x[b+8>>2];x[d+20>>2]=j;x[d+24>>2]=x[b+16>>2];j=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=j;b=g?13:15;b=f?b&14:b;b=W(1017,e|0,d+8|0,(i?b&3:b)|0)|0;e=x[23604];x[23604]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ba(8)|0;x[23604]=0;c=Q(54,d+136|0,11885)|0;a=x[23604];x[23604]=0;if((a|0)!=1){a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}a=P()|0;ca(b|0);break b}if(!y[a+63|0]){x[23604]=0;R(1018,a|0,a+36|0);b=x[23604];x[23604]=0;if((b|0)==1){break e}}v[a+28|0]=1;un(x[a+24>>2],x[a+4>>2]);x[23604]=0;R(1019,d+136|0,h|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}k=d,l=Bb(x[d+136>>2]),x[k+128>>2]=l;e=a+68|0;i=Bb(x[d+140>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=x[d+128>>2];if(!Ob(b,i)){k=d,l=gj(x[c>>2]),x[k+112>>2]=l;c=xf(c);while(1){b=x[d+112>>2];if(!xg(b,c)){break d}x[23604]=0;e=sd(b);b=Q(53,d+32|0,e|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break h}x[23604]=0;X(916,a|0,b|0,e+12|0,0);e=x[23604];x[23604]=0;if((e|0)==1){break g}xb(b);Tg(d+112|0);continue}}f=x[a+24>>2];g=x[b>>2];x[23604]=0;j=f;f=b+4|0;U(1020,j|0,g|0,f|0);g=x[23604];x[23604]=0;if((g|0)!=1){b=x[b>>2];x[23604]=0;R(1021,d- -64|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break r}x[23604]=0;R(962,d+80|0,d- -64|0);b=x[23604];x[23604]=0;if((b|0)==1){break q}x[23604]=0;b=Q(54,d+48|0,17617)|0;g=x[23604];x[23604]=0;if((g|0)==1){break p}x[23604]=0;U(919,d+96|0,d+80|0,b|0);g=x[23604];x[23604]=0;if((g|0)==1){break o}x[23604]=0;U(477,d+112|0,d+96|0,f|0);f=x[23604];x[23604]=0;if((f|0)==1){break n}x[23604]=0;R(169,e|0,d+112|0);f=x[23604];x[23604]=0;if((f|0)==1){break m}xb(d+112|0);xb(d+96|0);xb(b);xb(d+80|0);xb(d- -64|0);Yn(d+128|0);continue}break}a=P()|0;break f}a=P()|0;break f}a=P()|0;break i}a=P()|0;break j}a=P()|0;break k}a=P()|0;break l}a=P()|0;xb(d+112|0)}xb(d+96|0)}xb(b)}xb(d+80|0)}xb(d- -64|0);break f}a=P()|0;break f}a=P()|0;xb(b)}$w(d+136|0);break b}a=P()|0;break b}$w(d+136|0);as(h);hb=d+192|0;return}a=P()|0}as(h);T(a|0)}p()}function GV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=hb-384|0;hb=f;xc(b);d=hb-16|0;hb=d;h=f+344|0;mC(d+8|0,h);e=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(e|0)){bc(b,x[d+12>>2])}hb=d+16|0;d=(e|0)==(i|0);if(!d){kC(h)}a:{if(!d){break a}if(!oC(f+344|0)){break a}if(!Qb(x[b>>2],x[b+8>>2],Uc(nC(y[f+379|0]),lb))){break a}b:{if(!c){break b}Cd(a,2097152);Ag(a);uh(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[f+376|0];x[a+480204>>2]=D(y[f+377|0],1e4);j=a+480190|0;w[j>>1]=y[f+378|0];d=y[f+381|0];if(d>>>0<y[f+380|0]){Xe(_b(x[a+484360>>2],y[a+484376|0]),d)}d=f+80|0;g=Xb(d,6480);Ab(a+1298344|0,g);xb(g);g=Xb(d,11008);Ab(a+1298356|0,g);xb(g);x[a+1298404>>2]=5;Gu(b,d);Bq(_b(x[a+484360>>2],y[a+484376|0]),d,y[f+380|0],65535,65535);g=1;while(1){i=g&65535;if(i>>>0>z[j>>1]){bc(b,D(64-y[f+378|0]|0,37));h=a+484344|0;gg(h,y[f+379|0]);i=c&1;g=0;while(1)if(y[f+379|0]<=g>>>0){if(!(c&2)){break b}c=Xc(f+40|0,8,1,0,0);d=a+480190|0;g=1;while(1){e=g&65535;if(e>>>0>z[d>>1]){break b}fg(c,(D(e,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{c:{d:{if(i){if(Yg(h,g&65535,64)){break d}}bc(b,2048);break c}d=ac(x[h>>2],g);n=f,o=Bb(x[d>>2]),x[n+40>>2]=o;j=Bb(x[d+4>>2]);while(1){d=x[f+40>>2];if(!Ob(d,j)){break c}e=f+24|0;xm(e,b);k=hd(e);m=Re(e);e=wi(e);l=y[f+24|0];if((l-1&255)>>>0<=106){v[d|0]=l+13}v[d+1|0]=y[k|0];v[d+3|0]=y[m|0];v[d+5|0]=y[e|0];Hf(d);dk(f+40|0);continue}}g=g+1|0;continue}}else{d=f+40|0;jC(b,d);h=hb-16|0;hb=h;e=(D(i,104)+a|0)+484380|0;od(e,0);v[e+37|0]=y[d+22|0]<<4;v[h+15|0]=y[d+23|0];v[h+14|0]=64;n=e,o=y[Wb(h+15|0,h+14|0)|0]<<2,w[n+30>>1]=o;v[e+36|0]=y[d+24|0];x[e>>2]=y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24);k=y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24);if(!(k>>>0<3|k+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))>>>0>(y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24))>>>0)){w[e+34>>1]=z[e+34>>1]|2;x[e+4>>2]=y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24);x[e+8>>2]=(y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24))+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))}hb=h+16|0;e=f+8|0;ml(e,2,d);d=f+24|0;Dc(d,e);Bc(((i<<5)+a|0)+946304|0,d);g=g+1|0;xb(d);continue}}}g=1}hb=f+384|0;return g|0}function mV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,B=0,C=0,E=0;f=hb-32|0;hb=f;k=Oh(f+24|0);o=k+3|0;p=k+5|0;q=k+4|0;r=k+2|0;s=k+1|0;d=f+16|0;t=d|5;u=d|3;while(1){a:{if(A[a+12>>2]>l>>>0){z=of(x[a>>2],x[x[a+48>>2]+12>>2],l);b:while(1){if(!Qb(x[c>>2],x[c+8>>2],1)){break a}d=Be(c);if((d|0)==255){break a}m=d<<24>>24;d=m&31;h=D(d,6)+z|0;i=Bg(x[x[a+48>>2]+12>>2])>>>0>d>>>0;j=i?h:k;e=1;if(!(m&64)){d=Be(c);g=d<<24>>24;e=255;d=d&127;c:{d:{if((d|0)==1){break d}e=d-1|0;if(b?e>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}e=d+13|0}v[j|0]=e}C=i?h+1|0:s,E=Be(c),v[C|0]=E;e=(g|0)<0}g=i?h+3|0:o;d=i?h+5|0:p;n=i?h+4|0:q;i=i?h+2|0:r;while(1){e:{f:{g:{if(e&1){x[f+16>>2]=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);w[f+20>>1]=y[j+4|0]|y[j+5|0]<<8;e=Be(c);h=e&63;B=e<<24>>24;if(e&64){v[i|0]=1;v[n|0]=h;break e}e=Be(c);v[d|0]=e;if(h>>>0<=15){v[g|0]=h;Hf(j);h:{i:{j:{e=y[g|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[g|0]=9;v[d|0]=D(y[d|0]&15,17);break f}v[g|0]=0;v[i|0]=1;x[f+12>>2]=y[d|0]+1>>>1;x[f+8>>2]=64;C=n,E=x[rd(f+12|0,f+8|0)>>2],v[C|0]=E;break f}if((e|0)!=19){break f}if(y[d|0]==128){break g}vu(j);break f}if(h>>>0>44){break f}v[g|0]=y[h+26592|0];k:{switch(h-16|0){case 0:if(e>>>0>1){break g}v[d|0]=e|158;break f;case 1:case 2:v[f+12|0]=15;C=d,E=y[Wb(f+12|0,d)|0]|224,v[C|0]=E;break f;case 5:case 6:x[f+12>>2]=16;x[f+8>>2]=e+1;C=d,E=x[rd(f+12|0,f+8|0)>>2]/2|240,v[C|0]=E;break f;case 14:l:{m:{n:{o:{p:{h=e>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[g|0]=2;v[d|0]=e|240;break f}v[g|0]=3;v[d|0]=e|240;break f}v[g|0]=11;v[d|0]=(e<<3&120)+8|15;break f}v[g|0]=11;v[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+12>>2]=e+1>>>1;x[f+8>>2]=64;C=d,E=x[rd(f+12|0,f+8|0)>>2],v[C|0]=E;break f}if((m|0)>=0){continue b}break a}v[g|0]=0}uu(g,d,u,t);e=y[f+19|0];if(vi(e)>>>0<=vi(y[g|0])>>>0){break e}q:{if(y[i|0]){break q}if(!uq(g,d,1)){break q}v[i|0]=y[g|0];v[n|0]=y[d|0]}v[g|0]=e;v[d|0]=y[f+21|0]}e=(B|0)<0;continue}}}hb=f+32|0;return}l=l+1|0;continue}}function g9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=hb-16|0;hb=h;f=x[a+8>>2];e=x[a>>2];x[23604]=0;f=Q(551,e|0,f|0)|0;e=x[23604];x[23604]=0;a:{b:{if((e|0)!=1){if(f){break b}x[23604]=0;f=S(192,a|0)|0;e=x[23604];x[23604]=0;c:{if((e|0)==1){break c}x[23604]=0;j=d+484344|0;k=Td(f+1|0,1,1024);f=W(212,j|0,b|0,k|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}if(!f){break b}d=z[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=x[a+8>>2];e=x[a>>2];x[23604]=0;f=W(142,e|0,f|0,1)|0;e=x[23604];x[23604]=0;d:{if((e|0)!=1){if(!f){break b}x[23604]=0;i=S(192,a|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=x[j>>2];w[h+14>>1]=i&31;w[h+12>>1]=l;e=ac(e,b);e=cd(x[e>>2],x[x[e+48>>2]+12>>2],d,z[Wc(h+14|0,h+12|0)>>1]);if(i>>>0<32){continue}e:{if(i<<24>>24>=0){break e}x[23604]=0;g=S(192,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break a}v[e+5|0]=g;x[23604]=0;g=S(192,a|0)|0;f=x[23604];x[23604]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=y[g+43216|0];v[e+3|0]=f;h:{switch(f-1|0){case 0:if(!y[e+5|0]){break f}break e;case 12:if(y[e+2|0]){break e}v[e+2|0]=1;f=y[e+5|0];v[e+5|0]=0;v[e+3|0]=0;m=e,n=Td(f,0,64),v[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=y[e+5|0]&240;if(!f){break e}v[e+5|0]=f;break e;case 8:f=y[e+5|0];if(f>>>0<=128){m=e,n=ri(f<<1),v[m+5|0]=n;break e}if((f|0)!=164){break e}v[e+5|0]=145;v[e+3|0]=20;break e;case 13:f=y[e+5|0];v[e+5|0]=D(f>>>4|0,10)+(f&15);break e;case 18:vu(e);break e;case 16:if(y[e+5|0]>31){break e}v[e+3|0]=16;break e;case 27:break h;default:break e}}g=y[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}v[e+3|0]=f}v[e+5|0]=g&15|224;break e}v[e+3|0]=0}j:{k:{if(!(i&64)){break k}x[23604]=0;R(245,h+8|0,a|0);f=x[23604];x[23604]=0;if((f|0)==1){break j}v[e+1|0]=y[h+8|0];g=y[hd(h+8|0)|0];v[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}v[e|0]=f}if(!(i&32)){continue}v[e+2|0]=1;x[23604]=0;g=S(192,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break a}v[e+4|0]=g;if(!c){continue}v[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}yb(a);hb=h+16|0;return}b=P()|0;yb(a);T(b|0);p()}function _aa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;y=x[a+16>>2];z=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;r=x[a+128>>2];if(r){k=x[a+8>>2];g=x[a+12>>2];s=Xf(k,g,r);t=lb;h=x[a+76>>2];Cf(x[a>>2],x[a+4>>2],Ze(k,g,d),lb);q=lb>>>0>h>>>0?d:0}else{q=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+16|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;q=q-1|0;h=q;s=h?s:0;t=h?t:0;k=(((g&2147483647)<<1|b>>>31)&-2)+y|0;g=r;a:{b:while(1){c:{if((g|0)<=0){Ub(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){Kd(j,i>>>3<<16>>16);Jd(j,4);Ub(f+40|0,s,t);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}Kd(j,i>>>3<<16>>16);Jd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Tf(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+16|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;w=e<<8;e=w;e=Jia(h,G,e,e>>31);m=lb;n=e;e=Yb(l,-16777216,16776704);e=Jia(k,F,e,e>>31);l=n+e|0;n=lb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Yb(H,-16777216,16776704);m=Jia(i,E,e,e>>31);l=m+l|0;e=lb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Nc(m,e,24);x[g+4>>2]=e-(w&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];p=x[a+28>>2]+p|0;x[c>>2]=x[c>>2]+D(x[f>>2],p>>12);o=b+o|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],o>>12);Ub(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function T2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Kb(a);x[23604]=0;Z(91);c=x[23604];x[23604]=0;a:{b:{if((c|0)==1){c=Ta(62120,92520,93104,0)|0;d=ib;c:{d:{e:{if((da(62120)|0)==(d|0)){c=_(c|0)|0;x[23604]=0;b=Q(889,a|0,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break e}x[23604]=0;b=Q(889,b|0,17617)|0;d=x[23604];x[23604]=0;if((d|0)==1){break e}x[23604]=0;d=Q(889,b|0,17593)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}b=mb[x[x[c>>2]+8>>2]](c)|0;x[23604]=0;Q(889,d|0,(b?b:21502)|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;break a}f:{if((da(92520)|0)==(d|0)){c=_(c|0)|0;x[23604]=0;b=Q(889,a|0,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break f}x[23604]=0;b=Q(889,b|0,17617)|0;d=x[23604];x[23604]=0;if((d|0)==1){break f}x[23604]=0;d=Q(889,b|0,17568)|0;b=x[23604];x[23604]=0;if((b|0)==1){break f}b=mb[x[x[c>>2]+8>>2]](c)|0;x[23604]=0;Q(889,d|0,(b?b:21502)|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break f}x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;break a}e=da(93104)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){x[23604]=0;b=Q(889,a|0,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break g}x[23604]=0;b=Q(889,b|0,17617)|0;d=x[23604];x[23604]=0;if((d|0)==1){break g}x[23604]=0;d=Q(889,b|0,17584)|0;b=x[23604];x[23604]=0;if((b|0)==1){break g}b=mb[x[x[c>>2]+8>>2]](c)|0;x[23604]=0;Q(889,d|0,(b?b:21502)|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break g}x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;break a}x[23604]=0;b=Q(889,a|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}x[23604]=0;b=Q(889,b|0,17617)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}x[23604]=0;Q(889,b|0,13574)|0;b=x[23604];x[23604]=0;if((b|0)==1){break d}x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;break a}b=P()|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;if((c|0)!=1){break a}break c}b=P()|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;if((c|0)!=1){break a}break c}b=P()|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;if((c|0)==1){break c}break a}b=P()|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;if((c|0)!=1){break a}}V(0)|0;Vb()}p()}return}xb(a);T(b|0);p()}function Y5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=E(0),l=0,m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,C=0,D=0,F=E(0),G=E(0),H=E(0),I=0,J=0,K=0,L=E(0),M=E(0),N=E(0),O=E(0),P=E(0),Q=E(0),R=0,S=0,T=E(0);if(Qh(a+44|0)){f=x[a+44>>2];y=Cc(f,0);z=Cc(f,1);f=x[a+56>>2];A=Cc(f,0);C=Cc(f,1);n=x[a+4300>>2];s=x[a+4296>>2];l=s+1|0;m=a+4304|0;f=a+4272|0;t=l+x[zb(f,0)>>2]&4095;o=m+(t<<4)|0;u=l+x[zb(f,1)>>2]&4095;h=((u<<4)+m|0)+4|0;v=l+x[zb(f,2)>>2]&4095;p=((v<<4)+m|0)+8|0;i=x[zb(f,3)>>2];j=x[zb(f,4)>>2]+n|0;w=i+l&4095;D=((w<<4)+m|0)+12|0;q=x[zb(f,5)>>2]+n|0;i=a+4232|0;I=a+4296|0;l=d;while(1){if(l){u=u-1&4095;f=((u<<4)+m|0)+4|0;e=B[f>>2];J=j&1023;j=(J<<3)+I|0;r=B[j+65544>>2];L=B[D>>2];M=B[p>>2];N=B[h>>2];O=B[o>>2];P=B[z>>2];Q=B[y>>2];F=B[zb(i,0)>>2];G=B[j+65548>>2];h=zb(i,0);t=t-1&4095;o=(t<<4)+m|0;g=B[o>>2];H=B[h>>2];h=(n<<3)+a|0;k=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[h+69844>>2]=k+E(e*E(-.6180340051651001));k=g;g=E(E(G*H)+E(g*E(-.6180340051651001)));B[h+69840>>2]=k+E(g*E(.6180340051651001));B[o>>2]=e;B[f>>2]=g;w=w-1&4095;j=(w<<4)+m|0;D=j+12|0;e=B[D>>2];K=q&1023;p=(K<<3)+I|0;r=B[p+73736>>2];F=B[zb(i,1)>>2];G=B[p+73740>>2];R=zb(i,1);v=v-1&4095;q=(v<<4)+m|0;p=q+8|0;g=B[p>>2];H=B[R>>2];k=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[h+78036>>2]=k+E(e*E(-.6180340051651001));k=g;g=E(E(G*H)+E(g*E(-.6180340051651001)));B[h+78032>>2]=k+E(g*E(.6180340051651001));B[q+8>>2]=e;B[j+12>>2]=g;g=e;e=E(Q+E(1.0000000031710769e-30));B[A>>2]=g+E(E(e*B[a+4224>>2])+B[o>>2]);g=E(P+E(1.0000000031710769e-30));B[C>>2]=E(E(g*B[a+4224>>2])+B[f>>2])+B[j+12>>2];h=(s<<4)+a|0;k=e;e=B[a+4228>>2];r=E(k*e);S=h+4304|0,T=E(r+E(E(B[o>>2]*B[zb(i,2)>>2])+E(O*B[zb(i,3)>>2]))),B[S>>2]=T;e=E(g*e);S=h+4308|0,T=E(e+E(E(B[f>>2]*B[zb(i,4)>>2])+E(N*B[zb(i,5)>>2]))),B[S>>2]=T;S=h+4312|0,T=E(E(E(B[q+8>>2]*B[zb(i,6)>>2])+E(M*B[zb(i,7)>>2]))-e),B[S>>2]=T;S=h+4316|0,T=E(r+E(E(B[j+12>>2]*B[zb(i,8)>>2])+E(L*B[zb(i,9)>>2]))),B[S>>2]=T;l=l-1|0;C=C+4|0;A=A+4|0;z=z+4|0;y=y+4|0;q=K-1|0;j=J-1|0;n=n-1&1023;s=s-1&4095;h=f;continue}else{x[a+4300>>2]=n;x[a+4296>>2]=s;f=a;a=x[a+56>>2];di(f,b,c,Cc(a,0),Cc(a,1),d)}break}}}function Ts(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=hb-16|0;hb=k;g=x[a+24>>2];i=Uy(g,y[a+32|0]);j=x[i>>2];a:{if(Kc(j,x[i+4>>2])>>>0<=b>>>0){break a}if(eO(g,z[cc(j,b)>>1])>>>0<=c>>>0){break a}i=x[a>>2];b:{if(Dd(i,x[a+4>>2])>>>0>b>>>0){if(A[Zd(i,b)+4>>2]>c>>>0){break b}}Qn(a,0);if(Dd(x[a>>2],x[a+4>>2])>>>0<=b>>>0){break a}g=x[a+24>>2]}hc(k,x[d>>2],z[g+480188>>1]);g=k+8|0;l=x[k>>2];d=e?-2046629010:-2078137563;j=e?-1352371636:-873292572;e=x[k+4>>2];while(1){if(!f&(e|0)==(h|0)){x[g>>2]=d;x[g+4>>2]=j;e=g}else{i=y[OP(l,h)+841|0];m=i^Jia(d^h,f^j,435,256);i=!i;d=(q=d,r=Jia(m,lb,435,256),s=i,s?q:r);j=i?j:lb;h=h+1|0;f=h?f:f+1|0;continue}break}d=0;f=am(k,b,c);j=hb-16|0;hb=j;i=a+12|0;g=i;h=VN(z[f>>1],x[f+4>>2],Sd(g),jc(g));c:{if(Ob(h,Ef(g))){l=z[f>>1];m=x[f+4>>2];f=sd(h);if(!Tk(l,m,z[f>>1],x[f+4>>2])){break c}}h=Ef(g)}f=x[Ib(j+8|0,h)>>2];hb=j+16|0;if(xg(f,xf(i))){d=sd(f);d=tc(x[d+8>>2],x[d+12>>2])^1}j=x[e>>2]!=-2078137563|x[e+4>>2]!=-873292572;Jb(k,x[Zd(x[a>>2],b)>>2],c);h=1;n=Mb(x[x[k>>2]>>2],x[k+4>>2])^1;g=d|j;if(!(n|g)){break a}d:{e:{f:{g:{if(d){m=sd(f);g=Bb(x[m+8>>2]);o=Bb(x[m+12>>2]);f=x[e>>2];p=x[e+4>>2];l=hb-16|0;hb=l;x[l+8>>2]=g;while(1){h:{if(!Ob(g,o)){break h}if(WD(x[g>>2],x[g+4>>2],f,p)){break h}g=x[Vs(l+8|0)>>2];continue}break}hb=l+16|0;if(Ob(g,Bb(x[m+12>>2]))){break a}if(!j){break e}break g}if(j){break g}if(!g){break d}break f}x[a+28>>2]=x[a+28>>2]+1}if(d|n){break e}d=TN(i,am(k,b,c));i:{if(A[d+4>>2]<A[Cb(d)>>2]){f=hb-16|0;hb=f;d=SN(f,d);RN(x[d+4>>2]);x[d+4>>2]=x[d+4>>2]+8;ic(d);hb=f+16|0;break i}h=hb-32|0;hb=h;f=Cb(d);f=Tq(h+8|0,Uq(d,Eg(x[d>>2],x[d+4>>2])+1|0),Eg(x[d>>2],x[d+4>>2]),f);RN(x[f+8>>2]);x[f+8>>2]=x[f+8>>2]+8;xd(d,f);Sq(f);hb=h+32|0}}d=TN(i,am(k,b,c));j:{if(A[d+4>>2]<A[Cb(d)>>2]){f=hb-16|0;hb=f;d=SN(f,d);OM(x[d+4>>2],x[e>>2],x[e+4>>2]);x[d+4>>2]=x[d+4>>2]+8;ic(d);hb=f+16|0;break j}h=hb-32|0;hb=h;f=Cb(d);f=Tq(h+8|0,Uq(d,Eg(x[d>>2],x[d+4>>2])+1|0),Eg(x[d>>2],x[d+4>>2]),f);OM(x[f+8>>2],x[e>>2],x[e+4>>2]);x[f+8>>2]=x[f+8>>2]+8;xd(d,f);Sq(f);hb=h+32|0}}Jb(k,x[Zd(x[a>>2],b)>>2],c);sg(k,1);h=0}hb=k+16|0;return h|0}function Vfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-32|0;hb=e;a:{b:{if(!c){break b}n=e,o=Be(a),v[n+16|0]=o;cn(b,e+16|0);k=c-1|0;c=0;while(1){f=1;if(!k){break a}c:{d:{d=c<<1;c=d&254;if(!c){if(!af(a,e+16|0)){break b}g=1;d=y[e+16|0]<<1|1;c=d&255;if(d>>>0<=255){break d}break c}if((d&65535)>>>0<=255){break d}g=1;break c}if(!af(a,e+16|0)){break b}JT(b,e+16|0);k=k-1|0;continue}while(1){e:{f:{g:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!af(a,e+16|0)){break g}c=y[e+16|0]<<1|1;d=c&255;c=c>>>0>255}g=Lp(g,1)+c|0;c=d<<1&254;if(c){break f}if(!af(a,e+16|0)){break g}d=y[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(d>>>0>127){continue}}break}h:{if((g|0)<=2){j=0;h=g-2|0;break h}if(!af(a,e+16|0)){break b}d=Lp(g-3|0,8)|y[e+16|0];j=((d|0)>1279?2:1)+((d|0)>31999)|0;m=d^-1;h=0}d=c<<1&254;if(d){f=c>>>0>127}else{if(!af(a,e+16|0)){break b}c=y[e+16|0]<<1|1;d=c&255;f=c>>>0>255}l=Lp(h,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!af(a,e+16|0)){break b}d=y[e+16|0]<<1|1;c=d&255;d=d>>>0>255}g=1;h=k;d=Lp(f+l|0,1)+d|0;if(!d){while(1){i:{j:{k:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!af(a,e+16|0)){break k}c=y[e+16|0]<<1|1;d=c&255;c=c>>>0>255}g=Lp(g,1)+c|0;c=d<<1&254;if(c){break j}if(!af(a,e+16|0)){break k}d=y[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break i}c=0;break i}if(d>>>0>127){continue}}break}d=g+2|0}g=h;h=d+j|0;f=0;if(g>>>0<h>>>0|(h|0)<=0|(m|0)>=0){break a}d=x[b+4>>2];f=0;if((0-Rc(x[b>>2],d)|0)>(m|0)){break a}d=Ib(e+24|0,Bb(d));v[e+16|0]=0;g=e+16|0;j=hb-32|0;hb=j;f=x[d>>2];d=x[b>>2];i=de(f,Bb(d))+d|0;d=x[Cb(b)>>2];l=x[b+4>>2];l:{if(h>>>0<=d-l>>>0){d=h;f=l-i|0;if(d>>>0>f>>>0){wo(b,h-f|0,g);d=f;if(!d){break l}}KT(b,i,l,h+i|0);Mh(i,d,(g>>>0>=i>>>0?A[b+4>>2]>g>>>0?h:0:0)+g|0);break l}d=Cb(b);d=Bl(j,qk(b,Rc(x[b>>2],l)+h|0),i-x[b>>2]|0,d);DS(d,h,g);i=dq(b,d,i);Al(d)}Ib(j+24|0,i);hb=j+32|0;n=e,o=Ee(dA(Bb(x[b+4>>2]),h),m),x[n+16>>2]=o;n=e,o=dA(Bb(x[b+4>>2]),h),x[n+8>>2]=o;d=h;while(1){f=y[PR(e+16|0)|0];n=PR(e+8|0),o=f,v[n|0]=o;f=d>>>0>1;d=d-1|0;if(f){continue}break}k=k-h|0;continue}}f=0}hb=e+32|0;return f|0}function kx(a){a=a|0;var b=0,c=0,d=E(0),e=0;Zb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[23604]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}ea(877,e|0,67,5,c|0,b|0);b=x[23604];x[23604]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[23604]=0;ea(877,a+4528|0,62,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[23604]=0;ea(877,a+4552|0,53,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[23604]=0;ea(877,a+4576|0,43,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[23604]=0;ea(877,a+4600|0,32,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[23604]=0;ea(877,a+4624|0,22,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[23604]=0;ea(877,a+4648|0,75,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[23604]=0;ea(877,a+4672|0,69,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[23604]=0;ea(877,a+4696|0,60,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[23604]=0;ea(877,a+4720|0,48,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[23604]=0;ea(877,a+4744|0,36,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[23604]=0;ea(877,a+4768|0,25,5,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}x[23604]=0;ea(877,a+4792|0,0,0,0,0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[23604]=0;ea(877,a+4816|0,3,0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[23604]=0;ea(877,a+4840|0,3,0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}x[23604]=0;ea(877,a+4864|0,407,1,c|0,0);b=x[23604];x[23604]=0;if((b|0)==1){break a}x[23604]=0;ea(877,a+4888|0,400,1,c|0,0);b=x[23604];x[23604]=0;if((b|0)==1){break a}x[23604]=0;ea(877,a+4912|0,10,0,c|0,-1);b=x[23604];x[23604]=0;if((b|0)==1){break a}x[23604]=0;ea(877,a+4936|0,10,0,c|0,-1);c=x[23604];x[23604]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=V(92520)|0;if((ib|0)==(da(92520)|0)){_(c|0)|0;v[a+5045|0]=0;$();return}T(c|0);p()}function t5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-112|0;hb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];h=y[Fk(f,e)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}Rk(d+88|0,f,e,e-1|0);e=x[d+92>>2];x[b>>2]=x[d+88>>2];x[b+4>>2]=e}f=d+88|0;Pd(f);e=x[d+88>>2];Pd(d+72|0);e=Ek(e,x[d+76>>2],b);Pd(f);b:{c:{d:{e:{if((e|0)==x[d+92>>2]){a=x[b+4>>2];e=x[b>>2];f=oc(d+104|0,21502);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;if(Ic(e,a,d)){a=ba(8)|0;x[23604]=0;c=Q(54,d+88|0,10374)|0;b=x[23604];x[23604]=0;if((b|0)==1){break d}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}g=0;if(!c){break e}a=ba(8)|0;c=x[b+4>>2];b=x[b>>2];x[23604]=0;e=Ah(d+72|0,b,c);b=x[23604];x[23604]=0;f:{g:{h:{if((b|0)!=1){x[23604]=0;U(915,d+88|0,17517,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break h}c=0;b=pc(a,d+88|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(d+88|0);break g}b=P()|0;break f}b=P()|0;c=1}xb(e);if(!c){break c}}ca(a|0);break c}if(x[e+4>>2]!=2){a=ba(8)|0;x[23604]=0;c=Q(54,d+88|0,11459)|0;b=x[23604];x[23604]=0;if((b|0)!=1){a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}c=x[b+4>>2];b=x[b>>2];e=oc(d- -64|0,21502);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Ic(b,c,d+32|0)){a=ba(8)|0;x[23604]=0;c=Q(54,d+88|0,10374)|0;b=x[23604];x[23604]=0;if((b|0)!=1){a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}e=oc(d+56|0,7677);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Ic(b,c,d+24|0)){g=1;if(!ud(y[a+28|0])){break e}g=65536/+A[x[a+24>>2]+480244>>2];break e}e=oc(d+48|0,7729);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Ic(b,c,d+16|0)){g=1;if(!ud(y[a+28|0])){break e}g=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break e}e=oc(d+40|0,7747);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;g=0;if(!Ic(b,c,d+8|0)){break e}g=+A[x[a+24>>2]+480236>>2]*152587890625e-16}hb=d+112|0;return+g}b=P()|0;ca(a|0)}T(b|0)}p()}function j7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=E(0),z=0,A=0,C=0,D=0,G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,N=0,O=E(0),P=0,Q=E(0);a:{if(!x[a+4316>>2]){break a}if(!Qh(a+44|0)){break a}G=a+4300|0;H=a+4288|0;J=a+4264|0;K=a+4276|0;e=x[a+44>>2];s=Cc(e,0);t=Cc(e,1);e=x[a+56>>2];u=Cc(e,0);v=Cc(e,1);L=mb[x[x[a>>2]+192>>2]](a)|0;w=E(E(mb[x[x[a>>2]+200>>2]](a))/E(100));I=E(mb[x[x[a>>2]+188>>2]](a));z=mb[x[x[a>>2]+212>>2]](a)|0;M=z&1;o=x[a+4324>>2];i=x[a+4320>>2];m=x[a+4328>>2];k=x[a+4312>>2];N=x[a+4276>>2];p=x[a+4264>>2];A=x[a+4256>>2];C=y[a+4260|0];r=a+4316|0;D=d;while(1){if(D){h=B[t>>2];l=B[s>>2];j=x[r>>2];e=zn(j,k+A|0);j=zn(j,k);b:{if(C){P=zb(H,m),Q=l,B[P>>2]=Q;P=zb(G,m),Q=h,B[P>>2]=Q;q=zb(p,e);P=zb(p,j),Q=E(E(B[q>>2]*w)+l),B[P>>2]=Q;g=E(E(B[zb(N,e)>>2]*w)+h);e=K;break b}g=E(E(B[zb(p,e)>>2]*w)+E(E(l+h)*E(.5)));e=J}P=zb(x[e>>2],j),Q=g,B[P>>2]=Q;c:{if(L){f=B[a+4244>>2];g=E(f+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(g>E(1)){g=E(g+E(-2));B[a+4236>>2]=g}if(f>E(1)){f=E(f+E(-2));B[a+4240>>2]=f}g=E(F(g));g=E(E(g+g)+E(-1));f=E(F(f));f=E(E(f+f)+E(-1));break c}f=B[a+4240>>2];n=B[a+4244>>2];g=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f-E(g*n));B[a+4240>>2]=f}if(C){e=(m+2|0)%3|0;l=B[zb(H,e)>>2];h=B[zb(G,e)>>2]}e=x[r>>2];j=zb(p,zn(e,i+k|0));q=e;e=k+4096|0;O=B[zb(p,zn(q,e+i|0))>>2];n=B[j>>2];B[u>>2]=E(E(E(E(E(O-n)*E(E(i&4095)*E(.000244140625)))+n)-l)*I)+l;i=x[(C?4276:4264)+a>>2];j=x[r>>2];q=zb(i,zn(j,k+o|0));n=B[zb(i,zn(j,e+o|0))>>2];l=B[q>>2];B[v>>2]=E(E(E(E(E(n-l)*E(E(o&4095)*E(.000244140625)))+l)-h)*I)+h;m=((m|0)<=0?m+3|0:m)-1|0;x[a+4328>>2]=m;k=(((k|0)<=0?x[r>>2]<<12:0)+k|0)-4096|0;x[a+4312>>2]=k;h=M?f:g;f=B[a+4248>>2];h=E(h*f);d:{if(E(F(h))<E(2147483648)){e=~~h;break d}e=-2147483648}o=(z>>>0>1?e:0-e|0)+A|0;x[a+4324>>2]=o;i=z>>>0<4;t=t+4|0;s=s+4|0;g=E(g*f);e:{if(E(F(g))<E(2147483648)){e=~~g;break e}e=-2147483648}i=(i?e:0-e|0)+A|0;x[a+4320>>2]=i;D=D-1|0;v=v+4|0;u=u+4|0;continue}else{e=a;a=x[a+56>>2];di(e,b,c,Cc(a,0),Cc(a,1),d)}break}}}function Zaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;y=x[a+16>>2];z=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;q=x[a+128>>2];if(q){i=x[a+8>>2];g=x[a+12>>2];r=Xf(i,g,q);s=lb;h=x[a+76>>2];Cf(x[a>>2],x[a+4>>2],Ze(i,g,d),lb);p=lb>>>0>h>>>0?d:0}else{p=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+16|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;p=p-1|0;h=p;r=h?r:0;s=h?s:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=q;while(1)if((b|0)<=0){Ub(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;Kd(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Tf(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];t=x[a+68>>2];E=t>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+16|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;v=e<<8;e=v;e=Jia(h,G,e,e>>31);l=lb;m=e;e=Yb(k,-16777216,16776704);e=Jia(i,F,e,e>>31);k=m+e|0;m=lb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Yb(H,-16777216,16776704);l=Jia(t,E,e,e>>31);k=l+k|0;e=lb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Nc(l,e,24);x[g+4>>2]=e-(v&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];o=x[a+28>>2]+o|0;x[c>>2]=x[c>>2]+D(x[f>>2],o>>12);n=b+n|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],n>>12);Ub(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;Kd(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(j,4);Ub(f+40|0,r,s);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;u=x[a+16>>2];w=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;p=x[a+128>>2];if(p){k=x[a+8>>2];g=x[a+12>>2];q=Xf(k,g,p);r=lb;h=x[a+76>>2];Cf(x[a>>2],x[a+4>>2],Ze(k,g,d),lb);o=lb>>>0>h>>>0?d:0}else{o=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+16|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;o=o-1|0;h=o;q=h?q:0;r=h?r:0;k=(((g&2147483647)<<1|b>>>31)&-2)+u|0;g=p;a:{b:while(1){c:{if((g|0)<=0){Ub(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){Kd(j,i>>>3<<16>>16);Jd(j,4);Ub(f+40|0,q,r);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}Kd(j,i>>>3<<16>>16);Jd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Tf(j,w);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+16|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;t=e<<8;e=t;e=Jia(h,G,e,e>>31);m=lb;n=e;e=Yb(l,-16777216,16776704);e=Jia(k,F,e,e>>31);l=n+e|0;n=lb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Yb(H,-16777216,16776704);m=Jia(i,E,e,e>>31);l=m+l|0;e=lb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Nc(m,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],y);Ub(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function HJ(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=hb-128|0;hb=j;a:{b:{c:{if(!bm(f,g,h,i,0,0,0,0)){break c}l=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){k=4;if(n){break e}k=f|h|(g|l)?3:2;break d}k=!(f|h|(g|l))}}s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(k){break b}}Ed(j+16|0,b,c,d,e,f,g,h,i);b=x[j+16>>2];d=x[j+20>>2];e=x[j+24>>2];c=x[j+28>>2];gK(j,b,d,e,c,b,d,e,c);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}k=d;p=e&2147483647;n=h;m=i&2147483647;if((bm(b,c,k,p,f,g,h,m)|0)<=0){if(bm(b,c,k,p,f,g,n,m)){h=b;i=c;break a}Ed(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}q=i>>>16&32767;if(o){i=c;h=b}else{Ed(j+96|0,b,c,k,p,0,0,0,1081540608);k=x[j+104>>2];h=x[j+108>>2];p=h;o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){Ed(j+80|0,f,g,n,m,0,0,0,1081540608);n=x[j+88>>2];f=x[j+92>>2];m=f;q=(f>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}r=n;t=m&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;f:{if((l|0)>0|(l|0)>=0){k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(!(h|n|(i|l))){Ed(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}l=l<<1|n>>>31;k=n<<1|i>>>31;break f}l=p<<1|k>>>31;k=k<<1|i>>>31}p=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((o|0)>(q|0)){continue}break}o=q}m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;m=l;g:{if((l|0)<0){n=k;m=p;break g}k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(h|n|(i|m)){break g}Ed(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((m|0)==65535|m>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m<<1|n>>>31;n=c|n<<1;m=b;if(b>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){Ed(j- -64|0,h,i,n,m&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=n;e=m&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;hb=j+128|0}function Dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}A=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+24|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+32>>2];C=x[a+28>>2];E=x[a+72>>2];z=x[a+68>>2];F=z>>31;l=x[a+64>>2];G=l>>31;j=x[a+60>>2];H=j>>31;while(1){if(d){b=x[f+16>>2];v=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+A|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];y=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=v+(r<<1)|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],y)|0)+D(w[k+8>>1],t)|0)+D(s,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+24|0)+(q<<3)|0;y=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=Jia(j,H,e,e>>31);i=lb;v=e;e=Yb(g,-16777216,16776704);e=Jia(l,G,e,e>>31);g=v+e|0;m=lb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(y,-16777216,16776704);i=Jia(z,F,e,e>>31);g=i+g|0;e=lb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[b+4>>2]=e-(s&E);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+C|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+B|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Ub(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function xda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-128|0;hb=d;a:{b:{c:{d:{switch(y[a|0]-23|0){case 0:e=v[a+1|0];f=d,g=kR(c,+y[a+2|0]*1e4/240),v[f|0]=g;x[d+96>>2]=127;x[d+80>>2]=(D(y[a+3|0],127)>>>0)/185;f=d,g=x[rd(d+96|0,d+80|0)>>2],v[f+127|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:ef(d+80|0,15448);x[23604]=0;R(493,d- -64|0,d|0);a=x[23604];x[23604]=0;f:{g:{h:{i:{if((a|0)!=1){x[23604]=0;R(493,d+48|0,d+127|0);a=x[23604];x[23604]=0;if((a|0)==1){break i}x[23604]=0;X(494,d+96|0,d+80|0,d- -64|0,d+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}a=d+96|0;ve(d+112|0,a);Oe(b,x[d+112>>2],x[d+116>>2]);xb(a);xb(d+48|0);xb(d- -64|0);Db(d+80|0);break b}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(d+48|0)}xb(d- -64|0)}break c;case 1:ef(d+80|0,15388);x[23604]=0;R(493,d- -64|0,d|0);a=x[23604];x[23604]=0;j:{k:{l:{m:{if((a|0)!=1){x[23604]=0;R(493,d+48|0,d+127|0);a=x[23604];x[23604]=0;if((a|0)==1){break m}x[23604]=0;X(494,d+96|0,d+80|0,d- -64|0,d+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break l}a=d+96|0;ve(d+40|0,a);Oe(b,x[d+40>>2],x[d+44>>2]);xb(a);xb(d+48|0);xb(d- -64|0);Db(d+80|0);break b}a=P()|0;break j}a=P()|0;break k}a=P()|0;xb(d+48|0)}xb(d- -64|0)}break c;default:break e}}a=oc(d+32|0,15475);Oe(b,x[a>>2],x[a+4>>2]);break b;case 1:break d;default:break a}}c=v[a+1|0];v[d+127|0]=(c|0)<5?c:0;c=v[a+2|0];v[d+31|0]=(c|0)<0?127:c;a=v[a+3|0];v[d+30|0]=(a|0)<0?127:a;a=hb-16|0;hb=a;c=Xb(a,4009);dd(d+80|0,c);xb(c);hb=a+16|0;x[23604]=0;R(493,d- -64|0,d+127|0);a=x[23604];x[23604]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){x[23604]=0;R(493,d+48|0,d+31|0);a=x[23604];x[23604]=0;if((a|0)==1){break s}x[23604]=0;R(493,d|0,d+30|0);a=x[23604];x[23604]=0;if((a|0)==1){break r}x[23604]=0;ea(661,d+96|0,d+80|0,d- -64|0,d+48|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break q}a=d+96|0;ve(d+16|0,a);Oe(b,x[d+16>>2],x[d+20>>2]);xb(a);xb(d);xb(d+48|0);xb(d- -64|0);Db(d+80|0);break b}a=P()|0;break n}a=P()|0;break o}a=P()|0;break p}a=P()|0;xb(d)}xb(d+48|0)}xb(d- -64|0)}}Db(d+80|0);T(a|0);p()}e=1}hb=d+128|0;return e|0}function jh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=Kb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[23604]=0;R(45,b|0,Qc(e,d)|0);d=x[23604];x[23604]=0;d:{if((d|0)!=1){e:{while(1){if(Qc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Wi(c,a)>>2];x[23604]=0;R(46,b|0,(d>>>0>=128?63:d)<<24>>24);d=x[23604];x[23604]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Kb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[23604]=0;R(45,b|0,Qc(e,d)|0);d=x[23604];x[23604]=0;f:{if((d|0)!=1){g:{while(1){if(Qc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Wi(c,a)>>2];x[23604]=0;R(46,b|0,(d>>>0>=256?63:d)<<24>>24);d=x[23604];x[23604]=0;if((d|0)==1){break g}a=a+1|0;continue}break}break f}}break a}return;case 3:Yl(a,c,50032);return;case 5:Yl(a,c,51056);return;case 4:Yl(a,c,52080);return;case 6:Yl(a,c,53104);return;case 7:Yl(a,c,54128);return;case 8:Yl(a,c,55152);return;case 9:yy(a,c,56176);return;case 10:yy(a,c,50032);return;case 11:yy(a,c,54128);return;default:a=ba(8)|0;x[23604]=0;b=Q(44,a|0,10965)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}b=P()|0;ca(a|0);T(b|0);p();case 0:break c}}e=hb-16|0;hb=e;f=Kb(a);h:{while(1){i:{j:{k:{if(Qc(x[c+4>>2],y[c+11|0])>>>0>g>>>0){b=x[Wi(c,g)>>2];if(b>>>0>=2097152){x[23604]=0;R(46,f|0,63);a=x[23604];x[23604]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;v[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=y[e+10|0]|64}else{a=y[e+10|0]}x[23604]=0;R(46,f|0,a<<24>>24);a=x[23604];x[23604]=0;if((a|0)!=1){break j}break i}hb=e+16|0;break h}i=(-1<<b^-1)<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=v[j|0];x[23604]=0;R(46,f|0,(a|i)<<24>>24);h=x[23604];x[23604]=0;a=d;break l}x[23604]=0;a=a-1|0;R(46,f|0,v[a+(e+10|0)|0]|-128);h=x[23604];x[23604]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=P()|0;xb(f);T(a|0);p()}return}ha(b|0,92652,24);p()}a=P()|0;xb(b);T(a|0);p()}function Eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=hb-48|0;hb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}B=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+24|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+32>>2];E=x[a+28>>2];F=x[a+72>>2];A=x[a+68>>2];G=A>>31;l=x[a+64>>2];H=l>>31;j=x[a+60>>2];I=j>>31;while(1){if(d){b=x[f+16>>2];y=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+B|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];z=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=r+y|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],z)|0)+D(v[k+4|0],t)|0)+D(s,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+24|0)+(q<<3)|0;z=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=Jia(j,I,e,e>>31);i=lb;y=e;e=Yb(g,-16777216,16776704);e=Jia(l,H,e,e>>31);g=y+e|0;m=lb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(z,-16777216,16776704);i=Jia(A,G,e,e>>31);g=i+g|0;e=lb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[b+4>>2]=e-(s&F);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+E|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+C|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Ub(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function Zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0),h=0,i=E(0);d=hb-112|0;hb=d;c=hb-16|0;hb=c;e=b+16|0;zS(c+8|0,e);f=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((h|0)==(f|0)){bc(a,x[c+12>>2])}hb=c+16|0;if((f|0)!=(h|0)){Zb(e,0,128)}v[b+79|0]=0;v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;c=d- -64|0;Ud(c,a,kg(a));f=kc(d+88|0,c);yb(c);x[23604]=0;c=S(188,f|0)|0;e=x[23604];x[23604]=0;a:{b:{if((e|0)==1){break b}x[23604]=0;R(270,b+4|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}ke(d+56|0,x[b+4>>2],x[b+8>>2]);x[23604]=0;Wm(404,d- -64|0,f,x[d+56>>2],x[d+60>>2]);c=x[23604];x[23604]=0;if((c|0)!=1){x[23604]=0;c=S(143,a|0)|0;e=x[23604];x[23604]=0;c:{if((e|0)==1){break c}x[23604]=0;U(176,d+32|0,a|0,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}a=d+32|0;c=kc(d- -64|0,a);yb(a);a=x[c>>2];x[23604]=0;a=S(164,a|0)|0;e=x[23604];x[23604]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{a=x[c+8>>2];e=x[c>>2];x[23604]=0;a=W(142,e|0,a|0,5)|0;e=x[23604];x[23604]=0;if((e|0)==1){break e}if(!a){break f}x[23604]=0;Q(405,c|0,d+28|0)|0;a=x[23604];x[23604]=0;h:{if((a|0)!=1){a=4;if(!Rb(d+28|0,13465,4)){break h}if(!Rb(d+28|0,13977,4)){break h}x[23604]=0;a=S(143,c|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){break h}a=P()|0;break d}a=P()|0;break d}x[23604]=0;U(176,d+8|0,c|0,a|0);a=x[23604];x[23604]=0;i:{j:{k:{if((a|0)!=1){a=d+8|0;e=kc(d+32|0,a);yb(a);if(Rb(d+28|0,13465,4)){break k}x[23604]=0;g=E(za(406,e|0));a=x[23604];x[23604]=0;if((a|0)==1){break g}B[d+8>>2]=g;x[d+4>>2]=0;x[d>>2]=1065353216;g=B[Sp(d+8|0,d+4|0,d)>>2];B[b+144>>2]=g;i=E(F(g));if((i<E(11754943508222875e-54)^-1)&(!(i>=E(O))&g==g)){break j}x[b+144>>2]=0;break j}a=P()|0;break d}if(Rb(d+28|0,13977,4)){break j}x[23604]=0;a=S(143,e|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break i}x[b+148>>2]=a}yb(e);continue}}break}a=P()|0;yb(e);break d}yb(c);yb(f);hb=d+112|0;return}a=P()|0;break d}a=P()|0}yb(c);break a}a=P()|0;break a}a=P()|0;break a}a=P()|0}yb(f);T(a|0);p()}function nO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=hb-176|0;hb=c;i=1;p=2;d=x[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;v=D(i,3);w=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=x[a+12>>2];continue a}d=x[a>>2];e=bd(d,h<<1);DL(c+160|0,C[e>>3],C[e+8>>3]);d=bd(d,h);DL(c+144|0,C[d>>3],C[d+8>>3]);ii(c+128|0,C[c+144>>3],C[c+152>>3],C[c+160>>3],C[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=x[b>>2];e=bd(f,d);g=e+8|0;j=x[g+4>>2];x[c+120>>2]=x[g>>2];x[c+124>>2]=j;g=x[e+4>>2];x[c+112>>2]=x[e>>2];x[c+116>>2]=g;k=d+i|0;g=bd(f,k);n=C[g+8>>3];o=C[g>>3];r=d+w|0;g=bd(f,r);j=x[g+12>>2];x[c+104>>2]=x[g+8>>2];x[c+108>>2]=j;j=x[g+4>>2];x[c+96>>2]=x[g>>2];x[c+100>>2]=j;s=d+v|0;f=bd(f,s);t=C[f+8>>3];u=C[f>>3];g=c+80|0;f=c+112|0;Kk(g,f,o,n);j=c- -64|0;Ui(j,f,o,n);l=c+96|0;Kk(c+48|0,l,u,t);f=c+16|0;Ui(f,l,u,t);ii(c+32|0,0,1,C[c+16>>3],C[c+24>>3]);Kk(f,g,C[c+48>>3],C[c+56>>3]);l=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=l;l=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=l;Kk(c,j,C[c+32>>3],C[c+40>>3]);ii(f,C[c+160>>3],C[c+168>>3],C[c>>3],C[c+8>>3]);e=bd(x[b>>2],k);k=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=k;k=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=k;Ui(c,g,C[c+48>>3],C[c+56>>3]);ii(f,C[c+144>>3],C[c+152>>3],C[c>>3],C[c+8>>3]);e=bd(x[b>>2],r);g=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=g;Ui(c,j,C[c+32>>3],C[c+40>>3]);ii(f,C[c+128>>3],C[c+136>>3],C[c>>3],C[c+8>>3]);e=bd(x[b>>2],s);f=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=f;f=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=x[b>>2];a=bd(h,d+i|0);m=bd(h,d);n=C[a>>3];o=C[a+8>>3];Ui(c+160|0,m,n,o);h=x[c+172>>2];x[a+8>>2]=x[c+168>>2];x[a+12>>2]=h;h=x[c+164>>2];x[a>>2]=x[c+160>>2];x[a+4>>2]=h;Px(bd(x[b>>2],d),n,o);d=d+1|0;continue}}hb=c+176|0}function bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;u=x[a+16>>2];v=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){i=x[a+8>>2];g=x[a+12>>2];p=Xf(i,g,o);q=lb;h=x[a+76>>2];Cf(x[a>>2],x[a+4>>2],Ze(i,g,d),lb);n=lb>>>0>h>>>0?d:0}else{n=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+16|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;n=n-1|0;h=n;p=h?p:0;q=h?q:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+u|0;b=o;while(1)if((b|0)<=0){Ub(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;Kd(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Tf(j,v);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];r=x[a+68>>2];E=r>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+16|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;t=e<<8;e=t;e=Jia(h,G,e,e>>31);l=lb;m=e;e=Yb(k,-16777216,16776704);e=Jia(i,F,e,e>>31);k=m+e|0;m=lb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Yb(H,-16777216,16776704);l=Jia(r,E,e,e>>31);k=l+k|0;e=lb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Nc(l,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(y,x[f+4>>2]);Ub(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;Kd(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(j,4);Ub(f+40|0,p,q);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function rG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=x[d>>2];if(!h){break k}if(!a){g=c;break j}x[d>>2]=0;g=c;break i}l:{if(!x[x[116108]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=v[e|0];if(g){x[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return If(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=y[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=x[e>>2];if((d|d-16843009)&-2139062144){break p}x[a>>2]=d&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=y[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}x[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=x[(f<<2)+81920>>2];d=1;continue}d=y[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=y[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=y[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;x[a>>2]=d;g=g-1|0;a=a+4|0;break q}x[116080]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=y[e|0];if(!(e&3|d-1>>>0>126)){d=x[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=x[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=x[(h<<2)+81920>>2];d=1;continue}d=y[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((y[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((y[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=y[e|0]}if(d&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-g|0}x[116080]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c}function di(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=E(0),q=0,r=E(0);m=mb[x[x[a>>2]+136>>2]](a)|0;g=x[a+20>>2];h=m?h:y[g+25|0];j=B[g+144>>2];k=E(1);if(!(mb[x[x[a>>2]+136>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((mb[x[x[a>>2]+152>>2]](a)|0)<=0){break a}if(!EK(y[x[a+20>>2]+24|0])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(k*n);j=E(j*n);g=0;l=x[a+44>>2];m=Cc(l,0);l=Cc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;B[i>>2]=B[i>>2]+E(E(B[d+g>>2]*j)+E(k*B[g+m>>2]));i=c+g|0;B[i>>2]=B[i>>2]+E(E(B[e+g>>2]*j)+E(k*B[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[h+m>>2]-E(B[d+h>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]+E(B[h+l>>2]-E(B[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[d+h>>2]-E(B[h+m>>2]*k));i=c+h|0;B[i>>2]=B[i>>2]+E(B[e+h>>2]-E(B[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]-E(B[d+h>>2]-E(B[h+m>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]-E(B[e+h>>2]-E(B[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=B[i>>2];q=i;r=k;n=B[h+m>>2];i=c+h|0;o=B[i>>2];p=B[h+l>>2];k=E(E(E(E(k+n)+o)+p)*E(.5));B[q>>2]=r-E(E(k+E(k-E(B[d+h>>2]*j)))-n);B[i>>2]=o-E(E(k+E(k-E(B[e+h>>2]*j)))-p);g=g+1|0;continue}}g=EK(y[x[a+20>>2]+24|0]);j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[i>>2]=B[i>>2]+E(E(j*n)+E(k*o));g=c+g|0;B[g>>2]=B[g>>2]+E(E(k*n)+E(j*o));h=h+1|0;continue}}i:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break i}if(mb[x[x[a>>2]+136>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;B[d>>2]=B[a+m>>2]+B[d>>2];d=a+c|0;B[d>>2]=B[a+l>>2]+B[d>>2];g=g+1|0;continue}}}function Laa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=hb-16|0;hb=i;c=ff(a,c);_d(i,x[a+28>>2]);j=a;a:{if(!c){e=0;if(fd(a,5)){break a}}e=hb-224|0;hb=e;g=Dl(e+120|0,x[a+28>>2]);x[23604]=0;f=Q(394,e+104|0,28168)|0;a=x[23604];x[23604]=0;b:{c:{d:{e:{if((a|0)!=1){x[23604]=0;x[e+88>>2]=19924993;x[e+92>>2]=0;U(395,g|0,f|0,e+88|0);a=x[23604];x[23604]=0;if((a|0)==1){break e}Db(f);if(!(y[g+3|0]&64)){break d}break b}b=P()|0;break c}b=P()|0;Db(f);break c}v[e+103|0]=0;x[23604]=0;f=Q(394,e+88|0,5466)|0;a=x[23604];x[23604]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23604]=0;U(396,g|0,e+103|0,f|0);a=x[23604];x[23604]=0;if((a|0)==1){break q}Db(f);f=Kb(e+72|0);x[23604]=0;a=Q(394,e+56|0,9986)|0;h=x[23604];x[23604]=0;if((h|0)==1){break p}x[23604]=0;U(707,g|0,f|0,a|0);h=x[23604];x[23604]=0;if((h|0)==1){break o}Db(a);x[23604]=0;U(11,e+40|0,(y[e+103|0]?0:d)|0,f|0);d=x[23604];x[23604]=0;if((d|0)==1){break n}x[23604]=0;R(258,b|0,e+40|0);d=x[23604];x[23604]=0;if((d|0)==1){break m}d=e+40|0;xb(d);w[e+38>>1]=0;x[23604]=0;d=Q(394,d|0,10646)|0;a=x[23604];x[23604]=0;if((a|0)==1){break g}x[23604]=0;W(424,g|0,e+38|0,d|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break l}Db(d);pg(e+38|0,4e3);x[23604]=0;d=Q(394,e+24|0,13280)|0;a=x[23604];x[23604]=0;if((a|0)==1){break k}h=z[e+38>>1];a=x[Ib(e+16|0,h)>>2];x[23604]=0;X(708,g|0,b|0,d|0,a|0);a=x[23604];x[23604]=0;if((a|0)==1){break j}Db(d);w[e+14>>1]=65535;x[23604]=0;d=Q(394,e|0,8866)|0;a=x[23604];x[23604]=0;if((a|0)==1){break i}x[23604]=0;k=W(424,g|0,e+14|0,d|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break h}a=z[e+14>>1];Db(d);if(!((k|0)==1|a>>>0>=h>>>0)){Xe(b,a)}xb(f);break b}b=P()|0;break c}b=P()|0;Db(f);break c}b=P()|0;break f}b=P()|0;Db(a);break f}b=P()|0;break f}b=P()|0;xb(e+40|0);break f}b=P()|0;Db(d);break f}b=P()|0;break f}b=P()|0;Db(d);break f}b=P()|0;break f}b=P()|0;Db(d);break f}b=P()|0}xb(f)}Wg(g);T(b|0);p()}Wg(g);hb=e+224|0;e=c}_e(j,e);hb=i+16|0}function E_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=hb-16|0;hb=j;k=sw(x[g>>2]);o=bw(x[g>>2]);Jg(j,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[23604]=0;g=Q(1100,k|0,g<<24>>24)|0;i=x[23604];x[23604]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[23604]=0;g=Q(1100,k|0,48)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;g=v[i+1|0];x[23604]=0;g=Q(1100,k|0,g|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];zd();if(!EG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];zd();if(!Dj(h)){break d}g=g+1|0;continue}}e:{if(wd(x[j+4>>2],y[j+11|0])){h=x[f>>2];x[23604]=0;X(1094,k|0,i|0,g|0,h|0);h=x[23604];x[23604]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break e}Cl(i,g);x[23604]=0;r=S(1092,o|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){zr((i-a<<2)+d|0,x[f>>2]);break e}f:{if(v[uc(j,l)|0]<=0){break f}if(v[uc(j,l)|0]!=(m|0)){break f}m=x[f>>2];x[f>>2]=m+4;x[m>>2]=r;l=(Eb(x[j+4>>2],y[j+11|0])-1>>>0>l>>>0)+l|0;m=0}q=v[h|0];x[23604]=0;q=Q(1100,k|0,q|0)|0;n=x[23604];x[23604]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[23604]=0;i=S(1095,o|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}l=x[f>>2];h=l+4|0;x[f>>2]=h;x[l>>2]=i;g=g+1|0;break g}x[23604]=0;i=Q(1100,k|0,i<<24>>24)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[23604]=0;X(1094,k|0,g|0,c|0,h|0);i=x[23604];x[23604]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;xb(j);hb=j+16|0;return}a=P()|0;xb(j);T(a|0);p()}function he(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-16|0;hb=h;e=x[a>>2];a:{if(tc(e,x[a+4>>2])){break a}g=x[b+4>>2];if(g>>>0>=A[a+12>>2]){break a}c=z[b+8>>1];i=x[x[a+48>>2]+12>>2];f=Bg(i);if(c>>>0>=f>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?f-1|0:c;f=g;g=d?0:c;c=cd(e,i,f,g);f=y[b+12|0];j=f&4;b:{c:{if(f&2){break c}k=y[b+10|0];e=c;d=g;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((k|0)!=y[e+3|0]){break d}break b}if((k|0)==y[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}k=l&65535;d=c;e=g;while(1){if(k>>>0>=(e&65535)>>>0){e:{if(!j){if(y[d+3|0]){break e}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break b}if(y[d+2|0]){break e}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(f&1)){break f}d=x[i+480180>>2]&2;g:{h:{i:{if(!j){while(1){if((g&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(y[c+3|0]-9|0){case 4:if(!lT(x[x[i+8>>2]+88>>2])){break j}d=1;v[c+2|0]=1;v[c+4|0]=y[c+5|0];v[c+3|0]=y[b+10|0];v[c+5|0]=y[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){e=y[c+5|0];if(e>>>0>128){break j}v[c+2|0]=2;v[c+3|0]=y[b+10|0];a=1;break l}v[c+2|0]=2;v[c+3|0]=y[b+10|0];e=y[c+5|0];a=2}v[c+4|0]=a+e>>>a;v[c+5|0]=y[b+11|0];break b}c=c+6|0;g=g+1|0;continue}break}if(!j){break i}}e=y[b+11|0];g=13;m:{switch(y[b+10|0]-1|0){case 1:g=9;e=zm(D(d?2:4,e));break;case 0:break m;default:break g}}v[b+11|0]=e;v[b+10|0]=g;f=f&254;break h}e=y[b+11|0];v[h+14|0]=e;g=b;c=!d;d=y[b+10|0];n:{if(!(c|(d|0)!=9)){if(e>>>0>128){break g}d=2;c=(e&254)>>>1|0;break n}v[h+15|0]=d;if(!uq(h+15|0,h+14|0,1)){break g}d=y[h+15|0];if(!d){break g}c=y[h+14|0]}v[g+11|0]=c;v[b+10|0]=d;f=f&254}v[b+12|0]=f}d=1;if(f&1){break f}v[b+12|0]=f^4;if(he(a,b)){break a}}d=0;o:{p:{switch(x[b>>2]-1|0){case 0:c=x[b+4>>2]+1|0;if(c>>>0>=A[a+12>>2]){break a}x[b+4>>2]=c;break o;case 1:break p;default:break a}}c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=he(a,b);break a}d=1}hb=h+16|0;return d}function f5(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=hb-96|0;hb=j;a:{b:{c:{k=Fp(1,32);d:{e:{if(!k){a=Ol(ba(4)|0);x[23604]=0;U(105,a|0,92520,25);a=x[23604];x[23604]=0;if((a|0)!=1){break a}i=V(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:881;x[k>>2]=f;c=ag(j+80|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[23604]=0;e=Q(54,j- -64|0,e|0)|0;m=x[23604];x[23604]=0;j:{if((m|0)!=1){x[23604]=0;m=Q(892,c|0,e|0)|0;n=x[23604];x[23604]=0;if((n|0)==1){break j}x[23604]=0;R(255,m|0,l|0);l=x[23604];x[23604]=0;if((l|0)==1){break j}break i}i=V(0)|0;break f}i=V(0)|0;xb(e);break f}x[23604]=0;e=Q(54,j+48|0,e|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break g}ms(c,e)}xb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[23604]=0;a=S(765,96)|0;m=x[23604];x[23604]=0;k:{l:{m:{if((m|0)!=1){x[j+44>>2]=e;x[j+40>>2]=i;x[j+36>>2]=l;x[j+32>>2]=b;x[23604]=0;b=Q(893,f|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break m}x[j+16>>2]=b;b=x[Mf(j+24|0,j+16|0)>>2];d=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=d;x[23604]=0;d=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=d;b=fa(923,a|0,j|0,b|0,c|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break k}i=V(0)|0;te(j+16|0);break l}i=V(0)|0;break f}i=V(0)|0}Hb(a);break f}x[k+28>>2]=b;te(j+16|0);x[k+24>>2]=b+8;Sk(c);break d}i=V(0)|0}Sk(c);_(i|0)|0;x[23604]=0;X(887,11215,k|0,g|0,h|0);a=x[23604];x[23604]=0;if((a|0)!=1){x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)!=1){a=x[k+28>>2];if(a){mb[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){Hb(a);x[k+20>>2]=0}Hb(k);k=0;break d}i=V(0)|0;break e}i=V(0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;x[23604]=0;X(887,11215,0,g|0,h|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}$()}hb=j+96|0;return k|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break b}T(a|0);p()}V(0)|0;Vb()}p()}function O_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=hb-16|0;hb=j;k=Cu(x[g>>2]);o=hw(x[g>>2]);Jg(j,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[23604]=0;g=Q(19,k|0,g<<24>>24)|0;i=x[23604];x[23604]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[23604]=0;g=Q(19,k|0,48)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;g=v[i+1|0];x[23604]=0;g=Q(19,k|0,g|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];zd();if(!EG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];zd();if(!Dj(h)){break d}g=g+1|0;continue}}e:{if(wd(x[j+4>>2],y[j+11|0])){h=x[f>>2];x[23604]=0;X(1081,k|0,i|0,g|0,h|0);h=x[23604];x[23604]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i|0);break e}Cl(i,g);x[23604]=0;r=S(1079,o|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Cl((i-a|0)+d|0,x[f>>2]);break e}f:{if(v[uc(j,m)|0]<=0){break f}if(v[uc(j,m)|0]!=(l|0)){break f}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;m=(Eb(x[j+4>>2],y[j+11|0])-1>>>0>m>>>0)+m|0;l=0}q=v[h|0];x[23604]=0;q=Q(19,k|0,q|0)|0;n=x[23604];x[23604]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=y[g|0];if((i|0)!=46){break g}x[23604]=0;i=S(1082,o|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0}i=x[f>>2];x[23604]=0;X(1081,k|0,g|0,c|0,i|0);i=x[23604];x[23604]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g|0)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;xb(j);hb=j+16|0;return}x[23604]=0;i=Q(19,k|0,i<<24>>24)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0;continue}}a=P()|0;xb(j);T(a|0);p()}function Hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=hb-48|0;hb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}y=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+24|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}z=x[a+24>>2];A=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+72>>2];v=x[a+68>>2];C=v>>31;l=x[a+64>>2];E=l>>31;j=x[a+60>>2];F=j>>31;while(1){if(d){b=x[f+16>>2];t=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=t+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],u)|0)+D(w[k+8>>1],r)|0)+D(q,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+24|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=Jia(j,F,e,e>>31);i=lb;t=e;e=Yb(g,-16777216,16776704);e=Jia(l,E,e,e>>31);g=t+e|0;m=lb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(u,-16777216,16776704);i=Jia(v,C,e,e>>31);g=i+g|0;e=lb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],A);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],z);Ub(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function At(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Ld(b)}if(b>>>0>=4294967232){x[116080]=48;return 0}g=b>>>0<11?16:b+11&-8;e=a-8|0;i=x[e+4>>2];d=i&-8;a:{if(!(i&3)){if(g>>>0<256){break a}if(d>>>0>=g+4>>>0){c=e;if(d-g>>>0<=x[23600]<<1>>>0){break a}}c=0;break a}h=d+e|0;b:{if(d>>>0>=g>>>0){c=d-g|0;if(c>>>0<16){break b}x[e+4>>2]=i&1|g|2;d=e+g|0;x[d+4>>2]=c|3;x[h+4>>2]=x[h+4>>2]|1;eR(d,c);break b}if(x[23486]==(h|0)){d=d+x[23483]|0;if(d>>>0<=g>>>0){break a}x[e+4>>2]=i&1|g|2;c=e+g|0;d=d-g|0;x[c+4>>2]=d|1;x[23483]=d;x[23486]=c;break b}if(x[23485]==(h|0)){d=d+x[23482]|0;if(d>>>0<g>>>0){break a}c=d-g|0;c:{if(c>>>0>=16){x[e+4>>2]=i&1|g|2;f=e+g|0;x[f+4>>2]=c|1;d=d+e|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[e+4>>2]=d|i&1|2;c=d+e|0;x[c+4>>2]=x[c+4>>2]|1;c=0}x[23485]=f;x[23482]=c;break b}f=x[h+4>>2];if(f&2){break a}j=d+(f&-8)|0;if(j>>>0<g>>>0){break a}l=j-g|0;d:{if(f>>>0<=255){c=x[h+8>>2];f=f>>>3|0;d=x[h+12>>2];if((d|0)==(c|0)){n=93920,o=x[23480]&Nia(-2,f),x[n>>2]=o;break d}x[c+12>>2]=d;x[d+8>>2]=c;break d}k=x[h+24>>2];d=x[h+12>>2];e:{if((h|0)!=(d|0)){c=x[h+8>>2];x[c+12>>2]=d;x[d+8>>2]=c;break e}f:{c=h+20|0;f=x[c>>2];if(!f){f=x[h+16>>2];if(!f){break f}c=h+16|0}while(1){m=c;d=f;c=d+20|0;f=x[c>>2];if(f){continue}c=d+16|0;f=x[d+16>>2];if(f){continue}break}x[m>>2]=0;break e}d=0}if(!k){break d}c=x[h+28>>2];f=(c<<2)+94224|0;g:{if(x[f>>2]==(h|0)){x[f>>2]=d;if(d){break g}n=93924,o=x[23481]&Nia(-2,c),x[n>>2]=o;break d}x[(x[k+16>>2]==(h|0)?16:20)+k>>2]=d;if(!d){break d}}x[d+24>>2]=k;c=x[h+16>>2];if(c){x[d+16>>2]=c;x[c+24>>2]=d}c=x[h+20>>2];if(!c){break d}x[d+20>>2]=c;x[c+24>>2]=d}if(l>>>0<=15){x[e+4>>2]=i&1|j|2;c=e+j|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[e+4>>2]=i&1|g|2;c=e+g|0;x[c+4>>2]=l|3;d=e+j|0;x[d+4>>2]=x[d+4>>2]|1;eR(c,l)}c=e}if(c){return c+8|0}c=Ld(b);if(!c){return 0}e=x[a-4>>2];e=(e&3?-4:-8)+(e&-8)|0;vc(c,a,b>>>0>e>>>0?e:b);Hb(a);return c}function KJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=hb-96|0;hb=j;a:{b:{c:{d:{e:{f:{k=Fp(1,28);if(!k){a=Ol(ba(4)|0);x[23604]=0;U(105,a|0,92520,25);a=x[23604];x[23604]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:881;x[k>>2]=f;c=ag(j+80|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[23604]=0;e=Q(54,j- -64|0,e|0)|0;m=x[23604];x[23604]=0;k:{if((m|0)!=1){x[23604]=0;m=Q(892,c|0,e|0)|0;n=x[23604];x[23604]=0;if((n|0)==1){break k}x[23604]=0;R(255,m|0,l|0);l=x[23604];x[23604]=0;if((l|0)==1){break k}break j}i=V(0)|0;break g}i=V(0)|0;xb(e);break g}x[23604]=0;e=Q(54,j+48|0,e|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break h}ms(c,e)}xb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[23604]=0;a=S(765,80)|0;m=x[23604];x[23604]=0;l:{m:{n:{if((m|0)!=1){x[j+44>>2]=e;x[j+40>>2]=i;x[j+36>>2]=l;x[j+32>>2]=b;x[23604]=0;b=Q(893,f|0,d|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break n}x[j+16>>2]=b;b=x[Mf(j+24|0,j+16|0)>>2];d=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=d;x[23604]=0;d=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=d;b=fa(894,a|0,j|0,b|0,c|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break l}i=V(0)|0;te(j+16|0);break m}i=V(0)|0;break g}i=V(0)|0}Hb(a);break g}x[k+24>>2]=b;te(j+16|0);Sk(c);i=k;break d}i=V(0)|0}Sk(c);_(i|0)|0;x[23604]=0;X(887,15008,k|0,g|0,h|0);a=x[23604];x[23604]=0;if((a|0)!=1){x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){Hb(ls(a))}i=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){Hb(a);x[k+20>>2]=0}Hb(k);break d}i=V(0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)!=1){break e}break b}i=V(0)|0}_(i|0)|0;i=0;x[23604]=0;X(887,15008,0,g|0,h|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}$()}hb=j+96|0;return i|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break b}T(a|0);p()}V(0)|0;Vb()}p()}function Iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=hb-48|0;hb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}z=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+24|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}A=x[a+24>>2];B=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+72>>2];y=x[a+68>>2];E=y>>31;l=x[a+64>>2];F=l>>31;j=x[a+60>>2];G=j>>31;while(1){if(d){b=x[f+16>>2];t=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+z|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=p+t|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],u)|0)+D(v[k+4|0],r)|0)+D(q,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+24|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=Jia(j,G,e,e>>31);i=lb;t=e;e=Yb(g,-16777216,16776704);e=Jia(l,F,e,e>>31);g=t+e|0;m=lb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Yb(u,-16777216,16776704);i=Jia(y,E,e,e>>31);g=i+g|0;e=lb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],B);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],A);Ub(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function s5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-96|0;hb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[Fk(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Rk(d+72|0,f,e,e-1|0);e=x[d+76>>2];x[b>>2]=x[d+72>>2];x[b+4>>2]=e}f=d+72|0;Pd(f);e=x[d+72>>2];Pd(d+56|0);e=Ek(e,x[d+60>>2],b);Pd(f);b:{c:{d:{e:{if((e|0)==x[d+76>>2]){a=x[b+4>>2];e=x[b>>2];f=oc(d+88|0,21502);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Ic(e,a,d)){a=ba(8)|0;x[23604]=0;c=Q(54,d+72|0,10374)|0;b=x[23604];x[23604]=0;if((b|0)==1){break d}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}e=0;f=0;if(!c){break e}c=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[23604]=0;e=Ah(d+56|0,b,a);a=x[23604];x[23604]=0;f:{g:{h:{if((a|0)!=1){x[23604]=0;U(915,d+72|0,17517,e|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}a=0;b=pc(c,d+72|0);x[23604]=0;U(105,b|0,62120,904);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=P()|0;xb(d+72|0);break g}b=P()|0;break f}b=P()|0;a=1}xb(e);if(!a){break c}}ca(c|0);break c}if(x[e+4>>2]!=1){a=ba(8)|0;x[23604]=0;c=Q(54,d+72|0,11459)|0;b=x[23604];x[23604]=0;if((b|0)!=1){a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}c=x[b+4>>2];b=x[b>>2];e=oc(d+48|0,21502);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Ic(b,c,d+24|0)){a=ba(8)|0;x[23604]=0;c=Q(54,d+72|0,10374)|0;b=x[23604];x[23604]=0;if((b|0)!=1){a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}e=oc(d+40|0,10833);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Ic(b,c,d+16|0)){e=x[a+8>>2];f=e>>31;break e}e=oc(d+32|0,8529);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;f=0;if(!Ic(b,c,d+8|0)){break e}e=Ej(y[x[a+32>>2]+140|0]);f=0}hb=d+96|0;lb=f;return e|0}b=P()|0;ca(a|0)}T(b|0)}p()}function eia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=hb-1104|0;hb=d;x[d+1100>>2]=c;i=$A(d+40|0,b);r=fq(i);e=Sb(a);x[23604]=0;a=S(188,b|0)|0;c=x[23604];x[23604]=0;a:{if((c|0)!=1){x[d+8>>2]=a;x[d+36>>2]=85899345;t=d,u=D(x[Fb(d+8|0,d+36|0)>>2],50),x[t+24>>2]=u;a=x[Fb(d+1100|0,d+24|0)>>2];x[23604]=0;R(306,e|0,a|0);a=x[23604];x[23604]=0;if((a|0)!=1){x[23604]=0;h=S(318,d+24|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){x[23604]=0;f=Q(319,d+8|0,8192)|0;a=x[23604];x[23604]=0;b:{if((a|0)!=1){a=x[h>>2];c=0;while(1){if((c|0)!=256){g=zb(a,c);v[g+2|0]=c;w[g>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){s=m&255;e:{while(1){j=n&65535;while(1){x[23604]=0;o=Q(150,i|0,s|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Rc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:g;a=x[h>>2];l=8192;while(1){c=c&65535;a=zb(a,c);l=l-1|0;q=l&65535;t=Gb(x[f>>2],q),u=y[a+2|0],v[t|0]=u;a=x[h>>2];c=z[zb(a,c)>>1];if(c>>>0<8192){continue}break}a=Ib(d,Bb(x[e+4>>2]));c=Ee(Bb(x[f>>2]),q);l=Bb(x[f+4>>2]);a=x[a>>2];x[23604]=0;X(307,e|0,a|0,c|0,l|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=x[f>>2];x[23604]=0;R(320,e|0,Gb(a,q)|0);a=x[23604];x[23604]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(Rc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){continue}break}a=y[Gb(x[f>>2],q)|0];c=zb(x[h>>2],j);w[c>>1]=g;v[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<s)+m|0;n=a;continue}break}break}a=fq(i);x[23604]=0;Q(141,b|0,((a-r|0)+3&-4)+r|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}fc(f);sc(h);yb(i);hb=d+1104|0;return}c=P()|0;fc(f);break b}c=P()|0}sc(h);break a}c=P()|0;break a}c=P()|0;break a}c=P()|0}fc(e);yb(i);T(c|0);p()}function oO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;c=hb-176|0;hb=c;e=x[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=x[a+12>>2]}else{i=x[b>>2];h=bd(i,e+l|0);d=bd(i,e);o=C[h>>3];p=C[h+8>>3];Ui(c+160|0,d,o,p);i=x[c+172>>2];x[h+8>>2]=x[c+168>>2];x[h+12>>2]=i;i=x[c+164>>2];x[h>>2]=x[c+160>>2];x[h+4>>2]=i;Px(bd(x[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){w=D(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=x[a>>2];e=bd(d,j<<1);d=bd(d,j);o=C[d>>3];p=C[d+8>>3];r=C[e>>3];s=C[e+8>>3];ii(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=x[b>>2];d=bd(f,e);g=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=g;g=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=g;g=c+128|0;t=e+h|0;k=bd(f,t);ii(g,r,s,C[k>>3],C[k+8>>3]);u=e+y|0;k=bd(f,u);ii(c+112|0,o,p,C[k>>3],C[k+8>>3]);m=C[c+160>>3];n=C[c+168>>3];v=e+w|0;f=bd(f,v);ii(c+96|0,m,n,C[f>>3],C[f+8>>3]);k=c+80|0;f=c+144|0;m=C[c+112>>3];n=C[c+120>>3];Kk(k,f,m,n);q=c- -64|0;Ui(q,f,m,n);m=C[c+96>>3];n=C[c+104>>3];Kk(c+48|0,g,m,n);f=c+16|0;Uk(f,-0,-1);Ui(c,g,m,n);ii(c+32|0,C[c+16>>3],C[c+24>>3],C[c>>3],C[c+8>>3]);Kk(f,k,C[c+48>>3],C[c+56>>3]);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Ui(f,k,C[c+48>>3],C[c+56>>3]);d=bd(x[b>>2],t);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Kk(f,q,C[c+32>>3],C[c+40>>3]);d=bd(x[b>>2],u);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Ui(f,q,C[c+32>>3],C[c+40>>3]);d=bd(x[b>>2],v);f=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=f;f=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=f;e=e+1|0;continue}}}break}hb=c+176|0}function K3(a,b,c){a=a|0;b=E(b);c=c|0;var d=0,e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=0,n=0,o=0;d=hb-16|0;hb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(q(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=E(E(-1)/E(b*b));if(!(a&2147483647)){break e}e=E(E(b-b)/E(0));if((a|0)<0){break e}a=(q(E(b*E(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=E((a>>>23|0)+c|0);b=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));f=E(b*E(b*E(.5)));g=E(b/E(b+E(2)));h=E(g*g);i=E(h*h);e=b;b=(l(2,(q(E(b-f)),j(2))&-4096),r());f=E(E(g*E(f+E(E(h*E(E(i*E(.2849878668785095))+E(.6666666269302368)))+E(i*E(E(i*E(.24279078841209412))+E(.40000972151756287))))))+E(E(e-b)-f));b=E(E(k*E(.3010292053222656))+E(E(b*E(.434326171875))+E(E(f*E(.434326171875))+E(E(k*E(7.903415166765626e-7))+E(E(f+b)*E(-3168997136526741e-20))))))}e=b}b=E(e*E(2e3));if(!(E(F(b))<E(2147483648))){break c}a=~~b;break b;case 1:a=(D(x[a+24604>>2],100)|0)/128|0;break b;case 2:c=hb-16|0;hb=c;h:{i:{j:{k:{a=y[a+24648|0];if(a>>>0>=6){a=ba(8)|0;x[23604]=0;c=Q(54,c|0,5084)|0;d=x[23604];x[23604]=0;if((d|0)==1){break k}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break i}d=P()|0;xb(c);break j}hb=c+16|0;a=x[(a<<2)+61864>>2];break h}d=P()|0;ca(a|0)}T(d|0)}p()}break b;case 3:x[d>>2]=0;m=x[a+24640>>2];c=hb-80|0;hb=c;a=x[a+24636>>2];x[c+40>>2]=a;x[c>>2]=m;n=c+40|0;o=x[Je(n,c)>>2];l:{if((a|0)==x[Cp(n)+32>>2]){a=-1;if(x[Cp(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}x[d>>2]=a;hb=c+80|0;a=x[d>>2];break b;default:break d}}c=ba(8)|0;x[23604]=0;d=Q(54,d|0,10277)|0;a=x[23604];x[23604]=0;m:{if((a|0)!=1){a=pc(c,d);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(d);break m}a=P()|0;ca(c|0)}T(a|0);p()}a=-2147483648}hb=d+16|0;return a|0}p()}function q5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-96|0;hb=e;f=x[c+4>>2];a:{if(!f){break a}g=x[c>>2];h=y[Fk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Rk(e+72|0,g,f,f-1|0);f=x[e+76>>2];x[c>>2]=x[e+72>>2];x[c+4>>2]=f}f=e+72|0;Pd(f);g=x[e+72>>2];Pd(e+56|0);h=Ek(g,x[e+60>>2],c);Pd(f);f=x[c+4>>2];g=x[c>>2];b:{c:{d:{e:{if((h|0)==x[e+76>>2]){b=oc(e+88|0,21502);h=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=h;if(Ic(g,f,e)){a=ba(8)|0;x[23604]=0;b=Q(54,e+72|0,10374)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}c=P()|0;xb(b);break c}if(d){a=ba(8)|0;b=x[c+4>>2];c=x[c>>2];x[23604]=0;b=Ah(e+56|0,c,b);c=x[23604];x[23604]=0;f:{g:{h:{if((c|0)!=1){x[23604]=0;U(915,e+72|0,17517,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break h}d=0;c=pc(a,e+72|0);x[23604]=0;U(105,c|0,62120,904);c=x[23604];x[23604]=0;if((c|0)!=1){break b}c=P()|0;xb(e+72|0);break g}c=P()|0;break f}c=P()|0;d=1}xb(b);if(!d){break c}}ca(a|0);break c}Kb(a);break e}c=oc(e+48|0,21502);d=x[c+4>>2];x[e+24>>2]=x[c>>2];x[e+28>>2]=d;if(Ic(g,f,e+24|0)){a=ba(8)|0;x[23604]=0;b=Q(54,e+72|0,10374)|0;c=x[23604];x[23604]=0;if((c|0)!=1){a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}c=P()|0;xb(b);break c}c=P()|0;ca(a|0);break c}c=oc(e+40|0,12228);d=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=d;if(Ic(g,f,e+16|0)){i:{switch(x[b+52>>2]){case 0:Xb(a,5562);break e;case 1:Xb(a,11160);break e;case 2:Xb(a,9108);break e;default:break i}}Kb(a);break e}c=oc(e+32|0,11397);d=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=d;if(Ic(g,f,e+8|0)){j:{switch(x[b+56>>2]){case 0:Xb(a,15437);break e;case 1:Xb(a,15442);break e;case 2:Xb(a,12502);break e;case 3:Xb(a,9172);break e;default:break j}}Kb(a);break e}Kb(a)}hb=e+96|0;return}c=P()|0;ca(a|0)}T(c|0)}p()}function y5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-96|0;hb=d;f=1;g=x[c+4>>2];h=y[c+11|0];a:{if(wd(g,h)){break a}e=y[mJ(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+80|0;ir(e,c,0,Qc(g,h)-1|0);Ab(c,e);xb(e)}e=d+80|0;Pd(e);g=x[d+80>>2];Pd(d+72|0);g=lJ(g,x[d+76>>2],c);Pd(e);b:{c:{d:{e:{f:{if((g|0)==x[d+84>>2]){if(ne(c,21502)){a=ba(8)|0;x[23604]=0;b=Q(54,d+80|0,10374)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}c=P()|0;xb(b);break c}if(!f){break f}a=ba(8)|0;x[23604]=0;U(906,d+80|0,17517,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){a=pc(a,d+80|0);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}c=P()|0;xb(d+80|0);break c}c=P()|0;ca(a|0);break c}e=Kb(d+80|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:ve(d- -64|0,c);x[23604]=0;c=x[d+68>>2];x[d+8>>2]=x[d+64>>2];x[d+12>>2]=c;b=W(907,b|0,d+8|0,f|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){x[23604]=0;v[d+72|0]=b;R(908,a|0,d+72|0);a=x[23604];x[23604]=0;if((a|0)!=1){break g}}break i;case 1:ve(d+56|0,c);x[23604]=0;c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;b=XE(b,d+16|0,f);c=lb;f=x[23604];x[23604]=0;if((f|0)!=1){x[23604]=0;x[d+72>>2]=b;x[d+76>>2]=c;R(910,a|0,d+72|0);a=x[23604];x[23604]=0;if((a|0)!=1){break g}}break i;case 2:ve(d+48|0,c);x[23604]=0;c=x[d+52>>2];x[d+24>>2]=x[d+48>>2];x[d+28>>2]=c;i=+qa(911,b|0,d+24|0,f|0);b=x[23604];x[23604]=0;if((b|0)!=1){x[23604]=0;C[d+72>>3]=i;R(912,a|0,d+72|0);a=x[23604];x[23604]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ve(d+40|0,c);x[23604]=0;c=x[d+44>>2];x[d+32>>2]=x[d+40>>2];x[d+36>>2]=c;X(913,a|0,b|0,d+32|0,f|0);a=x[23604];x[23604]=0;if((a|0)!=1){break g}}c=P()|0;xb(e);break c}dd(a,e)}xb(e);break e}Kb(a)}hb=d+96|0;return}c=P()|0;ca(a|0)}T(c|0)}p()}function XZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=hb-1072|0;hb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+960|0;x[a+956>>2]=j;j=kw(j,100,11045,a+16|0);x[a+48>>2]=1071;k=a+48|0;o=le(a+536|0,0,k);x[a+48>>2]=1071;k=le(a+528|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+544|0;f=a+960|0;break d}j=zd();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=Ki(a+956|0,j,11045,a);if((j|0)!=-1){f=x[a+956>>2];Ie(o,f);Ie(k,Ld(j<<2));h=x[k>>2];if(!Lj(h)){break d}}x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)!=1){break a}j=P()|0;break c}Pc(a+520|0,x[d+28>>2]);x[23604]=0;r=S(1083,x[a+520>>2])|0;g=x[23604];x[23604]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[23604]=0;X(1094,r|0,f|0,f+j|0,h|0);g=x[23604];x[23604]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Kb(a+488|0);f=Kb(a+472|0);g=Kb(a+456|0);x[23604]=0;la(1122,c|0,q|0,x[a+520>>2],a+512|0,a+508|0,a+504|0,i|0,f|0,g|0,a+452|0);c=x[23604];x[23604]=0;if((c|0)==1){break i}x[a+36>>2]=1071;c=le(a+40|0,0,a+36|0);m=a+48|0;n=x[a+452>>2];k:{if((n|0)<(j|0)){l=((Eb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Eb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}l=(Eb(x[g+4>>2],y[g+11|0])+Eb(x[f+4>>2],y[f+11|0])|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Ie(c,Ld(l<<2));m=x[c>>2];if(m){break h}x[23604]=0;Z(1072);b=x[23604];x[23604]=0;if((b|0)!=1){break a}break g}j=P()|0;break e}j=P()|0;break f}l=x[d+4>>2];x[23604]=0;oa(1123,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,r|0,q|0,a+512|0,x[a+508>>2],x[a+504>>2],i|0,f|0,g|0,n|0);h=x[23604];x[23604]=0;if((h|0)!=1){x[23604]=0;b=ka(1103,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break b}}}j=P()|0;Mc(c)}Gc(g);Gc(f);xb(i)}$b(a+520|0)}Mc(k);Mc(o);T(j|0);p()}Mc(c);Gc(g);Gc(f);xb(i);$b(a+520|0);Mc(k);Mc(o);hb=a+1072|0;return b|0}p()}function nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;g=hb-48|0;hb=g;y=x[a+16>>2];while(1){if((h|0)!=2){f=h<<3;q=f+(g+24|0)|0;f=a+f|0;x[q+4>>2]=x[f+44>>2];x[q+8>>2]=x[f+48>>2];h=h+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;z=x[a+32>>2];A=x[a+28>>2];B=x[a+72>>2];u=x[a+68>>2];C=u>>31;v=x[a+64>>2];E=v>>31;h=x[a+60>>2];F=h>>31;q=x[a+8>>2];G=x[a+12>>2];while(1){if(d){f=x[g+16>>2];H=((((x[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+y|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;l=w[f+38>>1];r=w[f+36>>1];s=w[f+34>>1];t=w[f+32>>1];i=w[f+30>>1];k=w[f+28>>1];e=w[f+26>>1];f=w[f+24>>1];o=0;p=0;while(1){if((p|0)!=2){j=H+(p<<1)|0;x[(g+8|0)+(p<<2)>>2]=(((((D(w[j+8>>1],s)+D(w[j+4>>1],t)|0)+D(r,w[j+12>>1])|0)+D(l,w[j+16>>1])|0)/2|0)+((((D(w[j-8>>1],e)+D(w[j-12>>1],f)|0)+D(w[j-4>>1],k)|0)+D(w[j>>1],i)|0)/2|0)|0)/16384;p=p+1|0;continue}break}while(1){if((o|0)!=2){s=(g+8|0)+(o<<2)|0;e=x[s>>2];f=(g+24|0)+(o<<3)|0;t=x[f+8>>2];i=x[f+4>>2];x[f+8>>2]=i;r=e<<8;e=r;e=Jia(h,F,e,e>>31);k=lb;j=e;e=Yb(i,-16777216,16776704);e=Jia(v,E,e,e>>31);i=j+e|0;l=lb+k|0;l=e>>>0>i>>>0?l+1|0:l;e=Yb(t,-16777216,16776704);k=Jia(u,C,e,e>>31);i=k+i|0;e=lb+l|0;e=i>>>0<k>>>0?e+1|0:e;k=i+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Nc(k,e,24);x[f+4>>2]=e-(r&B);x[s>>2]=(e|0)/256;o=o+1|0;continue}break}n=n+A|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],n>>12);m=m+z|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],m>>12);Ub(g+16|0,q,G);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;h=0;while(1){if((h|0)!=2){b=h<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];h=h+1|0;continue}break}hb=g+48|0}function $Z(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=hb-464|0;hb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+352|0;x[a+348>>2]=j;j=kw(j,100,11045,a+16|0);x[a+48>>2]=1071;k=a+48|0;o=le(a+232|0,0,k);x[a+48>>2]=1071;k=le(a+224|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+240|0;f=a+352|0;break d}j=zd();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=Ki(a+348|0,j,11045,a);if((j|0)!=-1){f=x[a+348>>2];Ie(o,f);Ie(k,Ld(j));h=x[k>>2];if(!Lj(h)){break d}}x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)!=1){break a}j=P()|0;break c}Pc(a+216|0,x[d+28>>2]);x[23604]=0;r=S(18,x[a+216>>2])|0;g=x[23604];x[23604]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[23604]=0;X(1081,r|0,f|0,f+j|0,h|0);g=x[23604];x[23604]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Kb(a+192|0);f=Kb(a+176|0);g=Kb(a+160|0);x[23604]=0;la(1120,c|0,q|0,x[a+216>>2],a+208|0,a+207|0,a+206|0,i|0,f|0,g|0,a+156|0);c=x[23604];x[23604]=0;if((c|0)==1){break i}x[a+36>>2]=1071;c=le(a+40|0,0,a+36|0);m=a+48|0;n=x[a+156>>2];k:{if((n|0)<(j|0)){l=((Eb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Eb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}l=(Eb(x[g+4>>2],y[g+11|0])+Eb(x[f+4>>2],y[f+11|0])|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Ie(c,Ld(l));m=x[c>>2];if(m){break h}x[23604]=0;Z(1072);b=x[23604];x[23604]=0;if((b|0)!=1){break a}break g}j=P()|0;break e}j=P()|0;break f}l=x[d+4>>2];x[23604]=0;oa(1121,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,r|0,q|0,a+208|0,v[a+207|0],v[a+206|0],i|0,f|0,g|0,n|0);h=x[23604];x[23604]=0;if((h|0)!=1){x[23604]=0;b=ka(14,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break b}}}j=P()|0;Mc(c)}xb(g);xb(f);xb(i)}$b(a+216|0)}Mc(k);Mc(o);T(j|0);p()}Mc(c);xb(g);xb(f);xb(i);$b(a+216|0);Mc(k);Mc(o);hb=a+464|0;return b|0}p()}function nga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=x[a>>2];d=Kt(c,x[a+4>>2]);if(d>>>0<=63){l=hb-32|0;hb=l;g=64-d|0;d=x[Cb(a)>>2];b=x[a+4>>2];a:{if(g>>>0<=(d-b|0)/33>>>0){d=hb-16|0;hb=d;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(g,33);a=x[d+4>>2];c=x[d+8>>2];while(1){if((a|0)==(c|0)){ic(d);hb=d+16|0}else{rA(a);a=a+33|0;x[d+4>>2]=a;continue}break}break a}h=Cb(a);c=l+8|0;d=a;f=Kt(x[a>>2],b)+g|0;b=hb-16|0;hb=b;x[b+12>>2]=f;e=hb-16|0;hb=e;x[e+12>>2]=130150524;x[e+8>>2]=2147483647;a=x[Fb(e+12|0,e+8|0)>>2];hb=e+16|0;b:{if(a>>>0>=f>>>0){e=qS(d);if(e>>>0<a>>>1>>>0){x[b+8>>2]=e<<1;a=x[_c(b+8|0,b+12|0)>>2]}hb=b+16|0;break b}Sc();p()}f=Kt(x[d>>2],x[d+4>>2]);b=hb-16|0;hb=b;Df(c+12|0,h);c:{if(!a){a=0;x[c>>2]=0;e=0;break c}if(a>>>0>=130150525){qi();p()}e=Jc(D(a,33));x[b+12>>2]=a;x[b+8>>2]=e;a=x[b+8>>2];x[c>>2]=a;e=x[b+12>>2]}f=D(f,33)+a|0;x[c+4>>2]=f;x[c+8>>2]=f;n=yc(c),o=D(e,33)+a|0,x[n>>2]=o;hb=b+16|0;b=hb-16|0;hb=b;x[b>>2]=x[c+8>>2];a=x[c+8>>2];x[b+8>>2]=c+8;x[b+4>>2]=a+D(g,33);a=x[b>>2];while(1){if(x[b+4>>2]!=(a|0)){rA(a);a=x[b>>2]+33|0;x[b>>2]=a;continue}break}Hd(b);hb=b+16|0;b=hb-32|0;hb=b;h=Ib(b+24|0,x[d+4>>2]);i=Ib(b+16|0,x[d>>2]);j=Ib(b+8|0,x[c+4>>2]);e=hb-16|0;hb=e;a=hb-16|0;hb=a;g=hb-16|0;hb=g;f=hb-16|0;hb=f;j=x[j>>2];k=x[h>>2];h=x[i>>2];i=k-h|0;k=j+D((i|0)/-33|0,33)|0;m=ah(k,h,i);i=D((i|0)/33|0,33);x[f+12>>2]=m+i;yd(g+8|0,h+i|0,f+12|0);hb=f+16|0;yd(a+8|0,h,Ib(g,j+D((k-j|0)/33|0,33)|0));hb=g+16|0;g=x[a+8>>2];x[a>>2]=x[a+12>>2];yd(e+8|0,g,a);hb=a+16|0;hb=e+16|0;x[c+4>>2]=x[e+12>>2];qc(d,c+4|0);qc(d+4|0,c+8|0);qc(Cb(d),yc(c));x[c>>2]=x[c+4>>2];hb=b+32|0;d=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)!=(d|0)){a=a-33|0;x[c+8>>2]=a;continue}break}a=x[c>>2];if(a){yc(c);Hb(a)}}hb=l+32|0;return}if((d|0)!=64){Id(a,c+2112|0)}}function nR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){v[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];e=y[b+4|0];d=y[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[Wb(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d;case 0:v[a+5|0]=d;v[a+3|0]=c;Hf(a);g=y[b+6|0]==15;break d;case 1:v[a+3|0]=2;h=a,i=ri(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 2:v[a+3|0]=3;h=a,i=ri(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 3:v[a+3|0]=4;h=a,i=ri(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 4:v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d;case 12:v[a+3|0]=13;v[a+5|0]=c>>>1;break d;case 15:if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}v[a+5|0]=d;v[a+3|0]=c;FA(a,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];l:{if(!b){break l}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break l}if(y[a+2|0]){break l}v[a+2|0]=2;v[a+4|0]=b>>>2}hb=f+16|0;return g}function oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;g=hb-48|0;hb=g;z=x[a+16>>2];while(1){if((h|0)!=2){f=h<<3;q=f+(g+24|0)|0;f=a+f|0;x[q+4>>2]=x[f+44>>2];x[q+8>>2]=x[f+48>>2];h=h+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;A=x[a+32>>2];B=x[a+28>>2];C=x[a+72>>2];u=x[a+68>>2];E=u>>31;y=x[a+64>>2];F=y>>31;h=x[a+60>>2];G=h>>31;q=x[a+8>>2];H=x[a+12>>2];while(1){if(d){f=x[g+16>>2];I=(((x[g+20>>2]&2147483647)<<1|f>>>31)&-2)+z|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;l=w[f+38>>1];r=w[f+36>>1];s=w[f+34>>1];t=w[f+32>>1];i=w[f+30>>1];k=w[f+28>>1];e=w[f+26>>1];f=w[f+24>>1];o=0;p=0;while(1){if((p|0)!=2){j=p+I|0;x[(g+8|0)+(p<<2)>>2]=((((D(v[j+4|0],s)+D(v[j+2|0],t)|0)+D(r,v[j+6|0])|0)+D(l,v[j+8|0])<<8>>1)+(((D(v[j-4|0],e)+D(v[j-6|0],f)|0)+D(v[j-2|0],k)|0)+D(v[j|0],i)<<8>>1)|0)/16384;p=p+1|0;continue}break}while(1){if((o|0)!=2){s=(g+8|0)+(o<<2)|0;e=x[s>>2];f=(g+24|0)+(o<<3)|0;t=x[f+8>>2];i=x[f+4>>2];x[f+8>>2]=i;r=e<<8;e=r;e=Jia(h,G,e,e>>31);k=lb;j=e;e=Yb(i,-16777216,16776704);e=Jia(y,F,e,e>>31);i=j+e|0;l=lb+k|0;l=e>>>0>i>>>0?l+1|0:l;e=Yb(t,-16777216,16776704);k=Jia(u,E,e,e>>31);i=k+i|0;e=lb+l|0;e=i>>>0<k>>>0?e+1|0:e;k=i+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Nc(k,e,24);x[f+4>>2]=e-(r&C);x[s>>2]=(e|0)/256;o=o+1|0;continue}break}n=n+B|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],n>>12);m=m+A|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],m>>12);Ub(g+16|0,q,H);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;h=0;while(1){if((h|0)!=2){b=h<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];h=h+1|0;continue}break}hb=g+48|0}function Sf(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=j;i=y[a+79|0]?z[x[a>>2]+3836>>1]:i;c=z[a+20>>1];l=z[a+22>>1];m=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0;g=b;b=z[a+46>>1];f=c+(b?g&b?0:f:f)|0;w[a+20>>1]=f;b=2;h=z[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;f=z[x[a>>2]+3832>>1];h=z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((f>>>z[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=z[a+58>>1];f=c+(f?g&f?0:h:h)|0;w[a+20>>1]=f;if(f<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;f=z[x[a>>2]+3832>>1];k=z[a+24>>1]?D((c^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=z[a+34>>1];f=c+(f?g&f?0:k:k)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=h}i=((c+l|0)+m|0)+i<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:d=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+28768>>1];break e;case 1:d=0;b=z[((b&512?0:b&256?c^255:c)<<1)+28768>>1];break e;case 2:d=0;b=z[((b&256?c^255:c)<<1)+28768>>1];break e;case 3:d=0;b=z[((b&256?0:c)<<1)+28768>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=z[(e<<1)+28768>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+28768>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+i&65535;a=a>>>0>=8191?8191:a;b=0-d^z[((a&255)<<1)+28256>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function d5(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=hb+-64|0;hb=k;a:{b:{c:{j=Fp(1,32);d:{e:{if(!j){a=Ol(ba(4)|0);x[23604]=0;U(105,a|0,92520,25);a=x[23604];x[23604]=0;if((a|0)!=1){break a}i=V(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:881;x[j>>2]=f;c=ag(k+48|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[23604]=0;e=Q(54,k+32|0,e|0)|0;m=x[23604];x[23604]=0;j:{if((m|0)!=1){x[23604]=0;m=Q(892,c|0,e|0)|0;n=x[23604];x[23604]=0;if((n|0)==1){break j}x[23604]=0;R(255,m|0,l|0);l=x[23604];x[23604]=0;if((l|0)==1){break j}break i}i=V(0)|0;break f}i=V(0)|0;xb(e);break f}x[23604]=0;e=Q(54,k+16|0,e|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break g}ms(c,e)}xb(e);i=i+8|0;continue}}x[23604]=0;e=S(765,96)|0;i=x[23604];x[23604]=0;k:{l:{m:{if((i|0)!=1){x[23604]=0;d=Q(893,f|0,d|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break m}x[k>>2]=d;d=x[Mf(k+8|0,k)>>2];x[23604]=0;a=ja(924,e|0,a|0,b|0,d|0,c|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break k}i=V(0)|0;te(k);break l}i=V(0)|0;break f}i=V(0)|0}Hb(e);break f}x[j+28>>2]=a;te(k);x[j+24>>2]=a+8;Sk(c);break d}i=V(0)|0}Sk(c);_(i|0)|0;x[23604]=0;X(887,4934,j|0,g|0,h|0);a=x[23604];x[23604]=0;if((a|0)!=1){x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)!=1){a=x[j+28>>2];if(a){mb[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){Hb(a);x[j+20>>2]=0}Hb(j);j=0;break d}i=V(0)|0;break e}i=V(0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;x[23604]=0;X(887,4934,0,g|0,h|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}$()}hb=k- -64|0;return j|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break b}T(a|0);p()}V(0)|0;Vb()}p()}function LQ(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=hb-16|0;hb=l;g=x[b>>2];i=x[b+4>>2];a:{if((i|0)==(f|0)){b=ec(l+8|0,e,f);j=hb-16|0;hb=j;e=_k(c,d,g,f);x[j+12>>2]=e;b:{if((e|0)<=0){e=x[b>>2];break b}c:{if(!f){f=x[b>>2];break c}h=32-f|0;x[j+8>>2]=h;c=x[rd(j+8|0,j+12|0)>>2];x[j+12>>2]=e-c;d=x[b>>2];e=-1<<f&-1>>>h-c;x[d>>2]=x[d>>2]&(e^-1)|e&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;f=d+(c>>>3&536870908)|0;x[b>>2]=f;g=g+4|0;e=x[j+12>>2]}c=(e|0)/32|0;JQ(g,c,f);d=e-(c<<5)|0;x[j+12>>2]=d;c=c<<2;e=c+x[b>>2]|0;x[b>>2]=e;if((d|0)<=0){break b}d=-1>>>32-d|0;x[e>>2]=x[e>>2]&(d^-1)|d&x[c+g>>2];x[b+4>>2]=x[j+12>>2]}ec(a,e,x[b+4>>2]);hb=j+16|0;break a}j=a;h=ec(l,e,f);f=hb-16|0;hb=f;e=_k(c,d,g,i);x[f+12>>2]=e;d:{if((e|0)<=0){a=x[h+4>>2];break d}e:{if(!i){a=x[h+4>>2];break e}k=32-i|0;x[f+8>>2]=k;c=f+8|0;b=x[rd(c,f+12|0)>>2];x[f+12>>2]=e-b;a=x[h+4>>2];e=x[g>>2];x[f+8>>2]=b;m=32-a|0;x[f+4>>2]=m;d=x[h>>2];n=x[d>>2];c=x[Fb(c,f+4|0)>>2];e=e&(-1<<i&-1>>>k-b);x[d>>2]=(-1<<a&-1>>>m-c^-1)&n|(a>>>0>i>>>0?e<<a-i:e>>>i-a|0);k=a+c|0;a=k&31;x[h+4>>2]=a;d=d+(k>>>3&536870908)|0;x[h>>2]=d;b=b-c|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|e>>>c+i;x[h+4>>2]=b;a=b}g=g+4|0;e=x[f+12>>2]}c=32-a|0;d=-1<<a;i=d^-1;while(1){if((e|0)>=32){b=x[h>>2];e=x[g>>2];x[b>>2]=i&x[b>>2]|e<<a;x[h>>2]=b+4;x[b+4>>2]=d&x[b+4>>2]|e>>>c;e=x[f+12>>2]-32|0;x[f+12>>2]=e;g=g+4|0;continue}break}if((e|0)<=0){break d}i=x[g>>2];x[f+8>>2]=c;g=x[h>>2];b=x[g>>2];k=b;b=x[rd(f+12|0,f+8|0)>>2];e=i&-1>>>32-e;x[g>>2]=k&(d&-1>>>c-b^-1)|e<<a;c=a+b|0;a=c&31;x[h+4>>2]=a;c=g+(c>>>3&536870908)|0;x[h>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break d}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|e>>>b;a=x[f+12>>2];x[h+4>>2]=a}ec(j,x[h>>2],a);hb=f+16|0}hb=l+16|0}function Br(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=hb-128|0;hb=i;x[i+120>>2]=b;k=oG(c,d);x[i+4>>2]=1071;m=nG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ld(k);if(!j){x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;break b}Ie(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{x[23604]=0;h=Q(1073,a|0,i+120|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break f}if(k?h:1){x[23604]=0;b=Q(1073,a|0,i+120|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[23604]=0;n=S(1074,b|0)|0;b=x[23604];x[23604]=0;g:{if((b|0)!=1){if(g){break g}x[23604]=0;n=Q(1075,e|0,n|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break g}}a=P()|0;break b}r=o+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=r;if(!s){continue e}x[23604]=0;S(1076,a|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Eb(x[b+4>>2],y[b+11|0])|0)==(o|0)){break h}v[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}a=P()|0;break b}i:{if(y[h|0]!=1){break i}q=y[uc(b,o)|0];j:{if(g){break j}x[23604]=0;q=Q(1075,e|0,q<<24>>24)|0;t=x[23604];x[23604]=0;if((t|0)!=1){break j}a=P()|0;break b}k:{if((n&255)==(q&255)){s=1;if((Eb(x[b+4>>2],y[b+11|0])|0)!=(r|0)){break i}v[h|0]=2;l=l+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}a=P()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Mc(m);hb=i+128|0;return d|0}a=P()|0}else{n:{if(!wd(x[b+4>>2],y[b+11|0])){v[h|0]=1;break n}v[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Mc(m);T(a|0)}p()}function wY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=hb-16|0;hb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!y[j|0]){break a}j=j+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=x[b+4>>2];x[r+8>>2]=x[b>>2];x[r+12>>2]=i;s=hb-16|0;hb=s;u=Yh(s+8|0,x[a+8>>2]);m=j-c|0;k=0;o=0;n=hb-1040|0;hb=n;i=x[e>>2];x[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=rG(p,n+12|0,l>>>0>q>>>0?q:l,b);if((q|0)==-1){k=-1;l=0;i=x[n+12>>2];break g}t=(n+16|0)!=(p|0)?q:0;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=x[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=Er(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}x[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){x[e>>2]=o}hb=n+1040|0;Xh(u);hb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{x[h>>2]=f;if(x[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=jF(f,c,j-c|0,r+8|0,x[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}x[e>>2]=c;break n}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(k<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break k}c=x[e>>2];if((d|0)==(j|0)){j=d;continue}if(!jF(f,c,1,b,x[a+8>>2])){break m}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!y[j|0]){break b}j=j+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}hb=r+16|0;return a|0}f=x[h>>2];continue}}function yr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=hb-128|0;hb=i;x[i+120>>2]=b;k=oG(c,d);x[i+4>>2]=1071;m=nG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ld(k);if(!j){x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;break b}Ie(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{x[23604]=0;h=Q(1088,a|0,i+120|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break f}if(k?h:1){x[23604]=0;b=Q(1088,a|0,i+120|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[23604]=0;n=S(1089,b|0)|0;b=x[23604];x[23604]=0;g:{if((b|0)!=1){if(g){break g}x[23604]=0;n=Q(1090,e|0,n|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break g}}a=P()|0;break b}r=o+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=r;if(!s){continue e}x[23604]=0;S(1091,a|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Eb(x[b+4>>2],y[b+11|0])|0)==(o|0)){break h}v[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}a=P()|0;break b}i:{if(y[h|0]!=1){break i}q=x[Wi(b,o)>>2];j:{if(g){break j}x[23604]=0;q=Q(1090,e|0,q|0)|0;t=x[23604];x[23604]=0;if((t|0)!=1){break j}a=P()|0;break b}k:{if((n|0)==(q|0)){s=1;if((Eb(x[b+4>>2],y[b+11|0])|0)!=(r|0)){break i}v[h|0]=2;l=l+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}a=P()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Mc(m);hb=i+128|0;return d|0}a=P()|0}else{n:{if(!wd(x[b+4>>2],y[b+11|0])){v[h|0]=1;break n}v[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Mc(m);T(a|0)}p()}function JJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=hb+-64|0;hb=k;a:{b:{c:{d:{e:{f:{j=Fp(1,28);if(!j){a=Ol(ba(4)|0);x[23604]=0;U(105,a|0,92520,25);a=x[23604];x[23604]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:881;x[j>>2]=f;c=ag(k+48|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[23604]=0;e=Q(54,k+32|0,e|0)|0;m=x[23604];x[23604]=0;k:{if((m|0)!=1){x[23604]=0;m=Q(892,c|0,e|0)|0;n=x[23604];x[23604]=0;if((n|0)==1){break k}x[23604]=0;R(255,m|0,l|0);l=x[23604];x[23604]=0;if((l|0)==1){break k}break j}i=V(0)|0;break g}i=V(0)|0;xb(e);break g}x[23604]=0;e=Q(54,k+16|0,e|0)|0;l=x[23604];x[23604]=0;if((l|0)==1){break h}ms(c,e)}xb(e);i=i+8|0;continue}}x[23604]=0;e=S(765,80)|0;i=x[23604];x[23604]=0;l:{m:{n:{if((i|0)!=1){x[23604]=0;d=Q(893,f|0,d|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break n}x[k>>2]=d;d=x[Mf(k+8|0,k)>>2];x[23604]=0;a=ja(898,e|0,a|0,b|0,d|0,c|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break l}i=V(0)|0;te(k);break m}i=V(0)|0;break g}i=V(0)|0}Hb(e);break g}x[j+24>>2]=a;te(k);Sk(c);i=j;break d}i=V(0)|0}Sk(c);_(i|0)|0;x[23604]=0;X(887,14951,j|0,g|0,h|0);a=x[23604];x[23604]=0;if((a|0)!=1){x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){Hb(ls(a))}i=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){Hb(a);x[j+20>>2]=0}Hb(j);break d}i=V(0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)!=1){break e}break b}i=V(0)|0}_(i|0)|0;i=0;x[23604]=0;X(887,14951,0,g|0,h|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}$()}hb=k- -64|0;return i|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break b}T(a|0);p()}V(0)|0;Vb()}p()}function ii(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!li(p)){break a}if(!li(m)){break a}h=$e(b);f=$e(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=li(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=li(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=$e(d);f=$e(e);b:{if(h|f){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=li(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=li(c),w?u:v);break b}if(k){break b}c:{if($e(s)){break c}if($e(t)){break c}if($e(r)){break c}if(!$e(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=li(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=li(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=li(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=li(e),w?u:v)}m=(b*e+d*c)*O;p=(b*d-e*c)*O}Uk(a,p,m)}function eW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb+-64|0;hb=d;xc(b);Fo(a);a:{if(!Th(b,d+56|0)){break a}if(!aD(d+56|0)){break a}if(!c){k=1;break a}if(!Qb(x[b>>2],x[b+8>>2],4)){break a}ov(a);q=d,r=nv(),x[q+32>>2]=r;c=d+32|0;mv(Uh(x[a+4>>2])+32|0,c);Zq(c);j=x[Uh(x[a+4>>2])+32>>2];c=Fg(x[b>>2]);if(c&1){break a}f=c-4|0;Yc(b,f);g=hb-16|0;hb=g;c=g+8|0;$u(c,b);h=y[Gb(c,0)|0];e=y[Gb(c,1)|0];c=y[Gb(c,2)|0];hb=g+16|0;h=c|(e<<8|h<<16);if(!h){break a}x[23604]=0;R(161,j|0,h|0);c=x[23604];x[23604]=0;k=1;if((c|0)==1){a=V(92520)|0;if((ib|0)==(da(92520)|0)){_(a|0)|0;$();k=0;break a}T(a|0);p()}Yc(b,4);m=d+32|0;$C(m,b);l=x[j>>2];e=hb-32|0;hb=e;b=x[d+32>>2];v[e+24|0]=y[b|0];v[e+25|0]=y[b+1|0];v[e+26|0]=y[b+2|0];v[e+27|0]=y[b+3|0];g=Oq(e+8|0);c=b+f|0;x[g+12>>2]=c-4;x[g+8>>2]=b;tj(g,y[c-1|0]);c=h;b:while(1){c:{d:{e:{if(!c){break e}if(tj(g,1)){break d}b=1;while(1){f=tj(g,2);b=f+b|0;if((f|0)==3){continue}break}x[e+4>>2]=b;wc(e+4|0,c);b=0;f=x[e+4>>2];while(1)if((b|0)==(f|0)){if(!c){break e}break d}else{c=c-1|0;q=l+c|0,r=tj(g,8),v[q|0]=r;b=b+1|0;continue}}hb=e+32|0;break c}f=tj(g,2);b=f+2|0;x[e+4>>2]=b;f:{if((f|0)==3){g:{if(!tj(g,1)){b=5;f=7;break g}f=y[Gb(e+24|0,3)|0]}f=tj(g,f);while(1){i=tj(g,3);b=i+b|0;if((i|0)==7){continue}break}x[e+4>>2]=b;break f}f=tj(g,y[Gb(e+24|0,f)|0])}wc(e+4|0,c);b=0;o=x[e+4>>2];while(1){if((b|0)==(o|0)){continue b}i=0;n=c+f|0;if(h>>>0>n>>>0){i=y[l+n|0]}c=c-1|0;v[l+c|0]=i;b=b+1|0;continue}}break}ke(d+16|0,x[j>>2],x[j+4>>2]);Kg(d+24|0,x[d+16>>2],x[d+20>>2]);b=Yd(d+8|0);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;b=Xq(m,x[d+24>>2],x[d+28>>2],d);$c(Uh(x[a+4>>2])+12|0,b);yb(b)}hb=d- -64|0;return k|0}function rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;g=hb-48|0;hb=g;u=x[a+16>>2];while(1){if((h|0)!=2){f=h<<3;o=f+(g+24|0)|0;f=a+f|0;x[o+4>>2]=x[f+44>>2];x[o+8>>2]=x[f+48>>2];h=h+1|0;continue}break}v=x[a+24>>2];y=x[a+20>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;z=x[a+72>>2];s=x[a+68>>2];A=s>>31;t=x[a+64>>2];B=t>>31;h=x[a+60>>2];C=h>>31;o=x[a+8>>2];E=x[a+12>>2];while(1){if(d){f=x[g+16>>2];F=((((x[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+u|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;l=w[f+38>>1];p=w[f+36>>1];q=w[f+34>>1];r=w[f+32>>1];i=w[f+30>>1];k=w[f+28>>1];e=w[f+26>>1];f=w[f+24>>1];m=0;n=0;while(1){if((n|0)!=2){j=F+(n<<1)|0;x[(g+8|0)+(n<<2)>>2]=(((((D(w[j+8>>1],q)+D(w[j+4>>1],r)|0)+D(p,w[j+12>>1])|0)+D(l,w[j+16>>1])|0)/2|0)+((((D(w[j-8>>1],e)+D(w[j-12>>1],f)|0)+D(w[j-4>>1],k)|0)+D(w[j>>1],i)|0)/2|0)|0)/16384;n=n+1|0;continue}break}while(1){if((m|0)!=2){q=(g+8|0)+(m<<2)|0;e=x[q>>2];f=(g+24|0)+(m<<3)|0;r=x[f+8>>2];i=x[f+4>>2];x[f+8>>2]=i;p=e<<8;e=p;e=Jia(h,C,e,e>>31);k=lb;j=e;e=Yb(i,-16777216,16776704);e=Jia(t,B,e,e>>31);i=j+e|0;l=lb+k|0;l=e>>>0>i>>>0?l+1|0:l;e=Yb(r,-16777216,16776704);k=Jia(s,A,e,e>>31);i=k+i|0;e=lb+l|0;e=i>>>0<k>>>0?e+1|0:e;k=i+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Nc(k,e,24);x[f+4>>2]=e-(p&z);x[q>>2]=(e|0)/256;m=m+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],y);x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],v);Ub(g+16|0,o,E);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;h=0;while(1){if((h|0)!=2){b=h<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];h=h+1|0;continue}break}hb=g+48|0}function Eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;g=hb-48|0;hb=g;f=qO(g+32|0,1<<x[b+12>>2]);e=x[f>>2];while(1){c=x[a>>2];if(Eg(c,x[a+4>>2])>>>0>d>>>0){c=Ne(c,d);pO(bd(e,d),C[c>>3]);d=d+1|0;continue}break}oO(b,f);w=g,y=Bb(x[f>>2]),x[w+8>>2]=y;u=Bb(x[f+4>>2]);while(1){d=x[g+8>>2];if(Ob(d,u)){m=C[d+8>>3];k=hb-32|0;hb=k;o(+C[d>>3]);e=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;e=e&2147483647;q=c&2147483647;c=(e|0)==(q|0)&r>>>0<s>>>0|e>>>0<q>>>0;h=c?r:s;c=c?e:q;v=c;l(0,h|0);l(1,c|0);p=+n();t=c>>>20|0;i=p;a:{if((t|0)==2047){break a}c=(e|0)==(q|0)&r>>>0>s>>>0|e>>>0>q>>>0;l(0,(c?r:s)|0);c=c?e:q;l(1,c|0);m=+n();b:{if(!(h|v)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-t|0)>=65){break a}c:{if(c>>>0>=1534){p=p*190109156629516e-225;m=m*190109156629516e-225;i=5.260135901548374e210;break c}i=1;if(t>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=190109156629516e-225}zH(k+24|0,k+16|0,m);zH(k+8|0,k,p);i=i*M(C[k>>3]+C[k+16>>3]+C[k+8>>3]+C[k+24>>3]);break a}i=m}p=i;hb=k+32|0;pO(d,Po(p));Yn(g+8|0);continue}break}nO(b,f);mO(f);h=x[f>>2];e=ch(h,x[f+4>>2])>>>1|0;c=e>>>0<=1?1:e;d=1;while(1){if((c|0)!=(d|0)){Wy(bd(h,d),2);Wy(bd(h,d+e|0),0);d=d+1|0;continue}break}oO(b,f);w=g,y=Bb(x[f>>2]),x[w+24>>2]=y;e=Bb(x[f+4>>2]);while(1){h=x[g+24>>2];if(Ob(h,e)){kO(g+8|0,C[h>>3],C[h+8>>3]);c=x[g+20>>2];x[h+8>>2]=x[g+16>>2];x[h+12>>2]=c;c=x[g+12>>2];x[h>>2]=x[g+8>>2];x[h+4>>2]=c;Yn(g+24|0);continue}break}nO(b,f);mO(f);e=x[a>>2];c=Eg(e,x[a+4>>2]);b=x[f>>2];d=0;while(1){if((c|0)==(d|0)){fl(f);hb=g+48|0}else{a=bd(b,d);w=Ne(e,d),z=C[a>>3],C[w>>3]=z;d=d+1|0;continue}break}}function PL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;a:{b:{f=D(b,872)+a|0;e=x[f+1075080>>2];if(e&131072){i=a+480180|0;e=x[i>>2];j=1;c:{d:{e:{h=x[a+480208>>2];if(h&4096){if(!(e&16777248)){break e}j=!(h&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}i=a+480180|0;j=0;break c}if(!j){break c}Jb(g+8|0,a+1074312|0,21);if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break c}e=f+1075811|0;v[e|0]=y[e|0]+(y[f+1075815|0]<<2)}e=_x(a,y[f+1075814|0],y[f+1075811|0]);f:{if(cj(x[f+1075648>>2])){B[d>>2]=B[d>>2]+E(E(E(D(y[f+1075816|0],e)|0)*E(.05000000074505806))/E(7680));b=f+1075843|0;c=y[b|0];v[b|0]=c&159|64;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break f}v[b|0]=c|96;break f}d=x[a+480208>>2];if((d&2101248)==2101248){break a}h=x[i>>2];if(d&4096?h&67633152:0){break a}e=h&5?(y[f+1075814|0]&3)==1?0-e|0:e:e;l=f+1074992|0;k=a+1074312|0;Jb(g+8|0,k,21);h=x[a+480208>>2];g:{if(Mb(x[x[g+8>>2]>>2],x[g+12>>2])){d=h&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(h&131072){break h}i=x[i>>2];d=8;if((i|0)==1024){break h}d=7;if(i&524304){break h}d=i&16777248?h&4?6:7:6}Jb(g+8|0,k,80);if(!Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break g}d=y[f+1075783|0]==26?d+2|0:d}d=(0-D(y[f+1075816|0],e)|0)/(1<<d)|0;Hj(a,l,c,d,0);e=x[f+1075648>>2];c=Is(a,x[f+1075080>>2],e);if(!c){break f}mb[x[x[c>>2]+88>>2]](c,d,(e?y[e+33|0]:2)<<24>>24,b)}if(!j){break a}Jb(g+8|0,a+1074312|0,21);if(Mb(x[x[g+8>>2]>>2],x[g+12>>2])){break a}a=f+1075811|0;v[a|0]=y[a|0]+y[f+1075815|0];break a}if(!(y[f+1075662|0]&2)){break a}a=Is(a,e,x[f+1075648>>2]);if(!a){break a}mb[x[x[a>>2]+88>>2]](a,0,0,b);break a}a=f+1075811|0;b=y[a|0];if(b&1){x[c>>2]=x[c>>2]+D(y[f+1075816|0],167)}v[a|0]=b+1}hb=g+16|0}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;g=hb-48|0;hb=g;u=x[a+16>>2];while(1){if((h|0)!=2){f=h<<3;o=f+(g+24|0)|0;f=a+f|0;x[o+4>>2]=x[f+44>>2];x[o+8>>2]=x[f+48>>2];h=h+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;A=x[a+72>>2];s=x[a+68>>2];B=s>>31;t=x[a+64>>2];C=t>>31;h=x[a+60>>2];E=h>>31;o=x[a+8>>2];F=x[a+12>>2];while(1){if(d){f=x[g+16>>2];G=(((x[g+20>>2]&2147483647)<<1|f>>>31)&-2)+u|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;l=w[f+38>>1];p=w[f+36>>1];q=w[f+34>>1];r=w[f+32>>1];i=w[f+30>>1];k=w[f+28>>1];e=w[f+26>>1];f=w[f+24>>1];m=0;n=0;while(1){if((n|0)!=2){j=n+G|0;x[(g+8|0)+(n<<2)>>2]=((((D(v[j+4|0],q)+D(v[j+2|0],r)|0)+D(p,v[j+6|0])|0)+D(l,v[j+8|0])<<8>>1)+(((D(v[j-4|0],e)+D(v[j-6|0],f)|0)+D(v[j-2|0],k)|0)+D(v[j|0],i)<<8>>1)|0)/16384;n=n+1|0;continue}break}while(1){if((m|0)!=2){q=(g+8|0)+(m<<2)|0;e=x[q>>2];f=(g+24|0)+(m<<3)|0;r=x[f+8>>2];i=x[f+4>>2];x[f+8>>2]=i;p=e<<8;e=p;e=Jia(h,E,e,e>>31);k=lb;j=e;e=Yb(i,-16777216,16776704);e=Jia(t,C,e,e>>31);i=j+e|0;l=lb+k|0;l=e>>>0>i>>>0?l+1|0:l;e=Yb(r,-16777216,16776704);k=Jia(s,B,e,e>>31);i=k+i|0;e=lb+l|0;e=i>>>0<k>>>0?e+1|0:e;k=i+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Nc(k,e,24);x[f+4>>2]=e-(p&A);x[q>>2]=(e|0)/256;m=m+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],z);x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],y);Ub(g+16|0,o,F);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;h=0;while(1){if((h|0)!=2){b=h<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];h=h+1|0;continue}break}hb=g+48|0}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=hb-48|0;hb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+24|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;o=x[a+8>>2];C=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=b>>>21&2040;h=w[b+40246>>1];i=w[b+40244>>1];e=w[b+40242>>1];g=w[b+40240>>1];b=0;j=0;while(1){if((j|0)!=2){k=p+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+24|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=Jia(s,B,e,e>>31);i=lb;l=e;e=Yb(h,-16777216,16776704);e=Jia(r,A,e,e>>31);h=l+e|0;l=lb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(p,-16777216,16776704);i=Jia(q,z,e,e>>31);h=i+h|0;e=lb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(j&y);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Ub(f+16|0,o,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function ada(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=hb-48|0;hb=g;k=c+484344|0;gg(k,y[b+70|0]|y[b+71|0]<<8);a:{b:{while(1){if((y[b+70|0]|y[b+71|0]<<8)>>>0<=j>>>0){break b}f=x[a+8>>2];e=kg(a);bc(a,1);c:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=Be(a)+1|0;break c}c=Cg(a)}d=Cg(a);Yc(a,e+f|0);Ud(g,a,d);f=kc(g+24|0,g);yb(g);x[23604]=0;c=W(212,k|0,j&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=ac(x[k>>2],j);m=g,n=Bb(x[c>>2]),x[m>>2]=n;l=Bb(x[c+4>>2]);while(1){c=x[g>>2];if(!Ob(c,l)){break d}x[23604]=0;d=S(192,f|0)|0;e=x[23604];x[23604]=0;e:{f:{g:{if((e|0)!=1){e=d<<24>>24;if((e|0)>=0){break g}if(e&1){x[23604]=0;d=S(192,f|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}v[c|0]=d}d=e&255;if(e&2){break f}break e}break a}v[c|0]=e;d=255}x[23604]=0;e=S(192,f|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}v[c+1|0]=e}e=0;if(d&4){x[23604]=0;e=S(192,f|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}}if(d&8){x[23604]=0;h=S(192,f|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break a}v[c+3|0]=h}if(d&16){x[23604]=0;d=S(192,f|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}v[c+5|0]=d}h:{i:{d=y[c|0];if(!d){break i}i=255;if((d|0)==97){break h}if(d>>>0>96){break i}i=d+12|0;break h}i=0}v[c|0]=i;j:{if(y[c+5|0]|y[c+3|0]){Hf(c);break j}v[c+3|0]=0}if(y[c+1|0]==255){v[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){v[c+4|0]=d;v[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;v[c+4|0]=d;e=e-96>>>4|0;v[c+2|0]=y[e+27502|0];if((e|0)!=6){break k}v[c+4|0]=d<<2}dk(g);continue}}yb(f);j=j+1|0;continue}break}break a}hb=g+48|0;return}a=P()|0;yb(f);T(a|0);p()}function V8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-208|0;hb=c;e=Dl(c+104|0,a);x[23604]=0;d=Q(394,c+88|0,44334)|0;a=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[23604]=0;x[c+72>>2]=19924993;x[c+76>>2]=0;U(395,e|0,d|0,c+72|0);a=x[23604];x[23604]=0;if((a|0)==1){break n}Db(d);if(y[e+3|0]&64){break e}x[23604]=0;d=Q(394,c+72|0,13205)|0;a=x[23604];x[23604]=0;if((a|0)==1){break m}x[23604]=0;X(426,e|0,b|0,d|0,824);a=x[23604];x[23604]=0;if((a|0)==1){break l}Db(d);x[c+68>>2]=0;x[c+64>>2]=0;x[23604]=0;d=Q(394,c+48|0,16598)|0;a=x[23604];x[23604]=0;if((a|0)==1){break k}x[23604]=0;U(825,e|0,c+68|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break j}Db(d);x[23604]=0;d=Q(394,c+32|0,16570)|0;a=x[23604];x[23604]=0;if((a|0)==1){break i}x[23604]=0;U(825,e|0,c- -64|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}Db(d);a=x[c+68>>2];d=x[c+64>>2];o:{if(!a|d>>>0<a>>>0){break o}f=x[x[x[x[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}x[b+20>>2]=d;x[b+16>>2]=a}d=Sb(c+16|0);x[23604]=0;f=Q(394,c|0,13982)|0;a=x[23604];x[23604]=0;if((a|0)==1){break d}x[23604]=0;U(826,e|0,d|0,f|0);a=x[23604];x[23604]=0;if((a|0)==1){break g}Db(f);if(tc(x[d>>2],x[d+4>>2])){break f}a=x[b+16>>2];x[23604]=0;R(779,d|0,a|0);a=x[23604];x[23604]=0;if((a|0)!=1){break f}break c}a=P()|0;break a}a=P()|0;Db(d);break a}a=P()|0;break a}a=P()|0;Db(d);break a}a=P()|0;break a}a=P()|0;Db(d);break a}a=P()|0;break a}a=P()|0;Db(d);break a}a=P()|0;Db(f);break b}x[23604]=0;R(827,b|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}sc(d)}Wg(e);hb=c+208|0;return}a=P()|0;break b}a=P()|0}sc(d)}Wg(e);T(a|0);p()}function up(a,b,c,d){var e=E(0),f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=hb-16|0;hb=i;x[i+12>>2]=w[b+780>>1]+y[b+837|0];x[i+8>>2]=w[b+782>>1]+(y[b+838|0]&127);fe(i+12|0,0,127);fe(i+8|0,0,127);j=a+1074312|0;g=Tb(j,1);k=x[i+12>>2];a:{if(g){g=x[i+8>>2];break a}w[b+780>>1]=0;v[b+837|0]=k;g=x[i+8>>2];w[b+782>>1]=0;v[b+838|0]=g}l=D(k,d+256|0);m=(l|0)/256|0;b:{if(!(!Tb(j,36)|g|(l|0)<65024)){m=-1;if(!Tc(y[b+788|0])){break b}if(Qs(y[b+790|0],y[b+791|0])|z[b+786>>1]|!(y[b+851|0]&2)){break b}x[b+88>>2]=x[b+88>>2]&-32769;break b}x[b+88>>2]=x[b+88>>2]|32768;e=me(E(10),E(E(0-g|0)*E(.00937500037252903)));g=hb-16|0;hb=g;h=E(D(k,d+256|0)>>>0);c:{if(x[a+480180>>2]!=33554432){f=E(110);h=E(E(h/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break c}f=E(125);h=E(E(h*E(6))/E(65024))}n=g,o=Ih(E(me(E(2),h)*f)),x[n+12>>2]=o;fe(g+12|0,120,2e4);hb=g+16|0;d=x[a+24620>>2];g=x[g+12>>2];h=E(E(((d|0)<g<<1?d>>>1|0:g)>>>0)*E(6.2831854820251465));d:{if(!(!Tb(j,36)|y[a+480209|0]&128)){f=E(E(A[a+24620>>2])/h);h=E(E(E(e*f)+e)+E(-1));e=E(f*f);break d}f=E(e+e);e=E(h/E(A[a+24620>>2]));B[i+4>>2]=E(E(1)-f)*e;EN(i+4|0,E(2));h=E(E(f-B[i+4>>2])/e);e=E(E(1)/E(e*e))}f=E(e+E(h+E(1)));h=E(E(e+E(e+h))/f);e=E(E(-e)/f);f=E(E(1)/f);e:{if(y[b+845|0]==1){n=b,o=Ih(E(E(E(1)-f)*E(16777216))),x[n+60>>2]=o;n=b,o=Ih(E(h*E(16777216))),x[n+64>>2]=o;n=b,o=Ih(E(e*E(16777216))),x[n+68>>2]=o;a=-1;break e}d=Ih(E(f*E(16777216)));x[b+60>>2]=d;n=b,o=Ih(E(h*E(16777216))),x[n+64>>2]=o;n=b,o=Ih(E(e*E(16777216))),x[n+68>>2]=o;a=0;if(d){break e}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break b}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}hb=i+16|0;return m}function $ea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-48|0;hb=d;a:{b:{c:{d:{e:{f:{if(td(x[a+24>>2])){break f}j=Qc(x[a+8>>2],y[a+15|0]);f=hb-16|0;hb=f;g=f+8|0;x[g>>2]=-1;x[g+4>>2]=-1;x[23604]=0;h=TE(38);c=x[23604];x[23604]=0;b=lb;if((c|0)==1){V(0)|0;Vb();p()}e=hb-16|0;hb=e;c=Jh(e+8|0,Jia(h,b,1e3,0),lb);b=x[c>>2];hb=e+16|0;k=f,l=Gz(b,x[c+4>>2]),x[k>>2]=l;x[f+4>>2]=lb;e=dQ(g,f,Cb(f));x[23604]=0;h=TE(39);c=x[23604];x[23604]=0;b=lb;if((c|0)==1){V(0)|0;Vb();p()}i=a+24|0;g=hb-16|0;hb=g;c=Jh(g+8|0,h,b);b=x[c>>2];hb=g+16|0;k=f,l=Gz(b,x[c+4>>2]),x[k>>2]=l;x[f+4>>2]=lb;b=dQ(e,f,Cb(f));c=x[b>>2];b=x[b+4>>2];hb=f+16|0;if(j){e=Sb(d+32|0);x[23604]=0;x[d+16>>2]=b;R(32,e|0,d+16|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}x[23604]=0;x[d+16>>2]=c;R(32,e|0,d+16|0);b=x[23604];x[23604]=0;if((b|0)==1){break d}h=a+4|0;b=a;a=0;g:{while(1){if(Qc(x[b+8>>2],y[b+15|0])>>>0<=a>>>0){b=Bb(x[e>>2]);a=Bb(x[e+4>>2]);x[23604]=0;c=W(33,d+16|0,b|0,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break g}a=P()|0;break b}c=y[uc(h,a)|0];x[23604]=0;x[d+16>>2]=c;R(32,e|0,d+16|0);c=x[23604];x[23604]=0;if((c|0)!=1){a=a+1|0;continue}break}a=P()|0;break b}x[23604]=0;b=S(34,c|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){x[d+8>>2]=b;a=d+8|0;Hz(i,a);ej(a);gm(c);sc(e);break f}a=P()|0;gm(c);break b}lb=c;x[d+16>>2]=b;x[d+20>>2]=lb;b=Sb(d+32|0);x[23604]=0;U(37,b|0,d+16|0,d+24|0);a=x[23604];x[23604]=0;if((a|0)==1){a=P()|0;sc(b);T(a|0);p()}x[23604]=0;c=S(34,b|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break e}x[d+8>>2]=c;a=d+8|0;Hz(i,a);ej(a);gm(b)}hb=d+48|0;return}a=P()|0;gm(b);break a}a=P()|0;break b}a=P()|0}sc(e)}T(a|0);p()}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0;f=hb-48|0;hb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+24|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];q=x[a+68>>2];A=q>>31;r=x[a+64>>2];B=r>>31;s=x[a+60>>2];C=s>>31;o=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=b>>>21&2040;h=w[b+40246>>1];i=w[b+40244>>1];e=w[b+40242>>1];g=w[b+40240>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+p|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+24|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=Jia(s,C,e,e>>31);i=lb;l=e;e=Yb(h,-16777216,16776704);e=Jia(r,B,e,e>>31);h=l+e|0;l=lb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(p,-16777216,16776704);i=Jia(q,A,e,e>>31);h=i+h|0;e=lb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(j&z);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Ub(f+16|0,o,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function uq(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=y[a|0];switch(d|0){case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break a;case 2:break j;case 13:break k;case 0:break l;case 5:break c;case 9:break e;case 11:break f;case 20:break g;case 4:break h;case 3:break i;default:break d}}v[a|0]=0;break b}e=1;v[a|0]=1;v[f+15|0]=64;h=b,i=y[Wb(b,f+15|0)|0],v[h|0]=i;break a}d=c;c=y[b|0];if(!(c&3|c>>>0>223?d:1)){break a}v[b|0]=(c&252)>>>2;v[a|0]=12;break b}d=c;c=y[b|0];if(!(c&3|c>>>0>223?d:1)){break a}v[b|0]=(c&252)>>>2;v[a|0]=13;break b}d=y[b|0];if(d>>>0<240){while(1){if((e|0)==10){e=0;break a}g=y[e+44272|0];m:{n:{if(c){if(d>>>0<=g>>>0){break n}break m}if((d|0)!=(g|0)){break m}}v[a|0]=11;v[b|0]=e;e=e>>>0<10;break a}e=e+1|0;continue}}v[a|0]=11;v[b|0]=9;break b}o:{p:{q:{d=y[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}v[b|0]=0;v[a|0]=0;break b}v[a|0]=2;v[b|0]=y[b|0]<<2&60|2;break b}c=y[b|0];if(!c){break a}d=c&15;if(!d){v[b|0]=c>>>4;v[a|0]=3;break b}g=c&240;if(!g){v[a|0]=4;break b}if((d|0)==15){v[b|0]=c>>>4;v[a|0]=5;break b}if((g|0)!=240){break a}v[b|0]=d;v[a|0]=6;break b}c=b;b=y[b|0];v[c|0]=(b|0)==255?64:b>>>2|0;v[a|0]=2;break b}if((d|0)!=26){break a}r:{if(c){v[b|0]=0;break r}if(y[b|0]){break a}}v[a|0]=8;break b}s:{if(c){v[f+14|0]=y[b|0]&15;v[f+13|0]=9;c=y[Wb(f+14|0,f+13|0)|0];break s}c=y[b|0];if(c>>>0>15|(c&14)>>>0>9){break a}}v[b|0]=c&15;v[a|0]=8}e=1}hb=f+16|0;return e}function In(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;x[b+88>>2]=x[b+88>>2]|524288;a:{b:{if(!(y[a+480208|0]&8)){if(Tb(a+1074312|0,15)|x[a+480180>>2]==268435456){break b}break a}if(x[a+480180>>2]!=268435456){break a}}c=c?c:y[b+811|0];v[b+812|0]=c;v[b+811|0]=c}if(c){w[b+768>>1]=c}c:{d=x[b+656>>2];d:{if(cj(d)){c=z[b+768>>1];if(!c){break d}e=x[b+856>>2];f=x[a+1074392>>2];h=0-c|0;i=c;c=x[b+708>>2];g=(+(f>>>0)+1)*+(((c|0)<0?h:i)|0)/+A[a+1074416>>2];e:{if(F(g)<2147483648){a=~~g;break e}a=-2147483648}x[b+856>>2]=a;if(y[b+90|0]&16){a=D(x[x[d+44>>2]+36>>2]+1|0,a);x[b+856>>2]=a}a=a-(f?e:0)|0;d=a>>31;e=c>>31;if((e^c)-e>>>0<=(a^d)-d>>>0){if(!c){break d}x[b+708>>2]=0;x[b+852>>2]=c+x[b+852>>2];break c}x[b+708>>2]=c-a;x[b+852>>2]=a+x[b+852>>2];break c}c=1;f:{if(!(v[b+851|0]&1)){break f}d=x[a+480180>>2];if(d&524352){break f}if(x[a+1074416>>2]==1){if(Tb(a+1074312|0,6)){break f}d=x[a+480180>>2]}c=0;if((d|0)!=8){break f}c=(y[a+480208|0]&2)>>>1|0}g:{if(!x[b+700>>2]|!x[b+708>>2]){break g}e=x[a+480180>>2];d=z[b+768>>1];f=(e|0)==268435456&d>>>0>239;if(!((f?y[b+851|0]:c)&1)){break g}c=b+700|0;d=D((e|0)==64?2:4,f?d-240|0:d);d=Xi(a)?d:0-d|0;e=x[b+700>>2];f=x[b+708>>2];if(!(!(y[b+851|0]&16)&(e|0)>=(f|0))){Hj(a,b,c,d,1);d=x[b+708>>2];if((d|0)>=x[b+700>>2]){break g}x[c>>2]=d;break g}if((e|0)<=(f|0)){break g}Hj(a,b,c,0-d|0,1);e=x[b+700>>2];d=x[b+708>>2];h:{if((e|0)<(d|0)){x[c>>2]=d;break h}if((d|0)!=(e|0)){break g}}if(!Tb(a+1074312|0,112)){break g}v[b+851|0]=y[b+851|0]|16}if(x[b+700>>2]!=x[b+708>>2]){break d}if(!Tb(a+1074312|0,25)&x[a+480180>>2]!=1){break d}x[b+708>>2]=0}return}v[b+851|0]=y[b+851|0]|64}function cL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}g=x[b+4>>2];c:{if(!g){while(1){g=oh(d);d=x[d+8>>2];if(!g){continue}break}break c}d=_R(g)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;g=1;break a}x[e+8>>2]=x[d+8>>2];g=0}d:{e:{if(oh(d)){c=x[d+8>>2];x[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=x[d+8>>2];x[c+4>>2]=e}c=x[c>>2]}h=!y[d+12|0];if((b|0)!=(d|0)){f=x[b+8>>2];x[d+8>>2]=f;i=f+(oh(b)?0:4)|0,j=d,x[i>>2]=j;f=x[b>>2];x[d>>2]=f;Nl(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){Nl(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=y[c+12|0];f:{g:{if(!oh(c)){if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Vp(b);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}b=x[c>>2];h:{if(!(y[b+12|0]?0:b)){b=x[c+4>>2];if(y[b+12|0]?0:b){break h}v[c+12|0]=0;i:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break i}a=b}v[a+12|0]=1;return}if(!oh(b)){break g}b=x[b+8>>2]+4|0;break f}a=x[c+4>>2];if(y[a+12|0]?0:a){break h}v[b+12|0]=1;v[c+12|0]=0;Up(c);c=x[c+8>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[x[c+4>>2]+12|0]=1;Vp(a);return}if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Up(b);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];j:{if(y[d+12|0]?0:d){break j}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;return}if(oh(b)){b=x[b+8>>2]+4|0;break f}b=x[b+8>>2];break f}if(y[d+12|0]?0:d){break j}v[b+12|0]=1;v[c+12|0]=0;Vp(c);c=x[c+8>>2];d=x[c>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[d+12|0]=1;Up(a);return}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}function g_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=hb-624|0;hb=a;x[a+608>>2]=c;x[a+616>>2]=b;x[a+16>>2]=1104;h=le(a+200|0,a+208|0,a+16|0);Pc(a+192|0,x[e+28>>2]);x[23604]=0;i=S(1083,x[a+192>>2])|0;b=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+191|0]=0;b=x[e+4>>2];x[23604]=0;b=pa(1113,a+616|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}if(!b){break e}b=y[14515]|y[14516]<<8|(y[14517]<<16|y[14518]<<24);v[a+183|0]=b;v[a+184|0]=b>>>8;v[a+185|0]=b>>>16;v[a+186|0]=b>>>24;b=y[14512]|y[14513]<<8|(y[14514]<<16|y[14515]<<24);x[a+176>>2]=y[14508]|y[14509]<<8|(y[14510]<<16|y[14511]<<24);x[a+180>>2]=b;x[23604]=0;X(1094,i|0,a+176|0,a+186|0,a+128|0);b=x[23604];x[23604]=0;if((b|0)==1){break g}x[a+4>>2]=1071;d=le(a+8|0,0,a+4|0);e=a+16|0;b=x[a+196>>2];c=b-x[h>>2]|0;if((c|0)<393){break f}Ie(d,Ld((c>>2)+2|0));e=x[d>>2];if(e){break f}x[23604]=0;Z(1072);b=x[23604];x[23604]=0;if((b|0)==1){break c}break a}c=P()|0;break b}c=P()|0;break b}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((xG(a+16|0,a)|0)!=1){x[23604]=0;Y(1106,7918);b=x[23604];x[23604]=0;if((b|0)!=1){break a}break c}Mc(d)}else{b=a+128|0;j=e,k=y[(a+176|0)+(aw(b,b+40|0,x[c>>2])-b>>2)|0],v[j|0]=k;e=e+1|0;c=c+4|0;b=x[a+196>>2];continue}break}}x[23604]=0;b=Q(1088,a+616|0,a+608|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+616>>2];$b(a+192|0);Mc(h);hb=a+624|0;return b|0}c=P()|0;break b}c=P()|0;Mc(d)}$b(a+192|0);Mc(h);T(c|0);p()}p()}function Oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb-16|0;hb=g;i=ff(a,c);_d(g,x[a+28>>2]);j=a;a:{if(!i){c=0;if(fd(a,5)){break a}}e=hb-192|0;hb=e;f=Dl(e+88|0,x[a+28>>2]);x[23604]=0;a=Q(394,e+72|0,28175)|0;c=x[23604];x[23604]=0;b:{c:{d:{e:{if((c|0)!=1){x[23604]=0;x[e+8>>2]=19924993;x[e+12>>2]=0;U(395,f|0,a|0,e+8|0);c=x[23604];x[23604]=0;if((c|0)==1){break e}Db(a);if(!(y[f+3|0]&64)){break d}break b}c=P()|0;break c}c=P()|0;Db(a);break c}v[e+71|0]=0;v[e+70|0]=0;x[23604]=0;a=Q(394,e+56|0,9986)|0;c=x[23604];x[23604]=0;f:{g:{h:{i:{if((c|0)!=1){x[23604]=0;U(434,f|0,e+71|0,a|0);c=x[23604];x[23604]=0;if((c|0)==1){break i}Db(a);if(!y[e+71|0]){break b}mf(e+71|0,50);x[23604]=0;a=Q(394,e+40|0,13095)|0;c=x[23604];x[23604]=0;if((c|0)==1){break f}x[23604]=0;U(434,f|0,e+70|0,a|0);c=x[23604];x[23604]=0;if((c|0)==1){break g}Db(a);a=x[b>>2];c=_i(a,x[b+4>>2]);h=y[e+71|0];if(c>>>0<h>>>0){a=hz(e+8|0,x[b+12>>2]);x[23604]=0;U(435,b|0,h|0,a|0);c=x[23604];x[23604]=0;if((c|0)==1){break h}Wk(a);a=x[b>>2]}k=z[fj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=y[e+70|0];n=b,o=_i(x[b>>2],x[b+4>>2])>>>0>a>>>0?a:0,v[n+16|0]=o;break b}Xe(fj(x[b>>2],a),k);l=x[b>>2];x[23604]=0;R(436,e+8|0,c|0);m=x[23604];x[23604]=0;if((m|0)!=1){x[23604]=0;X(437,f|0,fj(l,a)|0,e+8|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break j}c=c+1|0;Db(e+8|0);continue}break}c=P()|0;break c}c=P()|0;Db(e+8|0);break c}c=P()|0;break c}c=P()|0;Db(a);break c}c=P()|0;Wk(a);break c}c=P()|0;Db(a);break c}c=P()|0}Wg(f);T(c|0);p()}Wg(f);hb=e+192|0;c=i}_e(j,c);hb=g+16|0}function n_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=hb-288|0;hb=a;x[a+272>>2]=c;x[a+280>>2]=b;x[a+16>>2]=1104;h=le(a+152|0,a+160|0,a+16|0);Pc(a+144|0,x[e+28>>2]);x[23604]=0;i=S(18,x[a+144>>2])|0;b=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+143|0]=0;b=x[e+4>>2];x[23604]=0;b=pa(1105,a+280|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}if(!b){break e}b=y[14515]|y[14516]<<8|(y[14517]<<16|y[14518]<<24);v[a+135|0]=b;v[a+136|0]=b>>>8;v[a+137|0]=b>>>16;v[a+138|0]=b>>>24;b=y[14512]|y[14513]<<8|(y[14514]<<16|y[14515]<<24);x[a+128>>2]=y[14508]|y[14509]<<8|(y[14510]<<16|y[14511]<<24);x[a+132>>2]=b;x[23604]=0;X(1081,i|0,a+128|0,a+138|0,a+118|0);b=x[23604];x[23604]=0;if((b|0)==1){break g}x[a+4>>2]=1071;d=le(a+8|0,0,a+4|0);e=a+16|0;b=x[a+148>>2];c=b-x[h>>2]|0;if((c|0)<99){break f}Ie(d,Ld(c+2|0));e=x[d>>2];if(e){break f}x[23604]=0;Z(1072);b=x[23604];x[23604]=0;if((b|0)==1){break c}break a}c=P()|0;break b}c=P()|0;break b}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((xG(a+16|0,a)|0)!=1){x[23604]=0;Y(1106,7918);b=x[23604];x[23604]=0;if((b|0)!=1){break a}break c}Mc(d)}else{b=a+118|0;j=e,k=y[((gi(b,b+10|0,y[c|0])-a|0)+a|0)+10|0],v[j|0]=k;e=e+1|0;c=c+1|0;b=x[a+148>>2];continue}break}}x[23604]=0;b=Q(1073,a+280|0,a+272|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+280>>2];$b(a+144|0);Mc(h);hb=a+288|0;return b|0}c=P()|0;break b}c=P()|0;Mc(d)}$b(a+144|0);Mc(h);T(c|0);p()}p()}function VZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;w=d&512;z=h<<2;while(1){if((u|0)==4){if(Eb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=EF(Pj(pd(n),1),uk(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=Hr(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(wd(x[n+4>>2],y[n+11|0])){break a}h=x[Wi(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(wd(x[m+4>>2],y[m+11|0])|!w){break a}B=c,C=EF(pd(m),uk(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}A=x[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!wk(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){h=h-4|0;s=x[h>>2];r=p+4|0;x[c>>2]=r;x[p>>2]=s;q=q-1|0;p=r;continue}break}d:{if(!q){s=0;break d}s=Hr(g,48);p=x[c>>2]}while(1){r=p+4|0;if((q|0)>0){x[p>>2]=s;q=q-1|0;p=r;continue}break}x[c>>2]=r;x[p>>2]=j}e:{if((e|0)==(h|0)){p=Hr(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}if(wd(x[l+4>>2],y[l+11|0])){s=-1}else{s=v[uc(l,0)|0]}q=0;t=0;while(1){if((e|0)!=(h|0)){r=x[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;x[c>>2]=p;x[r>>2]=k;r=0;t=t+1|0;if(Eb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){s=q;break f}s=-1;if(y[uc(l,t)|0]==127){break f}s=v[uc(l,t)|0]}h=h-4|0;q=x[h>>2];x[c>>2]=p+4;x[p>>2]=q;q=r+1|0;continue}break}h=x[c>>2]}zr(A,h)}u=u+1|0;continue}break}}function FP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;m=hb-16|0;hb=m;a:{if((b|0)==(c|0)){break a}x[m+12>>2]=-1953789045;rz(b,c,m+12|0);k=c-b|0;c=k>>2;x[m+8>>2]=c;e=rc(x[a>>2],x[a+4>>2]);d=11;b:{if(k>>>0>2488){break b}d=7;if(k>>>0>268){break b}d=5;if(k>>>0>152){break b}d=3;if(k>>>0>24){break b}d=c-1>>>1|0}i=e+1|0;x[m+4>>2]=i;k=x[_c(m+4|0,m+8|0)>>2];h=c-d>>>1|0;f=(h<<2)+b|0;l=x[f>>2];g=c-1|0;j=D(et(l^(x[b>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=j+l;f=d+h|0;d=(f<<2)+b|0;l=d;n=x[d>>2];d=e+j|0;x[l>>2]=n+d;x[b>>2]=d;d=(h>>>0)%(c>>>0)|0;e=(f>>>0)%(c>>>0)|0;f=x[a>>2];h=1;a=0;while(1)if((h|0)==(i|0)){while(1)if(k>>>0<=i>>>0){i=c+k|0;h=k>>>0>i>>>0?k:i;while(1){if((h|0)==(k|0)){break a}g=g+1|0;g=(c|0)!=(g|0)?g:0;d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;i=D(et(x[(g<<2)+b>>2]+(l+x[j>>2]|0)|0),1566083941);x[f>>2]=i^l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;i=i-a|0;x[f>>2]=i^x[f>>2];x[j>>2]=i;k=k+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;h=D(et(l^(x[j>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=h+l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;h=a+h|0;x[f>>2]=h+x[f>>2];x[j>>2]=h;i=i+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;n=(d<<2)+b|0;o=x[n>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;l=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;j=D(et(o^(x[l>>2]^x[(g<<2)+b>>2])),1664525);x[n>>2]=j+o;j=x[zb(f,h-1|0)>>2]+(a+j|0)|0;e=e+1|0;e=(c|0)!=(e|0)?e:0;n=(e<<2)+b|0;x[n>>2]=j+x[n>>2];x[l>>2]=j;h=h+1|0;continue}}hb=m+16|0}function Cs(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-144|0;hb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}d=x[c+4>>2];if(!d&A[c>>2]>=A[b+4>>2]|d){break h}a=ba(8)|0;x[23604]=0;b=Q(26,a|0,21502)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break g}b=P()|0;ca(a|0);break a}if(!x[b>>2]){a=ba(8)|0;x[23604]=0;b=S(768,a|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break f}b=P()|0;ca(a|0);break a}d=x[b>>2];j=x[b+4>>2];b=hb-16|0;hb=b;Kg(b+8|0,d,j);h=x[b+8>>2];g=f+120|0;xD(g,h,x[b+12>>2]);x[g+12>>2]=0;hb=b+16|0;i:{j:{if(a&2){b=Hm(f+96|0,g);x[23604]=0;b=S(769,b|0)|0;e=x[23604];x[23604]=0;d=1;if((e|0)==1){break i}if((b|0)==1){break j}d=Hm(f+72|0,g);x[23604]=0;e=S(770,d|0)|0;h=x[23604];x[23604]=0;d=1;if((h|0)==1){break e}k=(e|0)==1;if(k){break j}d=Hm(f+48|0,g);x[23604]=0;h=Q(771,d|0,c|0)|0;i=x[23604];x[23604]=0;d=1;if((i|0)==1){break d}l=(h|0)==1;if(l){break j}d=Hm(f+24|0,g);x[23604]=0;i=Q(772,d|0,c|0)|0;m=x[23604];x[23604]=0;d=1;if((m|0)==1){break c}if((i|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(e|0)==-1?-1:b;e=(i|0)==-1?-1:l?b:(h|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31920;while(1){if((b|0)==32436){break k}a=x[b>>2];if(a){d=Hm(f,g);x[23604]=0;a=Q(a|0,d|0,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break b}d=1;if((a|0)==1){break j}e=(a|0)==-1?-1:e}b=b+12|0;continue}}a=j;if(c){d=0;if((e|0)!=-1){break j}d=Uc(x[c>>2],x[c+4>>2])>>>0>a>>>0?-1:0;break j}d=0;if((e|0)!=-1){break j}d=a>>>0>2047?1:-1}hb=f+144|0;return d}b=P()|0;break a}ha(b|0,92812,24);p()}ha(b|0,92708,24);p()}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0}T(b|0);p()}function D3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-48|0;hb=c;g=Sb(a);a:{b:{c:{e=b+36|0;a=x[e>>2];f=x[b+40>>2];d:{if(Ob(a,f)){zc(c+40|0);break d}x[23604]=0;R(975,c+24|0,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}x[23604]=0;a=S(959,c+24|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break c}x[c+40>>2]=a;Of(c+24|0);f=x[b+40>>2];a=x[b+36>>2]}if(!Ob(a,f)){e=x[c+40>>2];a=x[e>>2]}f=x[e+4>>2];x[23604]=0;R(167,g|0,vn(a,f)|0);a=x[23604];x[23604]=0;e:{if((a|0)!=1){i=c,j=Bb(x[e>>2]),x[i+16>>2]=j;f=Bb(x[e+4>>2]);f:{g:{h:{i:{j:{k:{while(1){a=x[c+16>>2];if(!Ob(a,f)){Dk(c+40|0);hb=c+48|0;return}e=y[a+16|0];d=x[x[b+24>>2]+484360>>2];x[23604]=0;e=fj(d,e);R(976,c|0,e|0);d=x[23604];x[23604]=0;if((d|0)!=1){x[23604]=0;R(962,c+24|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break k}x[23604]=0;R(169,g|0,c+24|0);d=x[23604];x[23604]=0;if((d|0)==1){break j}xb(c+24|0);xb(c);d=Bi(x[g+4>>2]);l:{if(!wd(x[d+4>>2],y[d+11|0])){break l}d=y[a+12|0];x[23604]=0;d=Q(295,e|0,d|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break f}if(!d){break l}d=x[b+24>>2];h=x[d+1298404>>2];a=z[cc(x[e>>2],x[a+12>>2])>>1];e=x[d+484344>>2];x[23604]=0;R(969,c|0,ac(e,a)|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}x[23604]=0;X(221,c+24|0,0,h|0,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break g}a=c+24|0;Ab(Bi(x[g+4>>2]),a);xb(a);xb(c)}yI(c+16|0);continue}break}a=P()|0;break e}a=P()|0;break i}a=P()|0;xb(c+24|0)}xb(c);break e}a=P()|0;break e}a=P()|0;xb(c);break e}a=P()|0;break e}a=P()|0}Dk(c+40|0);break a}a=P()|0;Of(c+24|0);break a}a=P()|0}Vd(g);T(a|0);p()}function uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(x[a+4>>2]!=x[Cb(a)>>2]){c=hb-16|0;hb=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+56;a=x[c+4>>2];x[23604]=0;R(607,a|0,b|0);a=x[23604];x[23604]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;ic(c);hb=c+16|0;break a}a=P()|0;ic(c);T(a|0);p()}return}h=hb-32|0;hb=h;i=Cb(a);f=h+8|0;g=Gp(x[a>>2],x[a+4>>2])+1|0;d=hb-16|0;hb=d;x[d+12>>2]=g;e=hb-16|0;hb=e;x[e+12>>2]=76695844;x[e+8>>2]=2147483647;c=x[Fb(e+12|0,e+8|0)>>2];hb=e+16|0;b:{if(c>>>0>=g>>>0){e=PQ(a);if(e>>>0<c>>>1>>>0){x[d+8>>2]=e<<1;c=x[_c(d+8|0,d+12|0)>>2]}hb=d+16|0;break b}Sc();p()}g=Gp(x[a>>2],x[a+4>>2]);d=hb-16|0;hb=d;Df(f+12|0,i);c:{if(!c){c=0;x[f>>2]=0;e=0;break c}if(c>>>0>=76695845){qi();p()}e=Jc(D(c,56));x[d+12>>2]=c;x[d+8>>2]=e;c=x[d+8>>2];x[f>>2]=c;e=x[d+12>>2]}g=D(g,56)+c|0;x[f+4>>2]=g;x[f+8>>2]=g;j=yc(f),k=D(e,56)+c|0,x[j>>2]=k;hb=d+16|0;c=x[f+8>>2];x[23604]=0;R(607,c|0,b|0);b=x[23604];x[23604]=0;d:{if((b|0)!=1){x[f+8>>2]=x[f+8>>2]+56;e=hb-32|0;hb=e;b=Ib(e+24|0,x[a+4>>2]);d=Ib(e+16|0,x[a>>2]);g=Ib(e+8|0,x[f+4>>2]);c=x[b>>2];i=x[d>>2];d=hb-16|0;hb=d;x[d>>2]=x[g>>2];x[d+8>>2]=c;while(1){b=x[d>>2];if(og(c,i)){g=Mz(b);b=Mz(c);c=Qj(g,b);Qj(c+12|0,b+12|0);Kz(c+24|0,b+24|0);w[c+52>>1]=z[b+52>>1];g=x[b+48>>2];x[c+44>>2]=x[b+44>>2];x[c+48>>2]=g;g=x[b+40>>2];x[c+36>>2]=x[b+36>>2];x[c+40>>2]=g;b=NQ(d+8|0);NQ(d);c=x[b>>2];continue}break}hb=d+16|0;x[f+4>>2]=b;qc(a,f+4|0);qc(a+4|0,f+8|0);qc(Cb(a),yc(f));x[f>>2]=x[f+4>>2];hb=e+32|0;OQ(f);hb=h+32|0;break d}a=P()|0;OQ(f);T(a|0);p()}}function kK(a){var b=E(0),c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,k=0,l=E(0),m=0,n=E(0);c=hb-16|0;hb=c;e=a+4208|0;b=nx(B[zb(e,2)>>2]);f=x[a+16>>2]+24620|0;B[c+12>>2]=b/E(A[f>>2]);x[c+8>>2]=1056964608;b=dp(E(B[Pl(c+12|0,c+8|0)>>2]*E(6.2831854820251465)));b=E(M(E(E(E(b+b)+E(3))/E(5))));B[a+4236>>2]=b;B[a+4240>>2]=M(E(E(1)-E(b*b)));b=E(E(B[zb(e,1)>>2]*E(29))+E(2));a:{if(b<E(4294967296)&b>=E(0)){i=~~b>>>0;break a}i=0}v[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}v[a+4273|0]=k;l=me(E(10),E(E(E(B[a+4208>>2]*E(60))+E(-60))/E(20)));m=c,n=E(nx(B[zb(e,3)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;g=B[Pl(c+12|0,c+8|0)>>2];m=c,n=E(nx(B[zb(e,4)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;b=E(E(B[Pl(c+12|0,c+8|0)>>2]*E(6.2831854820251465))*E(.5));f=hb-16|0;hb=f;e=(q(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=pn(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=pn(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=pn(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=pn(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=pn(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=E(b-b);break b}d=Cw(b,f+8|0);b=pn(C[f+8>>3],d&1)}hb=f+16|0;b=E(E(E(1)-b)/E(b+E(1)));B[a+4268>>2]=b;g=dp(E(g*E(6.2831854820251465)));B[a+4264>>2]=-g;B[a+4260>>2]=E(E(l*E(M(E(E(1)-E(g*g)))))*E(M(E(E(1)-E(b*b)))))*B[(i<<2)+46096>>2];hb=c+16|0}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=hb-48|0;hb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+24|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+24|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=Jia(q,B,e,e>>31);i=lb;k=e;e=Yb(h,-16777216,16776704);e=Jia(p,A,e,e>>31);h=k+e|0;k=lb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=Jia(o,z,e,e>>31);h=i+h|0;e=lb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Ub(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function ZZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;z=d&512;while(1){if((u|0)==4){if(Eb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=FF(Ee(pd(n),1),pf(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];p=ll(g,32);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 3:if(wd(x[n+4>>2],y[n+11|0])){break a}p=y[uc(n,0)|0];q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 2:if(wd(x[m+4>>2],y[m+11|0])|!z){break a}B=c,C=FF(pd(m),pf(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}p=x[g+8>>2];A=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!fh(p,64,v[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){r=r-1|0;q=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=q;p=p-1|0;continue}break}if(p){q=ll(g,48)}else{q=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((p|0)>0){v[s|0]=q;p=p-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){p=ll(g,48);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break d}if(wd(x[l+4>>2],y[l+11|0])){q=-1}else{q=v[uc(l,0)|0]}p=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=x[c>>2];x[c>>2]=q+1;v[q|0]=k;s=0;t=t+1|0;if(Eb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){q=p;break e}q=-1;if(y[uc(l,t)|0]==127){break e}q=v[uc(l,t)|0]}r=r-1|0;p=y[r|0];w=x[c>>2];x[c>>2]=w+1;v[w|0]=p;p=s+1|0;continue}}Cl(A,x[c>>2])}u=u+1|0;continue}break}}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=hb-48|0;hb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+24|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];w=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+24|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=Jia(q,B,e,e>>31);i=lb;k=e;e=Yb(h,-16777216,16776704);e=Jia(p,A,e,e>>31);h=k+e|0;k=lb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=Jia(o,z,e,e>>31);h=i+h|0;e=lb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+w|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Ub(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function zda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;k=f,l=Sj(b),x[k>>2]=l;e=hb-16|0;hb=e;h=a;c=Sd(a);a:{if(c){g=jc(h);while(1){a=c;c=a+14|0;if(gt(b,c)){g=a;c=x[a>>2];if(c){continue}break a}if(!gt(c,b)){break a}g=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=jc(h);g=a}x[e+12>>2]=a;b=x[g>>2];if(!b){i=hb-16|0;hb=i;a=jc(h);j=ph(e,Jc(48),qh(i+8|0,a));a=x[j>>2];b=x[f>>2];c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+14|0]=d;v[a+15|0]=d>>>8;v[a+16|0]=d>>>16;v[a+17|0]=d>>>24;v[a+18|0]=c;v[a+19|0]=c>>>8;v[a+20|0]=c>>>16;v[a+21|0]=c>>>24;c=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);d=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[a+38|0]=d;v[a+39|0]=d>>>8;v[a+40|0]=d>>>16;v[a+41|0]=d>>>24;v[a+42|0]=c;v[a+43|0]=c>>>8;v[a+44|0]=c>>>16;v[a+45|0]=c>>>24;c=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);d=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[a+30|0]=d;v[a+31|0]=d>>>8;v[a+32|0]=d>>>16;v[a+33|0]=d>>>24;v[a+34|0]=c;v[a+35|0]=c>>>8;v[a+36|0]=c>>>16;v[a+37|0]=c>>>24;c=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a+22|0]=b;v[a+23|0]=b>>>8;v[a+24|0]=b>>>16;v[a+25|0]=b>>>24;v[a+26|0]=c;v[a+27|0]=c>>>8;v[a+28|0]=c>>>16;v[a+29|0]=c>>>24;w[a+46>>1]=0;k=jc(j),l=1,v[k+4|0]=l;hb=i+16|0;Vg(h,x[e+12>>2],g,x[e>>2]);b=Wd(e);cl(e);d=1}Ug(f+8|0,x[Ib(e,b)>>2],d);hb=e+16|0;a=Op(x[f+8>>2]);hb=f+16|0;return a+32|0}function Xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=hb-48|0;hb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+24|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;m=x[a+8>>2];A=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=b>>>21&2040;h=w[b+40246>>1];i=w[b+40244>>1];e=w[b+40242>>1];g=w[b+40240>>1];b=0;j=0;while(1){if((j|0)!=2){k=n+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+24|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=Jia(q,z,e,e>>31);i=lb;l=e;e=Yb(h,-16777216,16776704);e=Jia(p,y,e,e>>31);h=l+e|0;l=lb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(n,-16777216,16776704);i=Jia(o,v,e,e>>31);h=i+h|0;e=lb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Ub(f+16|0,m,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function $aa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=hb-16|0;hb=g;t=x[a+16>>2];u=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);o=x[a+128>>2];a:{if(!o){m=x[a+8>>2];p=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];n=0;break a}b=x[a+12>>2];p=b;m=x[a+8>>2];q=Xf(m,b,o);r=lb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];Cf(h,e,Ze(m,p,d),lb);n=lb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{s=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;n=n-1|0;b=n;q=b?q:0;r=b?r:0;h=(e<<1)+t|0;b=o;while(1)if((b|0)<=0){Ub(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Jd(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Tf(i,u);v=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=Jia(e,e>>31,b,b>>31);z=lb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(s,-16777216,16776704);j=Jia(j,A,b,b>>31);e=e+j|0;b=lb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Jia(e,e>>31,f,f>>31);f=j+e|0;b=lb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Nc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Ub(g,m,p);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue b}else{Kd(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Jd(i,4);Ub(g+8|0,q,r);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;hb=g+16|0}function Fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;g=hb-16|0;hb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];e=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+44>>2];l=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=l;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;while(1){l=b;if(d){b=Yb(l,-16777216,16776704);m=Jia(r,A,b,b>>31);n=lb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+t|0;b=(b>>>16&65520)+p|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=Jia(b,b>>31,s,B);m=b+m|0;o=lb+n|0;o=b>>>0>m>>>0?o+1|0:o;b=Yb(e,-16777216,16776704);e=Jia(q,z,b,b>>31);n=e+m|0;b=lb+o|0;b=e>>>0>n>>>0?b+1|0:b;e=n+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Nc(e,b,24);b=(e|0)/256|0;k=k+v|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+u|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Ub(g+8|0,i,h);b=e-(f&y)|0;c=c+8|0;d=d-1|0;e=l;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=e;x[a+44>>2]=l;x[a+24>>2]=j>>12;hb=g+16|0}function yJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);e=hb-48|0;hb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=x[a+24>>2];if((b|0)==x[d+24604>>2]){break d}a=e+8|0;vc(a,d+24604|0,40);x[e+8>>2]=b;by(d,a);break d;case 2:f=x[a+24>>2];d=f+24664|0;b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;d=f+24656|0;b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;b=x[f+24652>>2];x[e+8>>2]=x[f+24648>>2];x[e+12>>2]=b;d=hb-16|0;hb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ba(8)|0;x[23604]=0;b=Q(54,d|0,10689)|0;a=x[23604];x[23604]=0;i:{if((a|0)!=1){a=pc(c,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break g}a=P()|0;xb(b);break i}a=P()|0;ca(c|0)}T(a|0);p()}hb=d+16|0;break f}p()}v[e+8|0]=b;a=x[a+24>>2];if(!bx(e+8|0,a+24648|0)){break d}$x(a,e+8|0);break d;case 3:f=e+8|0;d=x[a+24>>2];vc(f,d+24604|0,40);b=hb-48|0;hb=b;j:{if((c|0)==-1){es(f,x[Cp(b+8|0)+32>>2]);zp(f,x[Cp(b+8|0)+36>>2]);break j}if((c|0)<=0){es(f,0);zp(f,0);break j}a=D(c,1e3);es(f,a);zp(f,a)}hb=b+48|0;if(x[d+24636>>2]==x[e+40>>2]&x[d+24640>>2]==x[e+44>>2]){break d}by(d,e+8|0);break d;default:d=ba(8)|0;x[23604]=0;c=Q(54,e+8|0,10277)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(d,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}b=P()|0;xb(c);break b;case 0:break e}}g=a,h=me(E(10),E(E(E(c|0)*E(.0010000000474974513))*E(.5))),B[g+48>>2]=h}hb=e+48|0;return}b=P()|0;ca(d|0)}T(b|0)}p()}function $V(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-48|0;hb=f;g=hi(b)^-1;a:{if(rc(x[d>>2],x[d+4>>2])>>>0<=g>>>0){As(a);break a}hi(b);if((y[c+4|0]|y[c+5|0]<<8)>>>0>=60){bc(b,4)}j=f,k=hi(b),x[j+44>>2]=k;bc(b,4);h=hi(b);i=hi(b);if(!((h|0)>0&(i|0)>36)){As(a);break a}if($p(Zd(x[e>>2],x[zb(x[d>>2],g)>>2]),12972)){As(a);break a}kv(f,b,i,h);d=kc(f+24|0,f);yb(f);b=x[d>>2];x[23604]=0;b=S(164,b|0)|0;e=x[23604];x[23604]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){x[23604]=0;S(173,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break d}break b}b=y[c+4|0]|y[c+5|0]<<8;if(b>>>0<=39){x[23604]=0;Q(174,d|0,8)|0;b=x[23604];x[23604]=0;if((b|0)==1){break b}b=y[c+4|0]|y[c+5|0]<<8}if((b&65535)>>>0<=59){x[23604]=0;Q(174,d|0,16)|0;b=x[23604];x[23604]=0;if((b|0)==1){break b}}x[23604]=0;S(175,d|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break b}e:{f:{b=y[c+4|0]|y[c+5|0]<<8;g:{if(b>>>0>=120){x[23604]=0;S(175,d|0)|0;c=x[23604];x[23604]=0;b=8;break g}h:{if(b>>>0>=100){x[23604]=0;Q(174,d|0,4)|0;b=x[23604];x[23604]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}x[23604]=0;S(175,d|0)|0;c=x[23604];x[23604]=0;b=4}if((c|0)==1){break b}x[23604]=0;Q(174,d|0,b|0)|0;break e}x[23604]=0;S(175,d|0)|0}b=x[23604];x[23604]=0;if((b|0)==1){break b}x[23604]=0;b=S(175,d|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break c}x[23604]=0;U(176,f|0,d|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}j=kc(a,f),k=x[f+44>>2],x[j+20>>2]=k;yb(f)}yb(d);break a}}a=P()|0;yb(d);T(a|0);p()}hb=f+48|0}function Yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;f=hb-48|0;hb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+24|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=b>>>21&2040;h=w[b+40246>>1];i=w[b+40244>>1];e=w[b+40242>>1];g=w[b+40240>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+n|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+24|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=Jia(q,A,e,e>>31);i=lb;l=e;e=Yb(h,-16777216,16776704);e=Jia(p,z,e,e>>31);h=l+e|0;l=lb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(n,-16777216,16776704);i=Jia(o,y,e,e>>31);h=i+h|0;e=lb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Ub(f+16|0,m,B);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function Hj(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=hb-16|0;hb=i;a:{if(!d){break a}g=x[c>>2];if(!g){break a}b:{c:{d:{e:{f=x[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=D(d,20)+g|0;break d}f=((D(d,36318)|0)/1024|0)+g|0;break d}f:{g:{h:{if(y[a+480208|0]&16){if((f|0)==4){break h}f=d>>31;x[i+12>>2]=(f^d)-f;wc(i+12|0,1020);h=x[i+12>>2];f=c;i:{if((d|0)>0){if(h>>>0<=15){h=x[(h<<2)+(Tb(a+1074312|0,7)?37536:37600)>>2];break i}h=x[(h&-4)+(Tb(a+1074312|0,7)?37664:38688)>>2];break i}if(h>>>0<=15){h=x[(h<<2)+(Tb(a+1074312|0,7)?37600:37536)>>2];break i}h=x[(h&-4)+(Tb(a+1074312|0,7)?38688:37664)>>2]}j=Jia(h,h>>31,g,g>>31);h=lb;j=j+32768|0;h=j>>>0<32768?h+1|0:h;k=f;f=Ec(Kia(j,h,65536,0),lb);x[k>>2]=f;if((f|0)!=(g|0)){break c}f=Tb(a+1074312|0,7);g=x[c>>2];if(!(f^(d|0)>0)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}if(Tb(a+1074312|0,7)){break g}g=x[c>>2]}f=g-d|0;break d}f=x[c>>2];if((d|0)<0){g=Jia(f,0,14317456,0);h=lb;f=Jia(f,0,0-d|0,0);d=lb;f=f+14317456|0;d=f>>>0<14317456?d+1|0:d;f=TM(Mia(g,h,f,d),lb);break d}d=Jia(f,f>>31,d,0);g=lb;if((g|0)>=0&d>>>0>=14317456|(g|0)>0){if(e){x[c>>2]=2147483647;break a}x[c>>2]=0;x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248;break a}d=TM(Mia(Jia(f,0,14317456,0),lb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),lb);x[c>>2]=d;if((d|0)>0){break a}break b}f=d+g|0}x[c>>2]=f}if((f|0)>0){break a}}x[c>>2]=1;if(x[a+480180>>2]!=2|e){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}hb=i+16|0}function vV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-32|0;hb=f;xc(c);while(1){a:{if(!Qb(x[c>>2],x[c+8>>2],3)){break a}d=f+24|0;Cq(d,c);i=hd(d);h=Re(d);d=y[f+24|0];if(d>>>0>=A[a+12>>2]){break a}g=cd(x[a>>2],x[x[a+48>>2]+12>>2],d,b);d=y[i|0];if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;continue}v[g|0]=d+1;if(y[h|0]==255){continue}v[g+2|0]=1;v[g+4|0]=y[h|0];continue}b:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;continue;case 0:continue;default:break b}}e=v[h|0];v[f+23|0]=e;h=0;d=d&127;if(d>>>0<=23){h=y[d+26576|0]}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{j=y[i|0];switch((j&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break d}}if((e|0)>=0){break f}d=0-e&15;break e}v[f+16|0]=64;e=y[Wb(f+23|0,f+16|0)|0];if(y[g+2|0]>1){break d}v[g+4|0]=e;v[g+2|0]=1;continue}d=3;if((e|0)>=0){break c}d=0-e&127;break e}if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e}if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;v[f+23|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+23|0]=e;break c}d=e&15|-48;break e}d=e&15|-64;break e}d=164;if((e|0)==100){break e}x[f+16>>2]=e- -64;x[f+12>>2]=0;x[f+8>>2]=128;e=x[nj(f+16|0,f+12|0,f+8|0)>>2];if(!y[g+3|0]){break d}o:{switch(y[g+2|0]){case 0:case 2:break o;default:continue}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;v[f+23|0]=e}d=h;if(!d){continue}}v[g+5|0]=e;v[g+3|0]=d;continue}break}hb=f+32|0}function Gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;g=hb-16|0;hb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}s=x[a+16>>2];b=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];l=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=l;t=x[a+32>>2];u=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;while(1){l=e;if(d){e=Yb(l,-16777216,16776704);f=Jia(p,A,e,e>>31);e=lb;b=Yb(b,-16777216,16776704);b=Jia(o,z,b,b>>31);f=b+f|0;e=lb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];m=f;f=x[g+12>>2]+s|0;b=(b>>>16&65520)+n|0;r=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=r;f=Jia(b,b>>31,q,B);m=m+f|0;b=lb+e|0;b=f>>>0>m>>>0?b+1|0:b;e=m+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Nc(e,b,24);b=(e|0)/256|0;k=k+u|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+t|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,b);Ub(g+8|0,i,h);e=e-(y&r)|0;c=c+8|0;d=d-1|0;b=l;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=b;x[a+44>>2]=l;x[a+24>>2]=j>>12;hb=g+16|0}function taa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0;f=hb+-64|0;hb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}t=l-4|0;o=D(b,e);u=o-8|0;h:while(1){b=x[c+8>>2];h=x[c>>2];x[23604]=0;b=W(142,h|0,b|0,l|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}x[23604]=0;U(176,f+16|0,c|0,d|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}b=f+16|0;h=kc(f+40|0,b);yb(b);x[23604]=0;R(510,b|0,h|0);b=x[23604];x[23604]=0;if((b|0)==1){break e}z=xe(f+16|0);q=x[f+16>>2];A=q-4|0;k=0;while(1){if((e|0)==(k|0)){Lc(f+16|0);yb(h);n=(q-l<<1)+n|0;continue h}x[23604]=0;g=S(503,h|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){x[23604]=0;b=S(192,h|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break f}x[f+8>>2]=b;fe(f+8|0,0,89);x[23604]=0;Q(174,h|0,1)|0;b=x[23604];x[23604]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>u>>>0){break j}m=0;if(b>>>0>A>>>0){break j}while(1)if((m|0)==8){b=b+t|0;continue i}else{r=x[f+8>>2];i=y[b+z|0];s=m&1;i=s?i>>>4|0:i&15;x[f+8>>2]=r+v[(i&7)+30632|0];B=g;g=w[(r<<1)+30640>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;x[f+12>>2]=B+(i>>>0<8?g:0-g|0);fe(f+8|0,0,88);fe(f+12|0,-32768,32767);g=x[f+12>>2];w[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+s|0;continue}}break}k=k+1|0;continue}break}break}break f}yb(c);hb=f- -64|0;return}b=P()|0;Lc(f+16|0);break d}b=P()|0}yb(h);break a}b=P()|0;break a}b=P()|0}yb(c);T(b|0);p()}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=hb-48|0;hb=f;s=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+24|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+32>>2];u=x[a+28>>2];v=x[a+72>>2];n=x[a+68>>2];y=n>>31;o=x[a+64>>2];z=o>>31;p=x[a+60>>2];A=p>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+s|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){q=(f+8|0)+(b<<2)|0;e=x[q>>2];g=(f+24|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;r=e<<8;e=r;e=Jia(p,A,e,e>>31);i=lb;j=e;e=Yb(h,-16777216,16776704);e=Jia(o,z,e,e>>31);h=j+e|0;j=lb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=Jia(n,y,e,e>>31);h=i+h|0;e=lb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(r&v);x[q>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+u|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+t|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Ub(f+16|0,m,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=hb-16|0;hb=g;t=x[a+16>>2];u=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);o=x[a+128>>2];a:{if(!o){m=x[a+8>>2];p=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];n=0;break a}b=x[a+12>>2];p=b;m=x[a+8>>2];q=Xf(m,b,o);r=lb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];Cf(h,e,Ze(m,p,d),lb);n=lb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{s=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;n=n-1|0;b=n;q=b?q:0;r=b?r:0;h=e+t|0;b=o;while(1)if((b|0)<=0){Ub(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(i,v[h+x[g+12>>2]|0]<<6);Jd(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Tf(i,u);w=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=Jia(e,e>>31,b,b>>31);z=lb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(s,-16777216,16776704);j=Jia(j,A,b,b>>31);e=e+j|0;b=lb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Jia(e,e>>31,f,f>>31);f=j+e|0;b=lb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Nc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Ub(g,m,p);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue b}else{Kd(i,v[h+x[g+12>>2]|0]<<6);Jd(i,4);Ub(g+8|0,q,r);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;hb=g+16|0}function Qg(a,b,c,d,e){var f=0,g=0;if(!b){f=hb-16|0;hb=f;a:{if((d|0)==189){v[a+3843|0]=e>>>7;v[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}g=D(b>>>0<3?b:b+6|0,44)+a|0;c=d&e;zp(g+16|0,c?g+148|0:0);v[g+188|0]=!c;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}b=D(d&256?b+9|0:b,44)+a|0;x[f+8>>2]=b+16;a=x[b+52>>2];x[f+12>>2]=a;g=a?2:1;b:{a=d&240;if((a|0)!=160){if((a|0)==192){break b}if((a|0)!=176){break a}c=e&3;a=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}e=x[(f+8|0)+(b<<2)>>2];DO(x[e>>2],d);DO(x[e+4>>2],d);w[e+22>>1]=a;az(e);FO(e);v[e+21|0]=c;az(e);FO(e);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=x[(f+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|e&255;az(a);b=b+1|0;continue}}v[b+58|0]=(e&32)>>>5;v[b+57|0]=(e&16)>>>4;a=e>>>1&7;w[b+46>>1]=a?9-a|0:0;w[b+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}c=a;a=v[(d&31)+29360|0];c=(c+D(d&256?a+18|0:a,84)|0)+808|0;c:{switch(b-32>>>5|0){case 0:v[c+79|0]=e>>>7;v[c+80|0]=(e&64)>>>6;v[c+78|0]=(e&32)>>>5;v[c+77|0]=(e&16)>>>4;Sn(c);w[c+14>>1]=z[((e&15)<<1)+29392>>1];break a;case 1:w[c+68>>1]=y[(e>>>6|0)+21487|0];EO(c);w[c+22>>1]=(e&63)<<2;break a;case 2:w[c+24>>1]=e>>>4;Sn(c);w[c+26>>1]=e&15;Sn(c);break a;case 3:a=e>>>4|0;w[c+28>>1]=a>>>0>=15?496:a<<4;w[c+30>>1]=e&15;Sn(c);break a;case 6:break c;default:break a}}w[c+12>>1]=e&7}hb=f+16|0;return}mb[x[x[b>>2]>>2]](b,c,d,e)}function e$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=hb-288|0;hb=a;x[a+272>>2]=c;x[a+280>>2]=b;dw(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Kb(a+208|0);b=Oc(d);x[23604]=0;R(59,d|0,b|0);b=x[23604];x[23604]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=y[a+238|0]<<24>>24;i=y[a+239|0]<<24>>24;while(1){d:{x[23604]=0;b=Q(1073,a+280|0,a+272|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(b){break c}g=x[a+204>>2];b=Eb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23604]=0;R(59,d|0,b<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+204>>2]=b+c}x[23604]=0;b=S(1074,x[a+280>>2])|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(cw(b,a+23|0,a+22|0,c,a+204|0,i,h,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[23604]=0;S(1076,a+280|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+228>>2],y[a+235|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}bG(a,c,x[a+204>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;rf(a+224|0,a+32|0,x[a+28>>2],e);x[23604]=0;b=Q(1073,a+280|0,a+272|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+280>>2];xb(d);xb(a+224|0);hb=a+288|0;break a}}b=P()|0;xb(d);xb(a+224|0);T(b|0);p()}return b|0}function FU(){var a=0,b=0,c=0;if(!y[467568]){a=hb-16|0;hb=a;fs(467216);x[116816]=-1;x[116814]=467272;x[116812]=93608;x[116804]=77596;v[467268]=0;b=a+8|0;Pc(b,x[116805]);c=x[x[116804]+8>>2];x[23604]=0;R(c|0,467216,b|0);b=x[23604];x[23604]=0;a:{if((b|0)!=1){$b(a+8|0);hb=a+16|0;break a}b=P()|0;$b(a+8|0);yn(467216);T(b|0);p()}ks(466544);x[116636]=77728;x[116634]=77708;x[116635]=0;xn(466544,467216);NG(467280,93752,467328);nw(466712,467280);NG(467336,93456,467384);nw(466880,467336);nw(467048,x[x[x[116720]-12>>2]+466904>>2]);MG(x[x[116634]-12>>2]+466536|0);CI(x[x[116720]-12>>2]+466880|0);MG(x[x[116720]-12>>2]+466880|0);a=hb-16|0;hb=a;ZG(467392);x[116860]=-1;x[116858]=467448;x[116856]=93608;x[116848]=77988;v[467444]=0;b=a+8|0;Pc(b,x[116849]);c=x[x[116848]+8>>2];x[23604]=0;R(c|0,467392,b|0);b=x[23604];x[23604]=0;b:{if((b|0)!=1){$b(a+8|0);hb=a+16|0;break b}b=P()|0;$b(a+8|0);Kr(467392);T(b|0);p()}JG(466632);x[116658]=78120;x[116656]=78100;x[116657]=0;xn(466632,467392);LG(467456,93752,467504);mw(466796,467456);LG(467512,93456,467560);mw(466964,467512);mw(467132,x[x[x[116741]-12>>2]+466988>>2]);KG(x[x[116656]-12>>2]+466624|0);CI(x[x[116741]-12>>2]+466964|0);KG(x[x[116741]-12>>2]+466964|0);v[467568]=1}a=hb-16|0;hb=a;c:{if(bb(a+12|0,a+8|0)|0){break c}b=Ld((x[a+12>>2]<<2)+4|0);x[116894]=b;if(!b){break c}b=Ld(x[a+8>>2]);if(b){c=x[116894];x[c+(x[a+12>>2]<<2)>>2]=0;if(!(ab(c|0,b|0)|0)){break c}}x[116894]=0}hb=a+16|0;x[116090]=42;x[116108]=467668}function JM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=hb-16|0;hb=c;d=D(b,872)+a|0;a:{if(x[d+1075080>>2]&134218752){break a}g=x[d+1075648>>2];if(!Ij(g)|y[g+15|0]&2){break a}e=sl(a,a+1074376|0,b,2,1);if((e-1&255)>>>0>249){break a}h=x[(D(e,160)+a|0)+906140>>2];if(!h){break a}e=y[d+1075780|0];b:{if(y[d+1075782|0]==1){v[c+8|0]=64;f=y[Wb(d+1075784|0,c+8|0)|0];break b}f=255;if(y[d+1075783|0]!=13){break b}v[c+8|0]=64;f=y[Wb(d+1075785|0,c+8|0)|0]}i=a+1074312|0;Jb(c+8|0,i,2);if(Mb(x[x[c+8>>2]>>2],x[c+12>>2])){if(e){if(Tc(e)){e=y[Gb(g+108|0,e-1|0)|0]}Wl(a,b,e,z[d+1075680>>1]);break a}if((f|0)==255){break a}mb[x[x[h>>2]+76>>2]](h,39,f,b);break a}j=x[g+4>>2];if(e){k=y[g+35|0]?j<<2:x[d+1075680>>2];d=w[d+1075768>>1];Jb(c+8|0,i,28);l=c,m=(Mb(x[x[c+8>>2]>>2],x[c+12>>2])?d<<2:d)+k|0,x[l+4>>2]=m;fe(c+4|0,0,256);d=a;if(Tc(e)){a=y[Gb(g+108|0,e-1|0)|0]}else{a=e}Wl(d,b,a&255,z[c+4>>1])}d=y[g+35|0];Jb(c+8|0,i,101);if(Mb(x[x[c+8>>2]>>2],x[c+12>>2])){a=(e|0)!=0}else{a=Tc(e)}if(a^1|(d|0)!=1?(a|(f|0)==255)==1:0){break a}c:{switch(y[g+36|0]){case 1:a=x[h+20>>2];if((f|0)!=255){Js(a,E(E(E(f<<1)/E(-127))+E(1)));break a}Js(a,E(E(E(j<<1>>>0)/E(-127))+E(1)));break a;case 0:break c;default:break a}}if((f|0)!=255){v[c+8|0]=127;v[c+4|0]=f<<1;m=h,n=7,o=y[Wb(c+8|0,c+4|0)|0],p=b,l=x[x[h>>2]+76>>2],mb[l](m|0,n|0,o|0,p|0);break a}x[c+8>>2]=127;x[c+4>>2]=j<<1;p=h,o=7,n=y[Fb(c+8|0,c+4|0)|0],m=b,l=x[x[h>>2]+76>>2],mb[l](p|0,o|0,n|0,m|0)}hb=c+16|0}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=hb-48|0;hb=f;s=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+24|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+32>>2];u=x[a+28>>2];w=x[a+72>>2];n=x[a+68>>2];y=n>>31;o=x[a+64>>2];z=o>>31;p=x[a+60>>2];A=p>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+s|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){q=(f+8|0)+(b<<2)|0;e=x[q>>2];g=(f+24|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;r=e<<8;e=r;e=Jia(p,A,e,e>>31);i=lb;j=e;e=Yb(h,-16777216,16776704);e=Jia(o,z,e,e>>31);h=j+e|0;j=lb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=Jia(n,y,e,e>>31);h=i+h|0;e=lb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(r&w);x[q>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+u|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+t|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Ub(f+16|0,m,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function r9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-112|0;hb=c;ij(c+88|0,b,1413829443);x[23604]=0;b=S(164,x[c+88>>2])|0;d=x[23604];x[23604]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){x[23604]=0;U(724,c- -64|0,a+140|0,1413894985);a=x[23604];x[23604]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){x[23604]=0;a=Q(801,c- -64|0,13470)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}b=28591;if(a){b=Kb(c+48|0);x[23604]=0;a=S(188,c- -64|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break m}x[23604]=0;U(253,c- -64|0,b|0,a|0);a=x[23604];x[23604]=0;if((a|0)==1){break m}x[23604]=0;d=Q(53,c+16|0,b|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break l}x[23604]=0;Y(802,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break k}x[23604]=0;U(803,c+32|0,d|0,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break j}a=c+32|0;e=Ab(b,a);xb(a);xb(c);xb(d);x[23604]=0;U(11,a|0,2,e|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}x[23604]=0;a=S(694,c+32|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break g}xb(c+32|0);xb(e);b=a-1>>>0<19398657?1252:28591}yb(c- -64|0);break a}a=P()|0;break b}a=P()|0;break f}a=P()|0;break f}a=P()|0;break i}a=P()|0;xb(c)}xb(d);break f}a=P()|0;break f}a=P()|0;xb(c+32|0)}xb(b);break d}a=P()|0}yb(c- -64|0);break b}x[23604]=0;a=W(142,x[c+88>>2],x[c+96>>2],2)|0;b=x[23604];x[23604]=0;if((b|0)==1){break c}b=28591;if(!a){break a}x[23604]=0;b=S(180,c+88|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;break b}a=P()|0}yb(c+88|0);T(a|0);p()}yb(c+88|0);hb=c+112|0;return b|0}function X_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=hb-384|0;hb=a;x[a+368>>2]=c;x[a+376>>2]=b;$v(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Kb(a+200|0);b=Oc(d);x[23604]=0;R(59,d|0,b|0);b=x[23604];x[23604]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+196>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=x[a+232>>2];i=x[a+236>>2];while(1){d:{x[23604]=0;b=Q(1088,a+376|0,a+368|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(b){break c}g=x[a+196>>2];b=Eb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23604]=0;R(59,d|0,b<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+196>>2]=b+c}x[23604]=0;b=S(1089,x[a+376>>2])|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(_v(b,a+23|0,a+22|0,c,a+196|0,i,h,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[23604]=0;S(1091,a+376|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+220>>2],y[a+227|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}bG(a,c,x[a+196>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;rf(a+216|0,a+32|0,x[a+28>>2],e);x[23604]=0;b=Q(1088,a+376|0,a+368|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+376>>2];xb(d);xb(a+216|0);hb=a+384|0;break a}}b=P()|0;xb(d);xb(a+216|0);T(b|0);p()}return b|0}function QI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{b:{switch(e<<31|e-2>>>1){case 4:px(a,b,c,d);return;case 0:e=32-G(d|1)|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<17){while(1){b=b-1|0;v[b|0]=y[(d&1)+15205|0];e=d>>>0>1;d=d>>>1|0;if(e){continue}break}}else{b=b-4|0;e=x[(d<<2&60)+25632>>2];v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;d=d>>>4|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 3:e=(34-G(d|1)|0)/3|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<65){while(1){b=b-1|0;v[b|0]=y[(d&7)+14626|0];e=d>>>0>7;d=d>>>3|0;if(e){continue}break}}else{b=b-2|0;e=z[(d<<1&126)+25696>>1];v[b|0]=e;v[b+1|0]=e>>>8;d=d>>>6|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 7:e=61;f=(35-G(d|1)|0)/4|0;c:{if((f|0)>(c-b|0)){break c}c=b+f|0;b=c;while(1){if(d>>>0>=257){b=b-2|0;e=z[(d<<1&510)+25824>>1];v[b|0]=e;v[b+1|0]=e>>>8;d=d>>>8|0;continue}break}e=0;if(!f){break c}while(1){b=b-1|0;v[b|0]=y[(d&15)+11028|0];f=d>>>0>15;d=d>>>4|0;if(f){continue}break}}x[a+4>>2]=e;break a;default:break b}}g=d;i=D(e,e);k=D(i,e);j=D(i,i);d:{while(1){h=f|1;if(e>>>0>g>>>0){break d}h=f|2;if(g>>>0<i>>>0){break d}h=f|3;if(g>>>0<k>>>0){break d}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){x[a+4>>2]=61;break a}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;v[c|0]=y[(d-D(b,e)|0)+4856|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}x[a+4>>2]=0;x[a>>2]=f;return}x[a>>2]=c}function W_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;h=Kb(a+208|0);Pc(a+16|0,x[d+28>>2]);x[23604]=0;b=S(1083,x[a+16>>2])|0;c=x[23604];x[23604]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[23604]=0;X(1094,b|0,82128,82154,a+224|0);b=x[23604];x[23604]=0;if((b|0)==1){break d}$b(a+16|0);c=Kb(a+192|0);b=Oc(c);x[23604]=0;R(59,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break b}b=uc(c,0);x[a+188>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[23604]=0;d=Q(1088,a+344|0,a+336|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break e}if(d){break c}g=x[a+188>>2];d=Eb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[23604]=0;R(59,c|0,d<<1);b=x[23604];x[23604]=0;if((b|0)==1){break b}b=Oc(c);x[23604]=0;R(59,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break b}b=uc(c,0);x[a+188>>2]=d+b}x[23604]=0;d=S(1089,x[a+344>>2])|0;g=x[23604];x[23604]=0;if((g|0)==1){break e}if(bn(d,16,b,a+188|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+224|0)){break c}x[23604]=0;S(1091,a+344|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;$b(a+16|0);break a}x[23604]=0;R(59,c|0,x[a+188>>2]-b|0);b=x[23604];x[23604]=0;f:{if((b|0)==1){break f}b=Pb(c);d=zd();x[a>>2]=f;if((aG(b,d,a)|0)!=1){x[e>>2]=4}x[23604]=0;b=Q(1088,a+344|0,a+336|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(c);xb(h);hb=a+352|0;return b|0}}b=P()|0;xb(c)}xb(h);T(b|0);p()}function d$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;h=Kb(a+208|0);Pc(a+16|0,x[d+28>>2]);x[23604]=0;b=S(18,x[a+16>>2])|0;c=x[23604];x[23604]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[23604]=0;X(1081,b|0,82128,82154,a+224|0);b=x[23604];x[23604]=0;if((b|0)==1){break d}$b(a+16|0);c=Kb(a+192|0);b=Oc(c);x[23604]=0;R(59,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break b}b=uc(c,0);x[a+188>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[23604]=0;d=Q(1073,a+264|0,a+256|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break e}if(d){break c}g=x[a+188>>2];d=Eb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[23604]=0;R(59,c|0,d<<1);b=x[23604];x[23604]=0;if((b|0)==1){break b}b=Oc(c);x[23604]=0;R(59,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break b}b=uc(c,0);x[a+188>>2]=d+b}x[23604]=0;d=S(1074,x[a+264>>2])|0;g=x[23604];x[23604]=0;if((g|0)==1){break e}if(en(d,16,b,a+188|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+224|0)){break c}x[23604]=0;S(1076,a+264|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;$b(a+16|0);break a}x[23604]=0;R(59,c|0,x[a+188>>2]-b|0);b=x[23604];x[23604]=0;f:{if((b|0)==1){break f}b=Pb(c);d=zd();x[a>>2]=f;if((aG(b,d,a)|0)!=1){x[e>>2]=4}x[23604]=0;b=Q(1073,a+264|0,a+256|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(c);xb(h);hb=a+272|0;return b|0}}b=P()|0;xb(c)}xb(h);T(b|0);p()}function Zy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{e=255;b:{c:{g=a+62|0;d=y[Gb(g,b)|0];if((d|0)==255){break c}if(v[Gb(g,b)|0]>=0){break b}f=a+26|0;d=d&127;if(z[cc(f,d)>>1]!=65535){if(z[cc(f,d)>>1]!=(b|0)){break c}}j=cc(f,d),k=b,w[j>>1]=k;j=Gb(g,b),k=d,v[j|0]=k;break b}i=a+8|0;f=a+26|0;d=0;h=255;while(1){if((d|0)!=18){if(z[cc(f,d)>>1]==65535){j=cc(f,d),k=b,w[j>>1]=k;j=Gb(g,b),k=d,v[j|0]=k;break b}else{if(!(y[Gb(i,d)|0]&32)){h=v[Gb(g,z[cc(f,d)>>1])|0]<0?d:h;e=d}d=d+1|0;continue}}break}if((e&255)!=255){d=(h&255)==255?e:h;e=d&255;j=Gb(g,z[cc(f,e)>>1]),k=255,v[j|0]=k;j=cc(f,e),k=b,w[j>>1]=k;j=Gb(g,b),k=d,v[j|0]=k}d=Vk(a,b)}g=d&255;if((g|0)==255){break a}if(Lj(x[a>>2])){break a}e=Zd(a+318|0,g);d=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[e+8|0]=d;v[e+9|0]=d>>>8;v[e+10|0]=d>>>16;v[e+11|0]=d>>>24;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;v[e+4|0]=d;v[e+5|0]=d>>>8;v[e+6|0]=d>>>16;v[e+7|0]=d>>>24;f=zO(g);h=f+3|0;d=0;while(1){if((d|0)==2){Qg(x[a>>2],x[a+4>>2],b,Ys(g)|192,y[Gb(c,10)|0])}else{e=d?h:f;Qg(x[a>>2],x[a+4>>2],b,e|32,y[Gb(c,d)|0]);Qg(x[a>>2],x[a+4>>2],b,e|64,y[Gb(c,d+2|0)|0]);Qg(x[a>>2],x[a+4>>2],b,e|96,y[Gb(c,d+4|0)|0]);Qg(x[a>>2],x[a+4>>2],b,e|128,y[Gb(c,d+6|0)|0]);Qg(x[a>>2],x[a+4>>2],b,e|224,y[Gb(c,d+8|0)|0]);d=d+1|0;continue}break}}}function Rca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-48|0;hb=e;w[e+46>>1]=254;c=$i(a);f=e+32|0;x[f>>2]=0;x[f+4>>2]=0;zc(f+8|0);if(c){Hp(f,c);ZB(f,c)}a:{b:{while(1){c:{if((b|0)==(c|0)){if(!(d&65535)){break a}c=Bb(x[a>>2]);d=Bb(x[a+4>>2]);b=hb-16|0;hb=b;c=Uz(c,d,z[e+46>>1]);x[b+8>>2]=c;if(Ob(c,d)){x[b>>2]=c;while(1){c=x[Pe(b)>>2];if(Ob(c,d)){c=z[c>>1];if((c|0)==z[e+46>>1]){continue}w[x[b+8>>2]>>1]=c;Pe(b+8|0);continue}break}c=x[b+8>>2]}hb=b+16|0;b=Ib(e+24|0,c);c=x[Ib(e+16|0,Bb(x[a+4>>2]))>>2];d=hb-16|0;hb=d;g=x[b>>2];b=x[a>>2];b=(no(g,Bb(b))<<1)+b|0;if(Ob(g,c)){Id(a,Vt(b+(no(c,g)<<1)|0,x[a+4>>2],b))}Ib(d+8|0,b);hb=d+16|0;k=e,l=Bb(x[a>>2]),x[k+8>>2]=l;d=Bb(x[a+4>>2]);break c}k=cc(x[f>>2],b),l=b-d|0,w[k>>1]=l;g=x[a+4>>2];h=x[a>>2];x[23604]=0;g=W(700,h|0,g|0,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break b}b=b+1|0;d=(z[g>>1]==254)+d|0;continue}break}while(1){b=x[e+8>>2];if(Ob(b,d)){d:{c=x[a+24>>2];g=x[c+484344>>2];b=z[b>>1];if(!pe(g,x[c+484348>>2],b)){break d}b=ac(g,b);k=e,l=Bb(x[b>>2]),x[k>>2]=l;g=Bb(x[b+4>>2]);h=x[f+4>>2];c=x[f>>2];while(1){b=x[e>>2];if(!Ob(b,g)){break d}e:{if(y[b+3|0]!=12){break e}j=Kc(c,h);i=y[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=y[cc(c,i)|0],v[k+5|0]=l}dk(e);continue}}Pe(e+8|0);continue}else{b=x[f>>2];d=Kc(b,x[f+4>>2]);c=z[a+28>>1];if(d>>>0<=c>>>0){break a}k=a,l=z[cc(b,c)>>1],w[k+28>>1]=l;break a}}}a=P()|0;nd(f);T(a|0);p()}nd(f);hb=e+48|0}function D_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=hb-432|0;hb=i;x[i+424>>2]=37;x[i+428>>2]=0;l=wr(i+424|1,13740,x[c+4>>2]);x[i+380>>2]=i+384;a=zd();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=Ig(i+384|0,30,a,i+424|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=Ig(i+384|0,30,a,i+424|0,i+80|0)}x[i+128>>2]=1071;k=le(i+368|0,0,i+128|0);b=i+384|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=zd();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=Ki(i+380|0,a,i+424|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=Ki(i+380|0,a,i+424|0,i+32|0)}if((j|0)==-1){x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)==1){break d}break e}a=x[i+380>>2];Ie(k,a)}f=a+j|0;g=Li(a,f,x[c+4>>2]);x[i+116>>2]=1071;e=le(i+120|0,0,i+116|0);g:{h:{if((i+384|0)==(a|0)){j=i+128|0;break h}j=Ld(j<<3);if(!j){x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)!=1){break e}a=P()|0;break g}Ie(e,j);b=a}a=i+104|0;Pc(a,x[c+28>>2]);x[23604]=0;ia(1102,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[23604];x[23604]=0;i:{if((a|0)!=1){$b(i+104|0);x[23604]=0;a=ka(1103,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break i}Mc(e);Mc(k);hb=i+432|0;break b}a=P()|0;$b(i+104|0);break g}a=P()|0}Mc(e);break c}p()}a=P()|0}Mc(k);T(a|0);p()}return a|0}function N_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=hb-256|0;hb=i;x[i+248>>2]=37;x[i+252>>2]=0;l=wr(i+248|1,13740,x[c+4>>2]);x[i+204>>2]=i+208;a=zd();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=Ig(i+208|0,30,a,i+248|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=Ig(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=1071;k=le(i+192|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=zd();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=Ki(i+204|0,a,i+248|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=Ki(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)==1){break d}break e}a=x[i+204>>2];Ie(k,a)}f=a+j|0;g=Li(a,f,x[c+4>>2]);x[i+116>>2]=1071;e=le(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Ld(j<<1);if(!j){x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)!=1){break e}a=P()|0;break g}Ie(e,j);b=a}a=i+104|0;Pc(a,x[c+28>>2]);x[23604]=0;ia(1097,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[23604];x[23604]=0;i:{if((a|0)!=1){$b(i+104|0);x[23604]=0;a=ka(14,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break i}Mc(e);Mc(k);hb=i+256|0;break b}a=P()|0;$b(i+104|0);break g}a=P()|0}Mc(e);break c}p()}a=P()|0}Mc(k);T(a|0);p()}return a|0}function lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=hb-48|0;hb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+24|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+24|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=Jia(o,z,e,e>>31);i=lb;k=e;e=Yb(h,-16777216,16776704);e=Jia(n,y,e,e>>31);h=k+e|0;k=lb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=Jia(m,v,e,e>>31);h=i+h|0;e=lb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Ub(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;f=hb-48|0;hb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+24|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];w=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+24|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=Jia(o,z,e,e>>31);i=lb;k=e;e=Yb(h,-16777216,16776704);e=Jia(n,y,e,e>>31);h=k+e|0;k=lb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(j,-16777216,16776704);i=Jia(m,w,e,e>>31);h=i+h|0;e=lb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Ub(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=hb-16|0;hb=g;r=x[a+16>>2];s=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){k=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];l=0;break a}b=x[a+12>>2];n=b;k=x[a+8>>2];o=Xf(k,b,m);p=lb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];Cf(h,e,Ze(k,n,d),lb);l=lb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;l=l-1|0;b=l;o=b?o:0;p=b?p:0;h=(e<<1)+r|0;b=m;while(1)if((b|0)<=0){Ub(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Jd(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Tf(i,s);v=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=Jia(e,e>>31,b,b>>31);y=lb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Yb(q,-16777216,16776704);j=Jia(j,z,b,b>>31);e=e+j|0;b=lb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Jia(e,e>>31,f,f>>31);f=j+e|0;b=lb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Nc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Ub(g,k,n);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue b}else{Kd(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Jd(i,4);Ub(g+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;hb=g+16|0}function C2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(A[a+4>>2]<A[Cb(a)>>2]){c=hb-16|0;hb=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+24;tJ(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+24;ic(c);hb=c+16|0;return}l=hb-32|0;hb=l;g=Cb(a);c=l+8|0;f=vn(x[a>>2],x[a+4>>2])+1|0;d=hb-16|0;hb=d;x[d+12>>2]=f;a:{e=bh(178956970);if(f>>>0<=e>>>0){f=zt(a);if(f>>>0<e>>>1>>>0){x[d+8>>2]=f<<1;e=x[_c(d+8|0,d+12|0)>>2]}hb=d+16|0;break a}Sc();p()}f=vn(x[a>>2],x[a+4>>2]);d=hb-16|0;hb=d;Df(c+12|0,g);b:{if(!e){e=0;x[c>>2]=0;g=0;break b}if(e>>>0>=178956971){qi();p()}g=Jc(D(e,24));x[d+12>>2]=e;x[d+8>>2]=g;e=x[d+8>>2];x[c>>2]=e;g=x[d+12>>2]}f=D(f,24)+e|0;x[c+4>>2]=f;x[c+8>>2]=f;n=yc(c),o=D(g,24)+e|0,x[n>>2]=o;hb=d+16|0;tJ(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+24;e=hb-32|0;hb=e;i=Ib(e+24|0,x[a+4>>2]);h=Ib(e+16|0,x[a>>2]);j=Ib(e+8|0,x[c+4>>2]);d=hb-16|0;hb=d;b=hb-16|0;hb=b;f=hb-16|0;hb=f;g=hb-16|0;hb=g;j=x[j>>2];k=x[i>>2];i=x[h>>2];h=k-i|0;k=j+D((h|0)/-24|0,24)|0;m=ah(k,i,h);h=D((h|0)/24|0,24);x[g+12>>2]=m+h;yd(f+8|0,h+i|0,g+12|0);hb=g+16|0;yd(b+8|0,i,Ib(f,j+D((k-j|0)/24|0,24)|0));hb=f+16|0;f=x[b+8>>2];x[b>>2]=x[b+12>>2];yd(d+8|0,f,b);hb=b+16|0;hb=d+16|0;x[c+4>>2]=x[d+12>>2];qc(a,c+4|0);qc(a+4|0,c+8|0);qc(Cb(a),yc(c));x[c>>2]=x[c+4>>2];hb=e+32|0;b=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)!=(b|0)){a=a-24|0;x[c+8>>2]=a;continue}break}a=x[c>>2];if(a){yc(c);Hb(a)}hb=l+32|0}function S3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-80|0;hb=e;f=Sb(a);a=0;c=x[b+24>>2];g=$i(_b(x[c+484360>>2],y[c+484376|0]));x[23604]=0;R(167,f|0,g|0);c=x[23604];x[23604]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=x[b+24>>2];d=x[c+484344>>2];h=x[c+484348>>2];c=z[cc(x[_b(x[c+484360>>2],y[c+484376|0])>>2],a)>>1];if(wm(d,h,c)){x[23604]=0;R(969,e+48|0,ac(d,c)|0);c=x[23604];x[23604]=0;c:{d:{e:{if((c|0)!=1){c=x[b+24>>2];x[23604]=0;U(956,e- -64|0,c|0,e+48|0);c=x[23604];x[23604]=0;if((c|0)==1){break e}x[23604]=0;R(169,f|0,e- -64|0);c=x[23604];x[23604]=0;if((c|0)==1){break d}xb(e- -64|0);xb(e+48|0);break b}a=P()|0;break a}a=P()|0;break c}a=P()|0;xb(e- -64|0)}xb(e+48|0);break a}f:{switch(c-65534|0){case 0:x[23604]=0;c=Q(54,e+32|0,9142)|0;d=x[23604];x[23604]=0;g:{if((d|0)!=1){x[23604]=0;R(169,f|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break g}xb(c);break b}a=P()|0;break a}a=P()|0;xb(c);break a;case 1:x[23604]=0;c=Q(54,e+16|0,9104)|0;d=x[23604];x[23604]=0;h:{if((d|0)!=1){x[23604]=0;R(169,f|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break h}xb(c);break b}a=P()|0;break a}a=P()|0;xb(c);break a;default:break f}}x[23604]=0;c=Q(54,e|0,14477)|0;d=x[23604];x[23604]=0;i:{if((d|0)!=1){x[23604]=0;R(169,f|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break i}xb(c);break b}a=P()|0;break a}a=P()|0;xb(c);break a}hb=e+80|0;return}a=a+1|0;continue}}a=P()|0}Vd(f);T(a|0);p()}function g$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;dw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Oc(d);x[23604]=0;R(59,d|0,b|0);b=x[23604];x[23604]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=y[a+222|0]<<24>>24;i=y[a+223|0]<<24>>24;while(1){d:{x[23604]=0;b=Q(1073,a+264|0,a+256|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Eb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23604]=0;R(59,d|0,b<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=b+c}x[23604]=0;b=S(1074,x[a+264>>2])|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(cw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[23604]=0;S(1076,a+264|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=eG(c,x[a+188>>2],e),B[j>>2]=k;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1073,a+264|0,a+256|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function f$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;dw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Oc(d);x[23604]=0;R(59,d|0,b|0);b=x[23604];x[23604]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=y[a+222|0]<<24>>24;i=y[a+223|0]<<24>>24;while(1){d:{x[23604]=0;b=Q(1073,a+264|0,a+256|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Eb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23604]=0;R(59,d|0,b<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=b+c}x[23604]=0;b=S(1074,x[a+264>>2])|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(cw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[23604]=0;S(1076,a+264|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=cG(c,x[a+188>>2],e),C[j>>3]=k;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1073,a+264|0,a+256|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function kz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;if(b&5){if((b|0)==1){d=Jia(x[a+24>>2],0,8363,0);c=lb;d=d+4136|0;c=d>>>0<4136?c+1|0:c;h=a,i=Uc(Mia(d,c,8272,0),lb),x[h+24>>2]=i}d=hb-16|0;hb=d;f=d+8|0;c=hb-16|0;hb=c;g=x[a+24>>2];a:{if(!g){v[f|0]=0;v[f+1|0]=0;break a}bB(c+8|0,Yb(dm(Po(+(g>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);g=x[c+8>>2];v[c+7|0]=x[c+12>>2];$s(f,g,c+7|0)}hb=c+16|0;Ib(Ib(d,a+36|0)+4|0,a+37|0);v[x[d>>2]]=y[f|0];v[x[d+4>>2]]=y[f+1|0];hb=d+16|0}if(b&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(b&7){w[a+32>>1]=64;c=z[a+34>>1];if(c&8){d=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=d;c=c&16?c|6:c&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=z[a+34>>1];if(!(c&32)){w[a+28>>1]=128;w[a+34>>1]=c|32}mf(a+40|0,15);mf(a+41|0,63);if(!y[a+41|0]){break b}d=y[a+40|0];if(!d){break b}c=y[a+39|0];if(c){c=zm(Uc(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}v[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|y[a+38|0]!=2){break d}v[a+38|0]=3;break d}if(y[a+38|0]!=4){break d}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}e:{if(!(!(y[a+35|0]&2)|b&16777218)){x[e+24>>2]=0;x[e+8>>2]=0;x[e+16>>2]=0;x[e+20>>2]=0;x[e>>2]=0;x[e+4>>2]=0;kl(a,0,e);break e}if(!(y[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Gb(a,8);v[b|0]=y[b|0]&3;a=Gb(a,9);v[a|0]=y[a|0]&3}hb=e+32|0}function Jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=hb-16|0;hb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}r=x[a+16>>2];e=x[a+48>>2];s=x[a+24>>2];t=x[a+20>>2];b=x[a+44>>2];j=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=j;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;while(1){j=b;if(d){b=Yb(j,-16777216,16776704);k=Jia(p,y,b,b>>31);l=lb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+r|0;b=(b>>>16&65520)+n|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=Jia(b,b>>31,q,z);k=b+k|0;m=lb+l|0;m=b>>>0>k>>>0?m+1|0:m;b=Yb(e,-16777216,16776704);e=Jia(o,v,b,b>>31);l=e+k|0;b=lb+m|0;b=e>>>0>l>>>0?b+1|0:b;e=l+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Nc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,t)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,s);Ub(g+8|0,i,h);b=e-(f&u)|0;c=c+8|0;d=d-1|0;e=j;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+48>>2]=e;x[a+44>>2]=j;hb=g+16|0}function Z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=hb-368|0;hb=a;x[a+352>>2]=c;x[a+360>>2]=b;$v(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Oc(d);x[23604]=0;R(59,d|0,b|0);b=x[23604];x[23604]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[23604]=0;b=Q(1088,a+360|0,a+352|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(b){break c}g=x[a+180>>2];b=Eb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23604]=0;R(59,d|0,b<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+180>>2]=b+c}x[23604]=0;b=S(1089,x[a+360>>2])|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(_v(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[23604]=0;S(1091,a+360|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+204>>2],y[a+211|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=eG(c,x[a+180>>2],e),B[j>>2]=k;rf(a+200|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1088,a+360|0,a+352|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+360>>2];xb(d);xb(a+200|0);hb=a+368|0;break a}}b=P()|0;xb(d);xb(a+200|0);T(b|0);p()}return b|0}function Y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=hb-368|0;hb=a;x[a+352>>2]=c;x[a+360>>2]=b;$v(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Oc(d);x[23604]=0;R(59,d|0,b|0);b=x[23604];x[23604]=0;a:{b:{c:{if((b|0)!=1){c=uc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[23604]=0;b=Q(1088,a+360|0,a+352|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(b){break c}g=x[a+180>>2];b=Eb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[23604]=0;R(59,d|0,b<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+180>>2]=b+c}x[23604]=0;b=S(1089,x[a+360>>2])|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}if(_v(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[23604]=0;S(1091,a+360|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+204>>2],y[a+211|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=cG(c,x[a+180>>2],e),C[j>>3]=k;rf(a+200|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1088,a+360|0,a+352|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+360>>2];xb(d);xb(a+200|0);hb=a+368|0;break a}}b=P()|0;xb(d);xb(a+200|0);T(b|0);p()}return b|0}function UZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=hb-496|0;hb=a;Pc(a+488|0,x[d+28>>2]);x[23604]=0;n=S(1083,x[a+488>>2])|0;g=x[23604];x[23604]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Eb(x[f+4>>2],y[f+11|0])){g=x[Wi(f,0)>>2];x[23604]=0;h=Q(1100,n|0,45)|0;j=x[23604];x[23604]=0;if((j|0)==1){break e}o=(g|0)==(h|0)}j=Kb(a+456|0);g=Kb(a+440|0);h=Kb(a+424|0);x[23604]=0;la(1122,c|0,o|0,x[a+488>>2],a+480|0,a+476|0,a+472|0,j|0,g|0,h|0,a+420|0);c=x[23604];x[23604]=0;if((c|0)==1){break d}x[a+4>>2]=1071;c=le(a+8|0,0,a+4|0);k=a+16|0;l=Eb(x[f+4>>2],y[f+11|0]);m=x[a+420>>2];f:{if((l|0)>(m|0)){i=((Eb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Eb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Eb(x[h+4>>2],y[h+11|0])+Eb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Ie(c,Ld(i<<2));k=x[c>>2];if(!k){break g}l=Eb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Pb(f);x[23604]=0;oa(1123,k|0,a+4|0,a|0,i|0,f|0,f+(l<<2)|0,n|0,o|0,a+480|0,x[a+476>>2],x[a+472>>2],j|0,g|0,h|0,m|0);f=x[23604];x[23604]=0;if((f|0)==1){break c}x[23604]=0;b=ka(1103,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}Mc(c);Gc(h);Gc(g);xb(j);$b(a+488|0);hb=a+496|0;return b|0}x[23604]=0;Z(1072);b=x[23604];x[23604]=0;if((b|0)==1){break c}p()}f=P()|0;break a}f=P()|0;break a}f=P()|0;break b}f=P()|0;Mc(c)}Gc(h);Gc(g);xb(j)}$b(a+488|0);T(f|0);p()}function Kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;g=hb-16|0;hb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}p=b;q=x[a+16>>2];b=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];j=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=j;t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];y=m>>31;n=x[a+60>>2];z=n>>31;while(1){j=e;if(d){e=Yb(j,-16777216,16776704);f=Jia(m,y,e,e>>31);e=lb;b=Yb(b,-16777216,16776704);b=Jia(l,u,b,b>>31);f=b+f|0;e=lb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];k=f;f=x[g+12>>2]+q|0;b=(b>>>16&65520)+p|0;o=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=o;f=Jia(b,b>>31,n,z);k=k+f|0;b=lb+e|0;b=f>>>0>k>>>0?b+1|0:b;e=k+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Nc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,r);Ub(g+8|0,i,h);e=e-(t&o)|0;c=c+8|0;d=d-1|0;b=j;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=b;x[a+44>>2]=j;hb=g+16|0}function xY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=hb-16|0;hb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!x[b>>2]){break a}b=b+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=hb-16|0;hb=r;s=Yh(r+8|0,x[a+8>>2]);i=f;j=g-f|0;m=0;o=hb-16|0;hb=o;k=x[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=Bw(j>>>0<4?o+12|0:i,x[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}vc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!x[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){x[e>>2]=k}hb=o+16|0;Xh(s);hb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=Vv(f,x[c>>2],x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=x[h>>2]+m|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=x[e>>2];b=d;continue}b=Vv(n+12|0,0,x[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-x[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=y[c|0];i=x[h>>2];x[h>>2]=i+1;v[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!x[b>>2]){break b}b=b+4|0;continue}}c=x[e>>2]}q=(c|0)!=(d|0)}hb=n+16|0;return q|0}f=x[h>>2];continue}}function eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;g=hb-16|0;hb=g;r=x[a+16>>2];s=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){k=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];l=0;break a}b=x[a+12>>2];n=b;k=x[a+8>>2];o=Xf(k,b,m);p=lb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];Cf(h,e,Ze(k,n,d),lb);l=lb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;l=l-1|0;b=l;o=b?o:0;p=b?p:0;h=e+r|0;b=m;while(1)if((b|0)<=0){Ub(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(i,v[h+x[g+12>>2]|0]<<6);Jd(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Tf(i,s);w=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=Jia(e,e>>31,b,b>>31);y=lb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Yb(q,-16777216,16776704);j=Jia(j,z,b,b>>31);e=e+j|0;b=lb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Jia(e,e>>31,f,f>>31);f=j+e|0;b=lb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Nc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Ub(g,k,n);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue b}else{Kd(i,v[h+x[g+12>>2]|0]<<6);Jd(i,4);Ub(g+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;hb=g+16|0}function a$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=Oi(x[d+4>>2]);i=So(x[d+28>>2],a+224|0);Ro(a+208|0,x[d+28>>2],a+332|0);d=Kb(a+192|0);c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[23604]=0;g=Q(1088,a+344|0,a+336|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(g){break c}h=x[a+188>>2];g=Eb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23604]=0;R(59,d|0,g<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=g+c}x[23604]=0;g=S(1089,x[a+344>>2])|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(bn(g,b,c,a+188|0,a+8|0,j,x[a+212>>2],y[a+219|0],a+16|0,a+12|0,i)){break c}x[23604]=0;S(1091,a+344|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=jG(c,x[a+188>>2],e,b),x[k>>2]=l;x[f+4>>2]=lb;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1088,a+344|0,a+336|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function __(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=Oi(x[d+4>>2]);i=So(x[d+28>>2],a+224|0);Ro(a+208|0,x[d+28>>2],a+332|0);d=Kb(a+192|0);c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[23604]=0;g=Q(1088,a+344|0,a+336|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(g){break c}h=x[a+188>>2];g=Eb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23604]=0;R(59,d|0,g<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=g+c}x[23604]=0;g=S(1089,x[a+344>>2])|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(bn(g,b,c,a+188|0,a+8|0,j,x[a+212>>2],y[a+219|0],a+16|0,a+12|0,i)){break c}x[23604]=0;S(1091,a+344|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=fG(c,x[a+188>>2],e,b),x[k>>2]=l;x[f+4>>2]=lb;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1088,a+344|0,a+336|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function ey(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=Oq(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(c,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(c,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1),67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(c,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Nb(Nb(Nb(Nb(c,o,1),n,1),m,1),l,1);g=k;f=j;e=i;d=h}Nb(c,g,1)}Nb(Nb(Nb(c,f,1),e,1),d,1)}}function Mfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=y[f+4|0];j=Gb(h,d),k=i+1|0,v[j|0]=k;f=y[f+6|0]|y[f+7|0]<<8;j=cc(g,d),k=f+1|0,w[j>>1]=k;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;g=y[g+6|0]|y[g+7|0]<<8;j=cc(f,d+12|0),k=g+1|0,w[j>>1]=k;d=d+1|0;continue}}cA(a+484|0,b+48|0,0);cA(a+590|0,b+68|0,0);cA(a+696|0,b+88|0,5);x[b>>2]=y[a+806|0]|y[a+807|0]<<8;d=v[a+808|0];b:{if((d|0)<0){v[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(v[a|0]&1){v[b+31|0]=d+1;break b}if(!d){break b}v[b+31|0]=d+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=y[a+810|0];break d}d=v[a+809|0];if((d|0)>=0){w[b+28>>1]=(d&255)+1}d=v[a+810|0];if((d|0)<0){break c}}v[b+30|0]=d+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;j=b,k=y[Wb(e+15|0,e+14|0)|0]>>>1|0,x[j+4>>2]=k}c=y[a+813|0]|y[a+814|0]<<8;if(c>>>0<=256){x[b+8>>2]=c;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];w[e+12>>1]=y[a+820|0]|y[a+821|0]<<8;w[e+10>>1]=100;j=b,k=y[Wc(e+12|0,e+10|0)|0],v[j+20|0]=k;w[e+8>>1]=y[a+822|0]|y[a+823|0]<<8;w[e+6>>1]=256;j=b,k=z[Wc(e+8|0,e+6|0)>>1]>>>2|0,v[j+19|0]=k;c=y[a+824|0];Bm(b,c&127,c>>>7|0);a=y[a+825|0];Am(b,a&127,a>>>7|0);hb=e+16|0}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=hb-48|0;hb=f;q=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+24|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}r=x[a+24>>2];s=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];v=m>>31;n=x[a+60>>2];y=n>>31;k=x[a+8>>2];z=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){o=(f+8|0)+(b<<2)|0;e=x[o>>2];g=(f+24|0)+(b<<3)|0;A=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;p=e<<8;e=p;e=Jia(n,y,e,e>>31);i=lb;j=e;e=Yb(h,-16777216,16776704);e=Jia(m,v,e,e>>31);h=j+e|0;j=lb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(A,-16777216,16776704);i=Jia(l,u,e,e>>31);h=i+h|0;e=lb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(p&t);x[o>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],s);x[c+4>>2]=x[c+4>>2]+D(r,x[f+12>>2]);Ub(f+16|0,k,z);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function YZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=hb-192|0;hb=a;Pc(a+184|0,x[d+28>>2]);x[23604]=0;n=S(18,x[a+184>>2])|0;g=x[23604];x[23604]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Eb(x[f+4>>2],y[f+11|0])){g=y[uc(f,0)|0];x[23604]=0;h=Q(19,n|0,45)|0;j=x[23604];x[23604]=0;if((j|0)==1){break e}o=(g|0)==(h&255)}j=Kb(a+160|0);g=Kb(a+144|0);h=Kb(a+128|0);x[23604]=0;la(1120,c|0,o|0,x[a+184>>2],a+176|0,a+175|0,a+174|0,j|0,g|0,h|0,a+124|0);c=x[23604];x[23604]=0;if((c|0)==1){break d}x[a+4>>2]=1071;c=le(a+8|0,0,a+4|0);k=a+16|0;l=Eb(x[f+4>>2],y[f+11|0]);m=x[a+124>>2];f:{if((l|0)>(m|0)){i=((Eb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Eb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Eb(x[h+4>>2],y[h+11|0])+Eb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Ie(c,Ld(i));k=x[c>>2];if(!k){break g}l=Eb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Pb(f);x[23604]=0;oa(1121,k|0,a+4|0,a|0,i|0,f|0,f+l|0,n|0,o|0,a+176|0,v[a+175|0],v[a+174|0],j|0,g|0,h|0,m|0);f=x[23604];x[23604]=0;if((f|0)==1){break c}x[23604]=0;b=ka(14,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}Mc(c);xb(h);xb(g);xb(j);$b(a+184|0);hb=a+192|0;return b|0}x[23604]=0;Z(1072);b=x[23604];x[23604]=0;if((b|0)==1){break c}p()}f=P()|0;break a}f=P()|0;break a}f=P()|0;break b}f=P()|0;Mc(c)}xb(h);xb(g);xb(j)}$b(a+184|0);T(f|0);p()}function Cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,B=0;i=hb-16|0;hb=i;od(d,32);g=i+8|0;MP(g,y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24),y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24),x[b>>2]);g=jc(g);MP(i,y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24),y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24),x[c>>2]);a=0;g=x[g>>2];if(g-838861>>>0>=4294128436){a=x[jc(i)>>2];x[d>>2]=D(g,320);w[d+34>>1]=1;a:{m=yg(d);if(!m){break a}l=g<<2;e=+(l>>>0);q=+(a>>>0)/e;r=+(g>>>0)/e;s=1/+A[d>>2];t=+A[i>>2];u=+A[i+8>>2];g=0;b:while(1){if((g|0)==(l|0)){break a}n=+(g>>>0);o=0;p=0;a=x[b+20>>2];if(Qd(x[b>>2],a)){e=n*r+u;c:{if(e<4294967296&e>=0){f=~~e>>>0;break c}f=0}k=z[b+34>>1];j=Gd(k);h=D(f,j);e=e-+(f>>>0);d:{if(k&1){f=z[a+(h<<1)>>1];a=z[a+(h+j<<1)>>1];break d}f=y[a+h|0]<<8;a=y[a+(h+j|0)|0]<<8}p=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}a=x[c+20>>2];if(Qd(x[c>>2],a)){e=n*q+t;e:{if(e<4294967296&e>=0){f=~~e>>>0;break e}f=0}k=z[c+34>>1];j=Gd(k);h=D(f,j);e=e-+(f>>>0);f:{if(k&1){f=z[a+(h<<1)>>1];a=z[a+(h+j<<1)>>1];break f}f=y[a+h|0]<<8;a=y[a+(h+j|0)|0]<<8}o=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}f=0;a=g;while(1)if((f|0)==80){g=g+1|0;continue b}else{e=s*+(a>>>0);v=x[d+20>>2]+(a<<1)|0,B=yz(p*(1-e)+o*e),w[v>>1]=B;a=a+l|0;f=f+1|0;continue}}}a=(m|0)!=0}hb=i+16|0;return a|0}function j$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=hb-240|0;hb=a;x[a+224>>2]=c;x[a+232>>2]=b;b=Oi(g);To(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=y[a+223|0]<<24>>24;while(1){d:{x[23604]=0;g=Q(1073,a+232|0,a+224|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(g){break c}h=x[a+188>>2];g=Eb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23604]=0;R(59,d|0,g<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=g+c}x[23604]=0;g=S(1074,x[a+232>>2])|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(en(g,b,c,a+188|0,a+8|0,i,x[a+212>>2],y[a+219|0],a+16|0,a+12|0,82128)){break c}x[23604]=0;S(1076,a+232|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=jG(c,x[a+188>>2],e,b),x[j>>2]=k;x[f+4>>2]=lb;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1073,a+232|0,a+224|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];xb(d);xb(a+208|0);hb=a+240|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function h$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=hb-240|0;hb=a;x[a+224>>2]=c;x[a+232>>2]=b;b=Oi(g);To(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=y[a+223|0]<<24>>24;while(1){d:{x[23604]=0;g=Q(1073,a+232|0,a+224|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(g){break c}h=x[a+188>>2];g=Eb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23604]=0;R(59,d|0,g<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=g+c}x[23604]=0;g=S(1074,x[a+232>>2])|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(en(g,b,c,a+188|0,a+8|0,i,x[a+212>>2],y[a+219|0],a+16|0,a+12|0,82128)){break c}x[23604]=0;S(1076,a+232|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=fG(c,x[a+188>>2],e,b),x[j>>2]=k;x[f+4>>2]=lb;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1073,a+232|0,a+224|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];xb(d);xb(a+208|0);hb=a+240|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function b$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=Oi(x[d+4>>2]);i=So(x[d+28>>2],a+224|0);Ro(a+208|0,x[d+28>>2],a+332|0);d=Kb(a+192|0);c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[23604]=0;g=Q(1088,a+344|0,a+336|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(g){break c}h=x[a+188>>2];g=Eb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23604]=0;R(59,d|0,g<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=g+c}x[23604]=0;g=S(1089,x[a+344>>2])|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(bn(g,b,c,a+188|0,a+8|0,j,x[a+212>>2],y[a+219|0],a+16|0,a+12|0,i)){break c}x[23604]=0;S(1091,a+344|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=lG(c,x[a+188>>2],e,b),x[k>>2]=l;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1088,a+344|0,a+336|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function _F(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=Oi(x[d+4>>2]);i=So(x[d+28>>2],a+224|0);Ro(a+208|0,x[d+28>>2],a+332|0);d=Kb(a+192|0);c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[23604]=0;g=Q(1088,a+344|0,a+336|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(g){break c}h=x[a+188>>2];g=Eb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23604]=0;R(59,d|0,g<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=g+c}x[23604]=0;g=S(1089,x[a+344>>2])|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(bn(g,b,c,a+188|0,a+8|0,j,x[a+212>>2],y[a+219|0],a+16|0,a+12|0,i)){break c}x[23604]=0;S(1091,a+344|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=gG(c,x[a+188>>2],e,b),x[k>>2]=l;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1088,a+344|0,a+336|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function $_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=Oi(x[d+4>>2]);i=So(x[d+28>>2],a+224|0);Ro(a+208|0,x[d+28>>2],a+332|0);d=Kb(a+192|0);c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[23604]=0;g=Q(1088,a+344|0,a+336|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(g){break c}h=x[a+188>>2];g=Eb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23604]=0;R(59,d|0,g<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=g+c}x[23604]=0;g=S(1089,x[a+344>>2])|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(bn(g,b,c,a+188|0,a+8|0,j,x[a+212>>2],y[a+219|0],a+16|0,a+12|0,i)){break c}x[23604]=0;S(1091,a+344|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=iG(c,x[a+188>>2],e,b),w[k>>1]=l;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1088,a+344|0,a+336|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function mF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){c=x[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[c|0];j=i&255;d:{if((i|0)>=0){w[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;w[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;x[a+8>>2]=f+2;w[f+2>>1]=i<<6&960|k&63|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;f=x[a+8>>2]+2|0;x[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return b|0}function VD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-96|0;hb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){Xb(a,9642);break j}d=b>>>24|0;if(!(b&65535)){e=hb-16|0;hb=e;f=Xb(e,4360);dd(c+80|0,f);xb(f);hb=e+16|0;x[23604]=0;x[c+24>>2]=d;R(95,c- -64|0,c+24|0);d=x[23604];x[23604]=0;k:{l:{m:{n:{if((d|0)!=1){x[23604]=0;x[c+8>>2]=b>>>16&255;R(96,c+48|0,c+8|0);b=x[23604];x[23604]=0;if((b|0)==1){break n}x[23604]=0;X(97,a|0,c+80|0,c- -64|0,c+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break m}xb(c+48|0);xb(c- -64|0);Db(c+80|0);break j}b=P()|0;break k}b=P()|0;break l}b=P()|0;xb(c+48|0)}xb(c- -64|0)}break a}e=hb-16|0;hb=e;f=Xb(e,4084);dd(c+80|0,f);xb(f);hb=e+16|0;x[23604]=0;x[c+44>>2]=d;R(95,c- -64|0,c+44|0);d=x[23604];x[23604]=0;if((d|0)==1){break i}x[23604]=0;x[c+40>>2]=b>>>16&255;R(96,c+48|0,c+40|0);d=x[23604];x[23604]=0;if((d|0)==1){break h}x[23604]=0;x[c+20>>2]=b>>>8&255;R(96,c+24|0,c+20|0);d=x[23604];x[23604]=0;if((d|0)==1){break g}x[23604]=0;x[c+4>>2]=b&255;R(96,c+8|0,c+4|0);b=x[23604];x[23604]=0;if((b|0)==1){break f}x[23604]=0;ma(98,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=x[23604];x[23604]=0;if((a|0)==1){break e}xb(c+8|0);xb(c+24|0);xb(c+48|0);xb(c- -64|0);Db(c+80|0)}hb=c+96|0;return}b=P()|0;break a}b=P()|0;break b}b=P()|0;break c}b=P()|0;break d}b=P()|0;xb(c+8|0)}xb(c+24|0)}xb(c+48|0)}xb(c- -64|0)}Db(c+80|0);T(b|0);p()}function k$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=hb-240|0;hb=a;x[a+224>>2]=c;x[a+232>>2]=b;b=Oi(g);To(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=y[a+223|0]<<24>>24;while(1){d:{x[23604]=0;g=Q(1073,a+232|0,a+224|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(g){break c}h=x[a+188>>2];g=Eb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23604]=0;R(59,d|0,g<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=g+c}x[23604]=0;g=S(1074,x[a+232>>2])|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(en(g,b,c,a+188|0,a+8|0,i,x[a+212>>2],y[a+219|0],a+16|0,a+12|0,82128)){break c}x[23604]=0;S(1076,a+232|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=lG(c,x[a+188>>2],e,b),x[j>>2]=k;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1073,a+232|0,a+224|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];xb(d);xb(a+208|0);hb=a+240|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function i$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=hb-240|0;hb=a;x[a+224>>2]=c;x[a+232>>2]=b;b=Oi(g);To(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=y[a+223|0]<<24>>24;while(1){d:{x[23604]=0;g=Q(1073,a+232|0,a+224|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(g){break c}h=x[a+188>>2];g=Eb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23604]=0;R(59,d|0,g<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=g+c}x[23604]=0;g=S(1074,x[a+232>>2])|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(en(g,b,c,a+188|0,a+8|0,i,x[a+212>>2],y[a+219|0],a+16|0,a+12|0,82128)){break c}x[23604]=0;S(1076,a+232|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=iG(c,x[a+188>>2],e,b),w[j>>1]=k;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1073,a+232|0,a+224|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];xb(d);xb(a+208|0);hb=a+240|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function hG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=hb-240|0;hb=a;x[a+224>>2]=c;x[a+232>>2]=b;b=Oi(g);To(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){c=uc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=y[a+223|0]<<24>>24;while(1){d:{x[23604]=0;g=Q(1073,a+232|0,a+224|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(g){break c}h=x[a+188>>2];g=Eb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[23604]=0;R(59,d|0,g<<1);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(d);x[23604]=0;R(59,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=uc(d,0);x[a+188>>2]=g+c}x[23604]=0;g=S(1074,x[a+232>>2])|0;h=x[23604];x[23604]=0;if((h|0)==1){break d}if(en(g,b,c,a+188|0,a+8|0,i,x[a+212>>2],y[a+219|0],a+16|0,a+12|0,82128)){break c}x[23604]=0;S(1076,a+232|0)|0;g=x[23604];x[23604]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(x[a+212>>2],y[a+219|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=gG(c,x[a+188>>2],e,b),x[j>>2]=k;rf(a+208|0,a+16|0,x[a+12>>2],e);x[23604]=0;b=Q(1073,a+232|0,a+224|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];xb(d);xb(a+208|0);hb=a+240|0;break a}}b=P()|0;xb(d);xb(a+208|0);T(b|0);p()}return b|0}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;f=hb-48|0;hb=f;q=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+24|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}r=x[a+24>>2];s=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];w=m>>31;n=x[a+60>>2];y=n>>31;k=x[a+8>>2];z=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+q|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){o=(f+8|0)+(b<<2)|0;e=x[o>>2];g=(f+24|0)+(b<<3)|0;A=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;p=e<<8;e=p;e=Jia(n,y,e,e>>31);i=lb;j=e;e=Yb(h,-16777216,16776704);e=Jia(m,w,e,e>>31);h=j+e|0;j=lb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(A,-16777216,16776704);i=Jia(l,u,e,e>>31);h=i+h|0;e=lb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Nc(i,e,24);x[g+4>>2]=e-(p&t);x[o>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],s);x[c+4>>2]=x[c+4>>2]+D(r,x[f+12>>2]);Ub(f+16|0,k,z);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function cI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-16|0;hb=h;g=x[a+32>>2];f=is(g);if(!f){f=hs(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ba(8)|0;x[23604]=0;c=Q(54,h|0,5961)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}if(c>>>0>=120){b=ba(8)|0;x[23604]=0;c=Q(54,h|0,11193)|0;a=x[23604];x[23604]=0;if((a|0)!=1){a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}a=P()|0;ca(b|0);break b}f=ry(g,65535);j=(f|0)==65535?255:f;w[h>>1]=j;f=g+D(j,872)|0;i=f+1074992|0;Tn(i,g,65535,1024);c=c+1|0;v[f+1075794|0]=c;v[f+1075791|0]=c;w[f+1075778>>1]=0;Xl(i);sp(x[a+32>>2],i,b+1|0,0,1,1);x[f+1075688>>2]=65536;Ps(x[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=dm(Hy(e*128,-128,128)+128),x[l>>2]=m;l=f+1075680|0,m=dm(Hy(d*256,0,256)),x[l>>2]=m;c=x[a+32>>2];i=c+1074478|0;b=i;c=b+(z[c+480212>>1]<<1)|0;g=z[h>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=z[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=z[f>>1];if((k|0)==(g|0)){continue}w[b>>1]=k;b=b+2|0;g=z[h>>1];continue}}l=x[a+32>>2],m=Py(i,c),w[l+480212>>1]=m;hb=h+16|0;return j|0}a=P()|0;ca(b|0)}T(a|0)}p()}function aE(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=Kb(a);a=y[b+11|0];h=x[b+4>>2];x[23604]=0;m=Qc(h,a);R(g|0,k|0,m|0);a=x[23604];x[23604]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(m|0)){a=!i;if(!(n?a&(o^-1):a)){break c}return}h=v[uc(b,a)|0];j=h&255;d:{e:{f:{g:{switch(i+1|0){case 1:i=1;h:{switch(j-123|0){case 2:break h;case 0:break d;default:break f}}i=3;break d;case 2:i:{switch(j-123|0){case 2:o=1;h=g+1|0;i=0;if(d>>>0<=g>>>0){g=h;break d}x[23604]=0;Q(f|0,k|0,Zd(c,g)|0)|0;j=x[23604];x[23604]=0;g=h;if((j|0)!=1){break d}a=P()|0;break b;case 0:break f;default:break i}}i=-1;h=h-48|0;if((h&255)>>>0>9){break d}n=1;i=2;l=h;break d;case 3:i=-1;j:{switch(j-123|0){case 2:i=0;if(d>>>0<=l>>>0){break d}x[23604]=0;Q(f|0,k|0,Zd(c,l)|0)|0;h=x[23604];x[23604]=0;if((h|0)!=1){break d}a=P()|0;break b;case 0:break d;default:break j}}if((h-48&255)>>>0>9){break d}l=(D(l,10)+h|0)-48|0;n=1;i=2;break d;case 4:break g;case 0:break e;default:break d}}j=(h|0)!=125;i=-1;h=125;if(j){break d}}i=0;x[23604]=0;Q(e|0,k|0,h|0)|0;h=x[23604];x[23604]=0;if((h|0)!=1){break d}a=P()|0;break b}i=-1}a=a+1|0;continue}break}b=ba(8)|0;x[23604]=0;a=S(104,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){x[23604]=0;U(105,a|0,42340,24);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;break b}a=P()|0;ca(b|0);break b}a=P()|0}xb(k);T(a|0)}p()}function aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-48|0;hb=e;od(b,2);f=e+16|0;Wj(f,2,a+1|0);d=e+32|0;Dc(d,f);ze(b+43|0,d);xb(d);a:{b:{c:{d:{switch(y[a|0]){case 0:f=x[b+4>>2];d=x[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b>>2]=d;x[e+32>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[e+16>>2]=d-1;d=e+32|0;f=x[Fb(d,e+16|0)>>2];x[b+4>>2]=f;x[e+32>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);d=x[Fb(d,b)>>2];x[b+8>>2]=d;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}f=e+16|0;zh(f,a+16|0);d=x[e+16>>2];x[e+32>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);zh(f,a+20|0);d=x[e+16>>2];x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);zh(f,a+24|0);d=x[e+16>>2];d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+40>>2]=d;x[e+8>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;kl(b,1,e)}v[e+32|0]=y[a+28|0];v[e+16|0]=64;g=b,h=y[Wb(e+32|0,e+16|0)|0]<<2,w[g+30>>1]=h;d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(y[a|0]==2){d=d&65535;x[b>>2]=d;break e}if(A[b>>2]>=65536){x[b>>2]=65535}d=x[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}x[b>>2]=a}hb=e+48|0}function Bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-80|0;hb=d;b=b&4095;w[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=hb-16|0;hb=e;f=Xb(e,4412);dd(d- -64|0,f);xb(f);hb=e+16|0;x[23604]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=Jia(e,e>>31,1e4,0);b=lb;c=c+14780|0;b=c>>>0<14780?b+1|0:b;b=Kia(c,b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(D(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;x[d+44>>2]=g+f;R(86,d+48|0,d+44|0);g=x[23604];x[23604]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){x[23604]=0;x[d+28>>2]=(e+D(f,-12)|0)+1;R(88,d+32|0,d+28|0);e=x[23604];x[23604]=0;if((e|0)==1){break j}x[23604]=0;x[d+12>>2]=(((D(b,306)+5|0)/-10|0)+c|0)+1;R(88,d+16|0,d+12|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;ea(347,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}xb(d+16|0);xb(d+32|0);break d}b=P()|0;break e}b=P()|0;break f}b=P()|0;break g}b=P()|0;xb(d+16|0)}xb(d+32|0)}xb(d+48|0)}break a}ef(d- -64|0,4392);x[23604]=0;R(348,d+48|0,d+78|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}x[23604]=0;U(131,a|0,d- -64|0,d+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}}xb(d+48|0);Db(d- -64|0);hb=d+80|0;return}b=P()|0;break a}b=P()|0;xb(d+48|0)}Db(d- -64|0);T(b|0);p()}function OH(a){var b=0,c=0,d=0,e=0;se(x[a+80>>2],x[a+20>>2]);while(1){c=x[a+28>>2];if((b|0)<x[a+24>>2]){se(x[a+80>>2],x[c+(b<<2)>>2]);b=b+1|0;continue}break}se(x[a+80>>2],c);a:{if(!x[a+396>>2]){break a}c=0;while(1){if(x[a+264>>2]<=(c|0)){break a}e=x[a+396>>2]+D(c,24)|0;d=x[e+16>>2];if(d){b=0;while(1){if((b|0)<x[(x[a+124>>2]+D(y[e+13|0],2096)|0)+4>>2]){se(x[a+80>>2],x[(b<<2)+d>>2]);b=b+1|0;d=x[e+16>>2];continue}break}se(x[a+80>>2],d)}se(x[a+80>>2],x[e+20>>2]);c=c+1|0;continue}}d=x[a+124>>2];if(d){c=0;while(1){if((c|0)<x[a+120>>2]){b=D(c,2096)+d|0;se(x[a+80>>2],x[b+8>>2]);se(x[a+80>>2],x[b+28>>2]);se(x[a+80>>2],x[b+32>>2]);se(x[a+80>>2],x[b+2084>>2]);b=x[b+2088>>2];se(x[a+80>>2],b?b-4|0:0);c=c+1|0;d=x[a+124>>2];continue}break}se(x[a+80>>2],d)}se(x[a+80>>2],x[a+260>>2]);se(x[a+80>>2],x[a+396>>2]);c=x[a+404>>2];if(c){b=0;while(1){if((b|0)<x[a+400>>2]){se(x[a+80>>2],x[(D(b,40)+c|0)+4>>2]);b=b+1|0;c=x[a+404>>2];continue}break}se(x[a+80>>2],c)}c=0;b=0;while(1){if(!(x[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;se(x[a+80>>2],x[d+800>>2]);se(x[a+80>>2],x[d+928>>2]);se(x[a+80>>2],x[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;se(x[a+80>>2],x[b+1068>>2]);se(x[a+80>>2],x[b+1076>>2]);se(x[a+80>>2],x[b+1084>>2]);se(x[a+80>>2],x[b+1092>>2]);se(x[a+80>>2],x[b+1100>>2]);c=c+1|0;continue}break}}function CO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=hb-16|0;hb=h;c=x[a>>2];a:{if(Lj(c)){i=hb-16|0;hb=i;e=Jc(3848);d=e+808|0;c=e+16|0;while(1){x[c+16>>2]=0;x[c+20>>2]=0;x[c+36>>2]=0;v[c+42|0]=1;w[c+40>>1]=257;x[c+24>>2]=0;x[c+28>>2]=0;w[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){x[d>>2]=0;x[d+4>>2]=0;x[d+68>>2]=0;x[d+72>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;w[d+20>>1]=511;x[d+16>>2]=-1;w[d+14>>1]=1;w[d+6>>1]=0;w[d+8>>1]=0;w[d+10>>1]=0;w[d+12>>1]=0;v[d+73|0]=0;v[d+74|0]=0;v[d+75|0]=0;v[d+76|0]=0;v[d+77|0]=0;v[d+78|0]=0;v[d+79|0]=0;v[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}x[e+3832>>2]=0;x[e+3836>>2]=0;c=e+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}Sn((e+D(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+D(f,44)|0)+16|0;c=x[(f<<2)+29280>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+D(c,84)|0;HO(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+D(c,84)|0;HO(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{x[(e+D(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}GO(e,b)}else{Ad((e+D(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=x[lf(i+8|0,e)>>2];hb=i+16|0;x[h+8>>2]=b;b=h+8|0;Hz(a,b);ej(b);break a}GO(c,b)}BO(a);hb=h+16|0}function gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=hb-16|0;hb=f;s=x[a+16>>2];t=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){l=x[a+8>>2];n=x[a+12>>2];b=x[a>>2];e=x[a+4>>2];i=0;break a}b=x[a+12>>2];n=b;l=x[a+8>>2];o=Xf(l,b,m);p=lb;i=x[a+76>>2];b=x[a>>2];e=x[a+4>>2];Cf(b,e,Ze(l,n,d),lb);i=lb>>>0>i>>>0?d:0}h=a+112|0;j=x[a+40>>2];k=x[a+36>>2];x[f>>2]=b;x[f+4>>2]=e;while(1){if(d){d=d-1|0;x[f+8>>2]=b;x[f+12>>2]=0;i=i-1|0;o=i?o:0;p=i?p:0;r=(((e&2147483647)<<1|b>>>31)&-2)+s|0;e=m;b:{c:while(1){d:{if((e|0)<=0){Ub(h,x[a+120>>2],x[a+124>>2]);e=x[a+116>>2];if(!e){break b}g=x[f+8>>2];q=((x[f+12>>2]&2147483647)<<1|g>>>31)&-2;g=0;b=0;break d}g=x[f+8>>2];q=((x[f+12>>2]&2147483647)<<1|g>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Kd(h,g>>>3<<16>>16);Jd(h,4);Ub(f+8|0,o,p);e=e-1|0;continue c}else{g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}break}Kd(h,g>>>3<<16>>16);Jd(h,e);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=Tf(h,t);e=x[a+32>>2];k=x[a+28>>2]+k|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=e+j|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Ub(f,l,n);c=c+8|0;b=x[f>>2];e=x[f+4>>2];continue}break}x[a>>2]=b;x[a+4>>2]=e;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;hb=f+16|0}function Fy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-16|0;hb=h;f=x[c+656>>2];a:{if(!cj(f)){i=x[c+704>>2];f=hb-16|0;hb=f;x[f+12>>2]=d;g=0;b:{if(!d){break b}j=x[b+480180>>2];if(j&20){e=b+1074312|0;d=Tb(e,73)?d&65535:d;if(y[b+480208|0]&16){e=Tb(e,73)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=x[((d>>>0)%768<<2)+34464>>2]<<6>>>e|0;break b}g=229079296/((d?d:1)>>>0)|0;break b}g=227001280/(d>>>0)|0;if(lm(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}wc(f+12|0,16777215);if(j&17408){g=Uc(Mia(Jia(i?i:8363,0,3506176,0),lb,(x[f+12>>2]<<8)+e|0,0),lb);break b}if(Xi(b)){d=x[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(y[b+480208|0]&16){g=Uc(Mia(Jia(i?i:8363,0,7012352,0),lb,(x[f+12>>2]<<8)+e|0,0),lb);break b}g=Uc(Mia(-1485242368,13,(x[f+12>>2]<<8)+e|0,0),lb)}e=g;hb=f+16|0;f=x[c+656>>2];break a}e=x[c+700>>2]}x[h+12>>2]=e;c=w[c+774>>1];c:{if(!c){break c}c=f?D(v[f+33|0],c):c;if(!c){break c}e=Ge(wj(+(c|0)/393216)*+(e>>>0));x[h+12>>2]=e}d:{if(!f){break d}c=x[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=x[b+1074420>>2];e=Jia(f,f>>31,e,e>>31);f=d+e|0;d=lb+(d>>31)|0;k=h,l=Ec(Kia(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),lb),x[k+12>>2]=l}wc(h+12|0,2147483647);c=x[h+12>>2];b=Kia(0,c,x[b+24620>>2]<<4,0);x[a+8>>2]=c;x[a>>2]=b;x[a+4>>2]=lb;hb=h+16|0}function J_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-16|0;hb=k;l=sw(x[g>>2]);g=bw(x[g>>2]);Jg(k,g);a:{b:{if(wd(x[k+4>>2],y[k+11|0])){x[23604]=0;X(1094,l|0,a|0,c|0,d|0);g=x[23604];x[23604]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[23604]=0;j=Q(1100,l|0,h<<24>>24)|0;h=x[23604];x[23604]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[23604]=0;h=Q(1100,l|0,48)|0;i=x[23604];x[23604]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[23604]=0;h=Q(1100,l|0,h|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}Cl(j,c);i=0;x[23604]=0;o=S(1092,g|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){zr((j-a<<2)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[uc(k,h)|0]){break e}if(v[uc(k,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Eb(x[k+4>>2],y[k+11|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[23604]=0;n=Q(1100,l|0,n|0)|0;m=x[23604];x[23604]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;xb(k);T(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;xb(k);hb=k+16|0}function KU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=hb-32|0;hb=k;e=b;b=x[a>>2];b=(no(e,Bb(b))<<1)+b|0;a:{b:{h=x[a+4>>2];if(h>>>0<A[Cb(a)>>2]){if((b|0)!=(h|0)){break b}d=hb-16|0;hb=d;a=zi(d,a,1);mo(x[a+4>>2],y[c|0]|y[c+1|0]<<8);x[a+4>>2]=x[a+4>>2]+2;ic(a);hb=d+16|0;break a}d=Cb(a);d=pj(k,qj(a,Kc(x[a>>2],h)+1|0),b-x[a>>2]>>1,d);x[23604]=0;R(277,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)!=1){h=hb-32|0;hb=h;c=x[d+4>>2];e=Ib(h+24|0,b);g=Ib(h+16|0,x[a>>2]);i=Ib(h+8|0,x[d+4>>2]);f=x[e>>2];j=x[g>>2];e=hb-16|0;hb=e;x[e>>2]=x[i>>2];x[e+8>>2]=f;while(1){g=x[e>>2];if(og(f,j)){i=AU(g);f=AU(f);mo(i,y[f|0]|y[f+1|0]<<8);f=gu(e+8|0);gu(e);f=x[f>>2];continue}break}hb=e+16|0;x[d+4>>2]=g;e=x[a+4>>2];g=x[d+8>>2];while(1){if((b|0)!=(e|0)){mo(g,y[b|0]|y[b+1|0]<<8);g=g+2|0;b=b+2|0;continue}break}x[d+8>>2]=g;qc(a,d+4|0);qc(a+4|0,d+8|0);qc(Cb(a),yc(d));x[d>>2]=x[d+4>>2];hb=h+32|0;b=c;yi(d);break a}a=P()|0;yi(d);T(a|0);p()}i=hb-16|0;hb=i;g=x[a+4>>2];e=(g-(b+2|0)|0)+b|0;j=zi(i,a,h-e>>1);f=x[j+4>>2];d=e;while(1){if(d>>>0>=h>>>0){ic(j);while(1){if((b|0)!=(e|0)){e=e-2|0;g=zU(g-2|0,e);continue}break}hb=i+16|0}else{mo(f,y[d|0]|y[d+1|0]<<8);f=f+2|0;x[j+4>>2]=f;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0;c=y[a|0];v[b+1|0]=y[a+1|0];v[b|0]=c}Ib(k+24|0,b);hb=k+32|0}function Zx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=OL(b,c);a:{if(!x[b+656>>2]|!(v[h+6|0]&1)){break a}e=x[h>>2];i=a+1074312|0;f=Tb(i,31);d=Ju(x[b+656>>2],c);if(tc(x[d>>2],x[d+4>>2])){break a}f=e+(f^1)|0;g=Tb(i,31);e=y[d+12|0];b:{c:{if(!g){d:{if(!(e&2)){break d}j=y[d+14|0];k=!(x[a+480180>>2]&1048580)+z[zb(x[d>>2],j)>>1]|0;g=0;if(!(!(y[b+89|0]&8)|(!(e&4)|(j|0)!=y[d+16|0]))){g=Tb(i,70)}if(g|(f|0)!=(k|0)){break d}f=z[zb(x[d>>2],y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){a=x[d>>2];if((z[zb(a,y[d+16|0])>>1]+1|0)!=(f|0)){break b}f=z[zb(a,y[d+15|0])>>1];if(!Tb(i,93)|(c|0)!=1|y[b+89|0]&8){break b}v[h+6|0]=y[h+6|0]&254;break b}j=1;e=z[Mk(x[d+4>>2])>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|y[b+669|0]&8)){if(z[h+4>>1]==65535){break f}if(Tb(i,97)){break f}e=y[d+12|0]}if(e&2){g=x[d>>2];e=z[zb(g,y[d+13|0])>>1];g=z[zb(g,y[d+14|0])>>1]+1|0;break e}e=z[Mk(x[d+4>>2])>>1];j=f>>>0>e>>>0;g=e;break e}g=x[d>>2];e=z[zb(g,y[d+15|0])>>1];g=z[zb(g,y[d+16|0])>>1]+1|0}e=f>>>0<g>>>0?f:e}g:{if(!j|c){break g}f=x[a+480180>>2];c=x[b+88>>2];if(!(!(f&16777248)&(!(c&2048)|(f|0)==16384))){c=c|4096;x[b+88>>2]=c}if(y[Mk(x[d+4>>2])+2|0]|!(z[b+786>>1]|x[a+480180>>2]&16777248)){break g}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=c|4096}f=e}l=h,m=Tb(i,31)+f|0,x[l>>2]=m}}function T_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-16|0;hb=k;l=Cu(x[g>>2]);g=hw(x[g>>2]);Jg(k,g);a:{b:{if(wd(x[k+4>>2],y[k+11|0])){x[23604]=0;X(1081,l|0,a|0,c|0,d|0);g=x[23604];x[23604]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[23604]=0;j=Q(19,l|0,h<<24>>24)|0;h=x[23604];x[23604]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[23604]=0;h=Q(19,l|0,48)|0;i=x[23604];x[23604]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[23604]=0;h=Q(19,l|0,h|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}Cl(j,c);i=0;x[23604]=0;o=S(1079,g|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Cl((j-a|0)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[uc(k,h)|0]){break e}if(v[uc(k,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Eb(x[k+4>>2],y[k+11|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[23604]=0;n=Q(19,l|0,n|0)|0;m=x[23604];x[23604]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;xb(k);T(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;xb(k);hb=k+16|0}function Qca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-48|0;hb=d;l=a+480190|0;c=z[l>>1];v[d+32|0]=0;dO(b,c+1|0,d+32|0);j=a+480192|0;if(z[j>>1]){h=Sb(d+32|0);q=d,r=Bb(x[a+484344>>2]),x[q+24>>2]=r;o=Bb(x[a+484348>>2]);m=a+480188|0;while(1){i=x[d+24>>2];if(Ob(i,o)){a:{if(!Ob(x[i>>2],x[i+4>>2])){break a}c=z[m>>1];x[23604]=0;v[d+8|0]=0;U(701,h|0,c|0,d+8|0);c=x[23604];x[23604]=0;if((c|0)!=1){q=d,r=Bb(x[i>>2]),x[q+16>>2]=r;k=0;b:while(1){f=0;if(A[i+12>>2]<=k>>>0){break a}while(1)if(z[m>>1]<=f>>>0){k=k+1|0;continue b}else{c:{c=x[d+16>>2];if(!Tc(y[c|0])){break c}d:{e:{c=y[c+1|0];if(c){g=z[j>>1];break e}g=z[j>>1];c=y[Gb(x[h>>2],f)|0];if(c){break e}c=1;break d}q=Gb(x[h>>2],f),r=c,v[q|0]=r;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break c}e=x[((e<<2)+a|0)+900380>>2];f:{if(!e){break f}e=z[cc(e+236|0,y[x[d+16>>2]]-1|0)>>1];if(e>>>0>z[l>>1]){break f}n=d+8|0;Jb(n,x[b>>2],e);sg(n,1)}c=c+1|0;continue}}f=f+1|0;Tz(d+16|0);continue}}}a=P()|0;fc(h);T(a|0);p()}vt(d+24|0);continue}else{c=z[a+480190>>1];while(1){if(c){Jb(d+8|0,x[b>>2],c);if(!Mb(x[x[d+8>>2]>>2],x[d+12>>2])){e=f;f=D(c,104)+a|0;f=e+Qd(x[f+484380>>2],x[f+484400>>2])|0}c=c-1|0;continue}else{fc(h)}break}}break}}hb=d+48|0;return f&65535}function $3(a){a=a|0;var b=0,c=0,d=0,e=0;e=hb-160|0;hb=e;d=Xb(e,11475);x[23604]=0;b=d+12|0;Q(54,b|0,10864)|0;c=x[23604];x[23604]=0;a:{if((c|0)==1){break a}x[23604]=0;b=d+24|0;Q(54,b|0,11305)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=d+36|0;Q(54,b|0,10856)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=d+48|0;Q(54,b|0,8161)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=d+60|0;Q(54,b|0,10841)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=d+72|0;Q(54,b|0,8227)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=d+84|0;Q(54,b|0,5581)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=d+96|0;Q(54,b|0,11879)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=d+108|0;Q(54,b|0,11248)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=d+120|0;Q(54,b|0,12080)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=d+132|0;Q(54,b|0,5433)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;b=d+144|0;Q(54,b|0,7253)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;W(966,a|0,d|0,13)|0;a=x[23604];x[23604]=0;if((a|0)!=1){b=d+156|0;while(1){b=xb(b-12|0);if((d|0)!=(b|0)){continue}break}hb=e+160|0;return}b=d+156|0}a=P()|0;while(1){b=xb(b-12|0);if((d|0)!=(b|0)){continue}break}T(a|0);p()}function UP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=x[a>>2];e=mh(c,x[a+4>>2]);if(e>>>0<b>>>0){h=hb-32|0;hb=h;g=b-e|0;e=x[Cb(a)>>2];b=x[a+4>>2];a:{if(g>>>0<=e-b>>8>>>0){b=hb-16|0;hb=b;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(g<<8);a=x[b+4>>2];e=x[b+8>>2];while(1){if((a|0)==(e|0)){ic(b);hb=b+16|0}else{tz(a);a=a+256|0;x[b+4>>2]=a;continue}break}break a}i=Cb(a);c=h+8|0;e=a;f=mh(x[a>>2],b)+g|0;b=hb-16|0;hb=b;x[b+12>>2]=f;d=hb-16|0;hb=d;x[d+12>>2]=16777215;x[d+8>>2]=2147483647;a=x[Fb(d+12|0,d+8|0)>>2];hb=d+16|0;b:{if(a>>>0>=f>>>0){d=Az(e);if(d>>>0<a>>>1>>>0){x[b+8>>2]=d<<1;a=x[_c(b+8|0,b+12|0)>>2]}hb=b+16|0;break b}Sc();p()}f=mh(x[e>>2],x[e+4>>2]);d=hb-16|0;hb=d;Df(c+12|0,i);c:{if(!a){b=0;x[c>>2]=0;a=0;break c}if(a>>>0>=16777216){qi();p()}b=Jc(a<<8);x[d+12>>2]=a;x[d+8>>2]=b;b=x[d+8>>2];x[c>>2]=b;a=x[d+12>>2]}f=(f<<8)+b|0;x[c+4>>2]=f;x[c+8>>2]=f;j=yc(c),k=(a<<8)+b|0,x[j>>2]=k;hb=d+16|0;b=hb-16|0;hb=b;x[b>>2]=x[c+8>>2];a=x[c+8>>2];x[b+8>>2]=c+8;x[b+4>>2]=a+(g<<8);a=x[b>>2];while(1){if(x[b+4>>2]!=(a|0)){tz(a);a=x[b>>2]+256|0;x[b>>2]=a;continue}break}Hd(b);hb=b+16|0;xd(e,c);a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)!=(b|0)){b=b-256|0;x[c+8>>2]=b;continue}break}a=x[c>>2];if(a){yc(c);Hb(a)}}hb=h+32|0;return}if(b>>>0<e>>>0){Id(a,c+(b<<8)|0)}}function AO(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-240|0;hb=e;if(!y[94576]){if(!y[94452]){c=hb-16|0;hb=c;Kb(94428);x[23610]=0;v[94444]=0;x[23612]=0;x[23604]=0;b=ga(28)|0;a=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){x[c+8>>2]=b;b=c+8|0;Rz(94440,Wd(b));ej(b);v[94444]=0;break f}a=Aa(92520,93104)|0;b=ib;if((da(92520)|0)==(b|0)){_(a|0)|0;x[23604]=0;Z(29);c=x[23604];x[23604]=0;if((c|0)==1){break d}p()}if((da(93104)|0)!=(b|0)){break c}_(a|0)|0;x[23604]=0;v[94444]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){a=P()|0;break c}if(y[94444]){break e}}x[23604]=0;Y(30,94424);b=x[23604];x[23604]=0;if((b|0)!=1){break e}a=P()|0;break c}hb=c+16|0;break a}a=P()|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;if((c|0)==1){break b}}ej(94448);ej(94440);xb(94428);T(a|0);p()}V(0)|0;Vb();p()}v[94452]=1}c=hb+-64|0;hb=c;b=c+16|0;g=hb-16|0;hb=g;h=gO(g+8|0);j=e+120|0;while(1){if((i|0)==12){hb=g+16|0}else{f=hb-48|0;hb=f;a=x[h+4>>2];d=x[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=WN(bO(f+8|0,32));break g}d=G(a);d=bO(f+8|0,(a<<d+1?32:31)-d|0);while(1){k=WN(d);if(a>>>0<=k>>>0){continue}break}a=x[h>>2]+k|0}hb=f+48|0;l=zb(b,i),m=a,x[l>>2]=m;i=i+1|0;continue}break}b=rO(c,b,vO(b));lO(j,b);gm(b);hb=c- -64|0;vc(94456,vc(e,j,120),116);v[94576]=1}hb=e+240|0}function nF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=z[c>>1];c:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break e}if((g-x[a+8>>2]|0)<4){break a}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;v[f|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return f|0}function pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;h=hb-16|0;hb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];k=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=k;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];m=x[a+68>>2];u=m>>31;n=x[a+64>>2];v=n>>31;o=x[a+60>>2];y=o>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){k=f;if(d){f=Yb(k,-16777216,16776704);g=Jia(n,v,f,f>>31);f=lb;e=Yb(e,-16777216,16776704);e=Jia(m,u,e,e>>31);g=e+g|0;f=lb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];l=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;p=(((((D(w[g+4>>1],w[e+34>>1])+D(w[g+2>>1],w[e+32>>1])|0)+D(w[g+6>>1],w[e+36>>1])|0)+D(w[g+8>>1],w[e+38>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+26>>1])+D(w[g-6>>1],w[e+24>>1])|0)+D(w[g-2>>1],w[e+28>>1])|0)+D(w[g>>1],w[e+30>>1])|0)/2|0)|0)/16384<<8;e=p;g=Jia(e,e>>31,o,y);l=l+g|0;e=lb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Nc(f,e,24);e=(f|0)/256|0;j=j+s|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Ub(h+8|0,z,A);f=f-(t&p)|0;c=c+8|0;d=d-1|0;e=k;continue}break}b=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=k;x[a+24>>2]=i>>12;hb=h+16|0}function me(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,k=0;d=(q(b),j(2));c=ZE(d);a:{b:{c:{d:{e=(q(a),j(2));e:{if(e-2139095040>>>0>=2164260864){if(c){break e}break c}if(!c){break d}}h=E(1);if((e|0)==1065353216){break b}c=d<<1;if(!c){break b}i=c>>>0<4278190081;c=e<<1;a=E(a+b);if(!(i&c>>>0<=4278190080)){break a}if((c|0)==2130706432){break b}a=c>>>0>2130706431^(d|0)>=0?E(0):E(b*b);break a}if(ZE(e)){h=E(a*a);if((e|0)<0){h=(YE(d)|0)==1?E(-h):h}if((d|0)>=0){break b}a=rv(E(E(1)/h));break a}if((e|0)<0){c=YE(d);if(!c){a=QD(a);break a}e=e&2147483647;i=((c|0)==1)<<16}if(e>>>0>8388607){break c}e=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}d=e-1060306944|0;c=d>>>15&240;f=+(l(2,e-(d&-8388608)|0),r())*C[c+93144>>3]+-1;g=f*f;f=((f*.288457581109214+-.36092606229713164)*(g*g)+((f*.480898481472577+-.7213474675006291)*g+(f*1.4426950408774342+(C[c+93152>>3]+ +(d>>23)))))*+b;o(+f);c=j(1)|0;j(0)|0;f:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break f}if(f>127.99999995700433){a=eD(i);break a}if(!(f<=-150)){break f}a=KC(i);break a}k=f;g=C[160];f=g+f;g=k-(f-g);g=(C[161]*g+C[162])*(g*g)+(C[163]*g+1);o(+f);j(1)|0;e=j(0)|0;d=i+e|0;i=d<<15;d=((e&31)<<3)+1024|0;c=x[d>>2];d=x[d+4>>2]+i|0;l(0,c|0);l(1,(c>>>0>c>>>0?d+1|0:d)|0);h=E(g*+n())}a=h}return a}function pS(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;d=y[a|0];a:{if(d>>>0>21){break a}v[a|0]=y[d+27040|0];b:{switch(d-8|0){case 0:v[b|0]=y[b|0]<<1;break a;case 4:v[b|0]=y[b|0]+1>>>1;break a;case 5:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=y[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 4:break i;case 3:break j;case 1:break k;case 0:break l;case 14:break c;case 10:break d;default:break m}}v[a|0]=0;break a}v[a|0]=29;v[c+15|0]=y[b|0]&15;v[c+14|0]=14;e=b,f=y[Wb(c+15|0,c+14|0)|0]<<4|15,v[e|0]=f;break a}v[a|0]=29;v[c+13|0]=y[b|0]&15;v[c+12|0]=14;e=b,f=y[Wb(c+13|0,c+12|0)|0]|240,v[e|0]=f;break a}v[b|0]=d&15|48;break a}v[a|0]=35;v[b|0]=y[b|0]<<4^128;break a}v[b|0]=d&15|176;break a}v[b|0]=d&15|64;break a}v[a|0]=15;v[b|0]=y[b|0]&15;break a}v[a|0]=24;v[b|0]=(y[b|0]<<3&120)+8&240;break a}v[a|0]=24;v[b|0]=(y[b|0]&15)+1>>>1;break a}v[a|0]=10;break a;case 8:a=y[b|0];if(a>>>0<=223){v[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){v[b|0]=a<<2&48|15;break a}v[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=y[b|0];if(a>>>0<=223){v[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}v[b|0]=a>>>2&3|240}hb=c+16|0}function IR(a,b){var c=0;a:{b:{c:{d:{if(ce(a,16575)){break d}if(ce(a,17344)){break d}if(ce(a,13445)){break d}if(ce(a,13555)){break d}if(!ce(a,14120)){break c}}w[b+10>>1]=4;x[b>>2]=11911;break b}e:{f:{if(ce(a,17339)){break f}if(ce(a,13455)){break f}if(!ce(a,16560)){break e}}v[b+12|0]=1;x[b>>2]=8309;w[b+10>>1]=4;return 1}g:{if(!ce(a,14166)){if(!ce(a,14171)){break g}}w[b+10>>1]=8;x[b>>2]=8087;break b}h:{if(!ce(a,15159)){if(!ce(a,15164)){break h}}x[b>>2]=16947;w[b+10>>1]=v[a+2|0]-48;break b}i:{if(!ce(a,27242)){if(!ce(a,27247)){break i}}x[b+4>>2]=1;x[b>>2]=16753;w[b+10>>1]=y[a|0]==56?8:4;return 1}if(!(Rb(a,15268,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=8427;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break b}j:{if(Rb(a,13483,3)){if(Rb(a,13617,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=8186;w[b+10>>1]=v[a+3|0]-48;return 1}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!Rb(a+1|0,13641,3)){v[b+14|0]=1;x[b>>2]=8475;w[b+10>>1]=v[a|0]-48;return 1}if((y[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Rb(c,13969,2)){if(Rb(c,13645,2)){break k}}v[b+14|0]=1;x[b>>2]=8475;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;return 1}c=0;if(Rb(a,13311,3)|(y[a+3|0]-49&255)>>>0>8){break a}x[b>>2]=8336;w[b+10>>1]=v[a+3|0]-48}c=1}return c}function $L(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;f=a+484376|0;while(1){a:{c=_b(x[a+484360>>2],y[f|0]);e=b&65535;if(Kc(x[c>>2],x[c+4>>2])>>>0>e>>>0){if(!jq(c,e)){break a}c=_b(x[a+484360>>2],y[a+484376|0])}if(Kc(x[c>>2],x[c+4>>2])>>>0>e>>>0){e=a+1074312|0;f=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(f|0)){_L(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){Qn(a+1298264|0,1);x[a+1074456>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;Ay(a+1074376|0);w[a+1074450>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0}else{Tn((D(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}v[c+797|0]=0;x[c+700>>2]=0;v[c+841|0]=0;v[c+805|0]=0;x[c+708>>2]=0;v[c+821|0]=0;x[c+764>>2]=0;v[c+819|0]=0;v[c+820|0]=0;Jb(d+8|0,e,23);if(Mb(x[x[d+8>>2]>>2],x[d+12>>2])){v[c+807|0]=1;v[c+808|0]=0}v[c+839|0]=0;c=c+872|0;continue}break}w[a+1074450>>1]=b;w[a+1074446>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}hb=d+16|0;return}b=b+1|0;continue}}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;h=ff(a,c);_d(g,x[a+28>>2]);i=a;a:{if(!h){c=0;if(fd(a,5)){break a}}d=hb-160|0;hb=d;e=Dl(d+56|0,x[a+28>>2]);x[23604]=0;a=Q(394,d+40|0,44339)|0;c=x[23604];x[23604]=0;b:{c:{d:{e:{if((c|0)!=1){x[23604]=0;x[d+24>>2]=19924993;x[d+28>>2]=0;U(395,e|0,a|0,d+24|0);c=x[23604];x[23604]=0;if((c|0)==1){break e}Db(a);if(!(y[e+3|0]&64)){break d}break b}c=P()|0;break c}c=P()|0;Db(a);break c}k=d,l=nf(x[b>>2],x[b+4>>2]),w[k+38>>1]=l;w[d+36>>1]=65535;x[23604]=0;a=Q(394,d+24|0,9997)|0;c=x[23604];x[23604]=0;f:{if((c|0)!=1){x[23604]=0;c=W(424,e|0,d+36|0,a|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break f}Db(a);if((c|0)!=1){w[d+38>>1]=z[d+36>>1]}pg(d+38|0,4e3);a=z[d+38>>1];g:{if(nf(x[b>>2],x[b+4>>2])>>>0>=a>>>0){break g}x[23604]=0;R(211,b|0,a|0);c=x[23604];x[23604]=0;if((c|0)!=1){break g}c=P()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}f=x[b>>2];x[23604]=0;R(425,d+8|0,c|0);j=x[23604];x[23604]=0;if((j|0)!=1){x[23604]=0;X(426,e|0,ac(f,c)|0,d+8|0,427);f=x[23604];x[23604]=0;if((f|0)==1){break h}c=c+1|0;Db(d+8|0);continue}break}c=P()|0;break c}c=P()|0;Db(d+8|0);break c}c=P()|0;break c}c=P()|0;Db(a)}Wg(e);T(c|0);p()}Wg(e);hb=d+160|0;c=h}_e(i,c);hb=g+16|0}function EH(a,b,c){var d=0,e=0,f=0,g=0,h=E(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0);i=(b<<2)+a|0;b=i+1068|0;j=c<<1&-4;p=b,q=$d(a,j),x[p>>2]=q;f=i+1076|0;p=f,q=$d(a,j),x[p>>2]=q;g=$d(a,c&-4);x[i+1084>>2]=g;a:{k=x[b>>2];if(!k){break a}f=x[f>>2];if(!f|!g){break a}b=c>>2;o=(b|0)>0?b:0;h=E(c|0);b=0;while(1){if((d|0)==(o|0)){b=0;d=c>>3;k=(d|0)>0?d:0;d=0;while(1){if((b|0)!=(k|0)){f=d|1;e=+E(E(E(f<<1)*E(3.1415927410125732))/h);p=g+(d<<2)|0,r=E(Me(e)),B[p>>2]=r;p=g+(f<<2)|0,r=E(-E(mi(e))),B[p>>2]=r;d=d+2|0;b=b+1|0;continue}break}}else{l=b<<2;e=+E(E(E(d<<2)*E(3.1415927410125732))/h);p=k+l|0,r=E(Me(e)),B[p>>2]=r;m=b|1;n=m<<2;p=k+n|0,r=E(-E(mi(e))),B[p>>2]=r;e=+E(E(E(E(m|0)*E(3.1415927410125732))/h)*E(.5));p=f+l|0,r=E(E(Me(e))*E(.5)),B[p>>2]=r;p=f+n|0,r=E(E(mi(e))*E(.5)),B[p>>2]=r;b=b+2|0;d=d+1|0;continue}break}d=$d(a,j);x[i+1092>>2]=d;if(!d){break a}b=0;g=c>>1;j=(g|0)>0?g:0;e=+(g|0);while(1){if((b|0)!=(j|0)){h=E(mi((+(b|0)+.5)/e*.5*3.1415927410125732));p=d+(b<<2)|0,r=E(mi(+E(h*h)*1.5707963705062866)),B[p>>2]=r;b=b+1|0;continue}break}b=$d(a,c>>2&-2);x[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Kl(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Il(a)>>>c<<2,w[p>>1]=q;a=a+1|0;continue}break}return 1}gc(a,3);return 0}function Og(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=x[a+480180>>2];if(!lm(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((D(a,-12)+e&255)<<1)+33776>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(Xi(a)){a=((e&255)>>>0)/12|0;b=Jia(x[(D(a,-12)+e<<6&960)+37664>>2]<<a,0,d,0);a=lb;c=a>>>21|0;h=f,i=Uc((a&2097151)<<11|b>>>21,c),x[h+8>>2]=i;wc(f+8|0,2147483647);e=x[f+8>>2];break a}if(y[a+480208|0]&16){a=e&255;e=z[((a>>>0)%12<<1)+33776>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;wc(f+12|0,-1>>>a|0);e=Uc(Mia(Jia(z[((D(a,-12)+e&255)<<1)+33776>>1],0,267616,0),lb,x[f+12>>2]<<a,0),lb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{b=Tb(a+1074312|0,76)?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)<=1?1:a;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(D(c,-12)+a<<3&248)|0;x[f+4>>2]=d+8;fe(f+4|0,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)<=-8?-8:a;e=D(b,z[(((a|0)>=95?95:a)<<1)+34272>>1])+D(z[(x[f+4>>2]<<1)+34256>>1],16-b|0)<<1>>>c|0;break a}if(!((c&255)>>>0<16&b-25>>>0<=83)){a=((e&255)>>>0)/12|0;e=z[(D((c&240)>>>4|0,12)+(D(a,-12)+e&255)<<1)+33376>>1]<<5>>>a|0;break a}e=z[(b<<1)+33150>>1]<<2}hb=f+16|0;return e}function SV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=hb-1088|0;hb=g;e=xh(a);Zb(e+20|0,0,1040);x[e+1064>>2]=0;x[e+1068>>2]=0;x[e+1060>>2]=c;v[e+1084|0]=d;a=e+1072|0;x[a>>2]=0;x[a+4>>2]=0;x[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(Gd(z[a+34>>1])>>>0<=d>>>0){break a}x[e+1064>>2]=0;x[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(A[c>>2]<=a>>>0){break j}a=x[b+8>>2];f=x[b>>2];x[23604]=0;a=W(142,f|0,a|0,2)|0;f=x[23604];x[23604]=0;if((f|0)==1){break i}if(!a){break j}x[23604]=0;a=S(180,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break h}if(!a){break e}x[23604]=0;U(176,g|0,b|0,a|0);a=x[23604];x[23604]=0;if((a|0)==1){break g}a=Yq(g+24|0,g);f=$c(e,a);vc(f+20|0,a+20|0,1040);yb(a);yb(g);x[e+1076>>2]=0;x[e+1080>>2]=0;h=x[e+1060>>2];a=x[h+20>>2];if(Fm(z[h+34>>1])>>>0>=2){x[23604]=0;R(181,f|0,a+(d<<1)|0);a=x[23604];x[23604]=0;if((a|0)!=1){break e}break f}x[23604]=0;R(182,f|0,a+d|0);a=x[23604];x[23604]=0;if((a|0)==1){break f}break e}d=d+1|0;a=x[e+1060>>2];continue c}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}a=V(30848)|0;if((ib|0)!=(da(30848)|0)){break b}_(a|0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break d}}a=x[i>>2];continue}break}break}a=P()|0}yb(e);T(a|0);p()}hb=g+1088|0;return e|0}function _2(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-80|0;hb=e;a:{b:{c:{d:{f=a+36|0;d=x[f>>2];c=x[a+40>>2];e:{if(Ob(d,c)){zc(e+72|0);break e}c=e+32|0;wn(c,a);x[23604]=0;c=S(959,c|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break d}x[e+72>>2]=c;Of(e+32|0);c=x[a+40>>2];d=x[a+36>>2]}c=(k=f,l=x[e+72>>2],m=Ob(d,c),m?k:l);f=x[a+8>>2];if((f|0)==-1){d=x[c+4>>2];f=d-24|0;g=x[c>>2];i=vn(g,d);j=C[f>>3];d=0;while(1){if((d|0)==(i|0)){c=f;break c}c=bl(g,d);if(h+C[c>>3]>b){break c}d=d+1|0;h=h+j;continue}}c=bl(x[c>>2],f);break b}d=P()|0;Of(e+32|0);break a}b=b-h}f=z[c+12>>1];d=x[a+24>>2];x[23604]=0;R(992,d|0,f|0);f=x[23604];x[23604]=0;if((f|0)!=1){f:{f=x[a+24>>2];d=y[a+64|0];c=TL(AR(e+32|0,b),y[c+16|0],z[c+12>>1],x[c+8>>2]);x[23604]=0;g=x[c+12>>2];x[e+16>>2]=x[c+8>>2];x[e+20>>2]=g;g=x[c+20>>2];x[e+24>>2]=x[c+16>>2];x[e+28>>2]=g;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;X(993,e+56|0,f|0,(d?7:1)|0,e+8|0);c=x[23604];x[23604]=0;if((c|0)==1){break f}c=_s(x[e+60>>2]);f=v[c+26|0]&1;d=x[(f?c+8|0:c+12|0)>>2];f=z[(f?c+20|0:c+22|0)>>1];b=C[c>>3];ni(e+56|0);c=x[a+24>>2];w[c+1074450>>1]=f;w[c+1074448>>1]=f;x[c+1074428>>2]=d;x[c+1074392>>2]=-2;b=h+b;C[a+16>>3]=b;Dk(e+72|0);hb=e+80|0;return+b}}d=P()|0;Dk(e+72|0)}T(d|0);p()}function QN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=hb-48|0;hb=f;n=Uy(x[a+24>>2],y[a+32|0]);o=$i(n);a:{b:{while(1){c:{w[b>>1]=m;e=m&65535;if(e>>>0>=o>>>0){break c}if(jq(n,e)){e=x[a>>2];d=Dd(e,x[a+4>>2]);g=z[b>>1];if(d>>>0<=g>>>0){x[c>>2]=0;break a}l=Zd(e,g);$k(f+32|0,x[l>>2]);hm(f+24|0,x[l>>2],x[l+4>>2]);e=x[f+36>>2];x[f+8>>2]=x[f+32>>2];x[f+12>>2]=e;g=hb-32|0;hb=g;e=x[f+12>>2];i=e;d=x[f+8>>2];e=_k(x[f+24>>2],x[f+28>>2],d,e);x[g+8>>2]=d;x[g+12>>2]=i;x[g+24>>2]=d;x[g+28>>2]=i;i=f+40|0;j=hb-16|0;hb=j;x[j+12>>2]=e;d=x[g+12>>2];d:{if(d){h=32-d|0;x[j+8>>2]=h;k=-1<<d;d=x[Fb(j+8|0,j+12|0)>>2];k=k&-1>>>h-d;h=x[g+8>>2];k=k&x[h>>2];if(k){ec(i,h,Iia(k));break d}if((e|0)==(d|0)){d=x[g+12>>2];x[i>>2]=x[g+8>>2];x[i+4>>2]=d;mP(i,e);break d}e=e-d|0;x[j+12>>2]=e;d=h+4|0}else{d=x[g+8>>2]}while(1){if(e>>>0>=32){h=x[d>>2];if(h){ec(i,d,Iia(h));break d}else{e=e-32|0;x[j+12>>2]=e;d=d+4|0;continue}}break}if(!e){ec(i,d,0);break d}h=x[d>>2]&-1>>>32-e;if(!h){ec(i,d,e);break d}ec(i,d,Iia(h))}hb=j+16|0;hb=g+32|0;hm(f+16|0,x[l>>2],x[l+4>>2]);if(x[f+40>>2]==x[f+16>>2]&x[f+44>>2]==x[f+20>>2]){break b}}m=z[b>>1]+1|0;continue}break}w[b>>1]=65535;x[c>>2]=-1;break a}x[c>>2]=0}hb=f+48|0;return(m&65535)>>>0<o>>>0|0}function qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=hb-16|0;hb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];k=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=k;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];m=x[a+68>>2];u=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){k=f;if(d){f=Yb(k,-16777216,16776704);g=Jia(n,y,f,f>>31);f=lb;e=Yb(e,-16777216,16776704);e=Jia(m,u,e,e>>31);g=e+g|0;f=lb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];l=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;p=((((D(v[g+2|0],w[e+34>>1])+D(v[g+1|0],w[e+32>>1])|0)+D(v[g+3|0],w[e+36>>1])|0)+D(v[g+4|0],w[e+38>>1])<<8>>1)+(((D(v[g-2|0],w[e+26>>1])+D(v[g-3|0],w[e+24>>1])|0)+D(v[g-1|0],w[e+28>>1])|0)+D(v[g|0],w[e+30>>1])<<8>>1)|0)/16384<<8;e=p;g=Jia(e,e>>31,o,z);l=l+g|0;e=lb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Nc(f,e,24);e=(f|0)/256|0;j=j+s|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Ub(h+8|0,A,B);f=f-(t&p)|0;c=c+8|0;d=d-1|0;e=k;continue}break}b=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=k;x[a+24>>2]=i>>12;hb=h+16|0}function oK(a){var b=0,c=E(0),d=0,e=0,f=0,g=E(0),h=0,i=0,k=E(0),m=0,n=0,o=E(0);d=hb-16|0;hb=d;b=x[x[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=me(E(10),E(E(E(B[zb(e,0)>>2]*E(120))+E(-60))/E(20))),B[n+4232>>2]=o;k=E(E(b>>>0)/E(1e3));n=a,o=me(E(10),E(E(-1)/E(k*E(E(B[zb(e,1)>>2]*E(499.989990234375))+E(.009999999776482582))))),B[n+4236>>2]=o;n=a,o=me(E(10),E(E(-1)/E(k*E(E(B[zb(e,2)>>2]*E(2950))+E(50))))),B[n+4240>>2]=o;x[d+12>>2]=1325400064;c=E(me(E(10),E(E(E(B[zb(e,3)>>2]*E(60))+E(-60))/E(20)))*E(2147483648));b=(q(c),j(2));g=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){g=E(rv(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=QD(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),r())*C[h+3568>>3]+-1;m=i*i;c=E((C[479]*m+(C[480]*i+C[481]))*m+(+(f>>23)*C[478]+C[h+3576>>3]+i))}g=c}B[d+8>>2]=E(E(g*E(67108864))/E(.6931471824645996))+E(67108864);n=a,o=E(B[Pl(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[n+4244>>2]=o;n=a,o=E(E(E(-1)/E(E(B[zb(e,4)>>2]*E(99))+E(1)))+E(1)),B[n+4248>>2]=o;c=E(E(E(B[zb(e,5)>>2]*E(4))*k)+E(2));c:{if(E(F(c))<E(2147483648)){h=~~c;break c}h=-2147483648}x[a+4252>>2]=h;hb=d+16|0}function aj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!Qd(x[a>>2],x[a+20>>2])){break a}ek(a);b:{switch(Fm(z[a+34>>1])-1|0){case 1:h=hb-48|0;hb=h;g=x[a+20>>2];c=x[a>>2];d=Gd(z[a+34>>1]);e=g+(D(c,d)<<1)|0;while(1){c:{d:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break d}f=e+(d<<5)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;$O(h+24|0,f,g+(D(d,e)<<1)|0,i,d,(c&4)>>>2|0,Tb(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;$O(h,f+(d<<7)|0,g+(D(a,d)<<1)|0,e,d,(c&16)>>>4|0,Tb(b+1074312|0,33))}hb=h+48|0;break c}while(1){if((c|0)!=(d|0)){w[e+(c+i<<1)>>1]=z[e+(c-d<<1)>>1];w[g+(c+j<<1)>>1]=z[g+(c<<1)>>1];c=c+1|0;continue}break}f=f+1|0;continue}break};return;case 0:break b;default:break a}}h=hb-48|0;hb=h;g=x[a+20>>2];c=x[a>>2];d=Gd(z[a+34>>1]);e=g+D(c,d)|0;while(1){e:{f:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break f}f=e+(d<<4)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;_O(h+24|0,f,g+D(d,e)|0,i,d,(c&4)>>>2|0,Tb(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;_O(h,f+(d<<6)|0,g+D(a,d)|0,e,d,(c&16)>>>4|0,Tb(b+1074312|0,33))}hb=h+48|0;break e}while(1){if((c|0)!=(d|0)){v[e+(c+i|0)|0]=y[e+(c-d|0)|0];v[g+(c+j|0)|0]=y[c+g|0];c=c+1|0;continue}break}f=f+1|0;continue}break}}}function AG(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=md(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=x[a+4>>2];i:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break i}c=md(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];j:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break j}c=md(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=Jia(e,d,10,0);d=b+c|0;c=lb;e=d-48|0;d=(b>>>0>d>>>0?c+1|0:c)-(d>>>0<48)|0;b=x[a+4>>2];l:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;c=y[b|0];break l}c=md(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=x[a+4>>2];m:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break m}b=md(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){x[a+4>>2]=x[a+4>>2]-1}lb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}x[a+4>>2]=x[a+4>>2]-1;break b}if(x[a+116>>2]<0){break a}}x[a+4>>2]=x[a+4>>2]-1}lb=-2147483648;return 0}function Aaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=hb-16|0;hb=l;k=hb-32|0;hb=k;h=k+28|0;f=k+24|0;g=hb-16|0;hb=g;a:{b:{if(!tc(b,x[Ib(g+8|0,Ef(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=sd(b);m=z[j>>1];j=x[j+4>>2];if(!Tk(e,i,m,j)){break b}}x[g+8>>2]=b;e=Ib(g,Bb(x[a>>2]));c:{f=x[g+8>>2];if(!tc(f,x[e>>2])){f=x[Ty(g+8|0)>>2];e=sd(f);j=z[e>>1];m=x[e+4>>2];e=z[c>>1];i=x[c+4>>2];if(!Tk(j,m,e,i)){break c}}if(!x[b>>2]){x[h>>2]=b;break a}x[h>>2]=f;b=f+4|0;break a}b=Sy(a,h,e,i);break a}if(Tk(m,j,e,i)){d:{f=Ry(b);if(!tc(f,x[Ib(g+8|0,Ef(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=sd(f);if(!Tk(e,i,z[j>>1],x[j+4>>2])){break d}}if(!x[b+4>>2]){x[h>>2]=b;b=b+4|0;break a}x[h>>2]=f;b=f;break a}b=Sy(a,h,e,i);break a}x[h>>2]=b;x[f>>2]=b;b=f}hb=g+16|0;f=b;b=x[b>>2];if(!b){b=hb-16|0;hb=b;g=jc(a);h=k+8|0;e=ph(h,Jc(36),qh(b+8|0,g));g=x[e>>2]+16|0;i=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=i;Qj(g+8|0,d);o=jc(e),p=1,v[o+4|0]=p;hb=b+16|0;Vg(a,x[k+28>>2],f,x[k+8>>2]);b=Wd(h);YN(h);n=1}Ug(l,x[Ib(k+8|0,b)>>2],n);hb=k+32|0;if(!y[jc(l)|0]){a=sd(x[l>>2])+8|0;XN(a);x[a>>2]=x[d>>2];x[a+4>>2]=x[d+4>>2];b=Cb(d);o=Cb(a),p=x[b>>2],x[o>>2]=p;x[b>>2]=0;x[d>>2]=0;x[d+4>>2]=0}a=x[Ib(l+8|0,x[l>>2])>>2];hb=l+16|0;return a|0}function kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-16|0;hb=e;q=x[a+16>>2];r=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=Xf(k,b,l);o=lb;h=x[a+76>>2];b=x[a>>2];g=x[a+4>>2];Cf(b,g,Ze(k,m,d),lb);h=lb>>>0>h>>>0?d:0}f=a+112|0;s=x[a+24>>2];t=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;while(1){if(d){i=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;d=d-1|0;p=(((i&2147483647)<<1|b>>>31)&-2)+q|0;i=l;b:{c:while(1){d:{if((i|0)<=0){Ub(f,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break b}b=x[e+8>>2];i=((x[e+12>>2]&2147483647)<<1|b>>>31)&-2;j=0;b=0;break d}b=x[e+8>>2];g=((x[e+12>>2]&2147483647)<<1|b>>>31)&-2;b=0;j=0;while(1)if((b|0)==2){Kd(f,j>>>3<<16>>16);Jd(f,4);Ub(e+8|0,n,o);i=i-1|0;continue c}else{j=(v[(b+g|0)+p|0]<<8)+j|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){j=(v[(b+i|0)+p|0]<<8)+j|0;b=b+1|0;continue}break}Kd(f,j>>>3<<16>>16);Jd(f,g);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Tf(f,r);x[c>>2]=x[c>>2]+D(b,t);x[c+4>>2]=x[c+4>>2]+D(b,s);Ub(e,k,m);c=c+8|0;continue}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;hb=e+16|0}function Lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=hb-16|0;hb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];v=w[b+2>>1];y=w[b>>1];k=0;while(1){if((k|0)!=2){b=(k<<1)+o|0;x[(k<<2)+e>>2]=(((((((D(w[b-8>>1],v)+D(w[b-12>>1],y)|0)+D(w[b-4>>1],u)|0)+D(w[b>>1],t)|0)+D(w[b+4>>1],s)|0)+D(w[b+8>>1],r)|0)+D(w[b+12>>1],q)|0)+D(w[b+16>>1],p)|0)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Ub(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;hb=e+16|0}function H8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0);h=w[d>>1];j=w[d+2>>1];a:{if((h|0)>(j|0)){break a}k=x[b>>2];g=rc(k,x[b+4>>2]);if(!g){break a}i=w[e>>1];if((i|0)<(h|0)|(i|0)>(j|0)|(g-1&65535)>>>0>(j-i&65535)>>>0|A[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(g|0)){break b}i=zb(k,f);f=f+1|0;if(!(B[i>>2]<E(0))){continue}break}return 0}i=(f|0)!=(g|0);f=0;if(i){break a}l=B[c>>2];if(l<=E(0)){break a}w[a+28>>1]=h;w[a>>1]=1;m=a,n=gL(g),w[m+30>>1]=n;B[a+32>>2]=F(l);Gj(a+4|0,(j-h|0)+1|0);c=Bb(x[b>>2]);h=Bb(x[b+4>>2]);f=Pj(Bb(x[a+4>>2]),w[e>>1]-w[d>>1]|0);g=hb-16|0;hb=g;b=hb-32|0;hb=b;jm(b+24|0,c,h);el(b+16|0,x[b+24>>2],x[b+28>>2],f);c=Gx(c,x[b+16>>2]);m=b,n=fL(f,x[b+20>>2]),x[m+8>>2]=n;yd(g+8|0,c,b+8|0);hb=b+32|0;hb=g+16|0;c=x[a+4>>2];g=w[a+30>>1];h=w[a+28>>1];b=w[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;j=zb(c,b+g|0);m=zb(c,b),o=E(B[j>>2]/B[a+32>>2]),B[m>>2]=o;b=z[e>>1];continue}else{c=w[a+30>>1];e=w[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=x[a+4>>2];d=w[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=zb(b,f-h|0);m=zb(b,f-e|0),o=E(B[a+32>>2]*B[g>>2]),B[m>>2]=o;f=f+1|0;continue}else{fp(a)}break}}break}f=1}return f|0}function Z5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=hb-16|0;hb=k;i=hb-32|0;hb=i;f=Ue(i+16|0,1,0);a:{b:{c:{while(1){e=Pb(f);g=e+Eb(x[f+4>>2],y[f+11|0])|0;c=x[b>>2];d=x[b+4>>2];if(!((d|0)>0|(d|0)>=0|(e|0)==(g|0))){v[e|0]=45;h=c;c=0-c|0;e=e+1|0;d=0-(((h|0)!=0)+d|0)|0}j=g-e|0;d:{if((j|0)<=19){h=G(d);m=D(64-((h|0)==32?G(c|1)+32|0:h)|0,1233)>>12;l=(m<<3)+91552|0;h=x[l>>2];n=j;j=x[l+4>>2];l=61;if((n|0)<(((d|0)==(j|0)&c>>>0>=h>>>0|d>>>0>j>>>0)+m|0)){break d}}e:{if(!d){g=ox(e,c);break e}if((d|0)==2&c>>>0>=1410065408|d>>>0>2){g=Mia(c,d,1410065408,2);h=Jia(g,lb,-1410065408,-3);d=d+lb|0;j=c;c=c+h|0;d=j>>>0>c>>>0?d+1|0:d;e=ox(e,g)}d=Mia(c,d,1e8,0);g=lb;e=Ik(e,d);c=Jia(d,g,-1e8,0)+c|0;g=ps(e,c)}l=0}x[i+12>>2]=l;x[i+8>>2]=g;if(!x[i+12>>2]){break c}c=Rf(Eb(x[f+4>>2],y[f+11|0]));x[23604]=0;R(58,f|0,c|0);c=x[23604];x[23604]=0;if((c|0)!=1){continue}break}break b}b=x[i+8>>2];c=Pb(f);x[23604]=0;R(59,f|0,b-c|0);b=x[23604];x[23604]=0;f:{if((b|0)!=1){x[23604]=0;R(60,k|0,f|0);b=x[23604];x[23604]=0;if((b|0)!=1){break f}break b}break b}xb(f);hb=i+32|0;break a}a=P()|0;xb(f);T(a|0);p()}x[23604]=0;R(57,a|0,k|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(k);hb=k+16|0;return}a=P()|0;xb(k);T(a|0);p()}function SI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;tf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=hb-32|0;hb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}l=x[c+28>>2];if(de(x[c+24>>2],l)>>>0<f>>>0){break b}m=b+12|0;n=x[c+16>>2];o=x[c>>2];e:while(1){d=0;if((f|0)==(h|0)){break a}while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{j=Mg(o,k,d,h);e=zb(x[b>>2],d);i=ee(Yf(C[j>>3])*134217728);j=e;e=(x[e>>2]>>1)+cm(i)|0;q=e;e=$r(m)+e&-4096;x[j>>2]=q-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;i=ee(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}e=Vc(e);r=sn(n,l,d,h),s=e,w[r>>1]=s;d=d+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=c- -64|0}function fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=hb-16|0;hb=e;q=x[a+16>>2];r=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){l=x[a+8>>2];n=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];i=0;break a}b=x[a+12>>2];n=b;l=x[a+8>>2];o=Xf(l,b,m);p=lb;i=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];Cf(b,f,Ze(l,n,d),lb);i=lb>>>0>i>>>0?d:0}g=a+112|0;j=x[a+40>>2];k=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;o=i?o:0;p=i?p:0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=m;while(1)if((b|0)<=0){Ub(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;Kd(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Tf(g,r);f=x[a+32>>2];k=x[a+28>>2]+k|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=f+j|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Ub(e,l,n);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue b}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;Kd(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(g,4);Ub(e+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;hb=e+16|0}function F_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=hb-384|0;hb=f;x[f+376>>2]=37;x[f+380>>2]=0;h=wr(f+376|1,21502,x[c+4>>2]);x[f+332>>2]=f+336;a=zd();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=Ig(f+336|0,30,a,f+376|0,f+32|0);break a}C[f+48>>3]=e;g=Ig(f+336|0,30,a,f+376|0,f+48|0)}x[f+80>>2]=1071;i=le(f+320|0,0,f+80|0);b=f+336|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=zd();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=Ki(f+332|0,a,f+376|0,f);break f}C[f+16>>3]=e;g=Ki(f+332|0,a,f+376|0,f+16|0)}if((g|0)==-1){x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)==1){break d}break e}a=x[f+332>>2];Ie(i,a)}j=a+g|0;l=Li(a,j,x[c+4>>2]);x[f+68>>2]=1071;h=le(f+72|0,0,f+68|0);g:{h:{if((f+336|0)==(a|0)){g=f+80|0;break h}g=Ld(g<<3);if(!g){x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)!=1){break e}a=P()|0;break g}Ie(h,g);b=a}a=f+56|0;Pc(a,x[c+28>>2]);x[23604]=0;ia(1102,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[23604];x[23604]=0;i:{if((a|0)!=1){$b(f+56|0);x[23604]=0;a=ka(1103,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break i}Mc(h);Mc(i);hb=f+384|0;break b}a=P()|0;$b(f+56|0);break g}a=P()|0}Mc(h);break c}p()}a=P()|0}Mc(i);T(a|0);p()}return a|0}function P_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=hb-208|0;hb=f;x[f+200>>2]=37;x[f+204>>2]=0;h=wr(f+200|1,21502,x[c+4>>2]);x[f+156>>2]=f+160;a=zd();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=Ig(f+160|0,30,a,f+200|0,f+32|0);break a}C[f+48>>3]=e;g=Ig(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=1071;i=le(f+144|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=zd();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=Ki(f+156|0,a,f+200|0,f);break f}C[f+16>>3]=e;g=Ki(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)==1){break d}break e}a=x[f+156>>2];Ie(i,a)}j=a+g|0;l=Li(a,j,x[c+4>>2]);x[f+68>>2]=1071;h=le(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Ld(g<<1);if(!g){x[23604]=0;Z(1072);a=x[23604];x[23604]=0;if((a|0)!=1){break e}a=P()|0;break g}Ie(h,g);b=a}a=f+56|0;Pc(a,x[c+28>>2]);x[23604]=0;ia(1097,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[23604];x[23604]=0;i:{if((a|0)!=1){$b(f+56|0);x[23604]=0;a=ka(14,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break i}Mc(h);Mc(i);hb=f+208|0;break b}a=P()|0;$b(f+56|0);break g}a=P()|0}Mc(h);break c}p()}a=P()|0}Mc(i);T(a|0);p()}return a|0}function HX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(Hg(a,x[b+8>>2],e)){Qv(b,c,d);return}a:{if(Hg(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;if(x[b+44>>2]!=4){f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;Nv(x[f>>2],x[f+4>>2],b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){d=1;if(x[b+24>>2]==1){break c}g=1;if(y[a+8|0]&2){break e}break c}g=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}x[b+44>>2]=a;if(d&1){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];h=a+16|0;rr(x[h>>2],x[a+20>>2],b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}rr(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}rr(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}rr(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function Hia(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}if(!d){break i}e=G(d)-G(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;jb=a-D(b,c)|0;kb=0;lb=0;return b}if(!a){break g}if(!d){break f}f=d-1|0;if(f&d){break f}jb=a;kb=e&f;a=e>>>Iia(d)|0;lb=0;return a}f=c-1|0;if(!(f&c)){break e}j=(G(c)+33|0)-G(e)|0;h=0-j|0;break c}j=e+1|0;h=63-e|0;break c}jb=0;a=(e>>>0)/(d>>>0)|0;kb=e-D(a,d)|0;lb=0;return a}e=G(d)-G(e)|0;if(e>>>0<31){break d}break b}jb=a&f;kb=0;if((c|0)==1){break a}c=Iia(c);d=c&31;if((c&63)>>>0>=32){e=0;a=b>>>d|0}else{e=b>>>d|0;a=((1<<d)-1&b)<<32-d|a>>>d}lb=e;return a}j=e+1|0;h=63-e|0}f=a;e=j&63;g=e&31;if((e&63)>>>0>=32){e=0;f=b>>>g|0}else{e=b>>>g|0;f=((1<<g)-1&b)<<32-g|f>>>g}h=h&63;g=h&31;if((h&63)>>>0>=32){i=a<<g;a=0}else{i=(1<<g)-1&a>>>32-g|b<<g;a=a<<g}b=i;if(j){h=d-1|0;k=c-1|0;h=(k|0)!=-1?h+1|0:h;g=k;while(1){e=e<<1|f>>>31;f=f<<1|b>>>31;k=e;l=h-(e+(f>>>0>g>>>0)|0)|0;m=l>>31;i=m;e=f;l=c&i;f=e-l|0;e=k-((d&i)+(e>>>0<l>>>0)|0)|0;i=b<<1|a>>>31;a=n|a<<1;b=i|o;k=m&1;n=k;j=j-1|0;if(j){continue}break}}jb=f;kb=e;i=b<<1|a>>>31;a=k|a<<1;lb=i|o;return a}jb=a;kb=b;a=0;b=0}lb=b;return a}function LI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;tf(c+48|0,c+32|0,f);a=x[d+4>>2];g=x[a+8>>2];j=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;f=c+16|0;a=hb-32|0;hb=a;a:{b:{c:{d:{l=x[c+4>>2];if(l>>>0>=j>>>0){if(A[f+4>>2]<j>>>0){break d}if(A[c+8>>2]<g>>>0){break c}if(de(x[f+8>>2],x[f+12>>2])>>>0<g>>>0){break b}m=b+12|0;n=x[c>>2];e:while(1){d=0;if((g|0)==(h|0)){break a}while(1)if((d|0)==(j|0)){h=h+1|0;continue e}else{k=Mg(n,l,d,h);e=zb(x[b>>2],d);i=ee(Yf(C[k>>3])*134217728);k=e;e=(x[e>>2]>>1)+cm(i)|0;o=e;e=$r(m)+e&-4096;x[k>>2]=o-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;i=ee(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}e=Vc(e);q=rn(f,d,h),r=e,w[q>>1]=r;d=d+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=c- -64|0}function Mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=hb-16|0;hb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];k=0;while(1){if((k|0)!=2){b=k+o|0;x[(k<<2)+e>>2]=(((((((D(v[b-4|0],y)+D(v[b-6|0],z)|0)+D(v[b-2|0],u)|0)+D(v[b|0],t)|0)+D(v[b+2|0],s)|0)+D(v[b+4|0],r)|0)+D(v[b+6|0],q)|0)+D(v[b+8|0],p)<<8)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Ub(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;hb=e+16|0}function pF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){j=x[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=y[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=y[j+2|0];i=y[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=y[j+3|0];m=y[j+2|0];k=y[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}x[f>>2]=c;x[a+12>>2]=i+j;f=x[a+8>>2]+4|0;x[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return b|0}function U9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=hb-16|0;hb=l;x[l+8>>2]=b;q=xf(a);while(1){if(xg(b,c)){b=x[Ib(l,q)>>2];k=sd(x[l+8>>2]);o=hb-16|0;hb=o;p=0;m=hb-16|0;hb=m;i=hb-32|0;hb=i;g=i+28|0;d=i+24|0;e=hb-16|0;hb=e;a:{b:{if(!tc(b,x[Ib(e+8|0,Ef(a))>>2])){f=y[k|0];j=x[k+4>>2];h=sd(b);n=y[h|0];h=x[h+4>>2];if(!Fn(f,j,n,h)){break b}}x[e+8>>2]=b;f=Ib(e,Bb(x[a>>2]));c:{d=x[e+8>>2];if(!tc(d,x[f>>2])){d=x[Ty(e+8|0)>>2];f=sd(d);h=y[f|0];n=x[f+4>>2];f=y[k|0];j=x[k+4>>2];if(!Fn(h,n,f,j)){break c}}if(!x[b>>2]){x[g>>2]=b;break a}x[g>>2]=d;b=d+4|0;break a}b=sy(a,g,f,j);break a}if(Fn(n,h,f,j)){d:{d=Ry(b);if(!tc(d,x[Ib(e+8|0,Ef(a))>>2])){f=y[k|0];j=x[k+4>>2];h=sd(d);if(!Fn(f,j,y[h|0],x[h+4>>2])){break d}}if(!x[b+4>>2]){x[g>>2]=b;b=b+4|0;break a}x[g>>2]=d;b=d;break a}b=sy(a,g,f,j);break a}x[g>>2]=b;x[d>>2]=b;b=d}hb=e+16|0;d=b;b=x[b>>2];if(!b){b=hb-16|0;hb=b;e=jc(a);g=i+8|0;e=ph(g,Jc(28),qh(b+8|0,e));Dz(x[e>>2]+16|0,k);r=jc(e),s=1,v[r+4|0]=s;hb=b+16|0;Vg(a,x[i+28>>2],d,x[i+8>>2]);b=Wd(g);cl(g);p=1}Ug(m+8|0,x[Ib(i+8|0,b)>>2],p);hb=i+32|0;hb=m+16|0;Ib(o+8|0,x[m+8>>2]);hb=o+16|0;b=x[Tg(l+8|0)>>2];continue}else{hb=l+16|0}break}}function Kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;od(b,0);uo(b);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=Ge(wj(+(f+1408|0)/1536)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[Wb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=y[a+6|0]|y[a+7|0]<<8;if(d>>>0<=256){w[b+28>>1]=d;w[b+34>>1]=z[b+34>>1]|32}x[b>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+4>>2]=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);x[b+8>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);d=y[a+20|0]|y[a+21|0]<<8;if(d&16){w[b+34>>1]=z[b+34>>1]|2;d=y[a+20|0]|y[a+21|0]<<8}if(d&32){w[b+34>>1]=z[b+34>>1]|4;d=y[a+20|0]|y[a+21|0]<<8}if(d&256){w[b+34>>1]=z[b+34>>1]|8;d=y[a+20|0]|y[a+21|0]<<8}if(d&512){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+40224|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[Wb(e+13|0,e+12|0)|0],w[g+32>>1]=h}x[b+12>>2]=y[a+27|0]|y[a+28|0]<<8|(y[a+29|0]<<16|y[a+30|0]<<24);x[b+16>>2]=y[a+31|0]|y[a+32|0]<<8|(y[a+33|0]<<16|y[a+34|0]<<24);hb=e+16|0}function w6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=0;i=hb-16|0;hb=i;if(Qh(a+44|0)){n=x[a+44>>2];j=Cc(n,0);k=Cc(n,1);n=x[a+56>>2];t=Cc(n,0);n=Cc(n,1);u=B[zb(a+4208|0,1)>>2];x[i+12>>2]=d;s=x[a+4220>>2];q=E(E(1)/E(s>>>0));v=x[a+4216>>2];o=d;f=n;g=t;while(1){if(o){h=x[a+4224>>2];a:{if(s>>>0>h>>>0){x[i+8>>2]=s-h;r=x[Fb(i+12|0,i+8|0)>>2];m=0;b:{if(u<E(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break b}p=E(h>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){B[g>>2]=B[j>>2];B[f>>2]=B[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;x[i+12>>2]=o;break a}m=v-h|0;x[i+4>>2]=m;l=x[Fb(i+12|0,i+4|0)>>2];e=0;c:{if(u<E(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break c}p=E(m>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){x[g>>2]=0;x[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;x[i+12>>2]=o;e=h+l|0;l=e>>>0<v>>>0?e:0}x[a+4224>>2]=l;continue}else{di(a,b,c,t,n,d)}break}}hb=i+16|0}function W2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=hb-2160|0;hb=b;zx(b+112|0);a:{b:{c:{f=x[c+4>>2];if(!f){a=ba(8)|0;x[23604]=0;b=Q(54,b+96|0,10345)|0;c=x[23604];x[23604]=0;if((c|0)==1){break c}a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break b}g=x[c>>2];d=x[c+12>>2];e=x[c+8>>2];x[b+88>>2]=e;x[b+92>>2]=d;c=x[b+92>>2];x[b+40>>2]=x[b+88>>2];x[b+44>>2]=c;x[b+84>>2]=f;x[b+80>>2]=g;c=x[b+84>>2];x[b+32>>2]=x[b+80>>2];x[b+36>>2]=c;h=HI(b+32|0);if(h){c=b- -64|0;x[c>>2]=e;x[b+68>>2]=d;d=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=d;x[b+60>>2]=f;x[b+56>>2]=g;c=x[b+60>>2];x[b+16>>2]=x[b+56>>2];x[b+20>>2]=c;c=AI(b+16|0)}else{c=0}x[b+72>>2]=c;x[b+76>>2]=0;d=0;c=2048;while(1){if(c){e=mb[f|0](g,(b+112|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=ec(b+48|0,b+112|0,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a=Cs(a,b+8|0,h?b+72|0:0);if(a+1>>>0>=3){a=ba(8)|0;x[23604]=0;b=Q(54,b+96|0,7975)|0;c=x[23604];x[23604]=0;if((c|0)!=1){a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break b}c=P()|0;ca(a|0);break b}hb=b+2160|0;return a|0}c=P()|0;ca(a|0)}T(c|0)}p()}function NV(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-32|0;hb=d;if(!Rb(a,13513,4)){od(b,32);uo(b);Ph(d,1,a+4|0);c=d+16|0;Dc(c,d);ze(b+43|0,c);xb(c);w[b+30>>1]=y[a+19|0]<<2;pg(b+30|0,256);w[b+32>>1]=y[a+17|0];pg(b+32|0,64);w[b+28>>1]=(y[a+47|0]&127)<<2;pg(b+28|0,256);if(v[a+47|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=y[a+18|0];if(c&16){w[b+34>>1]=z[b+34>>1]|2;c=y[a+18|0]}if(c&32){w[b+34>>1]=z[b+34>>1]|8;c=y[a+18|0]}if(c&64){w[b+34>>1]=z[b+34>>1]|4;c=y[a+18|0]}if(c<<24>>24<0){w[b+34>>1]=z[b+34>>1]|16}c=y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+12>>2]=y[a+64|0]|y[a+65|0]<<8|(y[a+66|0]<<16|y[a+67|0]<<24);x[b+16>>2]=y[a+68|0]|y[a+69|0]<<8|(y[a+70|0]<<16|y[a+71|0]<<24);ek(b);v[b+38|0]=y[(y[a+79|0]&7)+40224|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=y[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}w[b+34>>1]=c|z[b+34>>1]}c=y[a+72|0]|y[a+73|0]<<8|(y[a+74|0]<<16|y[a+75|0]<<24)}hb=d+32|0;return c|0}function gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-48|0;hb=k;if(nf(x[b>>2],x[b+4>>2])>>>0>c>>>0){while(1){i=m&65535;if(i>>>0<=c>>>0){g=Jf(x[b>>2],i);e=x[g>>2];if(Ob(e,x[g+4>>2])){n=k+24|0;e=Bb(e);o=Bb(x[Jf(x[b>>2],i)+4>>2]);f=yP(k,d);l=hb-16|0;hb=l;x[l+8>>2]=e;while(1){if(Ob(e,o)){j=hb-16|0;hb=j;if(!(y[e+5|0]|y[e+3|0]!=4)){g=j+8|0;Jb(g,x[f>>2],z[f+14>>1]);sg(g,0);v[e+3|0]=0}h=y[e+2|0];if(!(y[e+4|0]|(h|0)!=11)){g=j+8|0;Jb(g,x[f>>2],z[f+14>>1]);sg(g,0);v[e+2|0]=0;h=0}a:{b:{if(!y[e|0]){Jb(j+8|0,x[f>>2],z[f+14>>1]);if(Mb(x[x[j+8>>2]>>2],x[j+12>>2])){break b}h=y[e+2|0]}i=y[e+3|0];g=j+8|0;Jb(g,x[f>>2],z[f+14>>1]);sg(g,(i|0)==4|(h|0)==11);h=y[e+3|0];break a}h=y[e+3|0];g=y[e+2|0];if(!(h|(g|0)==11)){v[e+5|0]=0;h=4;v[e+3|0]=4;break a}if(g|(h|0)==4){break a}v[e+4|0]=0;v[e+2|0]=11}c:{d:{e:{if(!(!y[f+16|0]|h)){v[e+3|0]=17;i=0;h=125;break e}i=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(y[e+5|0]){break c}i=1;h=6}v[e+5|0]=h}v[f+16|0]=i}w[f+14>>1]=(z[f+14>>1]+1>>>0)%z[f+12>>1];hb=j+16|0;e=x[dk(l+8|0)>>2];continue}break}wP(n,f);hb=l+16|0;He(n);He(f)}m=m+1|0;continue}break}}wP(a,d);hb=k+48|0}function J9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=hb-16|0;hb=i;e=x[b+1298304>>2];if(!td(e)){d=hb-16|0;hb=d;c=Jc(12);x[23604]=0;e=S(861,c|0)|0;f=x[23604];x[23604]=0;a:{if((f|0)!=1){c=x[lf(d+8|0,e)>>2];hb=d+16|0;break a}a=P()|0;Hb(c);T(a|0);p()}x[i+8>>2]=c;c=b+1298304|0;d=i+8|0;pM(c,Wd(d));jy(d);e=x[c>>2]}f=hb-48|0;hb=f;c=f+16|0;fM(c,a);x[23604]=0;U(8,f+32|0,0,c|0);c=x[23604];x[23604]=0;b:{c:{if((c|0)!=1){xb(f+16|0);m=f,n=Bb(x[e>>2]),x[m+8>>2]=n;l=Bb(x[e+4>>2]);c=0;e=0;d:{while(1){e:{h=x[f+8>>2];if(!Ob(h,l)){if(!e){break e}c=x[e+4>>2];if(!c){break e}x[23604]=0;W(c|0,e|0,b|0,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break e}break d}j=0;d=x[h>>2];if(x[d+32>>2]==x[a+16>>2]){j=x[d+36>>2]==x[a+20>>2]}x[23604]=0;R(862,f+16|0,d+8|0);d=x[23604];x[23604]=0;if((d|0)==1){break d}g=hb-16|0;hb=g;k=f+16|0;ve(g+8|0,k);ve(g,f+32|0);d=AL(x[g+8>>2],x[g+12>>2],x[g>>2],x[g+4>>2]);hb=g+16|0;xb(k);f:{if(!(!j|(d|0)!=0)){e=x[h>>2];c=3;break f}if((c|0)<2&j){e=x[h>>2];c=2;break f}d=!d&(c|0)<=0;e=d?x[h>>2]:e;c=d?1:c}Fe(f+8|0);continue}break}xb(f+32|0);hb=f+48|0;break b}e=P()|0;xb(f+32|0);break c}e=P()|0;xb(f+16|0)}T(e|0);p()}hb=i+16|0}function i2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;tf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=hb-32|0;hb=a;a:{b:{c:{d:{h=x[c+4>>2];if(h>>>0>=f>>>0){if(A[c+20>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(de(x[c+24>>2],i)>>>0<e>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];b=0;e:while(1){d=0;if((b|0)==(e|0)){break a}while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{n=a,o=+(cm(ee(Yf(C[Mg(m,h,d,b)>>3])*134217728))+gd(_r(k),21)|0)*7.450580596923828e-9,C[n+24>>3]=o;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=ee(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Vc(g);n=sn(l,i,d,b),q=g,w[n>>1]=q;d=d+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=c- -64|0}function X8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=hb-32|0;hb=j;e=b;b=x[a>>2];h=D(zs(e,Bb(b)),6)+b|0;a:{if(!c){break a}b=x[Cb(a)>>2];i=x[a+4>>2];if((b-i|0)/6>>>0>=c>>>0){b=c;e=(i-h|0)/6|0;if(e>>>0<c>>>0){BA(a,c-e|0,d);b=e;if((h|0)==(i|0)){break a}}l=hb-16|0;hb=l;f=x[a+4>>2];g=D((f-(D(c,6)+h|0)|0)/6|0,6)+h|0;m=hq(l,a,(i-g|0)/6|0);k=x[m+4>>2];e=g;while(1){if(e>>>0>=i>>>0){ic(m);e=h;if((g|0)!=(e|0)){g=g-e|0;ah(D((g|0)/-6|0,6)+f|0,e,g)}hb=l+16|0}else{Nt(k,e);k=k+6|0;x[m+4>>2]=k;e=e+6|0;continue}break}c=D(d>>>0>=e>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=a;v[e+1|0]=a>>>8;v[e+2|0]=a>>>16;v[e+3|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[e+4|0]=a;v[e+5|0]=a>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Cb(a);f=LS(j,wA(a,Vj(x[a>>2],i)+c|0),(h-x[a>>2]|0)/6|0,b);KS(f,c,d);g=hb-32|0;hb=g;b=x[f+4>>2];e=Ib(g+24|0,h);d=Ib(g+16|0,x[a>>2]);c=Ib(g+8|0,x[f+4>>2]);n=f,o=HS(x[e>>2],x[d>>2],x[c>>2]),x[n+4>>2]=o;n=f,o=rL(h,x[a+4>>2],x[f+8>>2]),x[n+8>>2]=o;qc(a,f+4|0);qc(a+4|0,f+8|0);qc(Cb(a),yc(f));x[f>>2]=x[f+4>>2];hb=g+32|0;h=b;JS(f)}Ib(j+24|0,h);hb=j+32|0}function Sha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=hb-288|0;hb=f;Ve(b);a:{if(!Qb(x[a>>2],x[a+8>>2],1)){break a}while(1){d=f+32|0;fn(f+8|0,d,aq(d));j=x[a>>2];g=x[a+8>>2];d=hb-32|0;hb=d;Kg(d+16|0,x[f+8>>2],x[f+12>>2]);e=x[x[j>>2]+28>>2];h=x[d+20>>2];x[d+8>>2]=x[d+16>>2];x[d+12>>2]=h;mb[e|0](d+24|0,j,g,d+8|0);Kg(f+16|0,x[d+24>>2],x[d+28>>2]);hb=d+32|0;x[f+28>>2]=x[f+20>>2];o=f,q=c-Qc(x[b+4>>2],y[b+11|0])|0,x[o+4>>2]=q;d=x[Fb(f+28|0,f+4|0)>>2];if(!d){break a}j=f+32|0;m=j+d|0;k=gi(j,m,0);d=x[Ib(f,pf(b))>>2];l=hb-16|0;hb=l;g=de(d,pd(b));b:{c:{d=j;e=ji(d,k);d:{if(!e){pd(b);break d}if(!Cx(b,d)){h=Eb(x[b+4>>2],y[b+11|0]);i=Oc(b);e:{if(e>>>0<=i-h>>>0){i=Pb(b);if((g|0)==(h|0)){break e}n=g+i|0;dl(e+n|0,n,h-g|0);break e}Rl(b,i,(e+h|0)-i|0,h,g,0,e);i=x[b>>2]}e=e+h|0;Sg(b,e);id(e+i|0,0);e=g+i|0;while(1){if((d|0)!=(k|0)){id(e,y[d|0]);d=d+1|0;e=e+1|0;continue}break}Ee(pd(b),g);break d}d=ug(l,d,k);h=pd(d);i=pf(d);x[23604]=0;ja(340,b|0,e|0,g|0,h|0,i|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break c}xb(d)}hb=l+16|0;break b}a=P()|0;xb(d);T(a|0);p()}bc(a,k-j|0);if(k>>>0>=m>>>0){continue}break}bc(a,1)}hb=f+288|0}function Cd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb+-64|0;hb=d;x[a+480180>>2]=b;b=_p(a);Bz(d,b);e=x[d+12>>2];c=a+1074320|0;x[c>>2]=x[d+8>>2];x[c+4>>2]=e;c=x[d+4>>2];x[a+1074312>>2]=x[d>>2];x[a+1074316>>2]=c;Ds(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>z[a+480192>>1]){x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;fy(a,4);e=hb+-64|0;hb=e;b=a+484344|0;Fs(b);f=ak(x[b>>2],x[b+4>>2]);c=Kx(e+8|0,b);x[23604]=0;U(767,b|0,f|0,c|0);b=x[23604];x[23604]=0;a:{if((b|0)!=1){Nk(c);hb=e- -64|0;break a}a=P()|0;Nk(c);T(a|0);p()}QO(a+484360|0);Ve(a+1298308|0);Ve(a+1298320|0);Ve(a+1298332|0);c=Zb(d,0,64);b=vM(c);d=Ab(a+1298344|0,b);Ab(d+12|0,b+12|0);Ab(d+24|0,b+24|0);Ab(d+36|0,b+36|0);Ab(d+48|0,b+48|0);x[d+60>>2]=x[b+60>>2];ky(b);Fc(a+1298408|0);Fc(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}hb=c- -64|0;return}c=((c<<2)+a|0)+900380|0;e=x[c>>2];if(e){Hb(It(e))}x[c>>2]=0;b=b+1|0;continue}}function $1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;tf(c+48|0,c+32|0,e);a=x[d+4>>2];f=x[a+8>>2];h=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;e=c+16|0;a=hb-32|0;hb=a;a:{b:{c:{d:{i=x[c+4>>2];if(i>>>0>=h>>>0){if(A[e+4>>2]<h>>>0){break d}if(A[c+8>>2]<f>>>0){break c}if(de(x[e+8>>2],x[e+12>>2])>>>0<f>>>0){break b}k=b+12|0;l=x[c>>2];b=0;e:while(1){d=0;if((b|0)==(f|0)){break a}while(1)if((d|0)==(h|0)){b=b+1|0;continue e}else{m=a,n=+(cm(ee(Yf(C[Mg(l,i,d,b)>>3])*134217728))+gd(_r(k),21)|0)*7.450580596923828e-9,C[m+24>>3]=n;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=ee(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Vc(g);m=rn(e,d,b),o=g,w[m>>1]=o;d=d+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=c- -64|0}function tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;h=hb-16|0;hb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];i=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=i;r=x[a+72>>2];k=x[a+68>>2];s=k>>31;l=x[a+64>>2];t=l>>31;m=x[a+60>>2];u=m>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){i=f;if(d){f=Yb(i,-16777216,16776704);g=Jia(l,t,f,f>>31);f=lb;e=Yb(e,-16777216,16776704);e=Jia(k,s,e,e>>31);g=e+g|0;f=lb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];j=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;n=(((((D(w[g+4>>1],w[e+34>>1])+D(w[g+2>>1],w[e+32>>1])|0)+D(w[g+6>>1],w[e+36>>1])|0)+D(w[g+8>>1],w[e+38>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+26>>1])+D(w[g-6>>1],w[e+24>>1])|0)+D(w[g-2>>1],w[e+28>>1])|0)+D(w[g>>1],w[e+30>>1])|0)/2|0)|0)/16384<<8;e=n;g=Jia(e,e>>31,m,u);j=j+g|0;e=lb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Nc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Ub(h+8|0,v,y);f=f-(r&n)|0;c=c+8|0;d=d-1|0;e=i;continue}break}b=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=b;x[a+48>>2]=e;x[a+44>>2]=i;hb=h+16|0}function JA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-16|0;hb=g;a:{if(b&4){break a}e=y[a+14|0];b:{if(e>>>0>=y[a+15|0]){break b}c=y[a+12|0];if(!(c&2)){break b}v[a+12|0]=c&251}if(!(y[a+12|0]&2)|e>>>0<=y[a+13|0]){break a}d=x[a>>2];c=x[a+4>>2];if(ie(d,c)>>>0<=e>>>0){break a}d=z[Hc(d,c,e)>>1];c=Hc(x[a>>2],x[a+4>>2],y[a+14|0]-1|0);e=y[a+14|0];if(z[c>>1]<(d-1|0)){e=z[Hc(x[a>>2],x[a+4>>2],e)>>1]-1&65535;d=Ap(a,e,64,64);c=Ib(g+8|0,Pj(Bb(x[a>>2]),y[a+14|0]));h=bo(g,e,d&255);i=hb-32|0;hb=i;d=x[c>>2];c=x[a>>2];f=(Ht(d,Bb(c))<<2)+c|0;c=x[a+4>>2];c:{d:{if(c>>>0<A[Cb(a)>>2]){if((c|0)!=(f|0)){break d}mS(a,h);break c}d=Cb(a);d=Wf(i,vg(a,rc(x[a>>2],c)+1|0),f-x[a>>2]>>2,d);x[23604]=0;R(702,d|0,h|0);c=x[23604];x[23604]=0;if((c|0)!=1){f=dq(a,d,f);Vf(d);break c}a=P()|0;Vf(d);T(a|0);p()}k=hb-16|0;hb=k;m=x[a+4>>2];d=(m-(f+4|0)|0)+f|0;l=lh(k,a,c-d>>2);j=x[l+4>>2];e=d;while(1){if(c>>>0<=e>>>0){ic(l);UA(f,d,m);hb=k+16|0}else{Pp(j,z[e>>1]|z[e+2>>1]<<16);j=j+4|0;x[l+4>>2]=j;e=e+4|0;continue}break}v[f+2|0]=y[h+2|0];w[f>>1]=z[h>>1]}Ib(i+24|0,f);hb=i+32|0;break a}v[a+14|0]=e-1}if((b|0)!=16777216){v[a+17|0]=255}hb=g+16|0}function R7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-16|0;hb=h;if(!y[a+4242|0]){vx(a);a:{if(!y[a+4240|0]){break a}e=aM(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;us(a)}f=a+4256|0;b:{if(y[a+4244|0]){if(C[f>>3]>1){x[f>>2]=0;x[f+4>>2]=1072693248}break b}i=(x[a+4232>>2]&-2)!=4;e=C[f>>3];c:{if(F(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){ux(a);e=C[a+4256>>3]}C[f>>3]=e-+(g|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=mi(C[f>>3]*6.283185307179586);break d;case 1:e=F(C[f>>3]+-.5)*-4+1;break d;case 2:e=C[f>>3];e=e+e+-1;break d;case 3:e=C[f>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=C[a+4280>>3]*e+C[a+4272>>3]*(1-e)}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];FN(h+8|0,1);g=Fj(a);f:{if(!g){break f}f=x[a+4236>>2];if(y[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|ao(C[h+8>>3]*127)<<16,j=x[x[g>>2]+68>>2],mb[j](k|0,l|0)|0;break f}mb[x[x[g>>2]+44>>2]](g,f,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4264>>3]*+(d>>>0)+C[a+4256>>3]}g=a;a=x[a+44>>2];di(g,b,c,Cc(a,0),Cc(a,1),d);hb=h+16|0}function jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=hb-16|0;hb=e;o=x[a+16>>2];p=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+128>>2];a:{if(!k){j=x[a+8>>2];l=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];i=0;break a}b=x[a+12>>2];l=b;j=x[a+8>>2];m=Xf(j,b,k);n=lb;i=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];Cf(b,f,Ze(j,l,d),lb);i=lb>>>0>i>>>0?d:0}g=a+112|0;q=x[a+24>>2];r=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){f=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=k;while(1)if((b|0)<=0){Ub(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;Kd(g,(w[(h<<1|2)+f>>1]+w[((h&2147483646)<<1)+f>>1]|0)/8<<16>>16);Jd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Tf(g,p);x[c>>2]=x[c>>2]+D(b,r);x[c+4>>2]=x[c+4>>2]+D(b,q);Ub(e,j,l);c=c+8|0;continue b}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;Kd(g,(w[(h<<1|2)+f>>1]+w[((h&2147483646)<<1)+f>>1]|0)/8<<16>>16);Jd(g,4);Ub(e+8|0,m,n);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;hb=e+16|0}function uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=hb-16|0;hb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];i=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=i;r=x[a+72>>2];k=x[a+68>>2];s=k>>31;l=x[a+64>>2];t=l>>31;m=x[a+60>>2];u=m>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){i=f;if(d){f=Yb(i,-16777216,16776704);g=Jia(l,t,f,f>>31);f=lb;e=Yb(e,-16777216,16776704);e=Jia(k,s,e,e>>31);g=e+g|0;f=lb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];j=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;n=((((D(v[g+2|0],w[e+34>>1])+D(v[g+1|0],w[e+32>>1])|0)+D(v[g+3|0],w[e+36>>1])|0)+D(v[g+4|0],w[e+38>>1])<<8>>1)+(((D(v[g-2|0],w[e+26>>1])+D(v[g-3|0],w[e+24>>1])|0)+D(v[g-1|0],w[e+28>>1])|0)+D(v[g|0],w[e+30>>1])<<8>>1)|0)/16384<<8;e=n;g=Jia(e,e>>31,m,u);j=j+g|0;e=lb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Nc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Ub(h+8|0,y,z);f=f-(r&n)|0;c=c+8|0;d=d-1|0;e=i;continue}break}b=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=b;x[a+48>>2]=e;x[a+44>>2]=i;hb=h+16|0}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=hb-16|0;hb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];n=x[a+68>>2];u=n>>31;o=x[a+64>>2];v=o>>31;p=x[a+60>>2];y=p>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);k=Jia(o,v,e,e>>31);l=lb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+40242>>1])+D(w[h-2>>1],w[e+40240>>1])|0)+D(w[h+2>>1],w[e+40244>>1])|0)+D(w[h+4>>1],w[e+40246>>1])|0)/16384<<8;e=h;e=Jia(e,e>>31,p,y);k=e+k|0;m=lb+l|0;m=e>>>0>k>>>0?m+1|0:m;f=Yb(f,-16777216,16776704);e=Jia(n,u,f,f>>31);l=e+k|0;f=lb+m|0;f=e>>>0>l>>>0?f+1|0:f;e=l+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Nc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Ub(g+8|0,z,A);e=e-(h&t)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=g+16|0}function zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=1042;x[e+12>>2]=2;c=hb+-64|0;hb=c;h=x[e+8>>2]&2?16:10;f=hb-32|0;hb=f;d=Ue(f+16|0,1,0);a:{b:{c:{while(1){g=Pb(d);_o(f+8|0,g,Eb(x[d+4>>2],y[d+11|0])+g|0,z[b>>1],h);if(!x[f+12>>2]){break c}g=Rf(Eb(x[d+4>>2],y[d+11|0]));x[23604]=0;R(58,d|0,g|0);g=x[23604];x[23604]=0;if((g|0)!=1){continue}break}break b}b=x[f+8>>2];h=Pb(d);x[23604]=0;R(59,d|0,b-h|0);b=x[23604];x[23604]=0;d:{if((b|0)!=1){x[23604]=0;R(71,c|0,d|0);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break b}break b}xb(d);hb=f+32|0;break a}a=P()|0;xb(d);T(a|0);p()}b=c+16|0;Ll(b,c,x[e+8>>2]);d=x[e+12>>2];f=x[e+8>>2];x[23604]=0;X(75,c+32|0,b|0,f|0,d|0);b=x[23604];x[23604]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[e+24|0];d=x[e+20>>2];x[23604]=0;X(76,c+48|0,c+32|0,d|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;R(70,a|0,c+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}xb(c+48|0);xb(c+32|0);xb(c+16|0);xb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(c+48|0)}xb(c+32|0)}xb(c+16|0);xb(c);T(a|0);p()}hb=e+32|0}function kh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{c:{switch(b|0){case 1:b=Kb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[23604]=0;R(47,b|0,Qc(e,d)|0);d=x[23604];x[23604]=0;d:{if((d|0)!=1){e:{while(1){if(Qc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=v[uc(c,a)|0];x[23604]=0;R(48,b|0,((d|0)<0?65533:d&255)|0);d=x[23604];x[23604]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Kb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[23604]=0;R(47,b|0,Qc(e,d)|0);d=x[23604];x[23604]=0;f:{if((d|0)!=1){while(1){if(Qc(x[c+4>>2],y[c+11|0])>>>0<=a>>>0){break f}d=y[uc(c,a)|0];x[23604]=0;R(48,b|0,d|0);d=x[23604];x[23604]=0;if((d|0)!=1){a=a+1|0;continue}break}}break a}return;case 3:Vl(a,c,50032);return;case 5:Vl(a,c,51056);return;case 4:Vl(a,c,52080);return;case 6:Vl(a,c,53104);return;case 7:Vl(a,c,54128);return;case 8:Vl(a,c,55152);return;case 9:ny(a,c,56176);return;case 10:ny(a,c,50032);return;case 11:ny(a,c,54128);return;default:a=ba(8)|0;x[23604]=0;b=Q(44,a|0,10965)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}b=P()|0;ca(a|0);T(b|0);p();case 0:break c}}wM(a,c);return}ha(b|0,92652,24);p()}a=P()|0;Gc(b);T(a|0);p()}function IU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=1058;x[e+12>>2]=2;c=hb+-64|0;hb=c;h=x[e+8>>2]&2?16:10;f=hb-32|0;hb=f;d=Ue(f+16|0,1,0);a:{b:{c:{while(1){g=Pb(d);_o(f+8|0,g,Eb(x[d+4>>2],y[d+11|0])+g|0,x[b>>2],h);if(!x[f+12>>2]){break c}g=Rf(Eb(x[d+4>>2],y[d+11|0]));x[23604]=0;R(58,d|0,g|0);g=x[23604];x[23604]=0;if((g|0)!=1){continue}break}break b}b=x[f+8>>2];h=Pb(d);x[23604]=0;R(59,d|0,b-h|0);b=x[23604];x[23604]=0;d:{if((b|0)!=1){x[23604]=0;R(60,c|0,d|0);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break b}break b}xb(d);hb=f+32|0;break a}a=P()|0;xb(d);T(a|0);p()}b=c+16|0;Ll(b,c,x[e+8>>2]);d=x[e+12>>2];f=x[e+8>>2];x[23604]=0;X(73,c+32|0,b|0,f|0,d|0);b=x[23604];x[23604]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[e+24|0];d=x[e+20>>2];x[23604]=0;X(74,c+48|0,c+32|0,d|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;R(57,a|0,c+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}xb(c+48|0);xb(c+32|0);xb(c+16|0);xb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(c+48|0)}xb(c+32|0)}xb(c+16|0);xb(c);T(a|0);p()}hb=e+32|0}function Dt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=1058;x[e+12>>2]=2;c=hb+-64|0;hb=c;h=x[e+8>>2]&2?16:10;f=hb-32|0;hb=f;d=Ue(f+16|0,1,0);a:{b:{c:{while(1){g=Pb(d);_o(f+8|0,g,Eb(x[d+4>>2],y[d+11|0])+g|0,y[b|0],h);if(!x[f+12>>2]){break c}g=Rf(Eb(x[d+4>>2],y[d+11|0]));x[23604]=0;R(58,d|0,g|0);g=x[23604];x[23604]=0;if((g|0)!=1){continue}break}break b}b=x[f+8>>2];h=Pb(d);x[23604]=0;R(59,d|0,b-h|0);b=x[23604];x[23604]=0;d:{if((b|0)!=1){x[23604]=0;R(60,c|0,d|0);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break b}break b}xb(d);hb=f+32|0;break a}a=P()|0;xb(d);T(a|0);p()}b=c+16|0;Ll(b,c,x[e+8>>2]);d=x[e+12>>2];f=x[e+8>>2];x[23604]=0;X(73,c+32|0,b|0,f|0,d|0);b=x[23604];x[23604]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[e+24|0];d=x[e+20>>2];x[23604]=0;X(74,c+48|0,c+32|0,d|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;R(57,a|0,c+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}xb(c+48|0);xb(c+32|0);xb(c+16|0);xb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(c+48|0)}xb(c+32|0)}xb(c+16|0);xb(c);T(a|0);p()}hb=e+32|0}function c_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=hb-448|0;hb=a;x[a+432>>2]=c;x[a+440>>2]=b;x[a+20>>2]=1104;b=le(a+24|0,a+32|0,a+20|0);Pc(a+16|0,x[e+28>>2]);x[23604]=0;h=S(1083,x[a+16>>2])|0;i=x[23604];x[23604]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[23604]=0;c=pa(1113,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(re(y[g+11|0])){Ad(x[g>>2],0);oe(g,0);break d}Ad(g,0);bf(g,0)}if(y[a+15|0]){x[23604]=0;c=Q(1100,h|0,45)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}x[23604]=0;R(48,g|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}}x[23604]=0;d=Q(1100,h|0,48)|0;c=x[23604];x[23604]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-4|0;c=x[b>>2];while(1){if(!((d|0)!=x[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}x[23604]=0;W(1118,g|0,c|0,e|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break c}break a}x[23604]=0;c=Q(1088,a+440|0,a+432|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+440>>2];$b(a+16|0);Mc(b);hb=a+448|0;return c|0}}}c=P()|0;$b(a+16|0);Mc(b);T(c|0);p()}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;h=hb-16|0;hb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];l=x[a+68>>2];t=l>>31;m=x[a+64>>2];u=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=Jia(m,u,f,f>>31);f=lb;e=Yb(e,-16777216,16776704);e=Jia(l,t,e,e>>31);g=e+g|0;f=lb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;o=(((D(v[g|0],w[e+40242>>1])+D(v[g-1|0],w[e+40240>>1])|0)+D(v[g+1|0],w[e+40244>>1])|0)+D(v[g+2|0],w[e+40246>>1])<<8)/16384<<8;e=o;g=Jia(e,e>>31,n,y);k=k+g|0;e=lb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Nc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Ub(h+8|0,z,A);f=f-(s&o)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=h+16|0}function oN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=x[b+64>>2];a:{b:{g=x[b+60>>2];f=z[b+68>>1];if(!((g|0)==-1&(f|0)==65535)){c:{d:{if((e|0)==-1){break d}e=a+1074312|0;if(Tb(e,68)){break d}if(h=Tb(e,103),i=0,j=(f|0)!=65535,j?h:i){break c}if(h=Tb(e,49),i=0,j=(f|0)!=65535,j?h:i){break c}e=x[b+64>>2];break b}if((f|0)!=65535){break c}w[b+68>>1]=z[b+72>>1]+1}if((g|0)==-1){x[b+60>>2]=0}f=Kc(x[c>>2],x[c+4>>2]);e=z[b+68>>1];if(f>>>0<=e>>>0){e=z[c+28>>1];w[b+68>>1]=e}e:{if(z[b+72>>1]==(e&65535)){break e}c=a+1074312|0;if(Tb(c,26)){break e}if(Tb(c,68)|x[a+480180>>2]==1){break e}c=z[a+480188>>1];e=0;while(1){if((c|0)==(e|0)){break e}v[(D(e,872)+b|0)+1457|0]=0;e=e+1|0;continue}}x[b+52>>2]=x[b+60>>2];if(d){e=1;if(y[a+480208|0]&32){break a}}w[b+74>>1]=z[b+68>>1];return 1}if((e|0)!=-1){break b}e=0;break a}x[b+52>>2]=e;w[b+74>>1]=z[b+72>>1];f:{if(!x[b+20>>2]){break f}c=x[a+480180>>2];if((c|0)==32){if(Tb(a+1074312|0,103)){break f}c=x[a+480180>>2]}if((c|0)==2){break f}x[b+52>>2]=x[b+52>>2]+1}e=0;if(A[b+64>>2]<A[ac(x[a+484344>>2],z[b+70>>1])+12>>2]){break a}x[b+52>>2]=0;w[b+74>>1]=z[b+74>>1]+1;return 0}return e}function M8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=x[a>>2];d=ak(e,x[a+4>>2]);if(d>>>0<b>>>0){i=hb-32|0;hb=i;a:{b:{f=b-d|0;b=x[Cb(a)>>2];e=x[a+4>>2];c:{if(f>>>0<=(b-e|0)/52>>>0){Jx(a,f,c);break c}g=Cb(a);d=mL(a,ak(x[a>>2],e)+f|0);h=ak(x[a>>2],x[a+4>>2]);e=hb-16|0;hb=e;b=i+8|0;Df(b+12|0,g);d:{if(!d){d=0;x[b>>2]=0;g=0;break d}lL(e+8|0,d);d=x[e+8>>2];x[b>>2]=d;g=x[e+12>>2]}h=D(h,52)+d|0;x[b+4>>2]=h;x[b+8>>2]=h;j=yc(b),k=D(g,52)+d|0,x[j>>2]=k;hb=e+16|0;x[23604]=0;U(832,b|0,f|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}f=hb-32|0;hb=f;c=Ib(f+24|0,x[a+4>>2]);e=Ib(f+16|0,x[a>>2]);g=Ib(f+8|0,x[b+4>>2]);d=x[c>>2];h=x[e>>2];c=hb-16|0;hb=c;x[c>>2]=x[g>>2];x[c+8>>2]=d;while(1){e=x[c>>2];if(og(d,h)){g=jL(e);d=jL(d);e=Qj(g,d);x[e+20>>2]=x[d+20>>2];g=x[d+16>>2];x[e+12>>2]=x[d+12>>2];x[e+16>>2]=g;Qj(e+24|0,d+24|0);dd(e+36|0,d+36|0);x[e+48>>2]=x[d+48>>2];d=iL(c+8|0);iL(c);d=x[d>>2];continue}break}hb=c+16|0;x[b+4>>2]=e;qc(a,b+4|0);qc(a+4|0,b+8|0);qc(Cb(a),yc(b));x[b>>2]=x[b+4>>2];hb=f+32|0;kL(b)}hb=i+32|0;break a}a=P()|0;kL(b);T(a|0);p()}return}if(b>>>0<d>>>0){nL(a,e+D(b,52)|0)}}function qG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=hb-16|0;hb=l;g=y[a|0];a:{if(!g){f=a;break a}f=a;b:{while(1){if(!vk(g<<24>>24)){break b}g=y[f+1|0];f=f+1|0;if(g){continue}break}break a}c:{g=g&255;switch(g-43|0){case 0:case 2:break c;default:break a}}j=(g|0)==45?-1:0;f=f+1|0}d:{if(!((c|16)!=16|y[f|0]!=48)){n=1;if((y[f+1|0]&223)==88){f=f+2|0;m=16;break d}f=f+1|0;m=c?c:8;break d}m=c?c:10}c=0;while(1){e:{g=-48;i=v[f|0];f:{if((i-48&255)>>>0<10){break f}g=-87;if((i-97&255)>>>0<26){break f}g=-55;if((i-65&255)>>>0>25){break e}}i=g+i|0;if((i|0)>=(m|0)){break e}kf(l,m,0,0,0,k,h,0,0);g=1;g:{if(x[l+8>>2]|x[l+12>>2]){break g}o=Jia(k,h,m,0);p=lb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break g}h=p;k=i+o|0;h=k>>>0<i>>>0?h+1|0:h;n=1;g=c}f=f+1|0;c=g;continue}break}if(b){x[b>>2]=n?f:a}h:{i:{j:{if(c){x[116080]=68;a=d&1;j=a?0:j;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|j)){x[116080]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}x[116080]=68;break h}a=j^k;d=a-j|0;b=j>>31;e=(b^h)-((a>>>0<j>>>0)+b|0)|0}hb=l+16|0;lb=e;return d}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=hb-16|0;hb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=(i<<1)+m|0;x[(i<<2)+e>>2]=(((((((D(w[b-8>>1],t)+D(w[b-12>>1],u)|0)+D(w[b-4>>1],s)|0)+D(w[b>>1],r)|0)+D(w[b+4>>1],q)|0)+D(w[b+8>>1],p)|0)+D(w[b+12>>1],o)|0)+D(w[b+16>>1],n)|0)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Ub(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;hb=e+16|0}function zv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=c;x[e+12>>2]=d;c=hb+-64|0;hb=c;g=e+8|0;i=x[g>>2]&2?16:10;f=hb-32|0;hb=f;d=Ue(f+16|0,1,0);a:{b:{c:{while(1){h=Pb(d);_o(f+8|0,h,Eb(x[d+4>>2],y[d+11|0])+h|0,x[b>>2],i);if(!x[f+12>>2]){break c}h=Rf(Eb(x[d+4>>2],y[d+11|0]));x[23604]=0;R(58,d|0,h|0);h=x[23604];x[23604]=0;if((h|0)!=1){continue}break}break b}b=x[f+8>>2];i=Pb(d);x[23604]=0;R(59,d|0,b-i|0);b=x[23604];x[23604]=0;d:{if((b|0)!=1){x[23604]=0;R(71,c|0,d|0);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break b}break b}xb(d);hb=f+32|0;break a}a=P()|0;xb(d);T(a|0);p()}b=c+16|0;Ll(b,c,x[g>>2]);d=x[g+4>>2];f=x[g>>2];x[23604]=0;X(75,c+32|0,b|0,f|0,d|0);b=x[23604];x[23604]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[g+16|0];d=x[g+12>>2];x[23604]=0;X(76,c+48|0,c+32|0,d|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;R(70,a|0,c+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}xb(c+48|0);xb(c+32|0);xb(c+16|0);xb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(c+48|0)}xb(c+32|0)}xb(c+16|0);xb(c);T(a|0);p()}hb=e+32|0}function Ev(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=c;x[e+12>>2]=d;c=hb+-64|0;hb=c;g=e+8|0;i=x[g>>2]&2?16:10;f=hb-32|0;hb=f;d=Ue(f+16|0,1,0);a:{b:{c:{while(1){h=Pb(d);_o(f+8|0,h,Eb(x[d+4>>2],y[d+11|0])+h|0,y[b|0],i);if(!x[f+12>>2]){break c}h=Rf(Eb(x[d+4>>2],y[d+11|0]));x[23604]=0;R(58,d|0,h|0);h=x[23604];x[23604]=0;if((h|0)!=1){continue}break}break b}b=x[f+8>>2];i=Pb(d);x[23604]=0;R(59,d|0,b-i|0);b=x[23604];x[23604]=0;d:{if((b|0)!=1){x[23604]=0;R(71,c|0,d|0);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break b}break b}xb(d);hb=f+32|0;break a}a=P()|0;xb(d);T(a|0);p()}b=c+16|0;Ll(b,c,x[g>>2]);d=x[g+4>>2];f=x[g>>2];x[23604]=0;X(75,c+32|0,b|0,f|0,d|0);b=x[23604];x[23604]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[g+16|0];d=x[g+12>>2];x[23604]=0;X(76,c+48|0,c+32|0,d|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;R(70,a|0,c+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}xb(c+48|0);xb(c+32|0);xb(c+16|0);xb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(c+48|0)}xb(c+32|0)}xb(c+16|0);xb(c);T(a|0);p()}hb=e+32|0}function V9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=hb-16|0;hb=i;x[i+8>>2]=b;o=xf(a);while(1){if(xg(b,c)){b=x[Ib(i,o)>>2];j=sd(x[i+8>>2]);m=hb-16|0;hb=m;n=0;k=hb-16|0;hb=k;h=hb-32|0;hb=h;f=h+28|0;d=h+24|0;e=hb-16|0;hb=e;a:{b:{if(!tc(b,x[Ib(e+8|0,Ef(a))>>2])){g=y[j|0];l=y[sd(b)|0];if(!Gn(g,l)){break b}}x[e+8>>2]=b;g=Ib(e,Bb(x[a>>2]));c:{d=x[e+8>>2];if(!tc(d,x[g>>2])){d=x[Ty(e+8|0)>>2];l=y[sd(d)|0];g=y[j|0];if(!Gn(l,g)){break c}}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}b=ty(a,f,g);break a}if(Gn(l,g)){d:{d=Ry(b);if(!tc(d,x[Ib(e+8|0,Ef(a))>>2])){g=y[j|0];if(!Gn(g,y[sd(d)|0])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=ty(a,f,g);break a}x[f>>2]=b;x[d>>2]=b;b=d}hb=e+16|0;d=b;b=x[b>>2];if(!b){b=hb-16|0;hb=b;e=jc(a);f=h+8|0;e=ph(f,Jc(24),qh(b+8|0,e));OM(x[e>>2]+16|0,x[j>>2],x[j+4>>2]);p=jc(e),q=1,v[p+4|0]=q;hb=b+16|0;Vg(a,x[h+28>>2],d,x[h+8>>2]);b=Wd(f);cl(f);n=1}Ug(k+8|0,x[Ib(h+8|0,b)>>2],n);hb=h+32|0;hb=k+16|0;Ib(m+8|0,x[k+8>>2]);hb=m+16|0;b=x[Tg(i+8|0)>>2];continue}else{hb=i+16|0}break}}function Pn(a,b,c){var d=0,e=0,f=0,g=0;f=a+1074312|0;d=Tb(f,96);x[b+660>>2]=(d?0:x[b+660>>2])+c;e=x[a+480180>>2];d=x[b+84>>2];if(!(!(e&18)|d>>>0>c>>>0|(!(y[b+88|0]&2)|!d))){g=c;c=x[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&1&(e|0)==16384)|0;a:{b:{if(!Tc(y[b+788|0])){if(!Tb(f,114)){break b}}d=x[b+656>>2];c:{if(!d){break c}e=y[b+788|0];if(!Tc(e)){break c}d=z[cc(d+236|0,e-1|0)>>1];if(!d|d>>>0>z[a+480190>>1]){break a}}if(y[a+480210|0]&32){d=c;c=x[b+660>>2];x[b+660>>2]=d+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break a}d:{if(!Tb(f,57)){c=x[a+480180>>2];if((c|0)!=16){break d}}x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;return}if(!(c&1048581)){if(Tb(f,27)){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;return}x[b>>2]=0;x[b+4>>2]=0;return}c=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break a}a=x[b+76>>2];if(a>>>0<5){break a}x[b>>2]=0;x[b+4>>2]=a-2;return}if(!(y[b+88|0]&2)|(c|0)!=1){break a}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;return}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break a}x[b>>2]=0;x[b+4>>2]=c}}function OR(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;a:{if((d&255)>>>0<=4){while(1){d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!af(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!af(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){d=af(a,f+13|0);if(d){g=y[f+13|0];w[c>>1]=g<<1|1;v[b|0]=g>>>7;w[c>>1]=y[c|0]}if(!d){break a}if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!af(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){d=af(a,f+11|0);if(d){g=y[f+11|0];w[c>>1]=g<<1|1;v[b|0]=g>>>7;w[c>>1]=y[c|0]}if(!d){break a}if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}hb=f+16|0}function _U(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=hb-32|0;hb=g;v[g+12|0]=0;m=tm(g+16|0,d,g+12|0);f=x[m>>2];x[g+12>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=y[a|0];if(!(!i|(k|0)!=(e&255))){x[g+8>>2]=y[a+1|0];i=a+2|0;j=Fb(g+8|0,g+12|0);b:{k=b-2|0;if(!k){break b}j=x[j>>2];if(!(j&255)){break b}i=y[i|0];while(1){if(!(j&255)){break a}v[f|0]=i;h=x[g+12>>2]-1|0;x[g+12>>2]=h;f=f+1|0;j=j-1|0;continue}}v[f|0]=e;h=x[g+12>>2]-1|0;x[g+12>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;v[f|0]=k;h=x[g+12>>2]-1|0;x[g+12>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=x[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=v[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;v[c|0]=k;e=e-1|0;c=c+1|0;continue}break}fc(m);hb=g+32|0;return}n=y[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;v[l|0]=y[l|0]|D(f&n,257)>>>(h-j&7);l=b+1|0;b=d>>>0>l>>>0?l:0;j=j+1|0;h=(d>>>0<=l>>>0)+h|0;f=(f<<8|f)>>>1&255;continue}}}function dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=hb-1072|0;hb=d;x[d+1068>>2]=c;o=d,q=Be(b),v[o+8|0]=q;v[d+4|0]=1;c=d+8|0;g=y[Ye(c,d+4|0)|0];f=$A(c,b);l=fq(f);x[23604]=0;c=S(188,b|0)|0;e=x[23604];x[23604]=0;a:{if((e|0)!=1){x[d+4>>2]=c;x[d>>2]=536870911;wc(d+1068|0,x[Fb(d+4|0,d)>>2]<<3);x[23604]=0;m=x[d+1068>>2];k=Q(319,a|0,m|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){x[23604]=0;c=8;h=Q(150,f|0,8)|0;a=x[23604];x[23604]=0;b:{if((a|0)!=1){c:{o=Gb(x[k>>2],0),q=h,v[o|0]=q;i=1;a=g;while(1){c=c&255;n=c>>>0<=9?9:c;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}x[23604]=0;j=Q(150,f|0,c|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Gb(x[k>>2],i),q=h,v[o|0]=q;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=fq(f);x[23604]=0;Q(141,b|0,((a-l|0)+3&-4)+l|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break b}}}c=P()|0;fc(k);break a}yb(f);hb=d+1072|0;return}c=P()|0;break a}c=P()|0}yb(f);T(c|0);p()}
function FA(a,b){a:{b:{switch((y[a+3|0]|64)+-64|0){case 0:v[a+3|0]=y[a+5|0]?37:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(b){break a}b=a;a=y[a+5|0];v[b+5|0]=D(a>>>4|0,10)+(a&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=b?32:31;return;case 29:v[a+3|0]=b?33:0;return;case 27:v[a+3|0]=b?34:0;return;case 30:v[a+3|0]=b?35:0;return;case 31:v[a+3|0]=b?36:0;return;case 50:v[a+3|0]=b?25:0;return;case 51:v[a+3|0]=b?30:0;return;default:break b}}v[a+3|0]=0}}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=hb-16|0;hb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=i+m|0;x[(i<<2)+e>>2]=(((((((D(v[b-4|0],t)+D(v[b-6|0],u)|0)+D(v[b-2|0],s)|0)+D(v[b|0],r)|0)+D(v[b+2|0],q)|0)+D(v[b+4|0],p)|0)+D(v[b+6|0],o)|0)+D(v[b+8|0],n)<<8)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Ub(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;hb=e+16|0}function j2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=hb+-64|0;hb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;tf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=hb-32|0;hb=a;a:{b:{c:{d:{h=x[b+4>>2];if(h>>>0>=e>>>0){if(A[b+20>>2]<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}i=x[b+28>>2];if(de(x[b+24>>2],i)>>>0<d>>>0){break b}k=x[b+16>>2];l=x[b>>2];e:while(1){c=0;if((d|0)==(f|0)){break a}while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{m=a,n=C[Mg(l,h,c,f)>>3],C[m+24>>3]=n;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=ee(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Vc(g);m=sn(k,i,c,f),o=g,w[m>>1]=o;c=c+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=b- -64|0}function wn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-80|0;hb=c;g=Sb(a);a=x[b+24>>2];a:{b:{if(_i(x[a+484360>>2],x[a+484364>>2])){c:{d:{e:while(1){if(_i(x[a+484360>>2],x[a+484364>>2])>>>0<=f>>>0){break d}d=TL(BR(c+40|0,1),f&255,0,0);x[23604]=0;e=x[d+12>>2];x[c+16>>2]=x[d+8>>2];x[c+20>>2]=e;e=x[d+20>>2];x[c+24>>2]=x[d+16>>2];x[c+28>>2]=e;e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;X(993,c- -64|0,a|0,0,c+8|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}j=c,k=Bb(x[c+64>>2]),x[j+32>>2]=k;d=Bb(x[c+68>>2]);while(1){a=x[c+32>>2];if(!Ob(a,d)){f=f+1|0;ni(c- -64|0);a=x[b+24>>2];continue e}h=C[a>>3];e=x[a+16>>2];i=z[a+24>>1];a=c+40|0;x[a+16>>2]=f;x[a+12>>2]=i;x[a+8>>2]=e;C[a>>3]=h;x[23604]=0;R(1011,g|0,a|0);a=x[23604];x[23604]=0;if((a|0)!=1){gz(c+32|0);continue}break}break}a=P()|0;ni(c- -64|0);break b}hb=c+80|0;return}a=P()|0;break b}b=ba(8)|0;x[23604]=0;d=Q(54,c+40|0,7228)|0;a=x[23604];x[23604]=0;if((a|0)!=1){a=pc(b,d);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(d);break b}a=P()|0;ca(b|0)}Of(g);T(a|0)}p()}function r7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=0,v=0,w=0,z=E(0);i=x[a+44>>2];h=Cc(i,0);i=Cc(i,1);j=x[a+56>>2];n=Cc(j,0);j=Cc(j,1);k=a+4208|0;g=rc(x[k>>2],x[a+4212>>2]);o=D(x[x[a+16>>2]+1074404>>2],y[a+4233|0]);e=o<<1;if(g>>>0<e>>>0){Gj(k,e)}l=y[a+4232|0];a:{if(l){e=x[a+4220>>2];k=x[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=B[i>>2];e=e>>>0<o>>>0?e:0;g=e-o|0;g=((g|0)<0?e:g)<<1;v=zb(k,g);f=B[zb(k,g|1)>>2];s=B[h>>2];t=B[v>>2];p=E(s+t);B[n>>2]=p;q=E(r+f);B[j>>2]=q;f=E(0);m=E(0);b:{c:{switch(u|0){case 0:f=B[a+4224>>2];m=E(q*f);f=E(p*f);break b;case 1:case 2:f=B[a+4224>>2];m=E(p*f);f=E(q*f);break b;case 3:break c;default:break b}}f=E(E(E(E(s+r)*E(.5))+t)*B[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;i=i+4|0;h=h+4|0;g=e<<1;w=zb(k,g),z=E(F(f))<E(10000000195414814e-40)?E(0):f,B[w>>2]=z;w=zb(k,g|1),z=E(F(m))<E(10000000195414814e-40)?E(0):m,B[w>>2]=z;e=e+1|0;x[a+4220>>2]=e;l=l+1|0;continue}}e=h;h=d<<2;Zk(e,e+h|0,n);Zk(i,i+h|0,j)}h=a;a=x[a+56>>2];di(h,b,c,Cc(a,0),Cc(a,1),d)}function Z6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=E(0),t=0,u=0,v=0,w=0,y=0,z=E(0);a:{j=x[a+4272>>2];if(!j){break a}if(!Qh(a+44|0)){break a}f=x[a+44>>2];l=Cc(f,0);m=Cc(f,1);u=x[a+4252>>2]-1|0;i=x[a+4268>>2];k=x[a+4256>>2];n=d;f=x[a+56>>2];q=Cc(f,0);o=q;r=Cc(f,1);p=r;while(1){if(n){e=B[m>>2];f=i<<1;h=zb(k,f);g=B[l>>2];B[h>>2]=g;y=zb(k,f|1),z=e,B[y>>2]=z;s=B[a+4276>>2];e=E(E(F(nK(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)))*E(4.656612873077393e-10));e=E(E(E(s-e)*B[(e>=s?4236:4240)+a>>2])+e);B[a+4276>>2]=e;g=B[a+4244>>2];e=E(E(E(E(g-(e<g?g:e))*B[a+4248>>2])+E(.9999998807907104))*E(2147483648));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=B[zb(k,t)>>2];h=f<<5;v=h;w=h|-2147483648;h=f>>>0<67108864;e=E(B[a+4232>>2]*E(E((h?v:w)>>>(h?31:32-(f>>>26|0)|0)>>>0)*E(4.656612873077393e-10)));B[o>>2]=g*e;y=p,z=E(B[zb(k,t|1)>>2]*e),B[y>>2]=z;i=((i?0:j)+i|0)-1|0;x[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{di(a,b,c,q,r,d)}break}}}function a2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=hb+-64|0;hb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;tf(b+48|0,b+32|0,d);a=x[c+4>>2];e=x[a+8>>2];h=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;d=b+16|0;a=hb-32|0;hb=a;a:{b:{c:{d:{i=x[b+4>>2];if(i>>>0>=h>>>0){if(A[d+4>>2]<h>>>0){break d}if(A[b+8>>2]<e>>>0){break c}if(de(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}k=x[b>>2];e:while(1){c=0;if((e|0)==(f|0)){break a}while(1)if((c|0)==(h|0)){f=f+1|0;continue e}else{l=a,m=C[Mg(k,i,c,f)>>3],C[l+24>>3]=m;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=ee(C[wg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Vc(g);l=rn(d,c,f),n=g,w[l>>1]=n;c=c+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=b- -64|0}function KH(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),q=0;a:{if(y[b+21|0]){q=D(d,g);j=x[e>>2];l=x[f>>2];m=x[b>>2];b:{while(1){if((h|0)>0){if(x[a+1396>>2]<=9){Bk(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;k=(g|0)<0?-1:k;break c}k=Jl(a,b)}if((k|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((k|0)<0){if(!y[a+1376|0]){b=0;if(x[a+1384>>2]){break b}}gc(a,21);return 0}else{g=0;n=D(d,l);m=((m+n|0)+j|0)>(q|0)?(q-n|0)+j|0:m;n=(m|0)>0?m:0;k=D(k,x[b>>2]);o=E(0);d:{if(y[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=E(o+B[x[b+28>>2]+(g+k<<2)>>2]);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=o+B[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+E(B[x[b+28>>2]+(g+k<<2)>>2]+E(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}}break}x[e>>2]=j;x[f>>2]=l;b=1}return b}gc(a,21);return 0}aa(7470,13065,1887,6512);p()}function vN(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{switch(y[a+480224|0]-1|0){default:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=Jia(c,c>>31,5e4,0);e=lb;b=x[_c(d+12|0,d+8|0)>>2];c=Ec(Kia(c,e,b,b>>31),lb);break a;case 0:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=Jia(c,c>>31,1e4,0);e=lb;b=x[_c(d+12|0,d+8|0)>>2];c=Ec(Kia(c,e,b,b>>31),lb);break a;case 1:break b}}f=60/(+A[b+44>>2]/1e4*(+(Jia(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(lb>>>0)*4294967296))*+A[a+24620>>2];c:{d:{c=x[a+484344>>2];e=z[b+70>>1];if(!pe(c,x[a+484348>>2],e)){break d}c=ac(c,e);if(!Ob(x[c+24>>2],x[c+28>>2])){break d}c=c+24|0;break c}c=a+480248|0}e=x[c>>2];c=x[c+4>>2];if(!tc(e,c)){f=f*+A[zb(e,A[b+48>>2]%(rc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(F(f)<2147483648){c=~~f;break e}c=-2147483648}f=C[b+8>>3]+(f-+(c>>>0));C[b+8>>3]=f;if(f>=1){C[b+8>>3]=f+-1;c=c+1|0;break a}if(!(C[a+1074384>>3]<=-1)){break a}C[b+8>>3]=f+1;c=c-1|0}b=Jia(x[a+480244>>2],0,c,0);a=lb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Uc((a&65535)<<16|b>>>16,a>>>16|0);hb=d+16|0;return a?a:1}function i_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=hb-160|0;hb=a;x[a+144>>2]=c;x[a+152>>2]=b;x[a+20>>2]=1104;b=le(a+24|0,a+32|0,a+20|0);Pc(a+16|0,x[e+28>>2]);x[23604]=0;h=S(18,x[a+16>>2])|0;i=x[23604];x[23604]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[23604]=0;c=pa(1105,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}Ve(g);if(y[a+15|0]){x[23604]=0;c=Q(19,h|0,45)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}x[23604]=0;R(46,g|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}}x[23604]=0;d=Q(19,h|0,48)|0;c=x[23604];x[23604]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-1|0;c=x[b>>2];d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[23604]=0;W(1111,g|0,c|0,e|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break c}break a}x[23604]=0;c=Q(1073,a+152|0,a+144|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+152>>2];$b(a+16|0);Mc(b);hb=a+160|0;return c|0}}}c=P()|0;$b(a+16|0);Mc(b);T(c|0);p()}function qM(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=hb-32|0;hb=g;b=at(g);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(f<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;hb=g+32|0;f=f+1|0;continue}break}}function B7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=hb+-64|0;hb=b;g=Sb(a);x[23604]=0;Y(863,g|0);a=x[23604];x[23604]=0;a:{if((a|0)!=1){a=45088;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==45400){hb=b- -64|0;return g|0}k:{h=Bs(44);if(h){x[23604]=0;d=Q(54,b+32|0,x[a+4>>2])|0;c=x[23604];x[23604]=0;if((c|0)==1){break k}c=x[a>>2];x[23604]=0;R(864,b+48|0,d|0);e=x[23604];x[23604]=0;if((e|0)==1){break j}x[23604]=0;e=Q(54,b|0,x[a+8>>2])|0;f=x[23604];x[23604]=0;if((f|0)==1){break i}x[23604]=0;R(864,b+16|0,e|0);f=x[23604];x[23604]=0;if((f|0)==1){break h}x[23604]=0;c=fa(865,h|0,c|0,b+48|0,b+16|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break g}Db(b+16|0);xb(e);Db(b+48|0);xb(d);x[b+60>>2]=c;x[23604]=0;R(866,g|0,b+60|0);d=x[23604];x[23604]=0;if((d|0)==1){break b}v[c+40|0]=y[a+20|0];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;v[c+41|0]=y[c+41|0]&253|y[a+21|0]<<1}a=a+24|0;continue}break}a=P()|0;break c}a=P()|0;break d}a=P()|0;break e}a=P()|0;break f}a=P()|0;Db(b+16|0)}xb(e)}Db(b+48|0)}xb(d)}Hb(h);break a}a=P()|0;break a}a=P()|0}sc(g);T(a|0);p()}function nha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-48|0;hb=d;i=a+484344|0;j=a+480280|0;while(1){a:{if(Qb(x[b>>2],x[b+8>>2],9)){e=d+44|0;fo(b,e);c=kg(b);b:{if(!Rb(e,13857,4)){break b}if(!Rb(d+44|0,13513,4)){break b}if(!Rb(d+44|0,13689,4)){break b}if(!Rb(d+44|0,13694,4)){break b}if(Qb(x[b>>2],x[b+8>>2],c)){break a}}hg(b,8)}hb=d+48|0;return k|0}Ud(d,b,c);e=kc(d+24|0,d);yb(d);c=j;c:{d:{e:{if(!Rb(d+44|0,13424,4)){while(1){if((c|0)==(i|0)){break c}x[23604]=0;f=S(143,e|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break e}v[c+8|0]=f;c=c+32|0;continue}}if(y[d+44|0]!=70){break d}f=y[d+45|0];h=(f|0)==88;f:{if(!h){if((f-48&255)>>>0>9){break d}c=v[d+46|0];if((c|0)>47){break f}break d}c=v[d+46|0];if((c|0)<48){break d}}if(c>>>0>57){break d}g=v[d+47|0];if((g|0)<48|(g|0)>57){break d}c=(g+(h?-16:D(f,100)+48|0)|0)+D(c,10)&255;if(c>>>0>249){break c}x[23604]=0;R(384,e|0,(D(c,160)+a|0)+906300|0);c=x[23604];x[23604]=0;if((c|0)!=1){break c}}a=P()|0;yb(e);T(a|0);p()}if(Rb(d+44|0,13440,4)){break c}x[a+1074308>>2]=0;k=1}yb(e);continue}}function FH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-208|0;hb=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;b=4;f=4;e=2;while(1){g=b;b=(b+f|0)+4|0;x[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;f=g;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){f=0;e=1;h=0;b=1;g=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){Fw(a,c,b,d+16|0);Rr(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(A[(d+16|0)+(g<<2)>>2]>=f-a>>>0){Qr(a,c,e,x[d+12>>2],b,0,d+16|0);break d}Fw(a,c,b,d+16|0)}if((b|0)==1){Pr(d+8|0,1);b=0;break c}Pr(d+8|0,g);b=1}g=x[d+8>>2];e=g|1;x[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}h=g>>>0>1;f=x[d+12>>2];g=(f|0)!=0}Qr(a,c,e,f,b,0,d+16|0);if(!(g|((b|0)!=1|h))){break a}while(1){e:{if((b|0)<=1){g=yH(e,f);Rr(d+8|0,g);f=x[d+12>>2];e=x[d+8>>2];b=b+g|0;break e}e=d+8|0;Pr(e,2);x[d+8>>2]=x[d+8>>2]^7;Rr(e,1);f=a-4|0;h=d+16|0;g=b-2|0;Qr(f-x[h+(g<<2)>>2]|0,c,x[d+8>>2],x[d+12>>2],b-1|0,1,h);Pr(e,1);e=x[d+8>>2]|1;x[d+8>>2]=e;b=f;f=x[d+12>>2];Qr(b,c,e,f,g,1,h);b=g}a=a-4|0;if((b|0)!=1|(e|0)!=1|f){continue}break}}hb=d+208|0}function kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;h=hb-16|0;hb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];w=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=Jia(n,u,f,f>>31);f=lb;e=Yb(e,-16777216,16776704);e=Jia(m,t,e,e>>31);g=e+g|0;f=lb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=x[h+12>>2]+p|0;k=v[g|0];k=((D(v[g+1|0]-k|0,x[h+8>>2]>>>10&4194048)|0)/16384|0)+(k<<8)<<8;e=k;g=Jia(e,e>>31,o,w);l=g+l|0;e=lb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Nc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Ub(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=h+16|0}function Rda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=x[a>>2];c=Dd(d,x[a+4>>2]);if(c>>>0<b>>>0){h=hb-32|0;hb=h;c=b-c|0;b=x[Cb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=hb-16|0;hb=d;c=ot(d,a,c);a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)==(b|0)){ic(c);hb=d+16|0}else{XP(a);a=a+12|0;x[c+4>>2]=a;continue}break}break a}b=Cb(a);e=wl(h+8|0,Io(a,Dd(x[a>>2],d)+c|0),Dd(x[a>>2],x[a+4>>2]),b);b=hb-16|0;hb=b;c=YP(b,e+8|0,c);d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){XP(d);d=x[c>>2]+12|0;x[c>>2]=d;continue}break}Hd(c);hb=b+16|0;g=hb-32|0;hb=g;c=Ib(g+24|0,x[a+4>>2]);d=Ib(g+16|0,x[a>>2]);b=Ib(g+8|0,x[e+4>>2]);c=x[c>>2];d=x[d>>2];f=hb-16|0;hb=f;x[f>>2]=x[b>>2];x[f+8>>2]=c;while(1){b=x[f>>2];if(og(c,d)){Qj(Bi(b),Bi(c));b=vl(f+8|0);vl(f);c=x[b>>2];continue}break}hb=f+16|0;x[e+4>>2]=b;qc(a,e+4|0);qc(a+4|0,e+8|0);qc(Cb(a),yc(e));x[e>>2]=x[e+4>>2];hb=g+32|0;b=x[e+4>>2];while(1){a=x[e+8>>2];if((a|0)!=(b|0)){a=a-12|0;x[e+8>>2]=a;ZP(a);continue}break}a=x[e>>2];if(a){fr(e);Hb(a)}}hb=h+32|0;return}if(b>>>0<c>>>0){_P(a,d+D(b,12)|0)}}function hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;p=x[a+16>>2];q=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=Xf(k,b,l);o=lb;h=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];Cf(b,f,Ze(k,m,d),lb);h=lb>>>0>h>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;h=h-1|0;b=h;n=b?n:0;o=b?o:0;f=(f<<1)+p|0;b=l;while(1)if((b|0)<=0){Ub(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(g,w[f+(x[e+12>>2]<<1)>>1]/4<<16>>16);Jd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Tf(g,q);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Ub(e,k,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue b}else{Kd(g,w[f+(x[e+12>>2]<<1)>>1]/4<<16>>16);Jd(g,4);Ub(e+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;hb=e+16|0}function F7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=E(0),h=0,i=0;c=hb-32|0;hb=c;a:{d=x[a+20>>2];b:{if(!d){break b}x[d+148>>2]=-1;h=c,i=mb[x[x[a>>2]+40>>2]](a)|0,x[h+16>>2]=i;x[c+8>>2]=1073741822;f=x[Fb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=x[a+20>>2];d=0;x[23604]=0;R(270,e+4|0,b+4|0);b=x[23604];x[23604]=0;c:{d:{if((b|0)!=1){b=x[a+20>>2];ke(c+8|0,x[b+4>>2],x[b+8>>2]);x[c>>2]=0;x[c+4>>2]=0;e=x[c+12>>2];b=c+16|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=e;e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;e=hb-16|0;hb=e;x[e+8>>2]=0;FK(b,e+8|0);hb=e+16|0;b=x[x[a>>2]+180>>2];x[23604]=0;R(b|0,a|0,-1);b=x[23604];x[23604]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=x[x[a>>2]+184>>2];x[23604]=0;Y(d|0,a|0);d=x[23604];x[23604]=0;if((d|0)!=1){break b}break d}b=x[x[a>>2]+48>>2];x[23604]=0;g=E(Ya(b|0,a|0,d|0));b=x[23604];x[23604]=0;if((b|0)!=1){B[c+8>>2]=g;d=d+1|0;FK(c+16|0,c+8|0);continue}break}d=V(92520)|0;break c}d=V(92520)|0;break c}d=V(92520)|0}if((ib|0)!=(da(92520)|0)){break a}_(d|0)|0;Fc(x[a+20>>2]+4|0);$()}hb=c+32|0;return}T(d|0);p()}function jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=hb-16|0;hb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];v=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=Jia(n,u,f,f>>31);f=lb;e=Yb(e,-16777216,16776704);e=Jia(m,t,e,e>>31);g=e+g|0;f=lb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=(x[h+12>>2]<<1)+p|0;k=w[g>>1];k=k+((D(w[g+2>>1]-k|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=k;g=Jia(e,e>>31,o,v);l=g+l|0;e=lb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Nc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Ub(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=h+16|0}function zQ(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-80|0;hb=c;x[c+72>>2]=0;x[c+76>>2]=0;b=c- -64|0;x[b>>2]=0;x[b+4>>2]=0;x[c+56>>2]=0;x[c+60>>2]=0;x[c+48>>2]=0;x[c+52>>2]=0;nz(a,oz(a),c+48|0);b=oc(c+40|0,14050);Oe(qe(a,0),x[b>>2],x[b+4>>2]);b=oc(c+32|0,14154);Oe(qe(a,1),x[b>>2],x[b+4>>2]);b=oc(c+24|0,5457);Oe(qe(a,3),x[b>>2],x[b+4>>2]);b=oc(c+16|0,15554);Oe(qe(a,4),x[b>>2],x[b+4>>2]);b=oc(c+8|0,9167);Oe(qe(a,8),x[b>>2],x[b+4>>2]);e=qe(a+288|0,0);b=hb-16|0;hb=b;d=e;e=oc(b+8|0,4893);Oe(d,x[e>>2],x[e+4>>2]);hb=b+16|0;e=a+800|0;b=0;a=hb-80|0;hb=a;a:{b:{while(1){if((b|0)==128){break a}x[a+76>>2]=b<<3;c:{d:{if(b>>>0<=15){ef(a+32|0,4045);x[23604]=0;R(272,a+16|0,a+76|0);d=x[23604];x[23604]=0;if((d|0)==1){break c}x[23604]=0;U(273,a+48|0,a+32|0,a+16|0);d=x[23604];x[23604]=0;if((d|0)!=1){d=a+48|0;ve(a- -64|0,d);Oe(qe(e,b),x[a+64>>2],x[a+68>>2]);xb(d);xb(a+16|0);Db(a+32|0);break d}b=P()|0;xb(a+16|0);break b}d=oc(a+8|0,21502);Oe(qe(e,b),x[d>>2],x[a+12>>2])}b=b+1|0;continue}break}b=P()|0}Db(a+32|0);T(b|0);p()}hb=a+80|0;hb=c+80|0}function Nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-16|0;hb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Ub(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;hb=e+16|0}function $8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;od(c,0);w[d+14>>1]=y[a+36|0]|y[a+37|0]<<8;w[d+12>>1]=32767;g=c,h=(z[Wc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,w[g+28>>1]=h;w[d+10>>1]=y[a+38|0]|y[a+39|0]<<8;w[d+8>>1]=32767;g=c,h=(z[Wc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,w[g+30>>1]=h;w[c+32>>1]=64;x[c>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+4>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+8>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[c+24>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);e=y[b+166|0];if(e>>>0<=4){v[c+38|0]=y[e+43242|0]}e=y[b+167|0]|y[b+168|0]<<8;v[c+39|0]=e;f=(y[b+171|0]|y[b+172|0]<<8)>>>4|0;v[c+41|0]=f;b=(y[b+169|0]|y[b+170|0]<<8)>>>2|0;v[c+40|0]=b;if((b|f)&255){v[c+39|0]=e^-1}b=y[a+40|0]|y[a+41|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+40|0]|y[a+41|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+40|0]|y[a+41|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+40|0]|y[a+41|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}hb=d+16|0}function aX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;f=Sb(a);a=0;a:{b:{c:{d:{e:{while(1){if((vv(b,c,a)|0)==-1){break b}e=vv(b,c,a);x[23604]=0;X(108,d|0,b|0,a|0,e-a|0);e=x[23604];x[23604]=0;if((e|0)!=1){x[23604]=0;R(109,d+16|0,d|0);e=x[23604];x[23604]=0;if((e|0)==1){break e}x[23604]=0;R(110,f|0,d+16|0);e=x[23604];x[23604]=0;if((e|0)==1){break d}xb(d+16|0);xb(d);a=vv(b,c,a)+Qc(x[c+4>>2],y[c+11|0])|0;continue}break}a=P()|0;break a}a=P()|0;break c}a=P()|0;xb(d+16|0)}xb(d);break a}f:{g:{h:{i:{j:{k:{if(tc(x[f>>2],x[f+4>>2])){x[23604]=0;X(108,d+16|0,b|0,a|0,-1);c=x[23604];x[23604]=0;if((c|0)==1){break j}c=Qc(x[d+20>>2],y[d+27|0]);xb(d+16|0);if(!c){break k}}x[23604]=0;X(108,d|0,b|0,a|0,-1);a=x[23604];x[23604]=0;if((a|0)==1){break i}x[23604]=0;R(109,d+16|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}x[23604]=0;R(110,f|0,d+16|0);a=x[23604];x[23604]=0;if((a|0)==1){break g}xb(d+16|0);xb(d)}hb=d+32|0;return}a=P()|0;break a}a=P()|0;break a}a=P()|0;break f}a=P()|0;xb(d+16|0)}xb(d)}Vd(f);T(a|0);p()}function JH(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=B[b>>2];j=B[c>>2];k=B[d>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=f+B[b>>2];j=E(j-k);f=E(f-h);B[d>>2]=E(j*B[e>>2])-E(B[e+4>>2]*f);B[b>>2]=E(f*B[e>>2])+E(j*B[e+4>>2]);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=f+k;i=c-12|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+32>>2])-E(B[e+36>>2]*h);B[b>>2]=E(h*B[e+32>>2])+E(f*B[e+36>>2]);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=f+k;i=c-20|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+64>>2])-E(B[e+68>>2]*h);B[b>>2]=E(h*B[e+64>>2])+E(f*B[e+68>>2]);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=f+k;i=c-28|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+96>>2])-E(B[e+100>>2]*h);B[b>>2]=E(h*B[e+96>>2])+E(f*B[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}aa(15643,13065,2423,9113);p()}function HM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;f=D(b,872)+a|0;a:{if(c){Jb(e+8|0,a+1074312|0,90);if(!Mb(x[x[e+8>>2]>>2],x[e+12>>2])){v[f+1075803|0]=c}v[f+1075804|0]=c;break a}c=y[f+1075804|0]}g=f+1074992|0;i=b;h=c&255;j=0-h|0;b=a+480180|0;k=!(x[b>>2]&204473357)&(d^-1);CM(a,i,j,k);b=x[b>>2];b:{c:{if((b|0)!=268435456){if((b|0)!=16777216){break c}i=x[f+1075648>>2];if(!i|!x[i+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){BM(x[a+1074392>>2],x[a+1074416>>2],g,240-h|0);break b}if(!(b>>>0<224|d)){AM(g,224-h|0);break b}zM(g,j);break b}x[f+1075700>>2]=65535}d:{if(!((c&255)>>>0>223&k)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}ly(a,g,d);break b}if((b|0)==524288){break d}EM(a,g,d);break b}if((b|0)!=524288){break b}}f:{if(!(v[f+1075843|0]&1)){break f}if(x[a+1074416>>2]==1){Jb(e+8|0,a+1074312|0,6);if(Mb(x[x[e+8>>2]>>2],x[e+12>>2])){break f}b=x[a+480180>>2]}if(b&32832){break f}if(!(x[a+480208>>2]&2)|(b|0)!=8){break b}}Hj(a,g,f+1075692|0,0-(h<<2)|0,0)}hb=e+16|0}function dE(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;a:{h=hb+-64|0;hb=h;l=x[c>>2]&2?16:10;j=hb-32|0;hb=j;i=Ue(j+16|0,1,0);b:{c:{d:{while(1){k=Pb(i);$I(j+8|0,k,Eb(x[i+4>>2],y[i+11|0])+k|0,x[b>>2],l);if(!x[j+12>>2]){break d}k=Rf(Eb(x[i+4>>2],y[i+11|0]));x[23604]=0;R(58,i|0,k|0);k=x[23604];x[23604]=0;if((k|0)!=1){continue}break}break c}b=x[j+8>>2];l=Pb(i);x[23604]=0;R(59,i|0,b-l|0);b=x[23604];x[23604]=0;e:{if((b|0)!=1){x[23604]=0;R(g|0,h|0,i|0);b=x[23604];x[23604]=0;if((b|0)!=1){break e}break c}break c}xb(i);hb=j+32|0;break b}a=P()|0;xb(i);T(a|0);p()}b=h+16|0;Ll(b,h,x[c>>2]);g=x[c+4>>2];i=x[c>>2];x[23604]=0;X(f|0,h+32|0,b|0,i|0,g|0);b=x[23604];x[23604]=0;f:{g:{h:{i:{if((b|0)!=1){b=y[c+16|0];c=x[c+12>>2];x[23604]=0;X(e|0,h+48|0,h+32|0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break i}x[23604]=0;R(d|0,a|0,h+48|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}xb(h+48|0);xb(h+32|0);xb(h+16|0);xb(h);hb=h- -64|0;break a}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(h+48|0)}xb(h+32|0)}xb(h+16|0);xb(h);T(a|0);p()}}function Oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-16|0;hb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Ub(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;hb=e+16|0}function ff(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-80|0;hb=e;c=x[a+28>>2];Sm(x[x[c>>2]-12>>2]+c|0,0);if(!fd(a,4)){Sv(a)}a:{if(!x[a+4>>2]){break a}if(fd(a,6)){break a}if(fd(a,7)){break a}f=x[a+28>>2];g=e- -64|0;c=x[a+84>>2];d=D(x[a+20>>2],x[a+4>>2]);h=d;d=d+x[a+80>>2]|0;c=h>>>0>d>>>0?c+1|0:c;c=dh(g,d,c);d=x[c+12>>2];x[e+24>>2]=x[c+8>>2];x[e+28>>2]=d;d=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=d;zj(f,e+16|0)}d=0;b:{if(!fd(a,5)){break b}f=ch(x[a+44>>2],x[a+48>>2]);c=0;while(1){if((c|0)==(f|0)){break b}g=(x[a+96>>2]+c>>>0)%(f>>>0)|0;j=bd(x[a+44>>2],g);i=x[j>>2];c:{h=x[a+32>>2];if(Rc(h,x[a+36>>2])>>>0<=i>>>0){break c}i=Xm(e+48|0,Gb(h,i),z[j+12>>1]);j=Wv(b,i);Db(i);if(!j){break c}x[a+96>>2]=(g+1>>>0)%(f>>>0);d=bd(x[a+44>>2],g);c=x[d+4>>2];if(!c){break b}d=x[a+28>>2];f=e+32|0;b=x[a+12>>2];h=c;c=x[a+8>>2]+c|0;b=h>>>0>c>>>0?b+1|0:b;b=dh(f,c,b);c=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;zj(d,e);d=bd(x[a+44>>2],g);break b}c=c+1|0;continue}}hb=e+80|0;return d}function nz(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a|0]=e;v[a+1|0]=e>>>8;v[a+2|0]=e>>>16;v[a+3|0]=e>>>24;v[a+4|0]=d;v[a+5|0]=d>>>8;v[a+6|0]=d>>>16;v[a+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[a+24|0]=e;v[a+25|0]=e>>>8;v[a+26|0]=e>>>16;v[a+27|0]=e>>>24;v[a+28|0]=d;v[a+29|0]=d>>>8;v[a+30|0]=d>>>16;v[a+31|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[a+16|0]=e;v[a+17|0]=e>>>8;v[a+18|0]=e>>>16;v[a+19|0]=e>>>24;v[a+20|0]=d;v[a+21|0]=d>>>8;v[a+22|0]=d>>>16;v[a+23|0]=d>>>24;d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+8|0]=e;v[a+9|0]=e>>>8;v[a+10|0]=e>>>16;v[a+11|0]=e>>>24;v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function Bj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;x[i+16>>2]=c;x[i+24>>2]=b;Pc(i+8|0,x[d+28>>2]);c=0;x[23604]=0;j=S(18,x[i+8>>2])|0;b=x[23604];x[23604]=0;if((b|0)!=1){$b(i+8|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(Lg(i+24|0,i+16|0)){break b}c:{if(($m(j,v[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=$m(j,v[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=$m(j,v[g+2|0])}l=i,m=mb[x[x[a>>2]+36>>2]](a,x[i+24>>2],x[i+16>>2],d,e,f,b,k)|0,x[l+24>>2]=m;g=c+2|0;break c}b=x[j+8>>2];if(fh(b,1,v[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(fh(b,1,v[g|0])){continue}}break}while(1){if(Lg(i+24|0,i+16|0)){break c}b=zk(x[i+24>>2]);if(!fh(x[j+8>>2],1,b)){break c}Hl(i+24|0);continue}}if((fw(j,zk(x[i+24>>2]))|0)==(fw(j,v[g|0])|0)){g=g+1|0;Hl(i+24|0);break c}x[e>>2]=4}c=x[e>>2];continue}break}x[e>>2]=4}if(Lg(i+24|0,i+16|0)){x[e>>2]=x[e>>2]|2}hb=i+32|0;return x[i+24>>2]}a=P()|0;$b(i+8|0);T(a|0);p()}function RI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=hb+-64|0;hb=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;tf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{h=x[c+4>>2];if(f>>>0<=h>>>0){if(f>>>0>A[c+20>>2]){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(de(x[c+24>>2],i)>>>0<e>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){a=0;if((e|0)==(g|0)){break a}while(1)if((a|0)==(f|0)){g=g+1|0;continue e}else{d=Gh(m,h,a,g);j=zb(x[b>>2],a);d=x[d>>2]+(x[j>>2]>>1)|0;n=d;d=$r(k)+d&-4096;x[j>>2]=n-d;d=gd(d|2048,12);d=(d|0)>=32767?32767:d;o=sn(l,i,a,g),q=(d|0)<=-32768?-32768:d,w[o>>1]=q;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=hb-16|0;hb=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];l=x[a+68>>2];s=l>>31;m=x[a+64>>2];t=m>>31;n=x[a+60>>2];u=n>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);i=Jia(m,t,e,e>>31);j=lb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+40242>>1])+D(w[h-2>>1],w[e+40240>>1])|0)+D(w[h+2>>1],w[e+40244>>1])|0)+D(w[h+4>>1],w[e+40246>>1])|0)/16384<<8;e=h;e=Jia(e,e>>31,n,u);i=e+i|0;k=lb+j|0;k=e>>>0>i>>>0?k+1|0:k;f=Yb(f,-16777216,16776704);e=Jia(l,s,f,f>>31);j=e+i|0;f=lb+k|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Nc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Ub(g+8|0,v,y);e=e-(h&r)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=g+16|0}function iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;p=x[a+16>>2];q=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=Xf(k,b,l);o=lb;h=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];Cf(b,f,Ze(k,m,d),lb);h=lb>>>0>h>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;h=h-1|0;b=h;n=b?n:0;o=b?o:0;f=f+p|0;b=l;while(1)if((b|0)<=0){Ub(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(g,v[f+x[e+12>>2]|0]<<6);Jd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Tf(g,q);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Ub(e,k,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue b}else{Kd(g,v[f+x[e+12>>2]|0]<<6);Jd(g,4);Ub(e+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;hb=e+16|0}function dP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0;if(cj(x[a+656>>2])){e=y[a+797|0];e=(l=e,m=y[a+799|0],n=Tc(e),n?l:m);a:{b:{c:{if(!Tb(d+1074312|0,34)){break c}d=e&255;if(!d){break c}if(d>>>0<121){break b}}d=x[a+656>>2];break a}d=x[a+656>>2];e=y[Gb(d+108|0,(e&255)-1|0)|0]}k=E(E(x[a+704>>2])*b);d=x[d+44>>2];f=((e&255)+c|0)-61<<16>>16;d:{e:{c=x[a+852>>2]+w[a+772>>1]|0;if(c){g=x[d+36>>2];if(g){break e}}b=Tl(d,c+f<<16>>16);break d}j=g+1|0;h=Dx(c,j);e=Ex(c,j);b=E(1);i=w[d+28>>1];c=f+h<<16>>16;f:{if((i|0)>(c|0)){break f}f=x[d+4>>2];if((c|0)>(rc(f,x[d+8>>2])+i|0)-1<<16>>16){break f}if(!e){b=B[zb(f,c-i|0)>>2];break d}g:{h:{i:{switch(z[d>>1]-1|0){case 2:g=x[d+16>>2];if(!rc(g,x[d+20>>2])){break h}b=B[zb(g,e-1|0)>>2];break g;case 0:break i;default:break h}}h=x[d+16>>2];if(!rc(h,x[d+20>>2])){break h}b=B[zb(h,(e+D(g,Hx(c,z[d+30>>1])<<16>>16)|0)-1|0)>>2];break g}b=me(E(Tl(d,c+1<<16>>16)/Tl(d,c)),E(E(e|0)/E(j|0)))}b=E(b*B[zb(f,c-i|0)>>2])}}l=a,m=Mj(E(E(k*b)*E(16))),x[l+700>>2]=m}}function QG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;q=a;i=hb-1040|0;hb=i;r=x[116080];a:{b:{a=i+16|0;l=z[((b>>>0<=149?b:0)<<1)+90992>>1]+89168|0;c=x[x[116108]+20>>2];if(c){j=x[c+4>>2];c=x[c>>2];e=x[c>>2]+1794895138|0;h=Fl(x[c+8>>2],e);f=Fl(x[c+12>>2],e);d=Fl(x[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}s=d>>>2|0;t=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+t<<2)|0;o=Fl(x[d>>2],e);d=Fl(x[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|y[c+(d+o|0)|0]){break c}d=Vi(l,c+d|0);if(!d){f=c+(s+n<<2)|0;h=Fl(x[f>>2],e);e=Fl(x[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=y[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=If(g);d:{if(c>>>0>=1024){vc(a,g,1023);v[a+1023|0]=0;g=68;break d}vc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21502}break a}wa();p()}if(!y[a|0]){x[i>>2]=b;a=i+16|0;kw(a,1024,12882,i)}x[116080]=r;Xb(q,a);hb=i+1040|0}function NU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-144|0;hb=f;x[23604]=0;l=S(256,a|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){m=c+480192|0;while(1){a:{if((j&65535)>>>0>=l>>>0){yb(a);hb=f+144|0;return}x[23604]=0;R(275,a|0,f+8|0);e=x[23604];x[23604]=0;if((e|0)!=1){b:{e=Lb(z[f+8>>1]);if(!e|e>>>0>z[m>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}e=xi(e,b);g=y[f+11|0];c:{if(!g){break c}h=y[f+10|0];if(h&1){v[e+12|0]=y[e+12|0]|1}if(h&2){v[e+12|0]=y[e+12|0]|4}if(!(h&4)){break c}v[e+12|0]=y[e+12|0]|2}v[f+4|0]=g;v[f+7|0]=31;h=y[Wb(f+4|0,f+7|0)|0];x[23604]=0;h=h+1&255;R(276,e|0,h|0);g=x[23604];x[23604]=0;if((g|0)==1){break a}v[e+13|0]=y[f+13|0];v[e+14|0]=y[f+14|0];g=y[f+12|0];v[e+15|0]=g;v[e+16|0]=g;g=x[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;n=Lb(z[i+8>>1]);k=zb(g,e);w[k>>1]=n;i=Lb(z[i+10>>1]);w[f+4>>1]=d?i+128>>>2|0:i;pg(f+4|0,64);v[k+2|0]=y[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=P()|0;yb(a);T(b|0);p()}function IM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;f=D(b,872)+a|0;a:{if(c){Jb(e+8|0,a+1074312|0,90);if(!Mb(x[x[e+8>>2]>>2],x[e+12>>2])){v[f+1075804|0]=c}v[f+1075803|0]=c;break a}c=y[f+1075803|0]}g=f+1074992|0;i=b;h=c&255;b=a+480180|0;j=!(x[b>>2]&204473357)&(d^-1);CM(a,i,h,j);b=x[b>>2];b:{c:{if((b|0)!=268435456){if((b|0)!=16777216){break c}i=x[f+1075648>>2];if(!i|!x[i+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){BM(x[a+1074392>>2],x[a+1074416>>2],g,h-240|0);break b}if(!(b>>>0<224|d)){AM(g,h-224|0);break b}zM(g,h);break b}x[f+1075700>>2]=1}d:{if(!((c&255)>>>0>223&j)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}my(a,g,d);break b}if((b|0)==524288){break d}DM(a,g,d);break b}if((b|0)!=524288){break b}}f:{if(!(v[f+1075843|0]&1)){break f}if(x[a+1074416>>2]==1){Jb(e+8|0,a+1074312|0,6);if(Mb(x[x[e+8>>2]>>2],x[e+12>>2])){break f}b=x[a+480180>>2]}if(b&32832){break f}if(!(x[a+480208>>2]&2)|(b|0)!=8){break b}}Hj(a,g,f+1075692|0,h<<2,0)}hb=e+16|0}function _ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;h=hb-16|0;hb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];j=x[a+68>>2];r=j>>31;k=x[a+64>>2];s=k>>31;l=x[a+60>>2];t=l>>31;u=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=Jia(k,s,f,f>>31);f=lb;e=Yb(e,-16777216,16776704);e=Jia(j,r,e,e>>31);g=e+g|0;f=lb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;m=(((D(v[g|0],w[e+40242>>1])+D(v[g-1|0],w[e+40240>>1])|0)+D(v[g+1|0],w[e+40244>>1])|0)+D(v[g+2|0],w[e+40246>>1])<<8)/16384<<8;e=m;g=Jia(e,e>>31,l,t);i=i+g|0;e=lb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Nc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Ub(h+8|0,u,y);f=f-(q&m)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;hb=h+16|0}function Tn(a,b,c,d){v[a+841|0]=0;x[a+708>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;v[a+797|0]=0;x[a+764>>2]=0;w[a+802>>1]=0;w[a+804>>1]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;if(Tb(b+1074312|0,23)){v[a+807|0]=1;v[a+808|0]=0}v[a+846|0]=0;v[a+839|0]=0;w[a+774>>1]=0;v[a+850|0]=255;x[a+660>>2]=0;v[a+851|0]=y[a+851|0]&224;Zn(a+788|0);x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;v[a+845|0]=0;v[a+838|0]=0;v[a+821|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+836>>1]=32512;v[a+819|0]=0;v[a+820|0]=0;w[a+842>>1]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+852>>2]=0;x[a+856>>2]=0;v[a+851|0]=y[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+748>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|d;break a}x[a+748>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+784>>1]=0;v[a+795|0]=0;v[a+796|0]=0}function vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;f=hb-16|0;hb=f;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];n=x[a+8>>2];o=x[a+12>>2];while(1){if(d){e=x[f+8>>2];p=((((x[f+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;q=w[e+38>>1];r=w[e+36>>1];s=w[e+34>>1];t=w[e+32>>1];u=w[e+30>>1];v=w[e+28>>1];y=w[e+26>>1];e=w[e+24>>1];j=0;while(1){if((j|0)!=2){g=(j<<1)+p|0;x[(j<<2)+f>>2]=(((((D(w[g+8>>1],s)+D(w[g+4>>1],t)|0)+D(w[g+12>>1],r)|0)+D(w[g+16>>1],q)|0)/2|0)+((((D(w[g-8>>1],y)+D(w[g-12>>1],e)|0)+D(w[g-4>>1],v)|0)+D(w[g>>1],u)|0)/2|0)|0)/16384;j=j+1|0;continue}break}i=i+m|0;x[c>>2]=x[c>>2]+D(x[f>>2],i>>12);h=h+l|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],h>>12);Ub(f+8|0,n,o);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;hb=f+16|0}function xP(a,b,c){var d=0,e=0;d=y[a|0]&15;v[a|0]=y[d+27440|0];a:{b:{c:{switch(d|0){case 0:if(y[b|0]?c>>>0>=51:0){break b}v[a|0]=0;return;case 5:d:{e:{d=y[b|0];e=d&15;f:{if(!((e|0)!=2&(d&240)!=32)){v[a|0]=20;d=159;v[b|0]=159;break f}if((e|0)==12){break e}}if(c>>>0<51){break b}if((d&240)==192){break d}break b}if(c>>>0<51){break b}}v[a|0]=25;v[b|0]=0;return;case 7:if(c>>>0>51){break b}v[a|0]=0;return;case 10:a=y[b|0]&240;if(!a){break b}v[b|0]=a;return;case 11:v[b|0]=D(y[b|0]&15,17);return;case 12:v[b|0]=y[b|0]>>>2;return;case 13:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);return;case 14:g:{switch((y[b|0]>>>4|0)-1|0){case 0:v[a|0]=2;break a;case 1:v[a|0]=3;break a;case 7:if(c>>>0<52){break b}v[a|0]=20;v[b|0]=y[b|0]&15|96;return;case 8:v[a|0]=15;v[b|0]=y[b|0]&15;return;case 9:v[a|0]=11;v[b|0]=y[b|0]<<4|15;return;case 10:v[a|0]=11;break a;case 11:case 12:break g;default:break b}}v[a|0]=20;return;case 15:break c;default:break b}}if(y[b|0]<48){break b}v[a|0]=17}return}v[b|0]=y[b|0]|240}function c$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-32|0;hb=g;x[g+24>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=mb[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}Pc(g,x[d+28>>2]);x[23604]=0;b=S(1083,x[g>>2])|0;a=x[23604];x[23604]=0;d:{e:{f:{g:{if((a|0)!=1){$b(g);Pc(g,x[d+28>>2]);x[23604]=0;a=S(1084,x[g>>2])|0;d=x[23604];x[23604]=0;if((d|0)==1){break g}$b(g);x[23604]=0;R(1085,g|0,a|0);d=x[23604];x[23604]=0;if((d|0)==1){b=P()|0;break d}x[23604]=0;R(1086,g|12,a|0);a=x[23604];x[23604]=0;if((a|0)==1){break f}x[23604]=0;d=g+24|0;a=ua(1087,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+24>>2];while(1){d=Gc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;$b(g);break d}b=P()|0;$b(g);break d}b=P()|0;Gc(g);break d}b=P()|0;while(1){d=Gc(d-12|0);if((g|0)!=(d|0)){continue}break}}T(b|0);p()}v[f|0]=0}hb=g+32|0;return b|0}function Aj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;x[i+16>>2]=c;x[i+24>>2]=b;Pc(i+8|0,x[d+28>>2]);b=0;x[23604]=0;j=S(1083,x[i+8>>2])|0;c=x[23604];x[23604]=0;if((c|0)!=1){$b(i+8|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(Fh(i+24|0,i+16|0)){break b}c:{if((_m(j,x[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}d:{e:{c=_m(j,x[b>>2]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=_m(j,x[g+8>>2])}l=i,m=mb[x[x[a>>2]+36>>2]](a,x[i+24>>2],x[i+16>>2],d,e,f,c,k)|0,x[l+24>>2]=m;g=b+8|0;break c}if(wk(j,1,x[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(wk(j,1,x[g>>2])){continue}}break}while(1){if(Fh(i+24|0,i+16|0)){break c}if(!wk(j,1,xk(x[i+24>>2]))){break c}kn(i+24|0);continue}}if((ll(j,xk(x[i+24>>2]))|0)==(ll(j,x[g>>2])|0)){g=g+4|0;kn(i+24|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(Fh(i+24|0,i+16|0)){x[e>>2]=x[e>>2]|2}hb=i+32|0;return x[i+24>>2]}a=P()|0;$b(i+8|0);T(a|0);p()}function wj(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=Ci(a)&2047;c=Ci(5551115123125783e-32);d=e-c|0;a:{if(d>>>0>=Ci(512)-c>>>0){if((d|0)<0){return a+1}o(+a);c=j(1)|0;d=j(0)|0;b:{if(Ci(1024)>>>0>e>>>0){break b}b=0;if(!d&(c|0)==-1048576){break a}if(Ci(O)>>>0<=e>>>0){return a+1}if((c|0)>0|(c|0)>=0){return qr(3105036184601418e216)}if(c>>>0<3230714880){break b}return qr(12882297539194267e-247)}c=c<<1|d>>>31;e=!(d<<1)&(c|0)==-2129002496|c>>>0<2165964800?e:0}b=C[177];f=b+a;a=a-(f-b);b=a*a;g=b*b*(a*C[182]+C[181]);b=b*(a*C[180]+C[179]);a=a*C[178];o(+f);j(1)|0;i=j(0)|0;d=i<<4&2032;a=g+(b+(a+C[d+1464>>3]));d=d+1472|0;h=x[d>>2];c=x[d+4>>2];d=h;h=0;d=d+h|0;c=(i<<13)+c|0;c=d>>>0<h>>>0?c+1|0:c;if(!e){c:{if(!(i&-2147483648)){l(0,d|0);l(1,c+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){UD(XD()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function n$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-32|0;hb=g;x[g+24>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=mb[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}Pc(g,x[d+28>>2]);x[23604]=0;b=S(18,x[g>>2])|0;a=x[23604];x[23604]=0;d:{e:{f:{g:{if((a|0)!=1){$b(g);Pc(g,x[d+28>>2]);x[23604]=0;a=S(1067,x[g>>2])|0;d=x[23604];x[23604]=0;if((d|0)==1){break g}$b(g);x[23604]=0;R(1068,g|0,a|0);d=x[23604];x[23604]=0;if((d|0)==1){b=P()|0;break d}x[23604]=0;R(1069,g|12,a|0);a=x[23604];x[23604]=0;if((a|0)==1){break f}x[23604]=0;d=g+24|0;a=ua(1070,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+24>>2];while(1){d=xb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;$b(g);break d}b=P()|0;$b(g);break d}b=P()|0;xb(g);break d}b=P()|0;while(1){d=xb(d-12|0);if((g|0)!=(d|0)){continue}break}}T(b|0);p()}v[f|0]=0}hb=g+32|0;return b|0}function Xha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;od(b,32);g=b,h=dc(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24)),x[g>>2]=h;f=dc(y[a+10|0]|y[a+11|0]<<8|(y[a+12|0]<<16|y[a+13|0]<<24));x[b+4>>2]=f;g=b,h=dc(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))+f|0,x[g+8>>2]=h;if(!(d?0:c)){c=dc(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Lb(y[a+42|0]|y[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}bq(b,+(c|0)*.0006510416666666666);v[e+15|0]=y[a+9|0];v[e+14|0]=64;g=b,h=y[Wb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;if(v[a+40|0]&1){w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}b:{if(y[a+41|0]<=8){a=x[b+4>>2];c=x[b+8>>2];break b}w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1;a=x[b+4>>2]>>>1|0;x[b+4>>2]=a;c=x[b+8>>2]>>>1|0;x[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){w[b+34>>1]=z[b+34>>1]|2;break c}x[b+4>>2]=0;x[b+8>>2]=0}hb=e+16|0}function W5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=hb-160|0;hb=e;d=e+24|0;f=d+56|0;c=ks(f);x[d>>2]=77116;x[c>>2]=77136;x[d+56>>2]=77176;x[d>>2]=77156;h=f;f=d+4|0;xn(h,f);x[d>>2]=77116;x[c>>2]=77136;c=fs(f);x[c>>2]=76600;Kb(c+32|0);x[c+44>>2]=0;x[c+48>>2]=16;c=x[x[d>>2]-12>>2];x[23604]=0;f=ga(61)|0;h=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}x[23604]=0;U(62,e+16|0,c+d|0,f|0);c=x[23604];x[23604]=0;if((c|0)==1){break f}$b(e+16|0);c=hb-16|0;hb=c;x[c+8>>2]=17;hb=c+16|0;Nl(x[x[d>>2]-12>>2]+d|0,x[c+8>>2]);i=C[b>>3];x[23604]=0;b=Za(63,d|0,+i)|0;c=x[23604];x[23604]=0;if((c|0)==1){break e}x[23604]=0;R(64,e|0,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break d}x[23604]=0;R(60,g|0,e|0);c=x[23604];x[23604]=0;if((c|0)==1){break c}xb(e);ap(b);hb=e+160|0;break a}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}a=P()|0;xb(e)}ap(d);T(a|0);p()}x[23604]=0;R(57,a|0,g|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(g);hb=g+16|0;return}a=P()|0;xb(g);T(a|0);p()}function KI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;tf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;d=c+16|0;a:{b:{c:{d:{i=x[c+4>>2];if(i>>>0>=g>>>0){if(A[d+4>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}if(de(x[d+8>>2],x[d+12>>2])>>>0<f>>>0){break b}k=b+12|0;l=x[c>>2];e:while(1){a=0;if((f|0)==(h|0)){break a}while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{e=Gh(l,i,a,h);j=zb(x[b>>2],a);e=x[e>>2]+(x[j>>2]>>1)|0;m=e;e=$r(k)+e&-4096;x[j>>2]=m-e;e=gd(e|2048,12);e=(e|0)>=32767?32767:e;n=rn(d,a,h),o=(e|0)<=-32768?-32768:e,w[n>>1]=o;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function zJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;a:{b:{c:{d:{e:{f:{g:{f=a+36|0;e=x[f>>2];c=x[a+40>>2];h:{if(Ob(e,c)){zc(d+24|0);break h}c=d+8|0;wn(c,a);x[23604]=0;c=S(959,c|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break g}x[d+24>>2]=c;Of(d+8|0);c=x[a+40>>2];e=x[a+36>>2]}e=(h=f,i=x[d+24>>2],j=Ob(e,c),j?h:i);if((b|0)==-1){f=x[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=x[e>>2];if((vn(f,x[e+4>>2])|0)>(b|0)){break e}}b=ba(8)|0;x[23604]=0;c=Q(54,d+8|0,10825)|0;a=x[23604];x[23604]=0;if((a|0)==1){break f}a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}a=P()|0;xb(c);break d}a=P()|0;Of(d+8|0);break c}a=P()|0;ca(b|0);break d}x[a+8>>2]=b;b=x[a+24>>2];x[b+480208>>2]=x[b+480208>>2]&-4194305|g;ui(b+484360|0,y[bl(f,c)+16|0]);b=bl(x[e>>2],c);c=x[b+8>>2];b=x[b+12>>2];x[23604]=0;+qa(990,a|0,b|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break a}a=P()|0}Dk(d+24|0)}T(a|0)}p()}x[a+16>>2]=0;x[a+20>>2]=0;Dk(d+24|0);hb=d+32|0}function tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=Kt(c,d);d=b&63;if(e>>>0>d>>>0){c=rS(c,d);d=0;g=hb-16|0;hb=g;v[a+12|0]=0;Fc(a);e=hb-32|0;hb=e;a:{b:{if(Kh(a)>>>0<=14){if(bh(1073741823)>>>0<=14){break b}f=Cb(a);f=Wf(e+8|0,15,rc(x[a>>2],x[a+4>>2]),f);xd(a,f);Vf(f)}hb=e+32|0;break a}Sc();p()}h=0-y[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=y[e+1|0];if(!f){break c}v[g+7|0]=64;h=f+(h<<16>>16)|0;f=bo(g+8|0,h&65535,y[Wb(e+2|0,g+7|0)|0]);d:{if(A[a+4>>2]<A[Cb(a)>>2]){mS(a,f);break d}i=hb-32|0;hb=i;e=Cb(a);e=Wf(i+8|0,vg(a,rc(x[a>>2],x[a+4>>2])+1|0),rc(x[a>>2],x[a+4>>2]),e);Pp(x[e+8>>2],z[f>>1]|z[f+2>>1]<<16);x[e+8>>2]=x[e+8>>2]+4;xd(a,e);Vf(e);hb=i+32|0}d=d+1|0;continue}break}d=y[c+32|0];v[a+14|0]=d>>>4;v[a+13|0]=d&15;c=y[c+31|0];d=c&15;v[a+15|0]=d;v[a+16|0]=d;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}hb=g+16|0}e:{if(b<<24>>24>=0){c=y[a+12|0]&-2;a=a+12|0;break e}c=y[a+12|0]&-2|tc(x[a>>2],x[a+4>>2])^1;a=a+12|0}v[a|0]=c}function qv(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-32|0;hb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){f=c+1073741824|0;e=e+1|0;f=e?f:f+1|0;break a}f=c+1073741824|0;if(a|(b|0)!=134217728){break a}a=e&1;e=a+e|0;f=a>>>0>e>>>0?f+1|0:f;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){a=d<<4|c>>>28;e=c<<4|b>>>28;f=a&524287|2146959360;break a}e=0;f=2146435072;if(h>>>0>1140785151){break a}f=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;vf(g+16|0,a,b,c,e,h-15233|0);Ul(g,a,b,c,e,15361-h|0);b=x[g+8>>2];e=b<<4;b=x[g+12>>2]<<4|b>>>28;c=x[g>>2];f=x[g+4>>2];h=f;e=f>>>28|e;f=b;a=h&268435455;b=c|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){e=e+1|0;f=e?f:f+1|0;break a}if(b|(a|0)!=134217728){break a}a=e;e=e+(e&1)|0;f=a>>>0>e>>>0?f+1|0:f}hb=g+32|0;l(0,e|0);l(1,d&-2147483648|f);return+n()}function Xo(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=B[f>>2];k=B[c>>2];l=B[d>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=g+B[f>>2];k=E(k-l);g=E(g-i);B[d>>2]=E(k*B[e>>2])-E(B[e+4>>2]*g);B[f>>2]=E(g*B[e>>2])+E(k*B[e+4>>2]);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=g+l;j=c-12|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=g+l;j=c-20|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=g+l;j=c-28|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function Vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=hb-16|0;hb=g;x[g+12>>2]=1;a:{if($n(a)){c=x[a>>2];k=_f(c,x[a+4>>2]);x[g+8>>2]=k;l=x[Fb(g+12|0,g+8|0)>>2];while(1){if(l){l=l-1|0;if((b|0)!=(c|0)){i=Bb(x[b>>2]);e=Bb(x[b+4>>2]);f=hb-16|0;hb=f;h=hB(i,e);b:{if(h>>>0<=Dm(c)>>>0){x[f+8>>2]=e;m=x[c>>2];d=Kc(m,x[c+4>>2]);n=d>>>0>=h>>>0;if(n){d=e}else{x[f+8>>2]=i;TO(f+8|0,d);d=x[f+8>>2]}j=hb-16|0;hb=j;VO(j+8|0,i,d,m);d=x[j+12>>2];hb=j+16|0;if(!n){XO(c,x[f+8>>2],e,h-Kc(x[c>>2],x[c+4>>2])|0);break b}Id(c,d);break b}WO(c);Hp(c,qj(c,h));XO(c,i,e,h)}hb=f+16|0;vj(c+12|0,b+12|0);w[c+28>>1]=z[b+28>>1]}c=c+32|0;continue}break}if(!k){ez(a,1-k|0,b);break a}NO(a,x[a>>2]+32|0);break a}if(x[a>>2]){PO(a);e=x[a>>2];$n(a);Hb(e);o=Cb(a),q=0,x[o>>2]=q;x[a>>2]=0;x[a+4>>2]=0}d=Dp(a,1);e=hb-16|0;hb=e;if(bh(134217727)>>>0<d>>>0){Sc();p()}CP(e+8|0,d);d=x[e+8>>2];x[a+4>>2]=d;x[a>>2]=d;o=Cb(a),q=d+(x[e+12>>2]<<5)|0,x[o>>2]=q;hb=e+16|0;ez(a,1,b)}hb=g+16|0}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=hb-16|0;hb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];v=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){o=w[(x[g+12>>2]<<1)+q>>1]<<8;e=o;e=Jia(e,e>>31,n,y);k=lb;h=e;e=Yb(b,-16777216,16776704);e=Jia(m,v,e,e>>31);p=h+e|0;h=lb+k|0;h=e>>>0>p>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Jia(l,u,f,f>>31);k=e+p|0;f=lb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Nc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Ub(g+8|0,z,A);e=e-(t&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=g+16|0}function Gia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-48|0;hb=g;i=a+8|0;d=x[a+8>>2];h=yc(a);a:{if((d|0)!=x[h>>2]){break a}j=a+4|0;c=x[a+4>>2];e=x[a>>2];if(c>>>0>e>>>0){f=hb-16|0;hb=f;m=f+8|0;a=hb-16|0;hb=a;k=a+8|0;l=((c-e>>1)+1|0)/-2<<1;e=l+c|0;h=hb-16|0;hb=h;while(1){if((c|0)!=(d|0)){e=zU(e,c)+2|0;c=c+2|0;continue}break}x[h+12>>2]=e;yd(k,d,h+12|0);hb=h+16|0;c=x[a+8>>2];x[a+4>>2]=x[a+12>>2];yd(m,c,a+4|0);hb=a+16|0;hb=f+16|0;d=x[f+12>>2];x[i>>2]=d;x[j>>2]=l+x[j>>2];break a}x[g+24>>2]=d-e;x[g+44>>2]=1;d=g+24|0;c=x[_c(d,g+44|0)>>2];d=pj(d,c,c>>>2|0,x[a+16>>2]);c=Ib(g+16|0,x[a+4>>2]);e=x[Ib(g+8|0,x[a+8>>2])>>2];f=hb-32|0;hb=f;c=x[c>>2];x[f+24>>2]=c;e=xo(f+8|0,d+8|0,hB(c,e));c=x[e>>2];while(1){if(x[e+4>>2]!=(c|0)){k=c;c=x[f+24>>2];mo(k,y[c|0]|y[c+1|0]<<8);c=x[e>>2]+2|0;x[e>>2]=c;Pe(f+24|0);continue}break}Hd(e);hb=f+32|0;qc(a,d);qc(j,d+4|0);qc(i,d+8|0);qc(h,yc(d));yi(d);d=x[a+8>>2]}mo(d,y[b|0]|y[b+1|0]<<8);x[i>>2]=x[i>>2]+2;hb=g+48|0}function Hf(a){var b=0;a:{b:{switch(y[a+3|0]){case 0:if(!y[a+5|0]){break a}v[a+3|0]=1;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;b=a;a=y[a+5|0];v[b+5|0]=D(a>>>4|0,10)+(a&15);return;case 14:v[a+3|0]=19;return;case 15:if(y[a+5|0]<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=37;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break b}}v[a+3|0]=0}}function Aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=hb-16|0;hb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];w=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){o=v[x[g+12>>2]+q|0]<<16;e=o;e=Jia(e,e>>31,n,y);k=lb;h=e;e=Yb(b,-16777216,16776704);e=Jia(m,w,e,e>>31);p=h+e|0;h=lb+k|0;h=e>>>0>p>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Jia(l,u,f,f>>31);k=e+p|0;f=lb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Nc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Ub(g+8|0,z,A);e=e-(t&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=g+16|0}function yx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);c=hb-48|0;hb=c;a:{b=x[a+20>>2];b:{if(!b){break b}d=x[b+4>>2];b=x[b+8>>2];if(Rc(d,b)>>>0<4){break b}ke(c+16|0,d,b);b=Yd(c+8|0);d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=NT(c+24|0,x[c+16>>2],x[c+20>>2],c);x[23604]=0;b=S(143,d|0)|0;f=x[23604];x[23604]=0;c:{if((f|0)!=1){if(b){break c}b=x[x[a>>2]+40>>2];x[23604]=0;f=S(b|0,a|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}b=x[a+20>>2];if(Rc(x[b+4>>2],x[b+8>>2])-4>>>0<f<<2>>>0){break c}e=x[x[a>>2]+172>>2];b=0;x[23604]=0;R(e|0,a|0,-1);e=x[23604];x[23604]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=x[x[a>>2]+176>>2];x[23604]=0;Y(b|0,a|0);a=x[23604];x[23604]=0;if((a|0)!=1){break c}break a}x[23604]=0;g=E(za(406,d|0));e=x[23604];x[23604]=0;d:{if((e|0)==1){break d}e=x[x[a>>2]+44>>2];x[23604]=0;ya(e|0,a|0,b|0,E(Sl(g)?g:E(0)));e=x[23604];x[23604]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}yb(d)}hb=c+48|0;return}a=P()|0;yb(d);T(a|0);p()}function nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-2608|0;hb=f;d=$A(f,a);x[d+1060>>2]=0;x[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){v[a+4|0]=0;w[a>>1]=0;w[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}x[23604]=0;Y(302,d|0);a=x[23604];x[23604]=0;a:{b:{if((a|0)!=1){if((w[d+1068>>1]|w[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}x[23604]=0;j=Q(150,d|0,1)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=0;d:{while(1){x[23604]=0;k=Q(150,d|0,1)|0;e=x[23604];x[23604]=0;if((e|0)==1){break d}a=w[(d+D(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+D(a,6)|0;h=y[e+1072|0];if(w[e+1068>>1]<0){break e}if(w[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;v[b+g|0]=i;g=g+1|0;continue}break}a=V(30848)|0;break b}a=V(30848)|0;break b}a=V(30848)|0}if((ib|0)==(da(30848)|0)){_(a|0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0}yb(d);T(a|0);p()}a=fq(d);yb(d);hb=f+2608|0;return a|0}function a5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[23604]=0;Y(925,a|0);e=x[23604];x[23604]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[23604]=0;Y(901,b|0);e=x[23604];x[23604]=0;if((e|0)==1){break e}e=0;x[23604]=0;Y(926,c|0);f=x[23604];x[23604]=0;if((f|0)==1){break e}a=Zb(c,0,d);if(!y[b|0]){break b}if(Vi(b,7184)|(d|0)!=8){break d}x[a+4>>2]=927;x[a>>2]=928;break c}_(V(0)|0)|0;x[23604]=0;X(887,12151,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();return 0}if(!(Vi(b,11116)|(d|0)!=64)){x[a+60>>2]=929;x[a+56>>2]=930;x[a+52>>2]=931;x[a+48>>2]=932;x[a+44>>2]=933;x[a+40>>2]=934;x[a+36>>2]=935;x[a+32>>2]=936;x[a+28>>2]=937;x[a+24>>2]=938;x[a+20>>2]=939;x[a+16>>2]=940;x[a+12>>2]=941;x[a+8>>2]=942;x[a+4>>2]=943;x[a>>2]=944;break c}if(Vi(b,14995)|(d|0)!=24){break b}x[a+20>>2]=945;x[a+16>>2]=946;x[a+12>>2]=947;x[a+8>>2]=948;x[a+4>>2]=949;x[a>>2]=950}e=1}return e|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;f=hb-16|0;hb=f;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];n=x[a+8>>2];o=x[a+12>>2];while(1){if(d){e=x[f+8>>2];p=(((x[f+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;q=w[e+38>>1];r=w[e+36>>1];s=w[e+34>>1];t=w[e+32>>1];u=w[e+30>>1];y=w[e+28>>1];z=w[e+26>>1];e=w[e+24>>1];j=0;while(1){if((j|0)!=2){g=j+p|0;x[(j<<2)+f>>2]=((((D(v[g+4|0],s)+D(v[g+2|0],t)|0)+D(v[g+6|0],r)|0)+D(v[g+8|0],q)<<8>>1)+(((D(v[g-4|0],z)+D(v[g-6|0],e)|0)+D(v[g-2|0],y)|0)+D(v[g|0],u)<<8>>1)|0)/16384;j=j+1|0;continue}break}i=i+m|0;x[c>>2]=x[c>>2]+D(x[f>>2],i>>12);h=h+l|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],h>>12);Ub(f+8|0,n,o);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;hb=f+16|0}function qF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return c|0}function Nx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=hb-16|0;hb=d;f=y[a+2|0];if(!(!f|(f|0)==255)){x[d+12>>2]=f+1;x[d+8>>2]=10;Zg(b,x[rd(d+12|0,d+8|0)>>2]);i=y[a+3|0];v[b+15|0]=i;v[b+16|0]=i;j=y[a+4|0];v[b+13|0]=j;l=y[a+5|0];v[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=x[b>>2];k=ie(c,x[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=y[b+12|0]&-2|v[a|0]&1;v[b+12|0]=c;if(y[a|0]&2){break d}c=c&251;break c}}else{m=zb(c,e);h=(e<<2)+a|0;g=(y[h+6|0]|y[h+7|0]<<8)>>>4|0;w[m>>1]=g;e:{if(e){n=z[zb(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=zb(c,e),q=g,w[p>>1]=q}x[d+12>>2]=(((y[h+8|0]|y[h+9|0]<<8)<<16>>16)+o|0)/(f|0);x[d+8>>2]=0;x[d+4>>2]=64;p=m,q=x[nj(d+12|0,d+8|0,d+4|0)>>2],v[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}v[b+12|0]=c;if(j>>>0<=l>>>0?y[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}v[b+12|0]=a}hb=d+16|0}function QW(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb+-64|0;hb=b;e=Kb(a);x[23604]=0;a=ga(112)|0;c=x[23604];x[23604]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}x[23604]=0;c=Q(1,b+32|0,8865)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}x[23604]=0;a=ga(112)|0;d=x[23604];x[23604]=0;e:{f:{g:{h:{if((d|0)==1){break h}x[23604]=0;x[b+12>>2]=a;R(118,b+16|0,b+12|0);a=x[23604];x[23604]=0;if((a|0)==1){break h}x[23604]=0;U(2,b+48|0,c|0,b+16|0);a=x[23604];x[23604]=0;if((a|0)==1){break g}d=b+48|0;a=Ab(e,d);xb(d);xb(b+16|0);xb(c);x[23604]=0;c=ga(114)|0;d=x[23604];x[23604]=0;if((d|0)==1){break b}if(!c){break e}x[23604]=0;Q(119,a|0,17347)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break e}break b}a=P()|0;break f}a=P()|0;xb(b+16|0)}xb(c);break a}x[23604]=0;c=ga(113)|0;d=x[23604];x[23604]=0;if((d|0)==1){break b}if(!c){break d}x[23604]=0;Q(119,a|0,16649)|0;a=x[23604];x[23604]=0;if((a|0)==1){break b}}hb=b- -64|0;return}a=P()|0;break a}a=P()|0}xb(e);T(a|0);p()}function Efa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-48|0;hb=f;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;c=f+44|0;fo(b,c);a:{if(!jP(c)){break a}d=y[f+46|0];g=y[f+47|0];e=y[f+45|0];v[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e^-1)>>>1&3;g=g>>>0<192;w[a+2>>1]=z[(D(c,6)+(e<<1)|0)+27736>>1]<<g;i=D(D(y[(e+D(c,3)|0)+27512|0],z[((D(c,90)+D(e,30)|0)+(d>>>3&30)|0)+27520>>1]),1e3);d=d>>>1|0;d=D(((i>>>0)/z[(D(h,6)+(d&6)|0)+27712>>1]|0)+(d&1)|0,e?1:4);w[a>>1]=d;e=y[(g|c<<1)+27748|0];if(e+8>>>0>(d&65535)>>>0){break a}c=hb-32|0;hb=c;x[c+28>>2]=e+4;x[c+8>>2]=36;g=x[b>>2];h=x[b+8>>2];d=x[Fb(c+28|0,c+8|0)>>2];if(!Qb(g,h,d)){d=cf(b)}g=c+8|0;Mq(g,f);h=ec(c+16|0,x[c+8>>2],d);mc(c,x[b>>2],x[b+8>>2],x[h>>2],x[h+4>>2]);Mq(g,f);Zb(x[c+8>>2]+d|0,0,36-d|0);bc(b,x[c+28>>2]);hb=c+32|0;b=2;c=e>>>0<=2?2:e;while(1){if((b|0)!=(c|0)){d=b+f|0;b=b+1|0;if(!y[d|0]){continue}break a}break}b=e+f|0;if(Rb(b,9468,4)){b=Rb(b,10986,4)}else{b=0}v[a+5|0]=!b}hb=f+48|0;return a|0}function g2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=hb+-64|0;hb=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;tf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>A[c+20>>2]){break d}if(e>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(de(x[c+24>>2],h)>>>0<e>>>0){break b}i=b+12|0;j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{d=gd((x[Gh(k,g,a,b)>>2]+gd(_r(i),21)|0)+2048|0,12);d=(d|0)>=32767?32767:d;l=sn(j,h,a,b),m=(d|0)<=-32768?-32768:d,w[l>>1]=m;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function _p(a){var b=0,c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(z[a+480192>>1]){break a}c=Bb(x[a+484344>>2]);x[e+8>>2]=c;a=Bb(x[a+484348>>2]);while(1){if(!Ob(c,a)){d=1;break a}if(!(!Ob(x[c>>2],x[c+4>>2])|x[c+12>>2]==64)){break a}c=x[vt(e+8|0)>>2];continue}}d=16777216;break a}d=32;f=z[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(v[b+480281|0]&1){break a}c=c+1|0;if(z[b+480286>>1]==64){continue}break}break a}d=2}hb=e+16|0;return d}function pr(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;a:{b:{d=Ci(a)&2047;c=Ci(5551115123125783e-32);f=d-c|0;if(f>>>0<Ci(512)-c>>>0){f=d;break b}if((f|0)<0){return a+1}f=0;if(Ci(1024)>>>0>d>>>0){break b}o(+a);c=j(1)|0;e=0;if(!(j(0)|0)&(c|0)==-1048576){break a}if(Ci(O)>>>0<=d>>>0){return a+1}if((c|0)<0){return qr(12882297539194267e-247)}return qr(3105036184601418e216)}b=C[170];g=C[169]*a+b;b=g-b;a=b*C[172]+(b*C[171]+a);b=a*a;k=b*b*(a*C[176]+C[175]);e=b*(a*C[174]+C[173]);o(+g);j(1)|0;i=j(0)|0;c=i<<4&2032;a=k+(e+(C[c+1464>>3]+a));c=c+1472|0;h=x[c>>2];d=x[c+4>>2];c=h;h=0;c=c+h|0;d=(i<<13)+d|0;d=c>>>0<h>>>0?d+1|0:d;if(!f){c:{if(!(i&-2147483648)){l(0,c|0);l(1,d-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,c|0);l(1,d+1071644672|0);b=+n();g=b*a;a=g+b;if(a<1){UD(XD()*22250738585072014e-324);e=a+1;a=e+(g+(b-a)+(a+(1-e)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,c|0);l(1,d|0);b=+n();e=b*a+b}return e}function cW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=hb-32|0;hb=j;e=Hm(j+8|0,a);c=hb-48|0;hb=c;k=-1;a:{if(!WC(e,c+8|0)){break a}k=0;if(!_C(c+8|0)){break a}l=If(12972);if(l){o=x[e+12>>2];b:{if(!al(e,y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24))){break b}while(1){c:{if((y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24))>>>0>n>>>0){if(Nf(e,5)){break c}}f=m&1;break b}f=0;h=1;d:{if((y[c+12|0]|y[c+13|0]<<8)>>>0>=64){d=tq(e);a=d&63;g=d<<24>>24;e:{if(!(d&64)){break e}d=6;while(1){i=tq(e);a=(i&127)<<d|a;if(i<<24>>24>=0){break e}i=d>>>0<25;d=d+7|0;if(i){continue}break}}d=(g|0)<0;g=d?-2147483648:a;if(((d?(a|0)>=0?0-a|0:g:g)|0)<=0){break d}}while(1){d=tq(e);if(d){g=f>>>0>=l>>>0;a=g&h;if(!((h^1)&1|g)){a=(gp(d<<24>>24)&255)==y[f+12972|0]}h=a;f=f+1|0;continue}break}ad(e,4);m=(f|0)==(l|0)?h&1?1:m:m}n=n+1|0;continue}}al(e,o)}if(!f){break a}k=De(e,b,ZC(c+8|0),0)}hb=c+48|0;hb=j+32|0;return k|0}function m8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=rj(d,x[a+4>>2]);if(c>>>0<b>>>0){g=hb-32|0;hb=g;e=b-c|0;b=x[Cb(a)>>2];c=x[a+4>>2];a:{if(e>>>0<=b-c>>11>>>0){b=hb-16|0;hb=b;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(e<<11);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);hb=b+16|0}else{zx(a);a=a+2048|0;x[b+4>>2]=a;continue}break}break a}h=Cb(a);i=g+8|0;b=a;f=rj(x[a>>2],c)+e|0;c=hb-16|0;hb=c;x[c+12>>2]=f;d=hb-16|0;hb=d;x[d+12>>2]=2097151;x[d+8>>2]=2147483647;a=x[Fb(d+12|0,d+8|0)>>2];hb=d+16|0;b:{if(a>>>0>=f>>>0){d=Ax(b);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;break b}Sc();p()}d=SK(i,a,rj(x[b>>2],x[b+4>>2]),h);c=d;a=hb-16|0;hb=a;x[a>>2]=x[c+8>>2];f=x[c+8>>2];x[a+8>>2]=c+8;x[a+4>>2]=f+(e<<11);c=x[a>>2];while(1){if(x[a+4>>2]!=(c|0)){zx(c);c=x[a>>2]+2048|0;x[a>>2]=c;continue}break}Hd(a);hb=a+16|0;xd(b,d);RK(d)}hb=g+32|0;return}if(b>>>0<c>>>0){Id(a,d+(b<<11)|0)}}function lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;n=x[a+16>>2];o=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+128>>2];a:{if(!j){i=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];h=0;break a}b=x[a+12>>2];k=b;i=x[a+8>>2];l=Xf(i,b,j);m=lb;h=x[a+76>>2];b=x[a>>2];g=x[a+4>>2];Cf(b,g,Ze(i,k,d),lb);h=lb>>>0>h>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;b:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(g<<1)+n|0;b=j;while(1)if((b|0)<=0){Ub(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);Jd(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Tf(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Ub(e,i,k);c=c+8|0;continue b}else{Kd(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);Jd(f,4);Ub(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;hb=e+16|0}function Dc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=x[b>>2];e=hb-48|0;hb=e;f=x[b+4>>2];b=y[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Kb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){a=gi(c,c+d|0,0);x[23604]=0;W(52,f|0,c|0,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break h}a=P()|0;break b}if((b-3&255)>>>0>1){break h}x[23604]=0;b=W(52,f|0,c|0,c+d|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break g}c=pd(b);d=pf(b);g=pd(b);a=hb-16|0;hb=a;x[a>>2]=g;x[a+8>>2]=c;while(1){if(Ob(c,d)){c=v[c|0];v[x[a>>2]]=c?c:32;c=Le(a+8|0);Le(a);c=x[c>>2];continue}break}hb=a+16|0;x[23604]=0;c=Q(53,e+16|0,b|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break f}x[23604]=0;d=Q(54,e|0,17673)|0;a=x[23604];x[23604]=0;if((a|0)==1){break e}x[23604]=0;U(55,e+32|0,c|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break d}a=e+32|0;Ab(b,a);xb(a);xb(d);xb(c)}hb=e+48|0;break a}a=P()|0;break b}a=P()|0;break b}a=P()|0;break c}a=P()|0;xb(d)}xb(c)}xb(f);T(a|0);p()}}function Y1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;tf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;d=c+16|0;a:{b:{c:{d:{h=x[c+4>>2];if(h>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}if(de(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}i=b+12|0;j=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=gd((x[Gh(j,h,a,b)>>2]+gd(_r(i),21)|0)+2048|0,12);g=(g|0)>=32767?32767:g;k=rn(d,a,b),l=(g|0)<=-32768?-32768:g,w[k>>1]=l;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function _I(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;x[a+4>>2]=b;x[a>>2]=94456;e=(b>>>0)/48|0;d=((0-b|0)!=(D(e,-48)|0))+e|0;x[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;x[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){g=-1<<c}else{g=(1<<c)-1&-1>>>32-c|-1<<c}c=0;x[a+24>>2]=c;f=f?g&65536:0;x[a+28>>2]=f;g=Mia(c,f,d,0);h=lb;f=f^65536;if((h|0)==(f|0)&c>>>0>g>>>0|f>>>0>h>>>0){d=d+1|0;x[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;x[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}x[a+24>>2]=0;x[a+28>>2]=f?c&65536:0}x[a+16>>2]=d-((b>>>0)%(d>>>0)|0);b=e>>>0<63;d=63-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}x[a+48>>2]=b?c:-1;x[a+52>>2]=b?d:-1;d=64-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}x[a+40>>2]=e?c:0;x[a+44>>2]=e?d:0;c=e+1|0;e=c&31;if((c&63)>>>0>=32){d=-1<<e}else{d=(1<<e)-1&-1>>>32-e|-1<<e}x[a+32>>2]=0;x[a+36>>2]=b?d&65536:0;return a}function L6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=E(0),u=E(0),v=E(0),w=E(0),z=0,A=0,C=0,D=0,G=0,H=E(0);g=hb-16|0;hb=g;m=x[a+4240>>2];a:{if(!m){break a}if(!Qh(a+44|0)){break a}n=B[a+4220>>2];e=x[a+44>>2];D=g,G=Cc(e,0),x[D+8>>2]=G;D=g,G=Cc(e,1),x[D+12>>2]=G;e=x[a+56>>2];o=Cc(e,0);x[g>>2]=o;p=Cc(e,1);x[g+4>>2]=p;w=E(E(1)-n);q=x[a+4208>>2];z=y[a+4264|0];e=d;b:while(1){if(e){k=x[a+4244>>2];A=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;x[a+4244>>2]=(f|0)!=(m|0)?f:0;e=e-1|0;continue b}else{h=(z?1-l|0:f)&255;j=x[((h<<2)+a|0)+4248>>2];C=x[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=x[s>>2];x[s>>2]=i+4;j=k-j|0;t=B[zb(q,h+((j>>31&C)+j<<1)|0)>>2];u=B[i>>2];v=E(E(t*B[a+4224>>2])+E(u*B[a+4260>>2]));D=zb(q,f+A|0),H=E(F(v))<E(10000000195414814e-40)?E(0):v,B[D>>2]=H;h=g+r|0;i=x[h>>2];x[h>>2]=i+4;B[i>>2]=E(u*w)+E(n*t);l=l+1|0;f=f+1|0;continue}}break}di(a,b,c,o,p,d)}hb=g+16|0}function _v(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Eb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Eb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=aw(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=y[(a>>2)+82128|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=x[e>>2];if((a|0)!=(d|0)){f=-1;if((y[a-1|0]&95)!=(y[c|0]&127)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0}v[c|0]=80;break d}d=g&95;if((d|0)!=y[c|0]){break d}v[c|0]=d|128;if(!y[b|0]){break d}v[b|0]=0;if(!Eb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>84){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function FB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-560|0;hb=e;w[e+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}d=x[((b<<2)+a|0)+900380>>2];b:{if(d){b=bP(e,c);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;c=y[b+11|0]|y[b+12|0]<<8|(y[b+13|0]<<16|y[b+14|0]<<24);f=y[b+7|0]|y[b+8|0]<<8|(y[b+9|0]<<16|y[b+10|0]<<24);v[d+7|0]=f;v[d+8|0]=f>>>8;v[d+9|0]=f>>>16;v[d+10|0]=f>>>24;v[d+11|0]=c;v[d+12|0]=c>>>8;v[d+13|0]=c>>>16;v[d+14|0]=c>>>24;v[d+15|0]=y[b+15|0];c=x[b+44>>2];x[d+40>>2]=x[b+40>>2];x[d+44>>2]=c;c=x[b+36>>2];x[d+32>>2]=x[b+32>>2];x[d+36>>2]=c;c=x[b+28>>2];x[d+24>>2]=x[b+24>>2];x[d+28>>2]=c;c=x[b+20>>2];x[d+16>>2]=x[b+16>>2];x[d+20>>2]=c;cy(d+48|0,b+48|0);cy(d+68|0,b+68|0);cy(d+88|0,b+88|0);vc(d+108|0,b+108|0,448);It(b);break b}d=Bs(556);if(!d){d=0;x[((b<<2)+a|0)+900380>>2]=0;break a}d=bP(d,c);x[((b<<2)+a|0)+900380>>2]=d}g=a,h=z[Se(a+480192|0,e+558|0)>>1],w[g+480192>>1]=h}hb=e+560|0;return d|0}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;h=hb-16|0;hb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];w=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=Jia(l,s,f,f>>31);f=lb;e=Yb(e,-16777216,16776704);e=Jia(k,r,e,e>>31);g=e+g|0;f=lb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=x[h+12>>2]+p|0;i=v[g|0];i=((D(v[g+1|0]-i|0,x[h+8>>2]>>>10&4194048)|0)/16384|0)+(i<<8)<<8;e=i;g=Jia(e,e>>31,m,t);j=g+j|0;e=lb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Nc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Ub(h+8|0,u,w);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;hb=h+16|0}function cw(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Eb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Eb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=gi(l,l+32|0,a)-l|0;if((a|0)>31){break b}g=y[a+82128|0];d:{e:{switch((a&-2)-22|0){case 2:a=x[e>>2];if((a|0)!=(d|0)&(y[a-1|0]&95)!=(y[c|0]&127)){break b}x[e>>2]=a+1;v[a|0]=g;return 0;case 0:v[c|0]=80;break d;default:break e}}d=g&95;if((d|0)!=y[c|0]){break d}v[c|0]=d|128;if(!y[b|0]){break d}v[b|0]=0;if(!Eb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>21){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function h2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(de(x[c+24>>2],h)>>>0<d>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=gd(x[Gh(j,g,a,b)>>2]+2048|0,12);f=(f|0)>=32767?32767:f;k=sn(i,h,a,b),l=(f|0)<=-32768?-32768:f,w[k>>1]=l;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=hb-16|0;hb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];v=x[a+12>>2];while(1){b=f;if(d){f=Yb(b,-16777216,16776704);g=Jia(l,s,f,f>>31);f=lb;e=Yb(e,-16777216,16776704);e=Jia(k,r,e,e>>31);g=e+g|0;f=lb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=(x[h+12>>2]<<1)+p|0;i=w[g>>1];i=i+((D(w[g+2>>1]-i|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;g=Jia(e,e>>31,m,t);j=g+j|0;e=lb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Nc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Ub(h+8|0,u,v);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;hb=h+16|0}function fp(a){a=a|0;var b=0,c=0,d=0,e=E(0),f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0);b=x[a+36>>2];if(!b){Fc(a+16|0);return}a:{b:{switch(z[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Fc(c);return}Gj(c,b);b=w[a+28>>1];e=E(Tl(a,b+1<<16>>16)/Tl(a,b));c=x[a+36>>2]+1|0;e=me(e,E(E(1)/E(c>>>0)));a=x[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}f=me(e,E(b>>>0));n=zb(a,b-1|0),o=f,B[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;g=z[a+30>>1];if(g>>>0>1e3/(b>>>0)>>>0){Fc(c);return}Gj(c,D(b,g));h=z[a+30>>1];j=Hx(w[a+28>>1],h);i=x[a+36>>2];e=E(E(1)/E(i+1>>>0));c=0;c:while(1){if((c&65535)>>>0>=g>>>0){break a}b=1;d=Hx(c+j<<16>>16,h);f=Tl(a,d+1<<16>>16);d=d<<16>>16;f=me(E(f/Tl(a,d)),e);k=D(d,x[a+36>>2]);l=x[a+16>>2];while(1){d=b&65535;if(d>>>0>i>>>0){c=c+1|0;continue c}else{m=me(f,E(d>>>0));n=zb(l,(d+k|0)-1|0),o=m,B[n>>2]=o;b=b+1|0;continue}}};case 0:Fc(a+16|0);return;default:break b}}Fc(a+16|0);x[a+36>>2]=0}}function Xw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(de(x[c+24>>2],g)>>>0<d>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=cm(ee(Yf(C[Mg(i,f,a,b)>>3])*134217728));k=Ww(h,g,a,b),l=E(+(j|0)*7.450580596923828e-9),B[k>>2]=l;a=a+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=c- -64|0}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Ub(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;hb=e+16|0}function C5(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;x[23604]=0;g=Q(12,d+24|0,a|0)|0;c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){d:{if(!ud(y[g|0])){break d}Pc(d+16|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[23604]=0;c=S(67,x[d+16>>2])|0;e=x[23604];x[23604]=0;e:{f:{if((e|0)!=1){$b(d+16|0);e=um(d+8|0,a);f=x[x[a>>2]-12>>2];x[23604]=0;f=a+f|0;h=S(13,f|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break f}e=x[e>>2];x[23604]=0;c=Ra(68,c|0,e|0,f|0,h|0,+b)|0;e=x[23604];x[23604]=0;if((e|0)==1){break f}if(c){break d}c=x[x[a>>2]-12>>2];x[23604]=0;R(15,a+c|0,5);c=x[23604];x[23604]=0;if((c|0)!=1){break d}c=V(0)|0;break e}c=V(0)|0;$b(d+16|0);break e}c=V(0)|0}$j(g);break c}$j(g);break b}c=V(0)|0}_(c|0)|0;c=x[x[a>>2]-12>>2];x[23604]=0;Y(16,a+c|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}$()}hb=d+32|0;return a|0}a=P()|0;x[23604]=0;Z(17);d=x[23604];x[23604]=0;if((d|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;w[e+12>>1]=0;x[e+8>>2]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){w[e+6>>1]=0;OR(a,e+15|0,e+12|0,j,e+6|0);g=z[e+6>>1];f=z[e+12>>1];c=j;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!af(a,e+5|0)){break c}f=y[e+5|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+z[e+8>>1]|0;w[e+6>>1]=f;w[i>>1]=f;x[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=x[e+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}x[e+8>>2]=c}k=f;continue}}break}hb=e+16|0}function D5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-80|0;hb=e;x[e+72>>2]=c;a=Mf(a,e+72|0);c=zc(a+4|0);g=zc(a+24|0);h=zc(a+32|0);i=Sb(a+36|0);x[a+56>>2]=3;j=Sb(a+68|0);x[23604]=0;R(895,a|0,d|0);f=x[23604];x[23604]=0;a:{b:{c:{d:{if((f|0)!=1){f=x[b>>2];k=x[b+4>>2];l=x[b+12>>2];x[e+40>>2]=x[b+8>>2];x[e+44>>2]=l;x[e+32>>2]=f;x[e+36>>2]=k;b=Yd(e+24|0);f=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=f;x[23604]=0;f=x[e+36>>2];x[e+8>>2]=x[e+32>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;U(884,e+48|0,e+8|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break d}x[23604]=0;U(896,a|0,e+48|0,d|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}yb(e+48|0);x[23604]=0;Y(897,a|0);b=x[23604];x[23604]=0;if((b|0)==1){break b}te(e+72|0);hb=e+80|0;return a|0}d=P()|0;break a}d=P()|0;break a}d=P()|0;yb(e+48|0);break a}d=P()|0}Vd(j);Of(i);ds(h);Ti(g);Si(c);te(a);te(e+72|0);T(d|0);p()}function g8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=E(0),w=E(0),y=E(0),z=0,A=0,C=0,D=E(0);r=x[a+4220>>2];if(r){f=x[a+44>>2];k=Cc(f,0);l=Cc(f,1);g=x[a+56>>2];s=Cc(g,0);j=x[a+4208>>2];z=x[a+4228>>2];f=d;t=Cc(g,1);m=t;g=s;while(1){if(f){h=x[a+4224>>2];e=h-z|0;e=(x[a+4220>>2]&e>>31)+e<<1;A=zb(j,e);n=B[zb(j,e|1)>>2];u=B[a+4244>>2];o=B[A>>2];v=B[a+4252>>2];p=B[l>>2];w=B[a+4248>>2];q=B[k>>2];y=B[a+4256>>2];i=E(E(n*u)+E(E(o*v)+E(E(p*w)+E(q*y))));e=h<<1;C=zb(j,e),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;i=E(E(o*u)+E(E(n*v)+E(E(q*w)+E(p*y))));C=zb(j,e|1),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;h=h+1|0;x[a+4224>>2]=(h|0)!=(r|0)?h:0;B[g>>2]=E(q*B[a+4240>>2])+E(o*B[a+4236>>2]);B[m>>2]=E(p*B[a+4240>>2])+E(n*B[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{di(a,b,c,s,t,d)}break}}}function FG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Je(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=ct(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(TG(x[a+36>>2],f,i,g,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=ct(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Gr(nh(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break a}}d=nh(v[c+23|0]);x[a+48>>2]=d;break a}d=nh(v[c+23|0]);break a}d=-1}hb=c+32|0;return d}function mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;n=x[a+16>>2];o=Uf(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+128>>2];a:{if(!j){i=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];h=0;break a}b=x[a+12>>2];k=b;i=x[a+8>>2];l=Xf(i,b,j);m=lb;h=x[a+76>>2];b=x[a>>2];g=x[a+4>>2];Cf(b,g,Ze(i,k,d),lb);h=lb>>>0>h>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;b:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=g+n|0;b=j;while(1)if((b|0)<=0){Ub(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(f,v[x[e+12>>2]+g|0]<<6);Jd(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Tf(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Ub(e,i,k);c=c+8|0;continue b}else{Kd(f,v[x[e+12>>2]+g|0]<<6);Jd(f,4);Ub(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;hb=e+16|0}function vu(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;a:{if(y[a+3|0]!=19){break a}v[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=y[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}v[a+3|0]=0;break a}v[a+3|0]=2;v[a+5|0]=b|240;break a}v[a+3|0]=3;v[a+5|0]=b|240;break a}v[a+5|0]=b&15|16;break a}v[a+5|0]=b&3|48;break a}v[a+5|0]=b&15|32;break a}v[a+5|0]=b&15|176;break a}v[a+5|0]=b&3|64;break a}v[a+3|0]=15;v[a+5|0]=b&15;break a}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;break a}v[a+3|0]=0;break a}b=b&15;if(b){v[a+3|0]=11;x[c+12>>2]=b;x[c+8>>2]=14;d=a,e=y[rd(c+12|0,c+8|0)|0]|240,v[d+5|0]=e;break a}v[a+3|0]=0;break a}if((b|0)!=192){break a}v[a|0]=254;v[a+3|0]=0;break a}if((b|0)!=208){break a}v[a+3|0]=0}hb=c+16|0}function lF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=v[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((y[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];f=y[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function UL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=hb-16|0;hb=c;d=Kb(a);while(1){b:{c:{d:{if(Qc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Wi(f,g)>>2];if(b>>>0>=2097152){x[23604]=0;R(50,d|0,63);a=x[23604];x[23604]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[23604]=0;R(50,d|0,a<<24>>24);a=x[23604];x[23604]=0;if((a|0)!=1){break c}break b}hb=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=v[j|0];x[23604]=0;R(50,d|0,(a|i)<<24>>24);h=x[23604];x[23604]=0;a=e;break e}x[23604]=0;a=a-1|0;R(50,d|0,v[a+(c+10|0)|0]|-128);h=x[23604];x[23604]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=P()|0;xb(d);T(a|0);p()}}function GG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Je(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=ct(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(TG(x[a+36>>2],f,i,g,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=ct(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Gr(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break a}}d=x[c+20>>2];x[a+48>>2]=d;break a}d=x[c+20>>2];break a}d=-1}hb=c+32|0;return d}function _1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];g=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{h=x[c+4>>2];if(h>>>0>=g>>>0){if(A[d+4>>2]<g>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(de(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}i=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{f=gd(x[Gh(i,h,a,b)>>2]+2048|0,12);f=(f|0)>=32767?32767:f;j=rn(d,a,b),k=(f|0)<=-32768?-32768:f,w[j>>1]=k;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Ub(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;hb=e+16|0}function Vw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(de(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}h=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=cm(ee(Yf(C[Mg(h,g,a,b)>>3])*134217728));j=Uw(d,a,b),k=E(+(i|0)*7.450580596923828e-9),B[j>>2]=k;a=a+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=c- -64|0}function oF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=v[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((y[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];b=y[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=y[a+3|0];h=y[a+2|0];b=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function Iga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=hb-32|0;hb=e;b=hb-32|0;hb=b;x[b+16>>2]=1073741824;w[b+22>>1]=12;c=Jc(64);x[23604]=0;d=S(788,c|0)|0;f=x[23604];x[23604]=0;a:{b:{c:{if((f|0)!=1){c=lf(b+8|0,d);d=x[c>>2];x[23604]=0;R(789,d|0,a|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}a=x[c>>2];x[23604]=0;a=W(790,a|0,b+22|0,b+16|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}d:{if(!a){zc(b+24|0);break d}a=x[c>>2];x[23604]=0;R(791,a|0,15);a=x[23604];x[23604]=0;if((a|0)==1){break c}Mf(b+24|0,c)}bg(c);hb=b+32|0;b=x[b+24>>2];break a}a=P()|0;Hb(c);break b}a=P()|0;bg(c)}T(a|0);p()}x[e+24>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}x[23604]=0;c=Q(1,e+8|0,(a<<2)+32528|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){x[23604]=0;U(431,b|0,a|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break g}xb(c);a=a+1|0;continue}break}a=P()|0;break f}a=P()|0;xb(c)}bg(e+24|0);T(a|0);p()}hb=e+32|0;return b|0}function $da(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-144|0;hb=g;lq(a);a:{b:{if(!Nf(a,64)){break b}c:{d:{if(!al(a,60)){break d}if(!vQ(a,14e3)){break d}c=15;d=450;break c}lq(a);if(!Nf(a,128)){break b}b=0;if(!al(a,124)){break a}if(!vQ(a,15169)){break a}c=31;d=930}lq(a);b=0;e:{while(1){if((b&65535)>>>0>=c>>>0){break e}b=b+1|0;if(tQ(a)>>>0<=131072){continue}break}b=0;break a}ad(a,4);if(!Nf(a,2)){break b}b=0;e=hb-16|0;hb=e;c=hb-16|0;hb=c;ql(c+8|0,e+8|0);f=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((f|0)==(h|0)){ad(a,x[c+12>>2])}hb=c+16|0;if((f|0)==(h|0)){i=Lb(z[e+8>>1])}hb=e+16|0;if(i>>>0<178){break a}b=-1;if(!Nf(a,d)){break a}ad(a,d);d=hb-16|0;hb=d;e=g+8|0;xR(d+8|0,e);c=x[d+12>>2];kd(d,a,x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(c|0)){ad(a,x[d+12>>2])}hb=d+16|0;a=(c|0)==(f|0);if(!a){Wz(e)}if(!a){break a}b=uQ(y[g+8|0]);break a}b=-1}hb=g+144|0;return b|0}function Zr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(de(x[c+24>>2],g)>>>0<d>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=Gh(i,f,a,b);k=Ww(h,g,a,b),l=E(E(x[j>>2])*E(7.450580596923828e-9)),B[k>>2]=l;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;w[f+12>>1]=c;w[f+14>>1]=b;w[f+10>>1]=d;g=z[x[x[a+24>>2]+8>>2]+12>>1];a:{if(g>>>0<=b>>>0){break a}if(!c|$i(a)>>>0>=g>>>0){break a}pg(f+12|0,g-b&65535);k=f,l=il(x[a>>2],x[a+4>>2]),w[k+8>>1]=l;d=z[f+12>>1];aS(a,d+z[Se(f+14|0,f+8|0)>>1]|0);e=x[a>>2];c=a;if(Kc(e,x[a+4>>2])>>>0<b>>>0){eg(c,b);e=x[c>>2]}a=x[Ib(f,UO(Bb(e),b))>>2];h=f+10|0;j=hb-32|0;hb=j;b=a;a=x[c>>2];e=(no(b,Bb(a))<<1)+a|0;a=d;b:{if(!a){break b}b=x[Cb(c)>>2];i=x[c+4>>2];if(a>>>0<=b-i>>1>>>0){b=a;d=i-e>>1;if(d>>>0<a>>>0){qo(c,a-d|0,h);b=d;if((e|0)==(i|0)){break b}}RO(c,e,i,(a<<1)+e|0);Et(e,b,((e>>>0<=h>>>0?A[c+4>>2]>h>>>0?a:0:0)<<1)+h|0);break b}b=Cb(c);b=pj(j,qj(c,Kc(x[c>>2],i)+a|0),e-x[c>>2]>>1,b);pC(b,a,h);e=dq(c,b,e);yi(b)}Ib(j+24|0,e);hb=j+32|0;if(Kc(x[c>>2],x[c+4>>2])>>>0<=g>>>0){break a}eg(c,g)}hb=f+16|0}function XV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-96|0;hb=d;xc(b);Fo(a);a:{if(!Zu(b,d+56|0)){break a}if(!VC(d+56|0)){break a}b:{if(!c){break b}if(!Qb(x[b>>2],x[b+8>>2],dc(x[d+60>>2])-28|0)){break a}ov(a);g=d,h=nv(),x[g+32>>2]=h;e=d+32|0;mv(Uh(x[a+4>>2])+32|0,e);Zq(e);c=x[Uh(x[a+4>>2])+32>>2];x[23604]=0;R(177,e|0,b|0);b=x[23604];x[23604]=0;c:{if((b|0)==1){break c}b=x[d+32>>2];e=x[d+60>>2];f=x[d+68>>2];x[23604]=0;b=fa(178,b|0,dc(e)-28|0,c|0,dc(f)|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}e=0;if(!b){break a}ke(d+16|0,x[c>>2],x[c+4>>2]);Kg(d+24|0,x[d+16>>2],x[d+20>>2]);b=Yd(d+8|0);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;b=Xq(d+32|0,x[d+24>>2],x[d+28>>2],d);$c(Uh(x[a+4>>2])+12|0,b);yb(b);break b}a=Aa(92520,26440)|0;b=ib;d:{if((da(92520)|0)==(b|0)){break d}if((da(26440)|0)==(b|0)){break d}T(a|0);p()}_(a|0)|0;$();e=0;break a}e=1}hb=d+96|0;return e|0}function YW(){var a=0,b=0,c=0,d=0;c=hb-32|0;hb=c;a:{a=Xb(c+16|0,14892);if(!Qc(x[a+4>>2],y[a+11|0])){break a}b:{if((ng(a,14506)|0)!=-1){b=ng(a,14506);x[23604]=0;X(116,c|0,a|0,b+1|0,-1);b=x[23604];x[23604]=0;if((b|0)==1){break b}Ab(a,c);xb(c)}if((ng(a,16647)|0)!=-1){b=ng(a,16647);x[23604]=0;X(116,c|0,a|0,b+1|0,-1);b=x[23604];x[23604]=0;if((b|0)==1){break b}Ab(a,c);xb(c)}if((ng(a,13723)|0)!=-1){b=ng(a,13723);x[23604]=0;X(116,c|0,a|0,0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break b}Ab(a,c);xb(c)}if((ng(a,13572)|0)!=-1){b=ng(a,13572);x[23604]=0;X(116,c|0,a|0,0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break b}Ab(a,c);xb(c)}if((ng(a,13615)|0)!=-1){b=ng(a,13615);x[23604]=0;X(116,c|0,a|0,0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break b}Ab(a,c);xb(c)}x[23604]=0;b=S(117,a|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break a}}c=P()|0;xb(a);T(c|0);p()}xb(a);hb=c+32|0;return b|0}function BD(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-32|0;hb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;h=e;c=c&33554431;if(!(!e&(c|0)==16777216?!(a|b):!e&c>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(c^16777216|a|(b|h)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;vf(g+16|0,a,b,c,e,f-16129|0);Ul(g,a,b,c,e,16257-f|0);a=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|a>>>25;c=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];b=0;a=a&33554431;if(!(!b&(a|0)==16777216?!(c|f):!b&a>>>0<16777216)){e=e+1|0;break a}if(a^16777216|c|(b|f)){break a}e=(e&1)+e|0}hb=g+32|0;return l(2,d&-2147483648|e),r()}function rB(a,b){var c=0,d=0;d=y[a|0];if(d>>>0>=36){v[a|0]=0;return}c=y[d+26672|0];v[a|0]=c;a:{b:{c:{d:{e:{f:{switch(c-6|0){default:if((c|0)==31){break b}if((c|0)==23){break e}if(y[b|0]|(c|0)!=1){break a}v[a|0]=0;return;case 8:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);return;case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break c;case 13:break d;case 0:case 1:case 5:break f}}c=y[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}v[b|0]=a;return}a=y[b|0];if(a>>>0<=64){v[b|0]=a<<1;return}v[b|0]=128;return}g:{h:{i:{j:{c=y[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}v[a|0]=20;v[b|0]=159;return}v[a|0]=20;v[b|0]=192;return}if(c&14){break a}v[a|0]=21;v[b|0]=(y[b|0]!=80)<<6;return}v[a|0]=20;v[b|0]=y[b|0]&15|160;return}if(y[b|0]>31){break a}v[a|0]=16;return}v[b|0]=(d<<5|y[b|0]>>>3)^128}}function Ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;w[e+12>>1]=0;x[e+8>>2]=0;n=D(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){v[e+7|0]=0;NR(a,e+15|0,e+12|0,e+7|0);g=y[e+7|0];f=z[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!af(a,e+6|0)){break c}f=y[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+y[e+8|0]|0;v[e+7|0]=f;v[i|0]=f;x[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=x[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}x[e+8>>2]=c}j=f;continue}}break}hb=e+16|0}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=hb-16|0;hb=f;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[f+8>>2];n=((((x[f+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;o=w[e+38>>1];p=w[e+36>>1];q=w[e+34>>1];r=w[e+32>>1];s=w[e+30>>1];t=w[e+28>>1];u=w[e+26>>1];e=w[e+24>>1];h=0;while(1){if((h|0)!=2){g=(h<<1)+n|0;x[(h<<2)+f>>2]=(((((D(w[g+8>>1],q)+D(w[g+4>>1],r)|0)+D(w[g+12>>1],p)|0)+D(w[g+16>>1],o)|0)/2|0)+((((D(w[g-8>>1],u)+D(w[g-12>>1],e)|0)+D(w[g-4>>1],t)|0)+D(w[g>>1],s)|0)/2|0)|0)/16384;h=h+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],i);Ub(f+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;hb=f+16|0}function e6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0),w=E(0);h=hb-16|0;hb=h;if(Qh(a+44|0)){f=x[a+44>>2];g=Cc(f,0);x[h+8>>2]=g;f=Cc(f,1);x[h+12>>2]=f;i=x[a+56>>2];n=Cc(i,0);x[h>>2]=n;i=Cc(i,1);x[h+4>>2]=i;a:{if(B[zb(a+4208|0,2)>>2]!=E(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{j=g<<2;e=j+(h+8|0)|0;k=x[e>>2];x[e>>2]=k+4;e=a+j|0;l=e+4248|0;q=B[l>>2];m=B[k>>2];r=B[a+4236>>2];s=B[a+4232>>2];t=B[a+4228>>2];u=B[a+4220>>2];v=B[a+4224>>2];k=e+4240|0;o=B[k>>2];B[l>>2]=o;l=e+4264|0;w=B[l>>2];e=e+4256|0;p=B[e>>2];B[l>>2]=p;B[k>>2]=m;m=E(E(E(E(t*q)+E(E(u*m)+E(v*o)))-E(s*p))-E(r*w));B[e>>2]=m;j=h+j|0;e=x[j>>2];x[j>>2]=e+4;B[e>>2]=m;g=g+1|0;continue}}}e=g;g=d<<2;vc(n,e,g);vc(i,f,g);f=x[a+56>>2];n=Cc(f,0);i=Cc(f,1)}di(a,b,c,n,i,d)}hb=h+16|0}function Yr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(de(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}h=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=Gh(h,g,a,b);j=Uw(d,a,b),k=E(E(x[i>>2])*E(7.450580596923828e-9)),B[j>>2]=k;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function aaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;b=x[a+4>>2];if(ud(y[b+223884|0])){CN(b+223860|0);b=x[a+4>>2]}x[a+24>>2]=0;x[a+28>>2]=0;x[b>>2]=0;c=x[a>>2];x[b+40>>2]=x[c+480196>>2];x[b+44>>2]=x[c+480204>>2];x[b+80>>2]=x[c+480200>>2];c=z[c+480188>>1];x[f+8>>2]=0;x[f+12>>2]=0;d=f+8|0;w[d+4>>1]=65280;x[d>>2]=0;e=hb-16|0;hb=e;x[e+12>>2]=c;b=a+8|0;a:{if(Pm(b)>>>0>=c>>>0){g=x[b>>2];h=Eg(g,x[b+4>>2]);x[e+8>>2]=h;i=x[Fb(e+12|0,e+8|0)>>2];while(1){if(i){x[g>>2]=x[d>>2];w[g+4>>1]=z[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){PM(b,c-h|0,d);break a}Id(b,x[b>>2]+(c<<3)|0);break a}XN(b);Vy(b,Uq(b,c));PM(b,c,d)}hb=e+16|0;b=0;while(1){c=x[a>>2];if(z[c+480188>>1]<=b>>>0){hb=f+16|0}else{d=D(b,872);Tn((d+x[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+x[a+4>>2]|0;w[c+1432>>1]=0;v[c+1418|0]=0;v[c+1415|0]=0;v[c+1413|0]=0;b=b+1|0;continue}break}}function $z(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;zR(a,b);h=hb-16|0;hb=h;od(c,1);g=Lb(y[b+22|0]|y[b+23|0]<<8)<<1;x[c>>2]=g;v[c+37|0]=y[b+24|0]<<4;v[h+15|0]=y[b+25|0];v[h+14|0]=64;l=c,m=y[Wb(h+15|0,h+14|0)|0]<<2,w[l+30>>1]=m;f=Lb(y[b+26|0]|y[b+27|0]<<8);a=f<<1;j=f;k=Lb(y[b+28|0]|y[b+29|0]<<8);f=k<<1;a=k>>>0>=2?a+f>>>0<=g>>>0?a:j+f>>>0>g>>>0?a:j:a;a:{b:{switch(g|0){case 2:x[c>>2]=0;break a;case 0:break a;default:break b}}x[c+4>>2]=a;f=a+f|0;x[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;x[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){x[c+4>>2]=0;x[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){x[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}w[c+34>>1]=z[c+34>>1]|2}hb=h+16|0;ml(i,3,b);a=i+16|0;Dc(a,i);c=Bc(d,a);xb(a);a=0;while(1){if((a|0)!=32){d=a+c|0;if((y[d|0]-1&255)>>>0<=30){v[d|0]=32}a=a+1|0;continue}break}a=bA(b);hb=i+32|0;return a}function d2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(de(x[c+24>>2],g)>>>0<d>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=Mg(i,f,a,b);k=Ww(h,g,a,b),l=E(C[j>>3]),B[k>>2]=l;a=a+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=c- -64|0}function Jl(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Bk(a);a:{b:{c:{f=x[b+32>>2];d:{if(!f){e=x[b+2084>>2];if(e){break d}break b}c=x[b+4>>2];if((c|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Il(h);d=x[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=A[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=y[x[b+8>>2]+d|0];if((c|0)==255){break f}g=x[a+1392>>2];if(x[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=x[a+1396>>2];if((e|0)>=(c|0)){x[a+1392>>2]=g>>>c;x[a+1396>>2]=e-y[x[b+8>>2]+d|0];return d}x[a+1396>>2]=0;break b}d=d+1|0;continue}break}gc(a,21);x[a+1396>>2]=0}return-1}aa(11253,13065,1705,5406);p()}function zB(a){var b=0,c=0,d=0,e=0,f=0,g=0;if((y[a|0]-16&255)>>>0>=241){e=a+1954|0;c=a+1698|0;a:{b:{while(1){if((c|0)==(e|0)){c=0;e=0;while(1){b=32;if((c|0)==32){break a}d=D(c,13)+a|0;if(y[d+14|0]){break b}b=(c<<4)+a|0;if(y[b+418|0]|y[b+419|0]<<8|(y[b+420|0]<<16|y[b+421|0]<<24)){break b}f=y[b+422|0]|y[b+423|0]<<8|(y[b+424|0]<<16|y[b+425|0]<<24);if(y[d+942|0]|f>>>0>1048575){break b}d=D(c,11)+a|0;g=d+1346|0;if(y[g|0]>15|y[d+1351|0]>3|y[d+1356|0]>3){break b}c:{d:{e:{if(f){d=y[b+430|0]|y[b+431|0]<<8|(y[b+432|0]<<16|y[b+433|0]<<24);if(d>>>0<=1048574&(d>>>0<(y[b+426|0]|y[b+427|0]<<8|(y[b+428|0]<<16|y[b+429|0]<<24))>>>0|d>>>0>f>>>0)){break b}b=1;if(e){break c}if(f){break d}break e}b=1;if(e){break c}}if(Rb(g,26637,11)){break d}b=0;break c}b=1}e=b;c=c+1|0;continue}}b=v[c|0];c=c+1|0;if((b|0)>=-1){continue}break}return 0}b=c}a=b>>>0>31&e}else{a=0}return a}function _ca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-32|0;hb=g;e=hb-16|0;hb=e;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;zL(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);zL(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){if((d|0)==96){if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;f=y[b+31|0];a:{b:{if(!f){d=1;break b}d=16;if(f>>>0<17){break a}}v[b+31|0]=d}w[e+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[e+12>>1]=127;j=b,k=y[Wc(e+14|0,e+12|0)|0]+1|0,v[j+30|0]=k}v[b+33|0]=y[c+212|0];hb=e+16|0}else{i=y[c+d|0];j=cc(f,d+12|0),k=i,w[j>>1]=k;d=d+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){d=y[c+h|0];f=y[a+27|0]|y[a+28|0]<<8;j=cc(e,h+12|0),k=d>>>0<f>>>0?d:0,w[j>>1]=k;h=h+1|0;continue}break}ml(g,3,a+4|0);c=g+16|0;Dc(c,g);Bc(b+492|0,c);xb(c);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}hb=g+32|0}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=hb-16|0;hb=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];j=x[a+68>>2];s=j>>31;k=x[a+64>>2];t=k>>31;l=x[a+60>>2];u=l>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){m=w[(x[g+12>>2]<<1)+q>>1]<<8;e=m;e=Jia(e,e>>31,l,u);i=lb;h=e;e=Yb(b,-16777216,16776704);e=Jia(k,t,e,e>>31);n=h+e|0;h=lb+i|0;h=e>>>0>n>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Jia(j,s,f,f>>31);i=e+n|0;f=lb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Nc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Ub(g+8|0,v,y);e=e-(r&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=g+16|0}function jw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=x[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=x[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;e=y[b|0];if((e|0)!=61){b=c+1|0;if(e){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;c:{if(y[g+a|0]){break c}f=x[116894];if(!f){break c}b=x[f>>2];if(!b){break c}while(1){d:{c=a;e=b;i=0;h=g;d=0;e:{if(!g){break e}d=y[c|0];f:{if(!d){break f}while(1){g:{j=y[e|0];if(!j){break g}h=h-1|0;if(!h|(d|0)!=(j|0)){break g}e=e+1|0;d=y[c+1|0];c=c+1|0;if(d){continue}break f}break}i=d}d=(i&255)-y[e|0]|0}if(!d){b=b+g|0;if(y[b|0]==61){break d}}b=x[f+4>>2];f=f+4|0;if(b){continue}break c}break}k=b+1|0}return k}function WN(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;b=x[a>>2];Ib(g+8|0,b);a:{b:{c:{d:{e:{if(td(x[b+16>>2])){while(1){if(c>>>0>31){break e}x[23604]=0;d=ga(42)|0;e=x[23604];x[23604]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=V(93104)|0;if((ib|0)!=(da(93104)|0)){break c}_(c|0)|0;v[b+20|0]=0;x[23604]=0;Y(30,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break d}$();break e}v[b+20|0]=0}if(!y[b+20|0]){d=x[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=x[d+2496>>2];e=d+(b<<2)|0;i=x[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=x[d+(h<<2)>>2];b=i^(b&2147483647|x[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;x[e>>2]=b;x[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}hb=g+16|0;break a}c=P()|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break b}}T(c|0);p()}V(0)|0;Vb();p()}return x[a+28>>2]&f}function BE(a,b,c,d,e,f,g,h){var i=0,j=0,k=E(0);i=hb-96|0;hb=i;ay(x[a+24>>2]);v[x[a+24>>2]+1298420|0]=x[a+52>>2]!=0;x[i+92>>2]=f;x[i+88>>2]=e;x[i+84>>2]=d;x[i+80>>2]=c;e=i+32|0;c=i+80|0;a:{d=0;while(1){b:{if((d|0)!=4){if(x[(d<<2)+c>>2]){break b}}else{d=4}break a}d=d+1|0;continue}}c=$f(e,c,d,b);k=B[a+48>>2];e=x[a+32>>2];x[i+8>>2]=x[c+8>>2];d=x[c+4>>2];x[i>>2]=x[c>>2];x[i+4>>2]=d;d=hb-16|0;hb=d;x[d+8>>2]=x[i+8>>2];c=x[i+4>>2];x[d>>2]=x[i>>2];x[d+4>>2]=c;c=VI(i+48|0);x[c+8>>2]=e;x[c+4>>2]=0;x[c>>2]=h;e=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=e;x[c+20>>2]=x[d+8>>2];B[c+24>>2]=k;x[c>>2]=g;hb=d+16|0;while(1){if(b){d=x[a+24>>2];x[i+24>>2]=b;x[i+28>>2]=0;x[i+16>>2]=134217727;x[i+20>>2]=0;d=YI(d,x[Eq(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|j)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=i+96|0;return j}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0;g=hb-16|0;hb=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];j=x[a+68>>2];s=j>>31;k=x[a+64>>2];t=k>>31;l=x[a+60>>2];u=l>>31;w=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){m=v[x[g+12>>2]+q|0]<<16;e=m;e=Jia(e,e>>31,l,u);i=lb;h=e;e=Yb(b,-16777216,16776704);e=Jia(k,t,e,e>>31);n=h+e|0;h=lb+i|0;h=e>>>0>n>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Jia(j,s,f,f>>31);i=e+n|0;f=lb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Nc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Ub(g+8|0,w,y);e=e-(r&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=g+16|0}function Gl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;x[a+4>>2]=0;if(ud(y[nn(d+8|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){while(1){b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23604]=0;b=S(90,b|0)|0;c=x[23604];x[23604]=0;d:{if((c|0)!=1){if(!tc(b,-1)){break d}break b}break c}x[a+4>>2]=x[a+4>>2]+1;continue}}if(x[a+4>>2]>=(b|0)){break a}e:{while(1){c=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23604]=0;c=S(90,c|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break e}if(tc(c,-1)){break b}c=x[a+4>>2]+1|0;x[a+4>>2]=c;if((b|0)>(c|0)){continue}break}c=0;break a}}_(V(0)|0)|0;c=1;mn(x[x[a>>2]-12>>2]+a|0,1);f:{g:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23604]=0;Z(91);a=x[23604];x[23604]=0;if((a|0)!=1){break f}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break g}T(a|0);p()}$();break a}V(0)|0;Vb()}p()}c=2}kj(x[x[a>>2]-12>>2]+a|0,c)}hb=d+16|0;return a|0}function Qu(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-16|0;hb=g;a:{if(!c){break a}if(d){b=ec(g+8|0,a,b);a=hb-16|0;hb=a;x[a+12>>2]=c;d=x[b+4>>2];b:{if(!d){d=x[b>>2];break b}c=32-d|0;x[a+8>>2]=c;e=x[b>>2];h=c;c=x[Fb(a+8|0,a+12|0)>>2];x[e>>2]=-1<<d&-1>>>h-c|x[e>>2];c=x[a+12>>2]-c|0;x[a+12>>2]=c;d=e+4|0;x[b>>2]=d}x[a+4>>2]=-1;e=d;d=c>>>5|0;GC(e,d,a+4|0);e=x[a+12>>2];c=c&-32;f=e-c|0;x[a+12>>2]=f;if((c|0)!=(e|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]|-1>>>32-f}hb=a+16|0;break a}b=ec(g,a,b);a=hb-16|0;hb=a;x[a+12>>2]=c;d=x[b+4>>2];c:{if(!d){d=x[b>>2];break c}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];f=x[c>>2];h=e;e=x[Fb(a+8|0,a+12|0)>>2];x[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5|0;FC(e,d);e=c&31;x[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-e^-1)}hb=a+16|0}hb=g+16|0}function lp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;a:{b:{switch(y[a+480224|0]-1|0){default:b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;e=Jia(b,d,5e4,0);f=lb;b=x[_c(c+8|0,c)>>2];b=Ec(Kia(e,f,b,b>>31),lb);x[a+1074404>>2]=b;break a;case 1:b=x[a+24620>>2];x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=Jia(x[a+1074420>>2],0,Jia(x[a+1074408>>2],0,x[a+1074416>>2],0),lb),x[g>>2]=h;x[c+4>>2]=lb;b=Jia(b,0,6e5,0);d=c+8|0;f=b;e=lb;b=Nu(x[d>>2],x[d+4>>2],x[c>>2],x[c+4>>2])?c:d;b=Mia(f,e,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];e=Jia(b,d,1e4,0);f=lb;b=x[_c(c+8|0,c)>>2];b=Ec(Kia(e,f,b,b>>31),lb);x[a+1074404>>2]=b}d=a+1074404|0;a=x[a+480244>>2];b=Jia(a,a>>31,b,b>>31);a=lb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Ec(Kia(b,a,65536,0),lb);x[d>>2]=a?a:1;hb=c+16|0}function LP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=hb-16|0;hb=f;o=x[a+20>>2];g=z[a+34>>1]&65;x[f+8>>2]=g;x[f>>2]=g^65;g=b;k=a+24|0;p=d+1298224|0;e=d+1074992|0;l=Xi(d);q=a+4|0;r=a+12|0;s=a+8|0;t=a+16|0;d=d+480180|0;while(1){if((e|0)!=(p|0)){if(x[e+104>>2]==(a|0)){if(x[e+16>>2]){x[e+16>>2]=g}if(A[e+4>>2]>c>>>0){x[e>>2]=0;x[e+4>>2]=0}b=a;if(x[e+76>>2]){wc(e+76|0,c);b=x[e+104>>2]}h=x[e+88>>2];b=QC(h,b);i=x[(b?r:q)>>2];x[e+84>>2]=x[(b?t:s)>>2];x[e+80>>2]=i;b=h|x[f+8>>2];x[e+88>>2]=b;x[e+88>>2]=b&(x[f>>2]^-1);b=e+704|0;h=x[a+24>>2];a:{if(!x[e+704>>2]|!h){break a}if(lm(x[d>>2])){break a}i=x[(l?b:k)>>2];j=i>>>1|0;m=Jia(x[(l?k:b)>>2],0,x[e+700>>2],0);j=j+m|0;n=lb;u=e,v=Uc(Mia(j,j>>>0<m>>>0?n+1|0:n,i,0),lb),x[u+700>>2]=v}x[b>>2]=h}e=e+872|0;continue}break}x[a>>2]=c;x[a+20>>2]=g;jz(o);hb=f+16|0}function V1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(de(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}h=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=Mg(h,g,a,b);j=Uw(d,a,b),k=E(C[i>>3]),B[j>>2]=k;a=a+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=c- -64|0}function Aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=hb-16|0;hb=f;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[f+8>>2];n=(((x[f+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;o=w[e+38>>1];p=w[e+36>>1];q=w[e+34>>1];r=w[e+32>>1];s=w[e+30>>1];t=w[e+28>>1];u=w[e+26>>1];e=w[e+24>>1];h=0;while(1){if((h|0)!=2){g=h+n|0;x[(h<<2)+f>>2]=((((D(v[g+4|0],q)+D(v[g+2|0],r)|0)+D(v[g+6|0],p)|0)+D(v[g+8|0],o)<<8>>1)+(((D(v[g-4|0],u)+D(v[g-6|0],e)|0)+D(v[g-2|0],t)|0)+D(v[g|0],s)<<8>>1)|0)/16384;h=h+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],i);Ub(f+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;hb=f+16|0}
function v9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;e=Kb(d+16|0);a:{b:{c:{if(c>>>0<64){break c}x[23604]=0;c=S(175,b|0)|0;f=x[23604];x[23604]=0;d:{if((f|0)!=1){x[d+12>>2]=c;if((c|0)>0){break d}x[23604]=0;Q(54,a|0,21502)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break b}}break a}x[23604]=0;c=S(188,b|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){g=d,h=oi(c),x[g+8>>2]=h;c=x[rd(d+12|0,d+8|0)>>2];x[23604]=0;R(45,e|0,c|0);c=x[23604];x[23604]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{x[23604]=0;c=S(192,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break f}if(!c){break e}x[23604]=0;W(800,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[23604];x[23604]=0;if((c|0)!=1){continue}}break}break a}x[23604]=0;Q(174,b|0,4)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}dd(a,e)}xb(e);hb=d+32|0;return}a=P()|0;xb(e);T(a|0);p()}function YJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=0,n=0,o=E(0);e=a+4208|0;j=E(E(B[zb(e,2)>>2]*E(2999.9990234375))+E(.0010000000474974513));l=E(B[zb(e,3)>>2]*E(.9980000257492065));f=-3e3/+E(j*E(A[x[a+16>>2]+24620>>2]));e=a+4272|0;c=xj(10,f*+A[zb(e,4)>>2]);g=a+4232|0;n=zb(g,0),o=E(c),B[n>>2]=o;c=xj(10,f*+A[zb(e,5)>>2]);n=zb(g,1),o=E(c),B[n>>2]=o;m=f*(1/+E(l+E(.0010000000474974513))+-1);c=0;while(1){if((d|0)==4){d=a+4208|0;f=xj(10,+WJ(B[zb(d,0)>>2])*.05);b=4/M(c)*f;c=xj(10,+WJ(B[zb(d,1)>>2])*.1);B[a+4228>>2]=b*M(c);B[a+4224>>2]=f*M(1-c)}else{h=x[zb(e,d)>>2];k=d>>>1|0;i=xj(10,m*+(x[zb(e,d)>>2]+x[zb(e,k+4|0)>>2]>>>0));b=xj(10,f*+(h>>>0));j=B[zb(g,k)>>2];h=d<<1;i=(1-i)*.5;n=zb(g,h+2|0),o=E(b*(1-i)),B[n>>2]=o;n=zb(g,h+3|0),o=E(b*i),B[n>>2]=o;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;d=d+1|0;continue}break}}function Eda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!y[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=y[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?(y[d-1|0]==13&(i|0)==10)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&y[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}Ve(a);pp(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=v[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}np(a,e);c=c+1|0;continue}break}}function RH(a,b,c,d){var e=0,f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=0;e=hb-96|0;hb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=B[g+4>>2];f=B[g+8>>2];B[i+4>>2]=h+f;k=d<<1;B[(8-k<<2)+e>>2]=h-f;h=B[g+16>>2];f=B[g+12>>2];B[(7-k<<2)+e>>2]=h-f;B[i+8>>2]=-E(h+f);d=d+1|0;continue}break}QH(e+48|0);QH(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=B[i>>2];f=B[d+(e+48|0)>>2];l=B[d+70528>>2];m=B[d+70564>>2];n=B[d+e>>2];B[i>>2]=E(f*l)-E(m*n);i=a+d|0;d=c+d|0;f=E(E(f*m)+E(n*l));B[i>>2]=E(h*B[d>>2])-E(B[d+36>>2]*f);B[(17-g<<2)+a>>2]=E(h*B[d+36>>2])+E(f*B[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}hb=e+96|0}function $U(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;od(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=xq(a+4|0,a);d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d;c=xq(a+8|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=f;c=(y[a+15|0]|y[a+16|0]<<8)<<1;x[b+24>>2]=c;c=y[a+15|0]|y[a+16|0]<<8?c:16726;x[b+24>>2]=c;g=b,h=(D(xu(v[a+17|0],y[a+14|0]<<28>>24),c)>>>0)/8363|0,x[g+24>>2]=h;v[e+15|0]=y[a+18|0];v[e+14|0]=127;g=b,h=(((y[Wb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;c=y[a+14|0];if(c>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=c&240}c=y[a+19|0];if(c&4){w[b+34>>1]=z[b+34>>1]|1;c=y[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=z[b+34>>1];d=f|2;w[b+34>>1]=d;c=y[a+19|0];if(c&16){d=f|6;w[b+34>>1]=d;c=y[a+19|0]}if(!(c&64)){break a}w[b+34>>1]=d|128}hb=e+16|0}function a3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb+-64|0;hb=e;a:{b:{if((b|0)>=0){d=x[a+24>>2];if($i(_b(x[d+484360>>2],y[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=x[a+24>>2];g=x[f+484344>>2];i=x[f+484348>>2];h=z[cc(x[_b(x[f+484360>>2],y[f+484376|0])>>2],b)>>1];if(!wm(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<x[ac(g,h)+12>>2]){break c}}a=a+16|0;break a}w[f+1074448>>1]=b;c=f;f=b&65535;$L(c,f);c=x[a+24>>2];x[c+1074392>>2]=-2;x[c+1074428>>2]=d;g=y[a+64|0];b=e+24|0;w[b+4>>1]=0;v[b+6|0]=255;x[b+16>>2]=2;x[b>>2]=0;w[b+12>>1]=f;x[b+8>>2]=d;d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+48|0;yt(b,c,g?7:1,e);j=a,k=C[_s(x[e+52>>2])>>3],C[j+16>>3]=k;ni(b);a=a+16|0}hb=e- -64|0;return+C[a>>3]}function zL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=hb-16|0;hb=k;v[k+15|0]=c;v[k+14|0]=12;Zg(b,y[Wb(k+15|0,k+14|0)|0]);c=0;l=x[b>>2];m=x[b+4>>2];p=ie(l,m);while(1){if((c|0)==(p|0)){c=0;v[b+12|0]=0;a:{if(!(d&1)){break a}if(tc(l,m)){break a}c=1;v[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;v[b+12|0]=c}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=c|2}v[b+14|0]=g;v[b+13|0]=f}hb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=zb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+96|0]|y[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=zb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+144|0]|y[i+145|0]<<8;i=i+146|0}v[j+2|0]=y[i|0]}e:{if(!c){break e}i=zb(l,c);j=z[i>>1];n=zb(l,c-1|0);o=z[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;w[i>>1]=j;if(j>>>0>=z[n>>1]){break e}w[i>>1]=j+256}c=c+1|0;continue}break}}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;p=w[e+40246>>1];q=w[e+40244>>1];r=w[e+40242>>1];e=w[e+40240>>1];h=0;while(1){if((h|0)!=2){i=(h<<1)+o|0;x[(h<<2)+b>>2]=(((D(w[i>>1],r)+D(w[i-4>>1],e)|0)+D(w[i+4>>1],q)|0)+D(w[i+8>>1],p)|0)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Ub(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function d9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;od(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;x[c>>2]=y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24);x[c+4>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+8>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+24>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);d=y[b+151|0];if(d>>>0<=4){v[c+38|0]=y[d+43242|0]}d=y[b+152|0]|y[b+153|0]<<8;v[c+39|0]=d;e=(y[b+156|0]|y[b+157|0]<<8)>>>4|0;v[c+41|0]=e;b=(y[b+154|0]|y[b+155|0]<<8)>>>2|0;v[c+40|0]=b;if((b|e)&255){v[c+39|0]=d^-1}b=y[a+38|0]|y[a+39|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+38|0]|y[a+39|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+38|0]|y[a+39|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+38|0]|y[a+39|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}}function T9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-880|0;hb=b;c=Zb(a,0,76);x[c+84>>2]=0;x[c+88>>2]=0;x[c+80>>2]=256;w[c+76>>1]=65535;x[c+92>>2]=0;x[c+96>>2]=0;v[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=EP(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Sb(d);g=vy(c+223860|0);f=b+8|0;Zb(f,0,108);vz(b+120|0,48e3);Zb(b+664|0,0,72);v[b+754|0]=0;w[b+752>>1]=65535;v[b+746|0]=0;w[b+744>>1]=65535;v[b+738|0]=0;w[b+736>>1]=65535;x[b+748>>2]=0;x[b+740>>2]=0;Zb(b+756|0,0,103);x[b+868>>2]=0;x[b+872>>2]=0;v[b+875|0]=0;v[b+876|0]=0;v[b+877|0]=0;v[b+878|0]=0;x[b+860>>2]=0;x[b+864>>2]=0;v[b+859|0]=y[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=qp(e,f)+872|0;continue}break}x[23604]=0;R(487,d|0,32);a=x[23604];x[23604]=0;if((a|0)!=1){hb=b+880|0;return c|0}a=P()|0;rp(g);fc(d);T(a|0);p()}function NH(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[a+32>>2];a:{b:{b=x[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=x[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=y[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(A[a+40>>2]<c>>>0){gc(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=x[a+40>>2];if(e>>>0<=c+26>>>0){gc(a,1);break a}if(Rb(c,93444,4)){gc(a,21);break a}if(y[c+4|0]){gc(a,21);break a}d:{if(d){if(!x[a+992>>2]|!(v[c+5|0]&1)){break d}gc(a,21);break a}if(v[c+5|0]&1){break d}gc(a,21);break a}b=0;f=c+27|0;d=y[c+26|0];c=f+d|0;if(e>>>0<c>>>0){gc(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=y[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}gc(a,1)}return 0}function r6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=fi(a,b,c,d);x[b+4260>>2]=0;x[b>>2]=47228;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Sb(d)+24|0;if((d|0)!=(c|0)){continue}break}v[b+5046|0]=1;w[b+5044>>1]=0;a=b+4208|0;f=zb(a,0),g=1063675494,x[f>>2]=g;f=zb(a,1),g=1065185444,x[f>>2]=g;f=zb(a,2),g=0,x[f>>2]=g;f=zb(a,3),g=1032805417,x[f>>2]=g;f=zb(a,4),g=1053079357,x[f>>2]=g;f=zb(a,5),g=1059859440,x[f>>2]=g;f=zb(a,6),g=1047457519,x[f>>2]=g;f=zb(a,7),g=1062836634,x[f>>2]=g;f=zb(a,8),g=1038174126,x[f>>2]=g;f=zb(a,9),g=1065353216,x[f>>2]=g;f=zb(a,10),g=1065353216,x[f>>2]=g;f=zb(a,11),g=1048525618,x[f>>2]=g;f=zb(a,12),g=1059760811,x[f>>2]=g;x[23604]=0;R(851,b+44|0,2);a=x[23604];x[23604]=0;if((a|0)==1){a=P()|0;while(1){c=sc(c-24|0);if((e|0)!=(c|0)){continue}break}uf(b);T(a|0);p()}ei(b);return b|0}function bG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=hb-32|0;hb=h;a:{b:{c:{if((b|0)!=(c|0)){j=x[116080];x[116080]=0;g=hb-16|0;hb=g;zd();e=hb-16|0;hb=e;f=hb-16|0;hb=f;iw(f,b,h+28|0,2);k=x[f>>2];i=x[f+4>>2];b=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=b;x[e>>2]=k;x[e+4>>2]=i;hb=f+16|0;i=x[e>>2];f=x[e+4>>2];b=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=b;x[g>>2]=i;x[g+4>>2]=f;hb=e+16|0;f=x[g>>2];e=x[g+4>>2];b=x[g+12>>2];x[h+16>>2]=x[g+8>>2];x[h+20>>2]=b;x[h+8>>2]=f;x[h+12>>2]=e;hb=g+16|0;g=x[h+16>>2];i=x[h+20>>2];e=x[h+8>>2];f=x[h+12>>2];b=x[116080];if(!b){break c}if(x[h+28>>2]!=(c|0)){break b}l=e;m=f;n=g;o=i;if((b|0)!=68){break a}break b}x[d>>2]=4;break a}x[116080]=j;if(x[h+28>>2]==(c|0)){break a}}x[d>>2]=4;e=l;f=m;g=n;i=o}x[a>>2]=e;x[a+4>>2]=f;x[a+8>>2]=g;x[a+12>>2]=i;hb=h+32|0}function P1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-96|0;hb=d;x[23604]=0;e=x[b+12>>2];x[d+40>>2]=x[b+8>>2];x[d+44>>2]=e;e=x[b+4>>2];x[d+32>>2]=x[b>>2];x[d+36>>2]=e;e=S(1027,d+32|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){a:{b:{if(e){x[23604]=0;R(1028,d+72|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){b=d+80|0;dv(b,x[d+72>>2],x[d+76>>2]);e=mg(d+88|0,b);f=mg(d- -64|0,c);g=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=g;e=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=e;ev(a,d+8|0,d);break b}break a}x[23604]=0;R(1029,d+72|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}b=d+80|0;dv(b,x[d+72>>2],x[d+76>>2]);e=mg(d+56|0,b);f=mg(d+48|0,c);g=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=g;e=x[f+4>>2];x[d+16>>2]=x[f>>2];x[d+20>>2]=e;ev(a,d+24|0,d+16|0)}be(b);be(d+72|0);be(c);hb=d+96|0;return}}a=P()|0;be(c);T(a|0);p()}function rC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;x[23604]=0;f=Q(12,e+8|0,467048)|0;c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)!=1){d:{e:{if(!ud(y[f|0])){break e}c=um(e,467048);d=x[x[116762]-12>>2];g=x[d+467052>>2];x[23604]=0;d=d+467048|0;h=S(13,d|0)|0;i=x[23604];x[23604]=0;if((i|0)==1){break d}c=x[c>>2];x[23604]=0;b=a+b|0;a=ka(14,c|0,a|0,((g&176)==32?b:a)|0,b|0,d|0,h|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break d}if(a){break e}a=x[x[116762]-12>>2];x[23604]=0;R(15,a+467048|0,5);a=x[23604];x[23604]=0;if((a|0)!=1){break e}break d}$j(f);break b}a=V(0)|0;$j(f);break c}a=V(0)|0}_(a|0)|0;a=x[x[116762]-12>>2];x[23604]=0;Y(16,a+467048|0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$()}hb=e+16|0;return}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){V(0)|0;Vb();p()}T(a|0);p()}function pL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a|0)!=(b|0)){e=hb-16|0;hb=e;d=x[b>>2];h=x[b+4>>2];f=Vj(d,h);a:{if(f>>>0<=_t(a)>>>0){m=h;i=x[a>>2];c=Vj(i,x[a+4>>2]);n=c>>>0>=f>>>0;if(!n){x[e+12>>2]=d;x[e+12>>2]=x[e+12>>2]+D(c,6);m=x[e+12>>2]}j=hb-16|0;hb=j;p=j+8|0;c=hb-32|0;hb=c;jm(c+24|0,d,m);k=hb-16|0;hb=k;o=x[c+28>>2];l=x[c+24>>2];g=o-l|0;if((l|0)!=(o|0)){ah(i,l,g)}g=D((g|0)/6|0,6);x[k+12>>2]=g+i;yd(c+16|0,g+l|0,k+12|0);hb=k+16|0;d=Tp(d,x[c+16>>2]);q=c,r=Tp(i,x[c+20>>2]),x[q+12>>2]=r;yd(p,d,c+12|0);hb=c+32|0;c=x[j+12>>2];hb=j+16|0;if(!n){Lx(a,m,h,f-Vj(x[a>>2],x[a+4>>2])|0);break a}Id(a,c);break a}qL(a);Ot(a,wA(a,f));Lx(a,d,h,f)}hb=e+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];oL(a+24|0,b+24|0);vj(a+36|0,b+36|0);return a}function p5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[23604]=0;Y(901,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break g}x[23604]=0;Y(901,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break g}f=x[a+24>>2];x[23604]=0;d=Q(54,e+16|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break g}x[23604]=0;c=Q(54,e|0,c|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break f}x[23604]=0;X(916,f|0,d|0,c|0,1);b=x[23604];x[23604]=0;if((b|0)==1){break e}xb(c);xb(d);b=1;break b}b=V(0)|0;break c}b=V(0)|0;break d}b=V(0)|0;xb(c)}xb(d)}_(b|0)|0;b=0;x[23604]=0;X(887,6370,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$()}hb=e+32|0;return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;p=w[e+40246>>1];q=w[e+40244>>1];r=w[e+40242>>1];e=w[e+40240>>1];h=0;while(1){if((h|0)!=2){i=h+o|0;x[(h<<2)+b>>2]=(((D(v[i|0],r)+D(v[i-2|0],e)|0)+D(v[i+2|0],q)|0)+D(v[i+4|0],p)<<8)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Ub(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function gt(a,b){var c=0,d=0,e=0,f=0;e=hb-48|0;hb=e;d=e+24|0;GP(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);GP(e,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=x[d>>2];b=Lb(y[b|0]|y[b+1|0]<<8);a=x[e>>2];a=Lb(y[a|0]|y[a+1|0]<<8);c=1;a:{if(b>>>0<a>>>0){break a}c=0;if(a>>>0<b>>>0){break a}b=x[d+4>>2];b=Lb(y[b|0]|y[b+1|0]<<8);a=x[e+4>>2];a=Lb(y[a|0]|y[a+1|0]<<8);c=1;b:{if(b>>>0<a>>>0){break b}c=0;if(a>>>0<b>>>0){break b}b=x[d+8>>2];b=Lb(y[b|0]|y[b+1|0]<<8);a=x[e+8>>2];a=Lb(y[a|0]|y[a+1|0]<<8);c=1;c:{if(b>>>0<a>>>0){break c}c=0;if(a>>>0<b>>>0){break c}b=x[d+16>>2];a=x[e+12>>2];f=x[e+16>>2];d=x[d+12>>2];d=Lb(y[d|0]|y[d+1|0]<<8)<<16>>16;a=Lb(y[a|0]|y[a+1|0]<<8)<<16>>16;c=1;d:{if((d|0)<(a|0)){break d}c=0;if((a|0)<(d|0)){break d}c=Lb(y[b|0]|y[b+1|0]<<8)>>>0<Lb(y[f|0]|y[f+1|0]<<8)>>>0}}}}a=c;hb=e+48|0;return a}function fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-32|0;hb=g;e=b;b=x[a>>2];b=de(e,Bb(b))+b|0;e=LT(c,d);a:{if((e|0)<=0){break a}f=x[Cb(a)>>2];h=x[a+4>>2];if((f-h|0)>=(e|0)){x[g>>2]=d;i=h-b|0;if((i|0)<(e|0)){x[g>>2]=c;GS(g,i);f=x[g>>2];l=hb-16|0;hb=l;m=tk(l,a,e-i|0);j=x[m+4>>2];k=hb-16|0;hb=k;x[k+8>>2]=f;while(1){if(Ob(f,d)){sk(j,y[f|0]);j=j+1|0;f=x[Le(k+8|0)>>2];continue}break}hb=k+16|0;x[m+4>>2]=j;ic(m);hb=l+16|0;if((i|0)<=0){break a}}KT(a,b,h,b+e|0);Xt(c,x[g>>2],b);break a}f=Cb(a);f=Bl(g,qk(a,Rc(x[a>>2],h)+e|0),b-x[a>>2]|0,f);e=hb-32|0;hb=e;x[e+24>>2]=c;c=Lv(e+8|0,f+8|0,LT(c,d));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){sk(d,y[x[e+24>>2]]);d=x[c>>2]+1|0;x[c>>2]=d;Le(e+24|0);continue}break}Hd(c);hb=e+32|0;b=dq(a,f,b);Al(f)}Ib(g+24|0,b);hb=g+32|0}function gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=hb-432|0;hb=d;xc(b);lA(b,d+376|0,d+296|0,d+8|0);k=d,l=ri((m=y[d+427|0]+1|0,n=1,o=dc(x[d+408>>2]),o?m:n)),v[k+4|0]=l;i=y[Wb(27168,d+4|0)|0];v[d+7|0]=i;w[d+4>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Lb(z[d+8>>1])<<16>>16;if(!((e|0)<0|y[d+291|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=dc(x[d+296>>2]);if(e>>>0<g>>>0){if(Yc(b,g)){break c}}v[d+7|0]=h+1;break b}}else{d:{if(!Yc(b,dc(x[d+392>>2])+(f<<2)|0)){break d}if(!Yc(b,rm(b))){break d}e:{if(!c){j=Be(b);break e}j=pq(b)}w[d+2>>1]=j;k=d,l=z[Se(d+4|0,d+2|0)>>1],w[k+4>>1]=l}f=f+1|0;continue}break}g=dc(x[d+296>>2]);lA(b,d+376|0,d+296|0,d+8|0);h=h+1|0;continue}break}Ru(a);break a}w[a>>1]=z[d+4>>1];v[a+2|0]=y[d+7|0]}hb=d+432|0}function xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;h=x[a+40>>2];i=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[f+8>>2];g=(x[f+12>>2]<<1)+j|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;e=(((((D(w[g+4>>1],w[e+34>>1])+D(w[g+2>>1],w[e+32>>1])|0)+D(w[g+6>>1],w[e+36>>1])|0)+D(w[g+8>>1],w[e+38>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+26>>1])+D(w[g-6>>1],w[e+24>>1])|0)+D(w[g-2>>1],w[e+28>>1])|0)+D(w[g>>1],w[e+30>>1])|0)/2|0)|0)/16384|0;i=i+l|0;x[c>>2]=x[c>>2]+D(e,i>>12);h=h+k|0;x[c+4>>2]=x[c+4>>2]+D(e,h>>12);Ub(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;hb=f+16|0}function zd(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(y[467860]){return x[116964]}c=hb-32|0;hb=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=wG(a,d?14155:21502)}else{d=x[a<<2>>2]}x[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!vG(0)){b=89120;if(!Rb(c+8|0,89120,24)){break a}b=89144;if(!Rb(c+8|0,89144,24)){break a}a=0;if(!y[467632]){while(1){f=(a<<2)+467584|0,g=wG(a,21502),x[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}v[467632]=1;x[116902]=x[116896]}b=467584;if(!Rb(c+8|0,467584,24)){break a}b=467608;if(!Rb(c+8|0,467608,24)){break a}b=Ld(24);if(!b){break b}}a=x[c+12>>2];x[b>>2]=x[c+8>>2];x[b+4>>2]=a;a=x[c+28>>2];x[b+16>>2]=x[c+24>>2];x[b+20>>2]=a;a=x[c+20>>2];x[b+8>>2]=x[c+16>>2];x[b+12>>2]=a;break a}b=0}hb=c+32|0;v[467860]=1;x[116964]=b;return b}function Vm(a,b,c,d){var e=0,f=0;f=hb-16|0;hb=f;x[23604]=0;Y(900,a|0);e=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=x[a+24>>2];x[23604]=0;R(d|0,f|0,e|0);d=x[23604];x[23604]=0;if((d|0)==1){break i}d=x[f>>2];e=Dd(d,x[f+4>>2]);if(e>>>0<2147483647){break h}d=ba(8)|0;x[23604]=0;b=Q(954,d|0,7347)|0;e=x[23604];x[23604]=0;if((e|0)==1){break g}x[23604]=0;U(105,b|0,92880,154);b=x[23604];x[23604]=0;if((b|0)!=1){break b}b=V(0)|0;break f}b=V(0)|0;break e}b=V(0)|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=Qf(21502);break j}b=Qf(Pb(Zd(d,b)))}Vd(f);break d}b=V(0)|0;ca(d|0)}Vd(f)}_(b|0)|0;b=0;x[23604]=0;X(887,c|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break c}$()}hb=f+16|0;return b}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break a}V(0)|0;Vb()}p()}T(a|0);p()}function Bz(a,b){var c=0;c=hb-16|0;hb=c;a=Oq(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:ey(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;zf(a,107);break a;case 3:ey(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;zf(a,4);break a;case 2:break b;case 0:break c}}Nb(a,88,1);break a}ey(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}hb=c+16|0}function ry(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=z[a+480188>>1];g=d>>>0<=256?256:d;e=x[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(g|0)){f=D(c,872)+a|0;if(!x[f+1075068>>2]){if(!Ij(x[f+1075648>>2])|y[f+1075081|0]&24){break a}}if(y[f+1075081|0]&2){if(!td(e)){break a}if(!MM(e,c&65535)){break a}}c=c+1|0;continue}break}f=65535;e=8388608;if(b>>>0<=255){b=D(b,872)+a|0;if(!x[b+1075688>>2]){c=65535;if(x[b+1075068>>2]){break a}}e=x[b+1075680>>2]|x[b+1075672>>2]<<9}while(1){if((d|0)==(g|0)){c=f;break a}c=D(d,872)+a|0;if(!(x[c+1075688>>2]?0:x[c+1075068>>2])){b=(x[c+1075680>>2]|x[c+1075672>>2]<<9)>>>(x[c+1075080>>2]>>>1&1)|0;b:{c:{if(b>>>0<e>>>0){c=x[c+1075716>>2];break c}if((b|0)!=(e|0)){break b}c=x[c+1075716>>2];if(h>>>0>=c>>>0){break b}}e=b;f=d;h=c}d=d+1|0;continue}break}c=d}return c&65535}function n8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((rj(x[a>>2],x[a+4>>2])|0)==2){if((rj(x[a+12>>2],x[a+16>>2])|0)==(b|0)){break b}}x[23604]=0;R(853,a|0,2);c=x[23604];x[23604]=0;c:{if((c|0)==1){break c}x[23604]=0;R(853,a+12|0,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break c}x[23604]=0;R(854,a+24|0,2);c=x[23604];x[23604]=0;if((c|0)==1){break c}x[23604]=0;R(854,a+36|0,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=Kq(x[c+12>>2],a);f=zb(x[c+36>>2],a),g=d,x[f>>2]=g;a=a+1|0;continue}}else{e=Kq(x[a>>2],d);f=zb(x[a+24>>2],d),g=e,x[f>>2]=g;d=d+1|0;continue}}b=V(92520)|0;if((ib|0)!=(da(92520)|0)){break a}_(b|0)|0;Fc(a);UK(a);b=a+12|0;Fc(b);UK(b);b=a+24|0;Fc(b);TK(b);a=a+36|0;Fc(a);TK(a);$()}return}T(b|0);p()}function md(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];i=!!(b|d);e=b;f=x[a+4>>2];h=x[a+44>>2];b=f-h|0;g=b;c=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;a:{b=c>>>0<g>>>0?b+1|0:b;if(!(((b|0)>=(d|0)&c>>>0>=e>>>0|(b|0)>(d|0))&i)){i=ow(a);if((i|0)>=0){break a}f=x[a+4>>2];h=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=f;g=c;c=h-f|0;d=g+c|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=c>>>0>d>>>0?b+1|0:b;return-1}d=c+1|0;b=d?b:b+1|0;f=x[a+4>>2];h=x[a+8>>2];e=x[a+116>>2];g=e;c=x[a+112>>2];b:{if(!(e|c)){break b}e=c-d|0;c=g-(b+(c>>>0<d>>>0)|0)|0;j=h-f|0;g=j>>31;if((c|0)>=(g|0)&e>>>0>=j>>>0|(c|0)>(g|0)){break b}h=e+f|0}x[a+104>>2]=h;c=x[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){v[f-1|0]=i}return i}function E7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=hb-4112|0;hb=c;h=mb[x[x[a>>2]+116>>2]](a)|0;if(!h){mb[x[x[a>>2]+120>>2]](a)}x[c+12>>2]=0;f=hb-16|0;hb=f;while(1){d=x[a+44>>2];if(rj(d,x[a+48>>2])>>>0<=e>>>0){hb=f+16|0}else{x[f+12>>2]=0;d=Kq(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){B[d>>2]=B[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){x[c+8>>2]=b;wc(c+8|0,512);e=c+16|0;hy(e);d=x[c+8>>2];mb[x[x[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;B[c+4>>2]=F(B[g>>2]);i=c,j=B[tx(c+12|0,c+4|0)>>2],B[i+12>>2]=j;B[c+4>>2]=F(B[g+2048>>2]);i=c,j=B[tx(c+12|0,c+4|0)>>2],B[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){mb[x[x[a>>2]+124>>2]](a)}hb=c+4112|0;return E(B[c+12>>2])}function kZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=x[a>>2];c=rc(d,x[a+4>>2]);if(c>>>0<b>>>0){h=hb-32|0;hb=h;f=b-c|0;e=x[Cb(a)>>2];b=x[a+4>>2];a:{if(f>>>0<=e-b>>2>>>0){BF(a,f);break a}e=Yv(a);c=vg(a,rc(x[a>>2],b)+f|0);g=rc(x[a>>2],x[a+4>>2]);d=hb-16|0;hb=d;b=h+8|0;Df(b+12|0,e);b:{if(!c){c=0;x[b>>2]=0;e=0;break b}vF(d+8|0,x[b+16>>2],c);c=x[d+8>>2];x[b>>2]=c;e=x[d+12>>2]}g=(g<<2)+c|0;x[b+4>>2]=g;x[b+8>>2]=g;i=yc(b),j=(e<<2)+c|0,x[i>>2]=j;hb=d+16|0;e=hb-16|0;hb=e;d=pl(e,b+8|0,f);c=x[d>>2];while(1){if(x[d+4>>2]!=(c|0)){wF(c);c=x[d>>2]+4|0;x[d>>2]=c;continue}break}Hd(d);hb=e+16|0;xd(a,b);c=x[b+4>>2];a=x[b+8>>2];while(1){if((a|0)!=(c|0)){a=a-4|0;x[b+8>>2]=a;continue}break}a=x[b>>2];if(a){zF(x[b+16>>2],a,iz(b))}}hb=h+32|0;return}if(b>>>0<c>>>0){yF(a,d+(b<<2)|0)}}function yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;h=x[a+40>>2];i=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[f+8>>2];g=x[f+12>>2]+j|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;e=((((D(v[g+2|0],w[e+34>>1])+D(v[g+1|0],w[e+32>>1])|0)+D(v[g+3|0],w[e+36>>1])|0)+D(v[g+4|0],w[e+38>>1])<<8>>1)+(((D(v[g-2|0],w[e+26>>1])+D(v[g-3|0],w[e+24>>1])|0)+D(v[g-1|0],w[e+28>>1])|0)+D(v[g|0],w[e+30>>1])<<8>>1)|0)/16384|0;i=i+l|0;x[c>>2]=x[c>>2]+D(e,i>>12);h=h+k|0;x[c+4>>2]=x[c+4>>2]+D(e,h>>12);Ub(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;hb=f+16|0}function KE(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-48|0;hb=d;x[23604]=0;Y(900,a|0);e=x[23604];x[23604]=0;a:{b:{c:{if((e|0)!=1){e=Kb(d+32|0);x[23604]=0;Y(c|0,d+16|0);c=x[23604];x[23604]=0;d:{e:{if((c|0)!=1){h=d,i=Bb(x[d+16>>2]),x[h+8>>2]=i;f=1;while(1){g=Bb(x[d+20>>2]);c=x[d+8>>2];if(!Ob(c,g)){c=Qf(Pb(e));Vd(d+16|0);xb(e);break b}if(!f){x[23604]=0;Q(889,e|0,14481)|0;c=x[23604];x[23604]=0;if((c|0)==1){break e}c=x[d+8>>2]}x[23604]=0;Q(753,e|0,c|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break e}Wp(d+8|0);f=0;continue}}c=V(0)|0;break d}c=V(0)|0;Vd(d+16|0)}xb(e);break c}c=V(0)|0}_(c|0)|0;c=0;x[23604]=0;X(887,b|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$()}hb=d+48|0;return c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){V(0)|0;Vb();p()}T(a|0);p()}function S6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;h=hb-16|0;hb=h;if(Qh(a+44|0)){g=x[a+44>>2];r=h,s=Cc(g,0),x[r+8>>2]=s;r=h,s=Cc(g,1),x[r+12>>2]=s;g=x[a+56>>2];l=Cc(g,0);x[h>>2]=l;m=Cc(g,1);x[h+4>>2]=m;p=y[a+4273|0];q=y[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=x[i>>2];x[i>>2]=e+4;f=E(B[e>>2]*B[a+4240>>2]);e=a+j|0;i=e+4228|0;f=E(f+E(B[i>>2]*B[a+4236>>2]));B[i>>2]=f;f=nK(E(f*E(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=B[e>>2];o=B[a+4264>>2];f=E(E(E(f*B[a+4260>>2])-E(B[a+4268>>2]*B[i>>2]))-E(n*o));B[e>>2]=f;B[i>>2]=n+E(f*o);e=h+j|0;j=x[e>>2];x[e>>2]=j+4;B[j>>2]=f*E(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{di(a,b,c,l,m,d)}break}}hb=h+16|0}function Kn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;f=x[b+656>>2];if(!(!f|v[b+730|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}e=z[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;x[b+88>>2]=d;e=x[c>>2];x[b+76>>2]=e;g=x[c+4>>2];x[b+80>>2]=g;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<e>>>0){x[b+76>>2]=c;h=c}else{h=e}e=x[b+4>>2];if(h>>>0>=e>>>0){break b}x[b>>2]=0;x[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;x[b+88>>2]=d;x[b+76>>2]=x[c>>2]}if(!f){break a}if(!(!(y[f+60|0]&2|x[a+480180>>2]&1064964)|!x[f>>2])){x[b+88>>2]=d|4096}if(y[f+65|0]==255|z[b+728>>1]!=65535){break a}i=b,j=Vc(Ap(f+48|0,x[b+724>>2],256,64)),w[i+728>>1]=j;i=b,j=z[zb(x[f+48>>2],y[f+65|0])>>1],x[i+724>>2]=j}}function dp(a){var b=E(0),c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;e=(q(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=E(1);if(d>>>0<964689920){break a}b=Vh(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=E(-Vh(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=Wh(f+1.5707963267948966);break a}b=Wh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Vh(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=Wh(-4.71238898038469-+a);break a}b=Wh(+a+-4.71238898038469);break a}b=E(a-a);if(d>>>0>=2139095040){break a}b:{switch(Cw(a,c+8|0)&3){case 0:b=Vh(C[c+8>>3]);break a;case 1:b=Wh(-C[c+8>>3]);break a;case 2:b=E(-Vh(C[c+8>>3]));break a;default:break b}}b=Wh(C[c+8>>3])}a=b;hb=c+16|0;return a}function A2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-32|0;hb=d;j=d,k=rJ(),x[j+24>>2]=k;g=a+24|0;c=d+24|0;pJ(g,Wd(c));Ti(c);w[a+28>>1]=0;AO();f=hb-16|0;hb=f;e=Jc(144);x[23604]=0;h=Q(1013,e|0,4)|0;i=x[23604];x[23604]=0;a:{if((i|0)!=1){e=x[lf(f+8|0,h)>>2];hb=f+16|0;break a}a=P()|0;Hb(e);T(a|0);p()}x[d+24>>2]=e;oJ(a+32|0,Wd(c));ds(c);j=d,k=qJ(x[a>>2]),x[j+24>>2]=k;nJ(a+4|0,Wd(c));Si(c);un(x[g>>2],x[a+4>>2]);x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;v[a- -64|0]=0;j=d,k=gj(x[b>>2]),x[j+24>>2]=k;e=xf(b);b:{while(1){b=x[d+24>>2];if(!xg(b,e)){break b}c=sd(b);b=lg(d+8|0,c);x[23604]=0;X(916,a|0,b|0,c+12|0,0);c=x[23604];x[23604]=0;if((c|0)!=1){xb(b);Tg(d+24|0);continue}break}a=P()|0;xb(b);T(a|0);p()}hb=d+32|0}function aW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=hb-16|0;hb=g;Yc(b,y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24));h=Sb(a);a=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);x[23604]=0;R(170,h|0,a|0);a=x[23604];x[23604]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))>>>0<=a>>>0){break b}e=x[b+8>>2];f=x[b>>2];x[23604]=0;e=W(142,f|0,e|0,4)|0;f=x[23604];x[23604]=0;if((f|0)==1){break a}if(!e){break b}e=y[c+4|0]|y[c+5|0]<<8;x[23604]=0;e=Q(171,b|0,e|0)|0;f=x[23604];x[23604]=0;c:{if((f|0)!=1){x[g+12>>2]=e;if(Dd(x[d>>2],x[d+4>>2])>>>0<=e>>>0){break c}x[23604]=0;R(172,h|0,g+12|0);e=x[23604];x[23604]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}hb=g+16|0;return}}a=P()|0;sc(h);T(a|0);p()}function K0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;if(ud(y[nn(c+24|0,a,0)|0])){Pc(c+16|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[23604]=0;e=S(1045,x[c+16>>2])|0;d=x[23604];x[23604]=0;a:{b:{if((d|0)!=1){d=um(c+8|0,a);f=zc(c);g=x[x[a>>2]-12>>2];f=x[f>>2];d=x[d>>2];x[23604]=0;ma(1048,e|0,d|0,f|0,a+g|0,c+28|0,c+20|0);e=x[23604];x[23604]=0;if((e|0)!=1){break b}}b=V(0)|0;$b(c+16|0);_(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;mn(x[x[a>>2]-12>>2]+a|0,b);c:{d:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23604]=0;Z(91);a=x[23604];x[23604]=0;if((a|0)!=1){break c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break d}T(a|0);p()}$();break a}V(0)|0;Vb()}p()}$b(c+16|0);x[b>>2]=x[c+20>>2]}kj(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;return a|0}function JK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;e=x[b+4220>>2];f=x[b+4224>>2];g=x[b+4228>>2];h=x[b+4232>>2];i=x[b+4240>>2];j=x[b+4236>>2];l=y[b+4244|0];k=b+4208|0;Fi(k,33);d=x[k>>2];v[d+32|0]=l;v[d+24|0]=j;v[d+25|0]=j>>>8;v[d+26|0]=j>>>16;v[d+27|0]=j>>>24;v[d+28|0]=i;v[d+29|0]=i>>>8;v[d+30|0]=i>>>16;v[d+31|0]=i>>>24;v[d+16|0]=g;v[d+17|0]=g>>>8;v[d+18|0]=g>>>16;v[d+19|0]=g>>>24;v[d+20|0]=h;v[d+21|0]=h>>>8;v[d+22|0]=h>>>16;v[d+23|0]=h>>>24;v[d+8|0]=e;v[d+9|0]=e>>>8;v[d+10|0]=e>>>16;v[d+11|0]=e>>>24;v[d+12|0]=f;v[d+13|0]=f>>>8;v[d+14|0]=f>>>16;v[d+15|0]=f>>>24;v[d|0]=76;v[d+1|0]=70;v[d+2|0]=79;v[d+3|0]=32;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;ke(c+8|0,x[k>>2],x[b+4212>>2]);ec(a,x[c+8>>2],x[c+12>>2]);hb=c+16|0}function rK(a){var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Wh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=E(-Vh(d+1.5707963267948966));break a}a=Vh(d+-1.5707963267948966);break a}a=Wh(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=Vh(d+4.71238898038469);break a}a=E(-Vh(d+-4.71238898038469));break a}a=Wh(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}b:{switch(Cw(a,b+8|0)&3){case 0:a=Wh(C[b+8>>3]);break a;case 1:a=Vh(C[b+8>>3]);break a;case 2:a=Wh(-C[b+8>>3]);break a;default:break b}}a=E(-Vh(C[b+8>>3]))}hb=b+16|0;return a}function PJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=hb-48|0;hb=j;k=x[a+4>>2];l=x[a>>2];a=x[a+8>>2];x[j+32>>2]=b;x[j+44>>2]=a;x[j+36>>2]=l;x[j+40>>2]=k;x[23604]=0;a=Q(880,(d?d:881)|0,e|0)|0;b=x[23604];x[23604]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+16>>2]=a;a=x[Mf(j+24|0,j+16|0)>>2];b=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=b;x[23604]=0;b=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=b;c=+xa(882,j|0,+c,a|0);a=x[23604];x[23604]=0;if((a|0)==1){break d}te(j+16|0);break b}a=V(0)|0;break c}a=V(0)|0;te(j+16|0)}_(a|0)|0;x[23604]=0;ia(883,14919,d|0,e|0,f|0,g|0,h|0,i|0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();c=0}hb=j+48|0;return+c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function QH(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);f=B[a>>2];i=B[a+24>>2];c=E(f-i);d=B[a+16>>2];b=B[a+32>>2];g=B[a+8>>2];e=E(d+E(b-g));B[a+16>>2]=c+e;j=E(c-E(e*E(.5)));c=B[a+4>>2];e=B[a+20>>2];h=B[a+28>>2];k=E(E(E(c-e)-h)*E(.8660253882408142));B[a+4>>2]=j+k;l=E(E(d-b)*E(.1736481785774231));f=E(f+E(i*E(.5)));i=E(E(g+b)*E(.7660444378852844));m=E(l+E(f-i));n=E(E(c+e)*E(.9848077297210693));b=E(B[a+12>>2]*E(.8660253882408142));c=E(E(c+h)*E(.6427876353263855));o=E(E(n-b)-c);B[a+12>>2]=m+o;B[a+20>>2]=m-o;B[a+28>>2]=j-k;d=E(E(g+d)*E(.9396926164627075));g=E(E(f+d)-l);e=E(E(e-h)*E(.3420201539993286));h=E(E(e-b)-n);B[a+32>>2]=g+h;d=E(E(f-d)+i);b=E(E(b+e)-c);B[a+24>>2]=d+b;B[a+8>>2]=d-b;B[a>>2]=g-h}function Ap(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;f=x[a>>2];e=x[a+4>>2];i=ie(f,e)-1|0;while(1){a:{b:{if(ie(f,e)-1>>>0<=g>>>0){g=i;break b}if(z[Hc(f,e,g)>>1]<(b|0)){break a}e=x[a+4>>2];f=x[a>>2]}i=z[Hc(f,e,g)>>1];f=0;x[h+12>>2]=0;c:{if((b|0)>=(i|0)){j=h,k=(y[Hc(x[a>>2],x[a+4>>2],g)+2|0]<<16>>>0)/(d>>>0)|0,x[j+12>>2]=k;break c}e=0;if(g){e=g-1|0;f=(y[Hc(x[a>>2],x[a+4>>2],e)+2|0]<<16>>>0)/(d>>>0)|0;x[h+12>>2]=f;e=z[Hc(x[a>>2],x[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=i>>>0){break c}a=((y[Hc(x[a>>2],x[a+4>>2],g)+2|0]<<16>>>0)/(d>>>0)|0)-f|0;d=a;g=a>>31;a=b-e|0;b=Jia(d,g,a,a>>31);a=i-e|0;j=h,k=Ec(Kia(b,lb,a,a>>31),lb)+f|0,x[j+12>>2]=k}fe(h+12|0,0,65536);hb=h+16|0;return(D(x[h+12>>2],c)+32768|0)/65536|0}g=g+1|0;e=x[a+4>>2];f=x[a>>2];continue}}function hda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-80|0;hb=c;a:{d=x[a+4>>2];b:{if(d>>>0<b>>>0){f=Yd(c+72|0);e=b-d|0;g=dt(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){hm(c+56|0,x[a>>2],d);ec(f,x[c+56>>2],x[c+60>>2]);x[a+4>>2]=x[a+4>>2]+e;break c}d=Wn(c+56|0);x[23604]=0;b=Q(679,a|0,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break a}x[23604]=0;R(680,d|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}x[d+4>>2]=x[a+4>>2]+e;$k(c+40|0,x[a>>2]);hm(c+32|0,x[a>>2],x[a+4>>2]);$k(c+24|0,x[d>>2]);b=x[c+44>>2];x[c+8>>2]=x[c+40>>2];x[c+12>>2]=b;LQ(c+48|0,c+8|0,x[c+32>>2],x[c+36>>2],x[c+24>>2],x[c+28>>2]);ec(f,x[c+48>>2],x[c+52>>2]);kt(a,d);He(d)}a=ec(c+16|0,x[f>>2],x[f+4>>2]);Qu(x[a>>2],x[a+4>>2],e,0);break b}x[a+4>>2]=b}hb=c+80|0;return}a=P()|0;He(d);T(a|0);p()}function Hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;v[e+15|0]=0;w[e+12>>1]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){w[e+10>>1]=0;OR(a,e+15|0,e+12|0,j,e+10|0);i=z[e+10>>1];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!af(a,e+9|0)){break c}f=y[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;w[e+10>>1]=l;w[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}hb=e+16|0}function G2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(A[a+4>>2]<A[Cb(a)>>2]){d=hb-16|0;hb=d;a=Jo(d,a,1);cx(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+16;ic(a);hb=d+16|0;return}h=hb-32|0;hb=h;d=Cb(a);c=Cv(h+8|0,Gv(a,ch(x[a>>2],x[a+4>>2])+1|0),ch(x[a>>2],x[a+4>>2]),d);cx(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+16;g=hb-32|0;hb=g;f=Ib(g+24|0,x[a+4>>2]);d=Ib(g+16|0,x[a>>2]);b=Ib(g+8|0,x[c+4>>2]);f=x[f>>2];d=x[d>>2];e=hb-16|0;hb=e;x[e>>2]=x[b>>2];x[e+8>>2]=f;while(1){b=x[e>>2];if(og(f,d)){cx(dx(b),dx(f));b=ex(e+8|0);ex(e);f=x[b>>2];continue}break}hb=e+16|0;x[c+4>>2]=b;qc(a,c+4|0);qc(a+4|0,c+8|0);qc(Cb(a),yc(c));x[c>>2]=x[c+4>>2];hb=g+32|0;b=x[c+4>>2];while(1){a=x[c+8>>2];if((a|0)!=(b|0)){a=a-16|0;x[c+8>>2]=a;Tj(a);continue}break}a=x[c>>2];if(a){fr(c);Hb(a)}hb=h+32|0}function WZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=JF(c);b:{if(b){pk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;ok(k,a);break b}sr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Ch(k,a)}Hi(i,k);Gc(k);l=e,m=Mi(a),x[l>>2]=m;l=f,m=Ni(a),x[l>>2]=m;Jg(k,a);Ab(g,k);xb(k);Dh(k,a);Hi(h,k);Gc(k);a=nk(a);break a}a=IF(c);c:{if(b){pk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;ok(k,a);break c}sr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Ch(k,a)}Hi(i,k);Gc(k);l=e,m=Mi(a),x[l>>2]=m;l=f,m=Ni(a),x[l>>2]=m;Jg(k,a);Ab(g,k);xb(k);Dh(k,a);Hi(h,k);Gc(k);a=nk(a)}x[j>>2]=a;hb=k+16|0}function Gk(a,b,c){var d=0,e=0,f=0,g=0;e=hb-48|0;hb=e;d=x[a+24>>2];g=x[d+24620>>2];a:{if(!((g|0)!=(b|0)|x[d+24624>>2]!=(c|0))){if(y[a+29|0]){break a}SL(d,1);break a}f=e+8|0;vc(f,d+24604|0,40);x[e+28>>2]=c;x[e+24>>2]=b;c=x[e+44>>2];es(f,x[e+40>>2]);zp(f,c);by(d,f);if((b|0)==(g|0)){break a}b=x[a+24>>2];d=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(d|0)){b=x[c>>2];b:{if(!b){break b}if(!(mb[x[x[b>>2]+116>>2]](b)|0)){break b}mb[x[x[b>>2]+108>>2]](b,0);mb[x[x[b>>2]+96>>2]](b);mb[x[x[b>>2]+124>>2]](b)}c=c+160|0;continue}break}b=x[a+24>>2];d=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(d|0)){b=x[c>>2];c:{if(!b){break c}if(mb[x[x[b>>2]+116>>2]](b)|0){break c}mb[x[x[b>>2]+108>>2]](b,1);mb[x[x[b>>2]+120>>2]](b)}c=c+160|0;continue}break}}v[a+29|0]=1;hb=e+48|0}function Cy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{f=a+1074312|0;if(j=Tb(f,77),k=0,l=x[(D(c,872)+b|0)+704>>2]&134218752,l?j:k){break a}g=x[a+480180>>2]!=2?c:0;e=D(g,872);if(!d){x[(b+e|0)+1380>>2]=x[b+48>>2];return}h=(b+e|0)+1457|0;c=y[h|0];b:{if(c){c=c-1|0;v[h|0]=c;if(c&255){break b}if(!Tb(f,16)&x[a+480180>>2]!=2){break a}x[(D(g,872)+b|0)+1380>>2]=x[b+48>>2]+1;return}c:{if(Tb(f,17)|y[a+480180|0]&3){break c}c=b+616|0;i=e+c|0;e=0;a=z[a+480188>>1];while(1){if(a>>>0<=(e&65535)>>>0){break c}if(y[c+841|0]?(c|0)!=(i|0):0){break a}c=c+872|0;e=e+1|0;continue}}v[h|0]=d}a=x[(D(g,872)+b|0)+1380>>2];x[b+56>>2]=a;if((a|0)==-1){break a}d:{if(x[b+60>>2]==-1){break d}if(!Tb(f,68)){break d}x[b+60>>2]=a}x[b+64>>2]=a;if(!Tb(f,103)){break a}w[b+68>>1]=65535}}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;c=ff(a,c);_d(e,x[a+28>>2]);h=a;a:{if(!c){d=0;if(fd(a,5)){break a}}d=hb-32|0;hb=d;f=x[a+28>>2];Ff(f,d+30|0);b:{c:{d:{e:{a=z[d+30>>1];if(a>>>0>=4001){i=x[b+12>>2];a=hb-16|0;hb=a;g=Xb(a,15779);dd(d,g);xb(g);hb=a+16|0;x[23604]=0;U(423,d+16|0,d|0,d+30|0);a=x[23604];x[23604]=0;if((a|0)==1){break e}a=x[i+1298464>>2];x[23604]=0;U(351,a|0,2,d+16|0);a=x[23604];x[23604]=0;if((a|0)==1){break d}xb(d+16|0);Db(d);a=4e3}eg(fj(x[b>>2],0),a);b=fj(x[b>>2],0);j=d,k=Bb(x[b>>2]),x[j+16>>2]=k;b=Bb(x[b+4>>2]);break b}b=P()|0;break c}b=P()|0;xb(d+16|0)}Db(d);T(b|0);p()}while(1){a=x[d+16>>2];if(Ob(a,b)){Ff(f,d);w[a>>1]=z[d>>1];Pe(d+16|0);continue}break}hb=d+32|0;d=c}_e(h,d);hb=e+16|0}function q8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(A[a+4>>2]<A[Cb(a)>>2]){d=hb-16|0;hb=d;a=pz(d,a);Bx(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+4;ic(a);hb=d+16|0;return}h=hb-32|0;hb=h;d=Cb(a);c=Wf(h+8|0,vg(a,rc(x[a>>2],x[a+4>>2])+1|0),rc(x[a>>2],x[a+4>>2]),d);Bx(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+4;g=hb-32|0;hb=g;f=Ib(g+24|0,x[a+4>>2]);d=Ib(g+16|0,x[a>>2]);b=Ib(g+8|0,x[c+4>>2]);f=x[f>>2];d=x[d>>2];e=hb-16|0;hb=e;x[e>>2]=x[b>>2];x[e+8>>2]=f;while(1){b=x[e>>2];if(og(f,d)){Bx(Mk(b),Mk(f));b=VK(e+8|0);VK(e);f=x[b>>2];continue}break}hb=e+16|0;x[c+4>>2]=b;qc(a,c+4|0);qc(a+4|0,c+8|0);qc(Cb(a),yc(c));x[c>>2]=x[c+4>>2];hb=g+32|0;b=x[c+4>>2];while(1){a=x[c+8>>2];if((a|0)!=(b|0)){a=a-4|0;x[c+8>>2]=a;bg(a);continue}break}a=x[c>>2];if(a){iz(c);Hb(a)}hb=h+32|0}function _Z(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=MF(c);b:{if(b){pk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;ok(k,a);break b}sr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Ch(k,a)}Ab(i,k);xb(k);l=e,m=Mi(a),v[l|0]=m;l=f,m=Ni(a),v[l|0]=m;Jg(k,a);Ab(g,k);xb(k);Dh(k,a);Ab(h,k);xb(k);a=nk(a);break a}a=LF(c);c:{if(b){pk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;ok(k,a);break c}sr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Ch(k,a)}Ab(i,k);xb(k);l=e,m=Mi(a),v[l|0]=m;l=f,m=Ni(a),v[l|0]=m;Jg(k,a);Ab(g,k);xb(k);Dh(k,a);Ab(h,k);xb(k);a=nk(a)}x[j>>2]=a;hb=k+16|0}function wR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=v[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=D(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=v[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=y[e+45|0];if(y[e+44|0]|c>>>0>64){break a}b=Lb(y[e+42|0]|y[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=y[a+470|0];if(d>>>0>128){break a}b=y[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=Vz(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Cr(y[a|0],y[c|0])?c:a;continue}}a=y[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function G5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;g=hb-16|0;hb=g;if(a){a=oc(g+8|0,a);f=x[a>>2];c=x[a+4>>2];a=hb-16|0;hb=a;x[a>>2]=f;x[a+4>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;b=hb+-64|0;hb=b;f=a;c=0;a:{if(!x[a+4>>2]){break a}c=x[f>>2];h=x[f+4>>2];a=32576;while(1){if((a|0)==33152){d=33152;while(1){a=d;if((a|0)!=33200){x[b+40>>2]=c;x[b+44>>2]=h;d=oc(b+32|0,x[a+8>>2]);e=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=e;e=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=e;d=a+12|0;if(!HL(b+8|0,b)){continue}}break}c=(a|0)!=33200;break a}x[b+56>>2]=c;x[b+60>>2]=h;d=oc(b+48|0,x[a+8>>2]);e=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=e;e=x[d+4>>2];x[b+16>>2]=x[d>>2];x[b+20>>2]=e;a=a+12|0;if(!HL(b+24|0,b+16|0)){continue}break}c=1}hb=b- -64|0;hb=f+16|0}hb=g+16|0;return c|0}function WK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;if(!(rc(x[a>>2],x[a+4>>2])>>>0>511|x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){d=hb-16|0;hb=d;f=Jc(64);x[23604]=0;g=S(788,f|0)|0;h=x[23604];x[23604]=0;a:{b:{if((h|0)!=1){f=lf(d,g);g=x[f>>2];x[23604]=0;g=W(848,g|0,b|0,c|0)|0;h=x[23604];x[23604]=0;c:{d:{if((h|0)!=1){if((g|0)==1){break d}zc(d+8|0);break c}a=P()|0;bg(f);break b}Mf(d+8|0,f)}bg(f);hb=d+16|0;d=x[d+8>>2];break a}a=P()|0;Hb(f)}T(a|0);p()}x[e+8>>2]=d;e:{f:{if(!td(d)){x[23604]=0;b=Q(847,b|0,c|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break f}x[e>>2]=b;US(e+8|0,Wd(e));bg(e);d=x[e+8>>2]}if(!td(d)){break e}x[23604]=0;R(432,a|0,e+8|0);a=x[23604];x[23604]=0;i=d;if((a|0)!=1){break e}}a=P()|0;bg(e+8|0);T(a|0);p()}bg(e+8|0)}hb=e+16|0;return i}function IK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);c=hb-80|0;hb=c;d=x[b>>2];b=x[b+4>>2];e=Yd(c+48|0);f=x[e+4>>2];x[c>>2]=x[e>>2];x[c+4>>2]=f;b=Xq(c+56|0,d,b,c);x[23604]=0;d=S(188,b|0)|0;e=x[23604];x[23604]=0;a:{if((e|0)==1){break a}x[23604]=0;d=W(859,b|0,c+8|0,d|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Rb(c+8|0,17471,4)|x[c+12>>2]){break b}g=a,h=Fd(B[c+16>>2],E(0)),B[g+4220>>2]=h;g=a,h=Fd(B[c+20>>2],E(0)),B[g+4224>>2]=h;g=a,h=Fd(B[c+24>>2],E(0)),B[g+4228>>2]=h;d=x[c+28>>2];if(d>>>0<=5){x[a+4232>>2]=d}x[a+4236>>2]=x[c+32>>2];v[a+4240|0]=y[c+36|0]!=0;v[a+4241|0]=y[c+37|0]!=0;v[a+4242|0]=y[c+38|0]!=0;v[a+4243|0]=y[c+39|0]!=0;v[a+4244|0]=y[c+40|0]!=0;vs(a)}yb(b);hb=c+80|0;return}a=P()|0;yb(b);T(a|0);p()}function Ko(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;x[d+28>>2]=0;a:{b:{c:{if(ud(y[nn(d+24|0,a,0)|0])){Pc(d+16|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[23604]=0;g=S(1045,x[d+16>>2])|0;e=x[23604];x[23604]=0;d:{e:{if((e|0)==1){break e}e=um(d+8|0,a);f=zc(d);h=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[23604]=0;ma(c|0,g|0,e|0,f|0,a+h|0,d+28|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){break e}$b(d+16|0);break d}b=V(0)|0;$b(d+16|0);_(b|0)|0;b=x[d+28>>2]|1;x[d+28>>2]=b;mn(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23604]=0;Z(91);a=x[23604];x[23604]=0;if((a|0)!=1){break b}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break c}T(a|0);p()}$()}kj(x[x[a>>2]-12>>2]+a|0,x[d+28>>2])}hb=d+32|0;break a}V(0)|0;Vb()}p()}return a}function D8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-16|0;hb=h;k=ff(a,c);_d(h,x[a+28>>2]);l=a;a:{if(!k){c=0;if(fd(a,5)){break a}}e=hb-48|0;hb=e;i=x[a+28>>2];lk(i,e+40|0);f=x[e+44>>2];if(!f&A[e+40>>2]>=257|f){x[e+40>>2]=256;x[e+44>>2]=0}f=x[e+40>>2];m=x[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=f>>>0){break b}Ff(i,e+38|0);g=Kb(e+24|0);x[23604]=0;Q(430,i|0,g|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){x[23604]=0;U(11,e+8|0,d|0,g|0);a=x[23604];x[23604]=0;if((a|0)==1){break e}x[23604]=0;a=Q(841,b|0,e+38|0)|0;j=x[23604];x[23604]=0;if((j|0)==1){break d}j=a;a=e+8|0;Ab(j,a);xb(a);xb(g);c=c+1|0;continue}break}c=P()|0;break c}c=P()|0;break c}c=P()|0;xb(e+8|0)}xb(g);T(c|0);p()}hb=e+48|0;c=k}_e(l,c);hb=h+16|0}function A5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb+-64|0;hb=f;x[f+56>>2]=d;a=Mf(a,f+56|0);d=zc(a+4|0);g=zc(a+24|0);h=zc(a+32|0);i=Sb(a+36|0);x[a+56>>2]=3;j=Sb(a+68|0);x[23604]=0;R(895,a|0,e|0);k=x[23604];x[23604]=0;a:{b:{c:{d:{if((k|0)!=1){hc(f+24|0,b,c);b=Yd(f+16|0);x[23604]=0;c=x[b+4>>2];x[f+8>>2]=x[b>>2];x[f+12>>2]=c;c=x[f+24>>2];Ea(899,f+32|0,c|0,x[f+28>>2],f+8|0);b=x[23604];x[23604]=0;if((b|0)==1){break d}x[23604]=0;U(896,a|0,f+32|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}yb(f+32|0);x[23604]=0;Y(897,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){break a}}e=P()|0;break b}e=P()|0;break b}e=P()|0;yb(f+32|0)}Vd(j);Of(i);ds(h);Ti(g);Si(d);te(a);te(f+56|0);T(e|0);p()}te(f+56|0);hb=f- -64|0;return a|0}function wM(a,b){var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=Kb(a);a=pd(b);x[e+8>>2]=a;f=pf(b);b=0;a:{while(1){b:{if(!Ob(a,f)){if(!b){break b}x[23604]=0;R(48,d|0,65533);a=x[23604];x[23604]=0;if((a|0)!=1){break b}break a}a=y[a|0];c:{d:{if(!b){if(a<<24>>24>=0){b=0;x[23604]=0;R(48,d|0,a|0);a=x[23604];x[23604]=0;if((a|0)!=1){break c}break a}if((a&224)==192){c=a&31;b=1;break c}if((a&240)==224){c=a&15;b=2;break c}c=65533;if((a&248)!=240){break d}c=a&7;b=3;break c}if((a&192)!=128){c=0;x[23604]=0;R(48,d|0,65533);g=x[23604];x[23604]=0;b=0;if((g|0)==1){break a}}c=a&63|c<<6;b=b-1|0;if(b){break c}}b=0;x[23604]=0;R(48,d|0,c|0);a=x[23604];x[23604]=0;c=0;if((a|0)==1){break a}}a=x[Le(e+8|0)>>2];continue}break}hb=e+16|0;return}a=P()|0;Gc(d);T(a|0);p()}function dC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=x[b>>2];d=Kc(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=hb-32|0;hb=i;d=c-d|0;f=x[Cb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=hb-16|0;hb=f;e=zi(f,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){ic(e);hb=f+16|0}else{zq(d);d=d+2|0;x[e+4>>2]=d;continue}break}break b}f=Cb(b);e=pj(i+8|0,qj(b,Kc(x[b>>2],e)+d|0),Kc(x[b>>2],x[b+4>>2]),f);h=hb-16|0;hb=h;d=xo(h,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){zq(f);f=x[d>>2]+2|0;x[d>>2]=f;continue}break}Hd(d);hb=h+16|0;xd(b,e);yi(e)}hb=i+32|0;break a}if(c>>>0<d>>>0){Id(b,e+(c<<1)|0)}}c=Qb(x[a>>2],x[a+8>>2],c<<1);if(c){d=x[b>>2];hc(g+8|0,d,Kc(d,x[b+4>>2])<<1);qd(g,a,x[g+8>>2],x[g+12>>2])}hb=g+16|0;return c|0}function ZW(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-192|0;hb=c;b=c+16|0;ih(b,a);x[23604]=0;R(77,c+32|0,b|0);a=x[23604];x[23604]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[23604]=0;a=Q(78,c+48|0,c+32|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}xb(c+32|0);xb(c+16|0);b=x[x[a>>2]-12>>2];x[23604]=0;d=ga(61)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}x[23604]=0;U(62,c+8|0,a+b|0,d|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}$b(c+8|0);b=a+x[x[a>>2]-12>>2]|0;x[b+4>>2]=x[b+4>>2]&-75;x[b+4>>2]=x[b+4>>2]|8;x[23604]=0;b=Q(83,a|0,c+32|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}a=Ck(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>2];hf(b);hb=c+192|0;a=a?0:d;break a}b=P()|0;break d}b=P()|0;xb(c+32|0)}xb(c+16|0);break b}b=P()|0;hf(a)}T(b|0);p()}return a|0}function Yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-48|0;hb=g;h=a+8|0;c=x[a+8>>2];j=yc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Vt(d,c,a+d|0);x[h>>2]=c;x[i>>2]=a+x[i>>2];break a}x[g+24>>2]=c-e>>1;x[g+44>>2]=1;d=g+24|0;c=x[_c(d,g+44|0)>>2];c=Wf(d,c,c>>>2|0,x[a+16>>2]);e=Ib(g+16|0,x[a+4>>2]);f=x[Ib(g+8|0,x[a+8>>2])>>2];d=hb-32|0;hb=d;e=x[e>>2];x[d+24>>2]=e;e=pl(d+8|0,c+8|0,Ht(f,e));f=x[e>>2];while(1){if(x[e+4>>2]!=(f|0)){k=f;f=x[d+24>>2];Pp(k,z[f>>1]|z[f+2>>1]<<16);f=x[e>>2]+4|0;x[e>>2]=f;Fe(d+24|0);continue}break}Hd(e);hb=d+32|0;qc(a,c);qc(i,c+4|0);qc(h,c+8|0);qc(j,yc(c));Vf(c);c=x[a+8>>2]}Pp(c,z[b>>1]|z[b+2>>1]<<16);x[h>>2]=x[h>>2]+4;hb=g+48|0}function Gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;v[e+15|0]=0;w[e+12>>1]=0;n=D(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){v[e+11|0]=0;NR(a,e+15|0,e+12|0,e+11|0);i=y[e+11|0];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!af(a,e+10|0)){break c}f=y[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;v[e+11|0]=l;v[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}hb=e+16|0}function iM(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:jp(a,E(1));En(a,E(3.725290298461914e-9));ip(a,E(268435456));hp(a,0);break b;case 1:jp(a,E(32));En(a,E(4.656612873077393e-10));ip(a,E(2147483648));hp(a,0);break b;case 2:jp(a,E(2));En(a,E(7.450580596923828e-9));ip(a,E(134217728));hp(a,1);break b;default:jp(a,E(1));En(a,E(7.450580596923828e-9));ip(a,E(134217728));hp(a,1);Wx(a,0);Vx(a,1);Ux(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}jp(a,E(.75));En(a,E(7.450580596923828e-9));ip(a,E(134217728));hp(a,1);Wx(a,0);b=(b|0)==4;Vx(a,b?2:3);Ux(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}Wx(a,1);Vx(a,0);Ux(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function pH(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:mb[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function Ln(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=hb-16|0;hb=g;if(e){x[e>>2]=0}a:{h=x[a+484344>>2];if(!pe(h,x[a+484348>>2],b)){break a}i=ac(h,b);k=x[i+48>>2];b=cd(x[i>>2],x[k+12>>2],c,d);f=y[b+5|0];b:{c:{d:{e:{j=y[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}x[g+12>>2]=1;h=0;if((j|0)!=17){break b}h=x[a+480180>>2]==4;break b}x[g+12>>2]=2;h=0}x[g+8>>2]=x[i+12>>2]+(c^-1);d=0;c=x[Fb(g+8|0,g+12|0)>>2];a=c;while(1){f:{if(a){b=D(Bg(x[k+12>>2]),6)+b|0;if(y[b+3|0]==34){break f}c=d}f=(j-37&255)>>>0<254?f:c?f:f<<8;if(!e){break a}x[e>>2]=c;break a}i=f<<8;f=y[b+5|0]|(h?f>>>0<256?i+-8192|0:i:i);d=d+1|0;a=a-1|0;continue}}hb=g+16|0;return f}function DR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=x[b>>2];while(1){if((i|0)==128){eg(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(Fg(x[a>>2])&-2)){break c}Yc(a,c+(f<<10)|0);if(!_z(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((Fg(x[a>>2])|0)!=(d+D(f,i)|0)){break a}}Yc(a,c+D(f,z[e>>1])|0);h=_z(a,64,1)?h:k}Yc(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(Fg(x[a>>2])|0)){break d}}if(c>>>0>=255){Zz(b,254,65534);Zz(b,255,65535)}l=h}a=l&65535}else{j=z[cc(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function kv(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb+-64|0;hb=e;x[e+60>>2]=d;a:{f=x[b>>2];b:{if(!(mb[x[x[f>>2]+36>>2]](f,c,d)|0)){xh(a);break b}ul(e+40|0,x[b>>2],x[b+4>>2]);b=x[b>>2];d=x[x[b>>2]+24>>2];x[23604]=0;b=S(d|0,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}x[e+36>>2]=b-c;g=x[Fb(e+60|0,e+36|0)>>2];b=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=b;b=hb-16|0;hb=b;d=e+16|0;f=ul(b+8|0,x[d>>2],x[d+4>>2]);x[23604]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;X(158,e+48|0,b|0,c|0,g|0);c=x[23604];x[23604]=0;c:{if((c|0)!=1){be(d);hb=b+16|0;break c}a=P()|0;be(d);T(a|0);p()}b=Yd(e+24|0);c=x[e+52>>2];x[e+8>>2]=x[e+48>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;ev(a,e+8|0,e)}hb=e- -64|0;return}a=P()|0;be(e+40|0);T(a|0);p()}function Po(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}f=1072693248;g=-1023;if((b|0)!=1072693248){f=b;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;f=b;g=-1077}b=f+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=x[b>>2];d=_f(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=hb-32|0;hb=i;d=c-d|0;f=x[Cb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=hb-16|0;hb=f;e=sz(f,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){ic(e);hb=f+16|0}else{Pz(d);d=d+32|0;x[e+4>>2]=d;continue}break}break b}f=Cb(b);e=ft(i+8|0,Dp(b,_f(x[b>>2],e)+d|0),_f(x[b>>2],x[b+4>>2]),f);h=hb-16|0;hb=h;d=BP(h,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){Pz(f);f=x[d>>2]+32|0;x[d>>2]=f;continue}break}Hd(d);hb=h+16|0;xd(b,e);DP(e)}hb=i+32|0;break a}if(c>>>0<d>>>0){Id(b,e+(c<<5)|0)}}if(Qb(x[a>>2],x[a+8>>2],c<<5)){c=x[b>>2];hc(g+8|0,c,_f(c,x[b+4>>2])<<5);qd(g,a,x[g+8>>2],x[g+12>>2])}hb=g+16|0}function pda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=x[b>>2];d=ch(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=hb-32|0;hb=i;d=c-d|0;f=x[Cb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>4>>>0){f=hb-16|0;hb=f;e=Jo(f,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){ic(e);hb=f+16|0}else{$t(d);d=d+16|0;x[e+4>>2]=d;continue}break}break b}f=Cb(b);e=Cv(i+8|0,Gv(b,ch(x[b>>2],e)+d|0),ch(x[b>>2],x[b+4>>2]),f);h=hb-16|0;hb=h;d=ZD(h,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){$t(f);f=x[d>>2]+16|0;x[d>>2]=f;continue}break}Hd(d);hb=h+16|0;xd(b,e);iE(e)}hb=i+32|0;break a}if(c>>>0<d>>>0){Id(b,e+(c<<4)|0)}}if(Qb(x[a>>2],x[a+8>>2],c<<4)){c=x[b>>2];hc(g+8|0,c,ch(c,x[b+4>>2])<<4);qd(g,a,x[g+8>>2],x[g+12>>2])}hb=g+16|0}function aN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;i=-1;a:{if(!Yx(a,b,2)){break a}f=x[b+656>>2];d=a+1074312|0;g=Tb(d,31);h=x[b+740>>2];if(h?0:g){break a}h=h-Tb(d,31)|0;g=x[a+480180>>2];d=(g|0)==4096;j=f+88|0;f=d?64:(g|0)==16384?192:512;d=Ap(j,h,f,d?255:64)-(f>>>1|0)|0;if(y[b+746|0]&16){i=up(a,b,!(x[b+88>>2]&32768),d);break a}if(cj(x[b+656>>2])){if((d|0)==w[b+772>>1]){break a}k=b,l=Vc(d),w[k+772>>1]=l;v[b+851|0]=y[b+851|0]|64;break a}a=Xi(a);x[e+12>>2]=d;b:{if((d|0)<0){x[e+12>>2]=0-d;Rh(e+12|0,255);a=(x[e+12>>2]<<2)+(a?38688:37664)|0;break b}Rh(e+12|0,255);a=(x[e+12>>2]<<2)+(a?37664:38688)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];k=c,l=Ec(Kia(Jia(b,d,a,a>>31),lb,65536,0),lb),x[k>>2]=l}hb=e+16|0;return i}function jD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=hb-16|0;hb=h;f=Pb(b);d=Eb(x[b+4>>2],y[b+11|0]);i=Pb(c);g=Eb(x[c+4>>2],y[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(Mp(i,g,y[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=Ib(h+8|0,Ee(Ee(pd(b),e),1));d=Ib(h,pf(b));AC(b,x[c>>2],x[d>>2]);break c}if(!Qc(x[b+4>>2],y[b+11|0])){break c}f=Pb(b);d=Eb(x[b+4>>2],y[b+11|0]);i=Pb(c);g=Eb(x[c+4>>2],y[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=v[d|0];d=d+1|0;if(!tc(v[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Kb(a);break b}dd(a,b)}hb=h+16|0}function CG(a,b,c,d,e,f){var g=0;g=hb-80|0;hb=g;a:{if((f|0)>=16384){Ed(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Ed(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}Ed(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Ed(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}Ed(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;hb=g+80|0}function W8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;c=Bg(x[x[a+48>>2]+12>>2]);a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((Vj(x[a>>2],x[a+4>>2])|0)!=(c|0)){break b}b=hb-16|0;hb=b;d=Bb(x[a>>2]);a=Bb(x[a+4>>2]);sh(b+8|0);e=zs(a,d);c=hb-16|0;hb=c;x[c+8>>2]=d;while(1){if((e|0)>0){a=x[c+8>>2];d=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;e=e-1|0;dk(c+8|0);continue}break}hb=c+16|0;hb=b+16|0;break a}e=f+8|0;sh(e);c=aT(f+16|0,c,e);qL(a);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];e=Cb(c);g=Cb(a),h=x[e>>2],x[g>>2]=h;x[e>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Zj(c);x[a+12>>2]=b}hb=f+32|0}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>18|0;p=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){i=(e<<1)+p|0;j=w[i>>1];x[(e<<2)+b>>2]=j+((D(w[i+4>>1]-j|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Ub(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function Cw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=uH(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}hb=e+16|0;return c}function tR(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!Qb(x[a>>2],x[a+8>>2],1024)){x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;a=64;while(1){if(a){d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}Xz(c+8|0,b);qd(c+16|0,a,x[c+8>>2],x[c+12>>2])}hb=c+32|0}function r2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-80|0;hb=d;a=x[a+4>>2];fv(d+16|0,b);x[23604]=0;b=Q(1,d|0,17617)|0;e=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[23604]=0;U(2,d+32|0,d+16|0,b|0);e=x[23604];x[23604]=0;if((e|0)==1){break h}x[23604]=0;U(422,d+48|0,d+32|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break g}x[23604]=0;R(962,d- -64|0,d+48|0);c=x[23604];x[23604]=0;if((c|0)==1){break f}c=x[x[a>>2]+8>>2];x[23604]=0;R(c|0,a|0,d- -64|0);a=x[23604];x[23604]=0;if((a|0)==1){break e}xb(d- -64|0);xb(d+48|0);xb(d+32|0);xb(b);xb(d+16|0);hb=d+80|0;return}a=P()|0;break a}a=P()|0;break b}a=P()|0;break c}a=P()|0;break d}a=P()|0;xb(d- -64|0)}xb(d+48|0)}xb(d+32|0)}xb(b)}xb(d+16|0);T(a|0);p()}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>10&4194048;p=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){i=e+p|0;j=v[i|0];x[(e<<2)+b>>2]=((D(v[i+2|0]-j|0,o)|0)/16384|0)+(j<<8);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Ub(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function zj(a,b){var c=0,d=0,e=0,f=0;c=hb+-64|0;hb=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;Sm(d,e);a:{b:{if(ud(y[nn(c+56|0,a,1)|0])){d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23604]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;U(94,c+40|0,d|0,c+8|0);b=x[23604];x[23604]=0;c:{if((b|0)!=1){b=dh(c+24|0,-1,-1);b=WD(x[c+48>>2],x[c+52>>2],x[b+8>>2],x[b+12>>2])?e|4:e;break c}_(V(0)|0)|0;b=e|1;mn(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23604]=0;Z(91);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break b}T(a|0);p()}$()}kj(x[x[a>>2]-12>>2]+a|0,b)}hb=c- -64|0;return a}V(0)|0;Vb()}p()}function yy(a,b,c){var d=0,e=0,f=0,g=0;d=Kb(a);a=y[b+11|0];e=x[b+4>>2];x[23604]=0;R(45,d|0,Qc(e,a)|0);a=x[23604];x[23604]=0;if((a|0)!=1){a:{while(1){if(Qc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Wi(b,f)>>2];g=e&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|(e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}else{x[23604]=0;R(46,d|0,a<<24>>24);a=x[23604];x[23604]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[23604]=0;R(46,d|0,a<<24>>24);a=x[23604];x[23604]=0;if((a|0)!=1){break b}break a}x[23604]=0;R(46,d|0,63);a=x[23604];x[23604]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=P()|0;xb(d);T(a|0);p()}function o_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-416|0;hb=h;d=h+416|0;x[h+12>>2]=d;c=hb-144|0;hb=c;x[c+28>>2]=c+132;i=c+32|0;QF(x[a+8>>2],i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;g=rc(e,x[h+12>>2]);f=hb-16|0;hb=f;i=Yh(f+8|0,x[a+8>>2]);a=rG(e,c+12|0,g,c+16|0);Xh(i);hb=f+16|0;if((a|0)==-1){Fr(12468);p()}x[h+12>>2]=e+(a<<2);hb=c+144|0;f=hb-16|0;hb=f;i=f+8|0;a=hb-32|0;hb=a;Wo(a+24|0,e,x[h+12>>2]);h=a+16|0;e=x[a+24>>2];g=x[a+28>>2];c=hb-16|0;hb=c;x[c+8>>2]=b;while(1){if((e|0)!=(g|0)){UG(c+8|0,x[e>>2]);e=e+4|0;continue}break}hj(h,g,c+8|0);hb=c+16|0;b=x[a+16>>2];x[a+8>>2]=x[a+20>>2];yd(i,b,a+8|0);hb=a+32|0;hb=f+16|0;hb=d;return x[f+12>>2]}function hh(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0;f=$J(a);h=a+4208|0;c=E(E(B[zb(h,4)>>2]*E(1.899999976158142))+E(.10000000149011612));g=B[a+4268>>2];d=me(E(10),E(E(E(E(E(x[((b<<2)+a|0)+4292>>2])/g)*E(-60))/E(E(B[zb(h,3)>>2]*E(19.899999618530273))+E(.10000000149011612)))/E(20)));c=E(E(me(d,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-dp(c>E(1)?E(3.1415927410125732):E(f*E(E(6.2831854820251465)/g)))));a:{if(c==E(0)){break a}if(!Sl(c)){break a}g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(c>E(0)){e=E(M(c))}c=E(E(e-f)/g);if(E(F(c))>E(1)){c=E(E(E(-f)-e)/g)}e=wf(c)}b=(b<<3)+a|0;B[b+4404>>2]=e;B[b+4400>>2]=d;c=B[a+4272>>2];c=E(c*c);e=E(E(1)-c);d=E(d*d);return E(E(E(e*E(d/E(E(1)-E(c*d))))*e)+c)}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;n=w[e+40246>>1];o=w[e+40244>>1];p=w[e+40242>>1];e=w[e+40240>>1];f=0;while(1){if((f|0)!=2){g=(f<<1)+m|0;x[(f<<2)+b>>2]=(((D(w[g>>1],p)+D(w[g-4>>1],e)|0)+D(w[g+4>>1],o)|0)+D(w[g+8>>1],n)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Ub(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function J5(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=hb-48|0;hb=b;c=Kb(b+32|0);x[23604]=0;Y(888,b+16|0);a=x[23604];x[23604]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=Bb(x[b+16>>2]),x[f+8>>2]=g;d=1;while(1){e=Bb(x[b+20>>2]);a=x[b+8>>2];if(!Ob(a,e)){a=Qf(Pb(c));Vd(b+16|0);xb(c);break b}if(!d){x[23604]=0;Q(889,c|0,14481)|0;a=x[23604];x[23604]=0;if((a|0)==1){break d}a=x[b+8>>2]}x[23604]=0;Q(753,c|0,a|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break d}Wp(b+8|0);d=0;continue}}a=V(0)|0;break c}a=V(0)|0;Vd(b+16|0)}xb(c);_(a|0)|0;a=0;x[23604]=0;X(887,6946,0,0,0);c=x[23604];x[23604]=0;if((c|0)==1){break a}$()}hb=b+48|0;return a|0}b=P()|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){V(0)|0;Vb();p()}T(b|0);p()}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;od(c,2);v[d+16|0]=y[b+13|0];v[d|0]=64;e=d+16|0;i=c,j=y[Wb(e,d)|0]<<2,w[i+30>>1]=j;x[c+24>>2]=(y[b+14|0]|y[b+15|0]<<8)<<1;Wj(d,2,b+1|0);Dc(e,d);ze(c+43|0,e);xb(e);e=Xc(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}g=y[b+22|0]|y[b+23|0]<<8|(y[b+24|0]<<16|y[b+25|0]<<24);x[c>>2]=g;f=y[b+26|0]|y[b+27|0]<<8|(y[b+28|0]<<16|y[b+29|0]<<24);x[c+4>>2]=f;a=y[b+30|0]|y[b+31|0]<<8|(y[b+32|0]<<16|y[b+33|0]<<24);h=a-(a>>>0>f>>>0)|0;x[c+8>>2]=h;a=y[b|0];if(a&4){w[c+34>>1]=z[c+34>>1]|2;a=y[b|0]}if(a&8){w[c+34>>1]=z[c+34>>1]|4;a=y[b|0]}if(!(a&16)){break a}id(e,16);Lf(e,9);x[c+8>>2]=h>>>1;x[c+4>>2]=f>>>1;x[c>>2]=g>>>1}hb=d+32|0}function cA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;d=y[a|0];if(d&1){v[b+12|0]=y[b+12|0]|1;d=y[a|0]}if(d&2){v[b+12|0]=y[b+12|0]|4;d=y[a|0]}if(d&4){v[b+12|0]=y[b+12|0]|2;d=y[a|0]}if(d&16){v[b+12|0]=y[b+12|0]|16;d=y[a|0]}if(d&32){v[b+12|0]=y[b+12|0]|8}v[e+15|0]=y[a+1|0];v[e+14|0]=25;Zg(b,y[Wb(e+15|0,e+14|0)|0]);v[b+15|0]=y[a+2|0];v[b+16|0]=y[a+3|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];g=x[b>>2];i=ie(g,x[b+4>>2]);b=0;while(1){if((b|0)!=(i|0)){h=zb(g,b);f=(b<<2)+a|0;d=y[f+6|0]|y[f+7|0]<<8;w[h>>1]=d;a:{if(!b){break a}j=d;d=z[zb(g,b-1|0)>>1];if(j>>>0>=d>>>0){break a}w[h>>1]=d+1}k=h,l=Yb((y[f+8|0]|y[f+9|0]<<8)<<16>>16>>c,0,64),v[k+2|0]=l;b=b+1|0;continue}break}hb=e+16|0}function wG(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=jw(13725);if(y[b|0]?b:0){break a}b=jw(D(a,12)+78736|0);if(y[b|0]?b:0){break a}b=jw(14005);if(y[b|0]?b:0){break a}b=14614}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14614;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!Vi(e,14614)){break e}if(Vi(e,13387)){break d}}if(!a){c=78808;if(y[e+1|0]==46){break c}}return 0}c=x[116895];if(c){while(1){if(!Vi(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=Ld(36);if(c){x[c+4>>2]=20;x[c>>2]=78704;b=c+8|0;vc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[116895];x[116895]=c}c=a|c?c:78808}return c}function gI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;a:{b:{c:{d:{e:{if((b|0)>=0){g=a;a=x[a+32>>2];if((Bg(a)|0)>(b|0)){break e}}a=ba(8)|0;x[23604]=0;b=Q(54,f|0,10598)|0;c=x[23604];x[23604]=0;if((c|0)==1){break d}a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break b}c=P()|0;xb(b);break c}d=(a+(b<<5)|0)+480280|0;c=c?134218752:0;x[d>>2]=c|x[d>>2]&-134218753;d=(a+D(b,872)|0)+1075080|0;x[d>>2]=c|x[d>>2]&-134218753;a=z[a+480188>>1];d=a>>>0<=256?256:a;b=b+1|0;g=x[g+32>>2];while(1){if((a|0)==(d|0)){break a}e=g+D(a,872)|0;if((b|0)==z[e+1075778>>1]){e=e+1075080|0;x[e>>2]=c|x[e>>2]&-134218753}a=a+1|0;continue}}c=P()|0;ca(a|0)}T(c|0)}p()}hb=f+16|0}function ofa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=hb-528|0;hb=b;e=-1;a:{if(!Nf(a,1468)){break a}al(a,1464);c=b+524|0;KR(a,c);if(!ce(c,27257)){e=0;if(!ce(b+524|0,15373)){break a}}al(a,20);c=1;while(1){if((c&65535)>>>0<=31){if(HR(a,b)){c=c+1|0;d=bA(b)+d|0;continue}else{e=-1;break a}}break}e=0;if(d>>>0>40){break a}d=b+520|0;c=hb-16|0;hb=c;b:{if(!Nf(a,2)){v[c|0]=0;YB(d,c);break b}ql(c+8|0,d);aA(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;if(y[b+520|0]>128){break a}d=hd(b+520|0);c=hb-16|0;hb=c;c:{if(!Nf(a,512)){sR(b);break c}lu(c+8|0,b);aA(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;c=0;e=1;a=y[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=y[d|0]){continue}break}e=0}hb=b+528|0;return e|0}
function X$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=x[b+44>>2];i=x[b+24>>2];if(h>>>0<i>>>0){x[b+44>>2]=i;h=i}m=-1;n=-1;o=f&24;a:{if(!o|(e|0)==1&(o|0)==24){break a}if(h){j=h-Pb(b+32|0)|0;k=j>>31}b:{c:{switch(e|0){case 1:if(f&8){g=x[b+12>>2]-x[b+8>>2]|0;l=g>>31;break b}g=i-x[b+20>>2]|0;l=g>>31;break b;case 0:break b;case 2:break c;default:break a}}g=j;l=k}d=d+l|0;c=c+g|0;d=g>>>0>c>>>0?d+1|0:d;if((d|0)<0|(c>>>0>j>>>0&(d|0)>=(k|0)|(d|0)>(k|0))){break a}e=f&8;d:{if(!(c|d)){break d}if(x[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!i){break a}}if(e){e=x[b+8>>2];jn(b,e,c+e|0,h)}if(f&16){rw(b,x[b+20>>2],x[b+28>>2]);Jr(b,c)}m=c;n=d}dh(a,m,n)}function AE(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=hb-80|0;hb=g;ay(x[a+24>>2]);v[x[a+24>>2]+1298420|0]=x[a+52>>2]!=0;c=$f(g+32|0,d,c,b);i=B[a+48>>2];j=x[a+32>>2];x[g+8>>2]=x[c+8>>2];d=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=d;d=hb-16|0;hb=d;x[d+8>>2]=x[g+8>>2];c=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=c;c=VI(g+48|0);x[c+8>>2]=j;x[c+4>>2]=0;x[c>>2]=f;f=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=f;x[c+20>>2]=x[d+8>>2];B[c+24>>2]=i;x[c>>2]=e;hb=d+16|0;while(1){if(b){d=x[a+24>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;d=YI(d,x[Eq(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|h)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=g+80|0;return h}function On(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){v[b+809|0]=c;break a}c=y[b+809|0]}e=x[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=x[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){Nn(a,b,(d&240)>>>4|0,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){Mn(a,b,f,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+851|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}c=c-(a<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if((e|0)!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}h=b,i=Yb(c,0,256),x[h+688>>2]=i}function vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=hb-16|0;hb=i;d=x[Ib(i+8|0,Bb(x[a+4>>2]))>>2];f=hb-32|0;hb=f;e=d;d=x[a>>2];g=(no(e,Bb(d))<<1)+d|0;e=Py(b,c);a:{if((e|0)<=0){break a}d=x[Cb(a)>>2];h=x[a+4>>2];if((e|0)<=d-h>>1){k=h-g|0;j=k>>1;b:{if((e|0)<=(j|0)){d=c;break b}x[f>>2]=b;x[f>>2]=x[f>>2]+(j<<1);d=x[f>>2];MO(a,d,c,e-j|0);if((k|0)<=0){break a}}RO(a,g,h,(e<<1)+g|0);Zk(b,d,g);break a}d=Cb(a);e=pj(f,qj(a,Kc(x[a>>2],h)+e|0),g-x[a>>2]>>1,d);h=hb-16|0;hb=h;c=xo(h,e+8|0,Py(b,c));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){oj(d,z[b>>1]);d=x[c>>2]+2|0;x[c>>2]=d;b=b+2|0;continue}break}Hd(c);hb=h+16|0;g=dq(a,e,g);yi(e)}Ib(f+24|0,g);hb=f+32|0;hb=i+16|0;return a|0}function fi(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=44832;c=a+24|0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;b=Sb(a+44|0);d=Sb(b+12|0);e=Sb(b+24|0);f=Sb(b+36|0);x[23604]=0;R(851,b|0,0);g=x[23604];x[23604]=0;if((g|0)==1){a=P()|0;sc(f);sc(e);ss(d);ss(b);T(a|0);p()}w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;d=x[a+16>>2];x[d+946300>>2]=x[d+946300>>2]+1;x[23604]=0;d=S(852,a+92|0)|0;e=x[23604];x[23604]=0;a:{if((e|0)!=1){b=a+4200|0;x[c>>2]=d;d=y[a+4200|0];c=x[a+16>>2];e=x[a+20>>2];while(1){if((e|0)==((c+D(d,160)|0)+906300|0)|d>>>0>248){break a}d=d+1|0;v[b|0]=d;continue}}a=P()|0;GK(b);T(a|0);p()}return a}function jV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;od(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=xq(a+4|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=f;c=xq(a+8|0,a);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=c;v[e+15|0]=127;v[e+14|0]=y[a+15|0];g=b,h=(((y[Wb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;d=y[a+12|0];if(d>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=d&240}d=(y[a+13|0]|y[a+14|0]<<8)<<1;x[b+24>>2]=d;d=y[a+13|0]|y[a+14|0]<<8?d:16726;x[b+24>>2]=d;g=b,h=(D(xu(0,y[a+12|0]<<28>>24),d)>>>0)/8363|0,x[g+24>>2]=h;if(c>>>0>f>>>0){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}hb=e+16|0}function pp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-16|0;hb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Oc(a)>>>0>=b>>>0){break a}k=d,l=Eb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Xj(x[_c(d+12|0,d+8|0)>>2]);if((Oc(a)|0)==(b|0)){break a}e=hb-16|0;hb=e;f=Eb(x[a+4>>2],y[a+11|0]);b:{c:{h=io(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Oc(a)>>>0<b>>>0){si(e+8|0,c);break e}x[23604]=0;R(51,e+8|0,c|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=re(c);g=Pb(a);c=Eb(x[a+4>>2],c)}b=Te(b,g,c+1|0);if(i){Hb(g)}if(!h){cg(a,j);oe(a,f);Ad(a,b);break b}bf(a,f);break b}_(V(0)|0)|0;$()}hb=e+16|0}hb=d+16|0;return}dg();p()}function uy(a,b,c){var d=0,e=0,f=0,g=0;d=hb+-64|0;hb=d;e=x[a>>2];f=x[e-4>>2];g=x[e-8>>2];x[d+28>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+56>>2]=0;e=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+g|0;a:{if(Hg(f,c,0)){x[d+56>>2]=1;mb[x[x[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=x[d+32>>2]==1?a:0;break a}mb[x[x[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:e=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}e=x[d+24>>2]}hb=d- -64|0;return e}function _y(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;i=Vk(a,b);a:{if((i|0)==255){break a}if(Lj(x[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=Jia(1<<20-f,0,c,0);g=lb;c=c+24858e3|0;g=c>>>0<24858e3?g+1|0:g;c=Uc(Mia(c,g,49716e3,0),lb)}if(e){w[h+14>>1]=(b&3)+c;w[h+12>>1]=1023;c=z[Wc(h+14|0,h+12|0)>>1]}g=Ys(i);e=a+8|0;j=Gb(e,i),k=(f<<10|c)>>>8|(d?0:32),v[j|0]=k;Qg(x[a>>2],x[a+4>>2],b,g|160,c&255);c=Gb(e,i);Qg(x[a>>2],x[a+4>>2],b,g|176,y[c|0]);v[a+534|0]=1}hb=h+16|0}function R9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-16|0;hb=d;x[d+12>>2]=b;if(b>>>0<1073741808){a:{if(Zm(a)>>>0>=b>>>0){break a}k=d,l=Eb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=El(x[_c(d+12|0,d+8|0)>>2]);if((Zm(a)|0)==(b|0)){break a}e=hb-16|0;hb=e;i=1;f=b+1|0;c=Zm(a);g=Eb(x[a+4>>2],y[a+11|0]);b:{c:{j=Uo(b);d:{if(j){h=x[a>>2];b=a;c=g;break d}e:{if(b>>>0>c>>>0){dj(e+8|0,f);break e}x[23604]=0;R(1172,e+8|0,f|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}}f=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=re(c);h=Pb(a);c=Eb(x[a+4>>2],c)}b=_h(b,h,c+1|0);if(i){Hb(h)}if(!j){cg(a,f);oe(a,g);Ad(a,b);break b}bf(a,g);break b}_(V(0)|0)|0;$()}hb=e+16|0}hb=d+16|0;return}dg();p()}function Iea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb+-64|0;hb=c;i=c,j=cf(a)>>>5|0,w[i+32>>1]=j;w[c+16>>1]=3999;h=b+480190|0;d=z[Wc(c+32|0,c+16|0)>>1];w[h>>1]=d;g=1;while(1){f=g&65535;if(d>>>0>=f>>>0){d=Rj(b,f);e=c+32|0;wt(a,e);od(d,0);jj(c,2,e);e=c+16|0;Dc(e,c);Bc(((f<<5)+b|0)+946304|0,e);xb(e);x[d+24>>2]=8287;i=c,j=Lb(z[c+60>>1]),w[i+16>>1]=j;w[c>>1]=64;i=d,j=z[Wc(e,c)>>1]<<2,w[i+30>>1]=j;i=d,j=dc(x[c+52>>2])&-2,x[i>>2]=j;e=Lb(z[c+62>>1]);i=zb(d+68|0,0),j=e,x[i>>2]=j;e=Lb(z[c+56>>1]);f=Lb(z[c+58>>1]);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>A[d>>2]){break a}x[d+16>>2]=f;x[d+12>>2]=e<<1;w[d+34>>1]=z[d+34>>1]|8}g=g+1|0;d=z[h>>1];continue}break}hb=c- -64|0}function nea(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-192|0;hb=c;b=c+16|0;ih(b,a);x[23604]=0;R(77,c+32|0,b|0);a=x[23604];x[23604]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[23604]=0;a=Q(78,c+48|0,c+32|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}xb(c+32|0);xb(c+16|0);b=x[x[a>>2]-12>>2];x[23604]=0;d=ga(61)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}x[23604]=0;U(62,c+8|0,a+b|0,d|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}$b(c+8|0);x[23604]=0;b=Q(79,a|0,c+32|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}a=Ck(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=z[c+32>>1];hf(b);hb=c+192|0;a=(a?0:d)&65535;break a}b=P()|0;break d}b=P()|0;xb(c+32|0)}xb(c+16|0);break b}b=P()|0;hf(a)}T(b|0);p()}return a|0}function Ada(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){c=hb-16|0;hb=c;if(bh(119304647)>>>0<b>>>0){Sc();p()}e=D(b,36);d=Jc(e);x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=Cb(a),g=b+D(x[c+12>>2],36)|0,x[f>>2]=g;hb=c+16|0;d=hb-16|0;hb=d;x[d>>2]=a;b=x[a+4>>2];x[d+4>>2]=b;x[d+8>>2]=b+e;b=x[d+4>>2];e=x[d+8>>2];while(1){if((b|0)==(e|0)){ic(d);hb=d+16|0}else{c=Zb(b,0,36);x[c>>2]=0;x[c+4>>2]=0;w[c+22>>1]=0;w[c+24>>1]=0;w[c+26>>1]=0;w[c+28>>1]=0;v[c+21|0]=64;v[c+19|0]=64;v[c+20|0]=100;v[c+15|0]=0;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;x[c+8>>2]=0;x[c+12>>2]=0;w[c+30>>1]=0;w[c+32>>1]=0;b=b+36|0;x[d+4>>2]=b;continue}break}}return a|0}function eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;n=w[e+40246>>1];o=w[e+40244>>1];p=w[e+40242>>1];e=w[e+40240>>1];f=0;while(1){if((f|0)!=2){g=f+m|0;x[(f<<2)+b>>2]=(((D(v[g|0],p)+D(v[g-2|0],e)|0)+D(v[g+2|0],o)|0)+D(v[g+4|0],n)<<8)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Ub(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function ZK(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=hb-48|0;hb=e;d=Kb(e+32|0);x[23604]=0;R(842,b|0,e+24|0);g=x[23604];x[23604]=0;if((g|0)!=1){b:{g=x[e+28>>2];f=x[e+24>>2];Ve(d);x[23604]=0;g=!g&f>>>0>=255|g?255:f;R(59,d|0,g|0);f=x[23604];x[23604]=0;if((f|0)==1){break b}c:{while(1){if((g|0)==(h|0)){b=BU(Pb(d),Eb(x[d+4>>2],y[d+11|0]));if((b|0)==-1){break c}x[23604]=0;R(59,d|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break c}break b}f=uc(d,h);x[23604]=0;Q(843,b|0,f|0)|0;f=x[23604];x[23604]=0;if((f|0)!=1){h=h+1|0;continue}break}break b}x[23604]=0;U(11,e+8|0,a|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}a=e+8|0;Ab(c,a);xb(a);xb(d);hb=e+48|0;break a}}a=P()|0;xb(d);T(a|0);p()}}function Yl(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=y[b+11|0];e=x[b+4>>2];x[23604]=0;R(45,d|0,Qc(e,a)|0);a=x[23604];x[23604]=0;if((a|0)!=1){a:{while(1){if(Qc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Wi(b,f)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((e|0)==x[(a<<2)+c>>2]){x[23604]=0;R(46,d|0,a<<24>>24);a=x[23604];x[23604]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[23604]=0;R(46,d|0,a<<24>>24);a=x[23604];x[23604]=0;if((a|0)!=1){break b}break a}x[23604]=0;R(46,d|0,63);a=x[23604];x[23604]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=P()|0;xb(d);T(a|0);p()}function y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Dw(fb(x[a+60>>2],b|0,i|0,d+12|0)|0)){g=x[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[b+4>>2]|0}hb=d+32|0;return a|0}function Uca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=hb-16|0;hb=g;od(b,4);w[b+30>>1]=y[a+12|0]<<2;pg(b+30|0,256);e=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=e;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=f;c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+4>>2]=c;d=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+c|0;x[b+8>>2]=d;e=y[a+14|0];if(e&16){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;f=f>>>1|0;x[b>>2]=f;e=y[a+14|0]}if(e&32){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;x[b>>2]=f>>>1;e=y[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){w[b+34>>1]=34;w[b+34>>1]=y[a+14|0]&2?38:34}a=Xb(g,21502);ze(b+43|0,a);xb(a);hb=g+16|0}function bV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-208|0;hb=d;if(!ou(c,a)){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0}CB(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}c=hb-16|0;hb=c;x[c+12>>2]=64;x[c+8>>2]=255;e=y[Fb(c+12|0,c+8|0)|0];hb=c+16|0;v[d+12|0]=e;Zg(b,y[Wb(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;e=x[b>>2];f=ie(e,x[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=y[d+18|0];c=zb(e,0);break b}g=z[zb(e,a-1|0)>>1];x[d+12>>2]=1;b=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[b+1|0]&1)<<8|y[b|0];h=Je(d+12|0,d+8|0);c=zb(e,a);w[c>>1]=z[h>>1]+g;b=y[b+2|0]}v[c+2|0]=b;a=a+1|0;continue}}hb=d+208|0}function Yg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb+-64|0;hb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=x[a>>2];e=x[a+4>>2];if(pe(d,e,b)){break b}c:{d:{if(ak(d,e)>>>0<=b>>>0){d=Kx(f+8|0,a);x[23604]=0;U(187,a|0,b+1|0,d|0);e=x[23604];x[23604]=0;if((e|0)==1){break d}Nk(d);d=x[a>>2]}x[23604]=0;R(197,Jf(d,b)|0,c|0);c=x[23604];x[23604]=0;e:{if((c|0)!=1){c=Jf(x[a>>2],b);x[c+16>>2]=0;x[c+20>>2]=0;c=x[a>>2];x[23604]=0;Y(198,Jf(c,b)|0);c=x[23604];x[23604]=0;if((c|0)!=1){break e}}b=V(92520)|0;a=ib;break c}a=Jf(x[a>>2],b);g=Ob(x[a>>2],x[a+4>>2]);break b}b=V(92520)|0;a=ib;Nk(d)}if((da(92520)|0)!=(a|0)){break a}_(b|0)|0;$()}hb=f- -64|0;return g|0}T(b|0);p()}function eL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=E(0),k=0,l=E(0);g=hb-16|0;hb=g;e=w[d>>1];f=w[d+2>>1];if(!(!z[b>>1]|(e|0)>(f|0)|(!(B[c>>2]>E(0))|(f-e|0)>32766))){w[a>>1]=3;f=a+4|0;Fc(f);w[a+28>>1]=65472;x[g+12>>2]=1065353216;hL(f,g+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Fc(a+16|0);h=w[d>>1];w[a+28>>1]=h;e=hb-16|0;hb=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Wc(e+14|0,e+12|0)>>1];hb=e+16|0;w[a+30>>1]=b;i=E(F(B[c>>2]));B[a+32>>2]=i;i=me(i,E(E(1)/E(b|0)));Gj(f,(w[d+2>>1]-h|0)+1|0);b=x[a+4>>2];c=w[a+28>>1];e=w[d+2>>1];d=w[d>>1];while(1){if((d|0)>(e|0)){fp(a)}else{j=me(i,E(d|0));k=zb(b,d-c|0),l=j,B[k>>2]=l;d=d+1|0;continue}break}h=1}hb=g+16|0;return h|0}function Bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[f+8>>2];g=(x[f+12>>2]<<1)+j|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;e=(((((D(w[g+4>>1],w[e+34>>1])+D(w[g+2>>1],w[e+32>>1])|0)+D(w[g+6>>1],w[e+36>>1])|0)+D(w[g+8>>1],w[e+38>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+26>>1])+D(w[g-6>>1],w[e+24>>1])|0)+D(w[g-2>>1],w[e+28>>1])|0)+D(w[g>>1],w[e+30>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(e,i);x[c+4>>2]=x[c+4>>2]+D(e,h);Ub(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;hb=f+16|0}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;h=hb-16|0;hb=h;c=ff(a,c);_d(h,x[a+28>>2]);i=a;a:{if(!c){d=0;if(fd(a,5)){break a}}f=x[a+28>>2];a=hb-16|0;hb=a;x[a+12>>2]=0;gH(f,a+12|0,1);e=x[a+12>>2];d=e>>>2&3;v[a+11|0]=d;if(d){v[a+4|0]=3;d=y[Wb(a+4|0,a+11|0)|0];v[a+4|0]=0;v[a|0]=0;v[a+10|0]=0;b:{if(!d){break b}$h(f,a+4|0);if((d|0)==1){break b}$h(f,a);if(d>>>0<3){break b}$h(f,a+10|0);g=y[a+10|0]<<24}e=e&255|(y[a+4|0]<<8|y[a|0]<<16|g)}d=e>>>4|0;x[a+4>>2]=d;x[a>>2]=1e6;sx(b,x[Fb(a+4|0,a)>>2]);e=0;while(1){g=Eb(x[b+4>>2],y[b+11|0]);if(g>>>0<=e>>>0){if((d|0)!=(g|0)){Gl(f,d-g|0)}hb=a+16|0}else{yk(f,uc(b,e),1);e=e+1|0;continue}break}d=c}_e(i,d);hb=h+16|0}function WW(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-192|0;hb=c;b=c+16|0;ih(b,a);x[23604]=0;R(77,c+32|0,b|0);a=x[23604];x[23604]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[23604]=0;a=Q(78,c+48|0,c+32|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}xb(c+32|0);xb(c+16|0);b=x[x[a>>2]-12>>2];x[23604]=0;d=ga(61)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}x[23604]=0;U(62,c+8|0,a+b|0,d|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}$b(c+8|0);x[23604]=0;b=Q(82,a|0,c+32|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}a=Ck(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>2];hf(b);hb=c+192|0;a=a?0:d;break a}b=P()|0;break d}b=P()|0;xb(c+32|0)}xb(c+16|0);break b}b=P()|0;hf(a)}T(b|0);p()}return a|0}function yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=Sj(b),x[i>>2]=j;d=hb-16|0;hb=d;g=a;c=Sd(a);a:{if(c){f=jc(g);while(1){a=c;c=a+13|0;if(ht(b,c)){f=a;c=x[a>>2];if(c){continue}break a}if(!ht(c,b)){break a}f=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=jc(g);f=a}x[d+12>>2]=a;b=x[f>>2];if(!b){c=hb-16|0;hb=c;a=jc(g);h=ph(d,Jc(20),qh(c+8|0,a));b=x[h>>2];a=x[e>>2];a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+17|0]=0;v[b+13|0]=a;v[b+14|0]=a>>>8;v[b+15|0]=a>>>16;v[b+16|0]=a>>>24;i=jc(h),j=1,v[i+4|0]=j;hb=c+16|0;Vg(g,x[d+12>>2],f,x[d>>2]);b=Wd(d);cl(d);h=1}Ug(e+8|0,x[Ib(d,b)>>2],h);hb=d+16|0;hb=e+16|0;return x[e+8>>2]+17|0}function l5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;x[23604]=0;Y(900,a|0);e=x[23604];x[23604]=0;a:{b:{c:{if((e|0)==1){break c}x[23604]=0;Y(901,b|0);e=x[23604];x[23604]=0;if((e|0)==1){break c}x[23604]=0;Y(901,c|0);f=x[23604];x[23604]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=oc(d+24|0,b);c=oc(d+16|0,c);g=x[c>>2];c=x[c+4>>2];x[23604]=0;h=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=h;WE(922,f,d+8|0,g,c);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,5468,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();e=0}hb=d+32|0;return e|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function sN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-112|0;hb=f;x[f+108>>2]=0;e=Ln(a,e&65535,d,c,f+108|0);c=y[b+790|0];if(!x[f+108>>2]){d=(c|0)==15;h=d&!y[b+792|0];e=e<<8;a:{if(e){x[b+664>>2]=e;break a}e=0;if(d){break a}e=x[b+664>>2]}h=h?0:y[b+836|0]<<16}if((c|0)==15){c=y[b+792|0];b:{if(!c){c=x[b+76>>2];x[f>>2]=1;g=x[_c(f,f+108|0)>>2]<<3;e=Jia(c,0,e,0);d=(256<<g>>>1|0)+e|0;c=lb;c=d>>>0<e>>>0?c+1|0:c;e=g+8|0;g=d;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}e=Uc(c,e);break b}cQ(f);if(c>>>0>9){break b}c=x[b+104>>2];if(!c){break b}e=x[zb(c+68|0,y[b+792|0]-1|0)>>2]+e|0}x[b+664>>2]=e}Pn(a,b,e+h|0);hb=f+112|0}function py(a,b,c,d){var e=0,f=0,g=0;a:{if(!d){break a}if(c){v[b+815|0]=c;break a}c=y[b+815|0]}e=x[a+480180>>2];d=e&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=x[a+480208>>2]&4096;if(!d){break h}if(!a){break b}c=0-(d>>>2|0)|0;break d}a=x[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(e&16777248)|!d){break c}break b}c=0-(d>>>2|0)|0;break d}if(y[a+480209|0]&16){break b}d=c&240;c=d?d>>>2|0:0-(c<<2&60)|0;if(!Tb(a+1074312|0,56)){break d}c=c>>2}if(!c){break b}}a=x[b+692>>2];w[b+784>>1]=0;f=b,g=Yb(a+c|0,0,256),x[f+692>>2]=g}}function TV(){var a=0,b=0,c=0,d=0;a=lC(x[(x[x[116762]-12>>2]+467048|0)+28>>2],10);c=hb-16|0;hb=c;x[23604]=0;b=Q(12,c+8|0,467048)|0;d=x[23604];x[23604]=0;a:{b:{c:{d:{if((d|0)!=1){e:{if(!ud(y[b|0])){break e}d=um(c,467048);x[23604]=0;a=Q(20,d|0,a|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){if(x[a>>2]){break e}a=x[x[116762]-12>>2];x[23604]=0;R(15,a+467048|0,1);a=x[23604];x[23604]=0;if((a|0)!=1){break e}}a=V(0)|0;$j(b);break d}$j(b);break c}a=V(0)|0}_(a|0)|0;b=x[x[116762]-12>>2];x[23604]=0;Y(16,b+467048|0);b=x[23604];x[23604]=0;if((b|0)==1){break b}$()}hb=c+16|0;break a}c=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(c|0);p()}V(0)|0;Vb();p()}Aq(467048)}function YG(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[23604]=0;c=Q(1052,d+8|0,a|0)|0;b=x[23604];x[23604]=0;c:{if((b|0)!=1){d:{if(!ud(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23604]=0;b=S(1053,b|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[23604]=0;Y(1054,a+b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break d}}b=V(0)|0;XG(c);break c}XG(c);break b}b=V(0)|0}_(b|0)|0;c=x[x[a>>2]-12>>2];x[23604]=0;Y(16,a+c|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}$()}hb=d+16|0;return a|0}a=P()|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;if((c|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function s1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{b:{c:{while(1){if((b|0)==(c|0)){break c}x[23604]=0;R(1032,d|0,b|0);f=x[23604];x[23604]=0;if((f|0)!=1){d=d+12|0;x[e+28>>2]=d;b=b+12|0;continue}break}_(V(0)|0)|0;a=$f(e+8|0,a,e+24|0,e+28|0);b=hb-16|0;hb=b;d=Ib(b+8|0,x[x[a+8>>2]>>2]);e=x[Ib(b,x[x[a+4>>2]>>2])>>2];c=hb-16|0;hb=c;a=x[d>>2];x[c+8>>2]=a;while(1){if(og(a,e)){Db(Bi(a));a=x[vl(c+8|0)>>2];continue}break}hb=c+16|0;hb=b+16|0;x[23604]=0;Z(91);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break b}T(a|0);p()}hb=e+32|0;return d|0}V(0)|0;Vb()}p()}function dy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;b=x[a>>2];if(!tc(b,x[a+4>>2])){b=Bb(b);x[e+8>>2]=b;f=Bb(x[a+4>>2]);while(1){if(Ob(b,f)){yo(b,4194304,67108864);c=x[b>>2];g=c+g|0;b=d;d=c>>>0>g>>>0?b+1|0:b;b=x[Fe(e+8|0)>>2];continue}else{f=x[a>>2];b=rc(f,x[a+4>>2]);l=e,m=Bb(f),x[l>>2]=m;f=Mia(g,d,b,0);d=f;h=((lb&1)<<31|d>>>1)&2147483647;g=b<<24;d=0;i=Bb(x[a+4>>2]);while(1){b=x[e>>2];if(Ob(b,i)){j=b;c=x[b>>2];b=c>>>8|0;c=h+(c<<24)|0;b=b+k|0;c=Uc(Mia(c,c>>>0<h>>>0?b+1|0:b,f,k),lb);x[j>>2]=c;b=g;g=b-c|0;d=d-(b>>>0<c>>>0)|0;Fe(e);continue}else{d=x[a>>2];if(!rc(d,x[a+4>>2])){Hu();p()}x[d>>2]=x[d>>2]+g}break}}break}}hb=e+16|0}function P3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-32|0;hb=d;e=Sb(a);a=0;c=x[b+24>>2];c=Us(x[c+484344>>2],x[c+484348>>2]);x[23604]=0;R(167,e|0,c|0);c=x[23604];x[23604]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=x[b+24>>2];f=x[c+484344>>2];if(Us(f,x[c+484348>>2])>>>0<=a>>>0){break b}x[23604]=0;R(969,d|0,ac(f,a)|0);c=x[23604];x[23604]=0;if((c|0)!=1){c=x[b+24>>2];x[23604]=0;U(956,d+16|0,c|0,d|0);c=x[23604];x[23604]=0;if((c|0)==1){break e}x[23604]=0;R(169,e|0,d+16|0);c=x[23604];x[23604]=0;if((c|0)==1){break d}a=a+1|0;xb(d+16|0);xb(d);continue}break}a=P()|0;break a}a=P()|0;break c}a=P()|0;xb(d+16|0)}xb(d);break a}hb=d+32|0;return}a=P()|0}Vd(e);T(a|0);p()}function K2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{b:{c:{while(1){if((b|0)==(c|0)){break c}x[23604]=0;R(1007,d|0,b|0);f=x[23604];x[23604]=0;if((f|0)!=1){d=d+16|0;x[e+28>>2]=d;b=b+16|0;continue}break}_(V(0)|0)|0;a=$f(e+8|0,a,e+24|0,e+28|0);b=hb-16|0;hb=b;d=Ib(b+8|0,x[x[a+8>>2]>>2]);e=x[Ib(b,x[x[a+4>>2]>>2])>>2];c=hb-16|0;hb=c;a=x[d>>2];x[c+8>>2]=a;while(1){if(og(a,e)){Tj(dx(a));a=x[ex(c+8|0)>>2];continue}break}hb=c+16|0;hb=b+16|0;x[23604]=0;Z(91);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break b}T(a|0);p()}hb=e+32|0;return d|0}V(0)|0;Vb()}p()}function Aq(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[23604]=0;c=Q(12,d+8|0,a|0)|0;b=x[23604];x[23604]=0;c:{if((b|0)!=1){d:{if(!ud(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23604]=0;b=S(21,b|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[23604]=0;R(15,a+b|0,1);b=x[23604];x[23604]=0;if((b|0)!=1){break d}}b=V(0)|0;$j(c);break c}$j(c);break b}b=V(0)|0}_(b|0)|0;c=x[x[a>>2]-12>>2];x[23604]=0;Y(16,a+c|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}$()}hb=d+16|0;return a|0}a=P()|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;if((c|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Y$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;a:{b:{if(!tc(b,-1)){i=x[a+8>>2];j=x[a+12>>2];d=x[a+24>>2];if((d|0)==x[a+28>>2]){g=-1;if(!(y[a+48|0]&16)){break a}h=x[a+20>>2];k=x[a+44>>2];x[23604]=0;f=a+32|0;R(46,f|0,0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Oc(f);x[23604]=0;R(59,f|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}c=Pb(f);rw(a,c,Eb(x[a+36>>2],y[a+43|0])+c|0);Jr(a,d-h|0);x[a+44>>2]=x[a+20>>2]+(k-h|0);d=x[a+24>>2]}x[e+12>>2]=d+1;c=x[_c(e+12|0,a+44|0)>>2];x[a+44>>2]=c;if(y[a+48|0]&8){d=Pb(a+32|0);jn(a,d,d+(j-i|0)|0,c)}g=bH(a,b<<24>>24);break a}g=qw(b);break a}_(V(0)|0)|0;$()}hb=e+16|0;return g|0}function en(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0,n=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;n=a&255;if((n|0)!=y[k+24|0]){m=45;if(y[k+25|0]!=(n|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Eb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;a=gi(k,k+26|0,a)-k|0;if((a|0)>23){break c}d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(a|0)<22){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+82128|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+82128|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[h>>1],w[e+40242>>1])+D(w[h-2>>1],w[e+40240>>1])|0)+D(w[h+2>>1],w[e+40244>>1])|0)+D(w[h+4>>1],w[e+40246>>1])|0)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Ub(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function Cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[f+8>>2];g=x[f+12>>2]+j|0;e=(((e>>>16|0)+4&131064)<<1)+b|0;e=((((D(v[g+2|0],w[e+34>>1])+D(v[g+1|0],w[e+32>>1])|0)+D(v[g+3|0],w[e+36>>1])|0)+D(v[g+4|0],w[e+38>>1])<<8>>1)+(((D(v[g-2|0],w[e+26>>1])+D(v[g-3|0],w[e+24>>1])|0)+D(v[g-1|0],w[e+28>>1])|0)+D(v[g|0],w[e+30>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(e,i);x[c+4>>2]=x[c+4>>2]+D(e,h);Ub(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;hb=f+16|0}function bn(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;if(x[k+96>>2]!=(a|0)){m=45;if(x[k+100>>2]!=(a|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Eb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;f=aw(k,k+104|0,a)-k|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+82128|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+82128|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function lha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=hb-48|0;hb=c;d=a;a:{if(Mt(x[d>>2],x[d+8>>2])){x[g>>2]=0;break a}CS(c+16|0,c+32|0);mc(c+24|0,x[d>>2],x[d+8>>2],x[c+16>>2],x[c+20>>2]);h=x[c+28>>2];i=y[c+32|0];f=i&127;x[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(D(h,7)+a|0)+D(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=y[(c+32|0)+e|0];f=i&127|f<<7;x[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}bc(d,h);CS(c+8|0,c+32|0);mc(c+24|0,x[d>>2],x[d+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+28>>2];f=x[g>>2];e=0;a=b;continue}break}bc(d,e);if(a>>>0<33){break a}x[g>>2]=-1}hb=c+48|0}function Lga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;x[d+28>>2]=0;Uj(a,d+28|0);a:{b:{i=x[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Kb(d+16|0);x[23604]=0;w[d+14>>1]=0;e=W(428,a|0,g|0,255)|0;h=x[23604];x[23604]=0;if((h|0)==1){break b}if(!e){break d}x[23604]=0;R(417,a|0,d+14|0);e=x[23604];x[23604]=0;if((e|0)==1){break b}x[23604]=0;U(11,d|0,c|0,g|0);e=x[23604];x[23604]=0;if((e|0)!=1){x[23604]=0;e=Q(429,b|0,d+14|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break e}Ab(e,d);xb(d);xb(g);f=f+1|0;continue}break}f=P()|0;break a}f=P()|0;xb(d);break a}xb(g)}hb=d+32|0;return}f=P()|0}xb(g);T(f|0);p()}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[h|0],w[e+40242>>1])+D(v[h-1|0],w[e+40240>>1])|0)+D(v[h+1|0],w[e+40244>>1])|0)+D(v[h+2|0],w[e+40246>>1])<<8)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Ub(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function OE(a,b,c,d){var e=0,f=0,g=0;f=hb-32|0;hb=f;x[23604]=0;Y(900,a|0);e=x[23604];x[23604]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}x[23604]=0;Y(901,b|0);e=x[23604];x[23604]=0;if((e|0)==1){break f}g=x[a+24>>2];x[23604]=0;e=Q(54,f|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break e}x[23604]=0;U(d|0,f+16|0,g|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break d}a=f+16|0;b=Qf(Pb(a));xb(a);xb(e);break b}b=V(0)|0;break c}b=V(0)|0;break c}b=V(0)|0;xb(e)}_(b|0)|0;b=0;x[23604]=0;X(887,c|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$()}hb=f+32|0;return b}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;w[d+30>>1]=0;Ff(a,d+30|0);a:{b:{i=z[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Kb(d+16|0);x[23604]=0;w[d+14>>1]=0;e=Q(430,a|0,g|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break b}if(!e){break d}x[23604]=0;R(417,a|0,d+14|0);e=x[23604];x[23604]=0;if((e|0)==1){break b}x[23604]=0;U(11,d|0,c|0,g|0);e=x[23604];x[23604]=0;if((e|0)!=1){x[23604]=0;e=Q(429,b|0,d+14|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break e}Ab(e,d);xb(d);xb(g);f=f+1|0;continue}break}f=P()|0;break a}f=P()|0;xb(d);break a}xb(g)}hb=d+32|0;return}f=P()|0}xb(g);T(f|0);p()}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;e=x[a+40>>2];f=x[a+36>>2];j=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;k=x[a+32>>2];l=x[a+28>>2];h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=((((x[b+12>>2]&2147483647)<<1|i>>>31)&2147483646)<<1)+j|0;g=0;while(1){if((g|0)!=2){x[(g<<2)+b>>2]=w[(g<<1)+i>>1];g=g+1|0;continue}break}f=f+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],f>>12);e=e+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],e>>12);Ub(b+8|0,h,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;hb=b+16|0}function r1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;h=Kb(a);f=Kb(d+16|0);a=1;a:{b:{c:{while(1){e=a&65535;c=x[b+24>>2];if(e>>>0>z[c+480192>>1]){if(!(i&1)){break c}x[23604]=0;R(233,h|0,f|0);a=x[23604];x[23604]=0;if((a|0)!=1){break c}a=P()|0;break a}c=YL(c,e);x[23604]=0;c=Q(54,d|0,c|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break b}e=wd(x[d+4>>2],y[d+11|0]);x[23604]=0;g=Q(753,f|0,c|0)|0;j=x[23604];x[23604]=0;d:{if((j|0)==1){break d}x[23604]=0;Q(889,g|0,21472)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}i=e^1|i;xb(c);a=a+1|0;continue}break}a=P()|0;xb(c);break a}xb(f);hb=d+32|0;return}a=P()|0}xb(f);xb(h);T(a|0);p()}function jga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(A[a+4>>2]<A[Cb(a)>>2]){d=hb-16|0;hb=d;a=yU(d,a);oA(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;ic(a);hb=d+16|0;return}h=hb-32|0;hb=h;d=Cb(a);c=wU(h+8|0,xU(a,nq(x[a>>2],x[a+4>>2])+1|0),nq(x[a>>2],x[a+4>>2]),d);oA(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=hb-32|0;hb=g;f=Ib(g+24|0,x[a+4>>2]);d=Ib(g+16|0,x[a>>2]);b=Ib(g+8|0,x[c+4>>2]);f=x[f>>2];d=x[d>>2];e=hb-16|0;hb=e;x[e>>2]=x[b>>2];x[e+8>>2]=f;while(1){b=x[e>>2];if(og(f,d)){oA(ko(b),ko(f));b=fu(e+8|0);fu(e);f=x[b>>2];continue}break}hb=e+16|0;x[c+4>>2]=b;qc(a,c+4|0);qc(a+4|0,c+8|0);qc(Cb(a),yc(c));x[c>>2]=x[c+4>>2];hb=g+32|0;vU(c);hb=h+32|0}function _j(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(A[a+4>>2]<A[Cb(a)>>2]){d=hb-16|0;hb=d;a=yU(d,a);gB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;ic(a);hb=d+16|0;return}h=hb-32|0;hb=h;d=Cb(a);c=wU(h+8|0,xU(a,nq(x[a>>2],x[a+4>>2])+1|0),nq(x[a>>2],x[a+4>>2]),d);gB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=hb-32|0;hb=g;f=Ib(g+24|0,x[a+4>>2]);d=Ib(g+16|0,x[a>>2]);b=Ib(g+8|0,x[c+4>>2]);f=x[f>>2];d=x[d>>2];e=hb-16|0;hb=e;x[e>>2]=x[b>>2];x[e+8>>2]=f;while(1){b=x[e>>2];if(og(f,d)){gB(ko(b),ko(f));b=fu(e+8|0);fu(e);f=x[b>>2];continue}break}hb=e+16|0;x[c+4>>2]=b;qc(a,c+4|0);qc(a+4|0,c+8|0);qc(Cb(a),yc(c));x[c>>2]=x[c+4>>2];hb=g+32|0;vU(c);hb=h+32|0}function q1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;h=Kb(a);f=Kb(c+16|0);a=1;a:{b:{c:{while(1){d=a&65535;e=x[b+24>>2];if(d>>>0>z[e+480190>>1]){if(!(i&1)){break c}x[23604]=0;R(233,h|0,f|0);a=x[23604];x[23604]=0;if((a|0)!=1){break c}a=P()|0;break a}x[23604]=0;e=Q(54,c|0,ZL(e,d)|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break b}d=wd(x[c+4>>2],y[c+11|0]);x[23604]=0;g=Q(753,f|0,e|0)|0;j=x[23604];x[23604]=0;d:{if((j|0)==1){break d}x[23604]=0;Q(889,g|0,21472)|0;g=x[23604];x[23604]=0;if((g|0)==1){break d}i=d^1|i;xb(e);a=a+1|0;continue}break}a=P()|0;xb(e);break a}xb(f);hb=c+32|0;return}a=P()|0}xb(f);xb(h);T(a|0);p()}function kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-80|0;hb=d;e=Gf(d+48|0);x[23604]=0;g=Q(750,b|0,e|0)|0;f=x[23604];x[23604]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23604]=0;S(751,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[23604]=0;U(176,d|0,b|0,g|0);f=x[23604];x[23604]=0;if((f|0)==1){break a}f=kc(d+24|0,d);$c(e+8|0,f);yb(f);yb(d);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}x[23604]=0;Q(174,b|0,2-c|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break d}break a}jl(a,e)}Md(e);hb=d+80|0;return}a=P()|0;Md(e);T(a|0);p()}function Ho(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Ue(f+16|0,1,0);b:{c:{d:{while(1){d=Pb(c);ts(f+8|0,d,Eb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[f+12>>2]){break d}d=Rf(Eb(x[c+4>>2],y[c+11|0]));x[23604]=0;R(58,c|0,d|0);d=x[23604];x[23604]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=Pb(c);x[23604]=0;R(59,c|0,b-d|0);b=x[23604];x[23604]=0;e:{if((b|0)!=1){x[23604]=0;R(71,e|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break e}break c}break c}xb(c);hb=f+32|0;break b}a=P()|0;xb(c);T(a|0);p()}x[23604]=0;R(70,a|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(e);hb=e+16|0;break a}a=P()|0;xb(e);T(a|0);p()}}function ET(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Ue(f+16|0,1,0);b:{c:{d:{while(1){d=Pb(c);gx(f+8|0,d,Eb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[f+12>>2]){break d}d=Rf(Eb(x[c+4>>2],y[c+11|0]));x[23604]=0;R(58,c|0,d|0);d=x[23604];x[23604]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=Pb(c);x[23604]=0;R(59,c|0,b-d|0);b=x[23604];x[23604]=0;e:{if((b|0)!=1){x[23604]=0;R(71,e|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break e}break c}break c}xb(c);hb=f+32|0;break b}a=P()|0;xb(c);T(a|0);p()}x[23604]=0;R(70,a|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(e);hb=e+16|0;break a}a=P()|0;xb(e);T(a|0);p()}}function FX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(Hg(a,x[b+8>>2],f)){Rv(b,c,d,e);return}g=y[b+53|0];j=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;m=a+16|0;Nv(x[m>>2],x[a+20>>2],b,c,d,e,f);k=y[b+53|0];g=g|k;l=y[b+52|0];h=h|l;i=a+24|0;j=(j<<3)+m|0;a:{if(i>>>0>=j>>>0){break a}while(1){h=h&1;g=g&1;if(y[b+54|0]){break a}b:{if(l){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!k){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;Nv(x[i>>2],x[i+4>>2],b,c,d,e,f);k=y[b+53|0];g=k|g;l=y[b+52|0];h=l|h;i=i+8|0;if(j>>>0>i>>>0){continue}break}}v[b+53|0]=(g&255)!=0;v[b+52|0]=(h&255)!=0}function Er(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=hb-16|0;hb=h;f=d?d:467572;d=x[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=y[b|0];d=a<<24>>24;if((d|0)>=0){x[i>>2]=a;e=(d|0)!=0;break a}if(!x[x[116108]>>2]){x[i>>2]=d&57343;e=1;break a}a=a-194|0;if(a>>>0>50){break c}d=x[(a<<2)+81920>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=y[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){x[f>>2]=0;x[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=y[b|0];if((g&192)==128){continue}break}}x[f>>2]=0;x[116080]=25;e=-1;break a}x[f>>2]=d}hb=h+16|0;return e}function iI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Bg(a)|0)>(b|0)){break d}}a=ba(8)|0;x[23604]=0;d=Q(54,d|0,10598)|0;b=x[23604];x[23604]=0;if((b|0)==1){break c}a=pc(a,d);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}b=P()|0;xb(d);break b}if(c<0|c>1){a=ba(8)|0;x[23604]=0;d=Q(54,d|0,11627)|0;b=x[23604];x[23604]=0;if((b|0)!=1){a=pc(a,d);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}b=P()|0;xb(d);break b}b=P()|0;ca(a|0);break b}e=(a+D(b,872)|0)+1075740|0,f=dm(c*64),x[e>>2]=f;hb=d+16|0;return}b=P()|0;ca(a|0)}T(b|0)}p()}function qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[a>>2];d=gq(c,x[a+4>>2]);if(d>>>0<b>>>0){f=hb-32|0;hb=f;c=b-d|0;b=x[Cb(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=(b-e|0)/48>>>0){d=hb-16|0;hb=d;b=aU(d,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);hb=d+16|0}else{xS(a);a=a+48|0;x[b+4>>2]=a;continue}break}break a}b=Cb(a);d=ZT(f+8|0,_T(a,gq(x[a>>2],e)+c|0),gq(x[a>>2],x[a+4>>2]),b);b=hb-16|0;hb=b;x[b>>2]=x[d+8>>2];e=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=D(c,48)+e;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){xS(c);c=x[b>>2]+48|0;x[b>>2]=c;continue}break}Hd(b);hb=b+16|0;YT(a,d);XT(d)}hb=f+32|0;return}if(b>>>0<d>>>0){Id(a,c+D(b,48)|0)}}function GD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;e=Pb(b);d=Eb(x[b+4>>2],y[b+11|0]);i=Pb(c);j=Eb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(Mp(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=Ib(g+8|0,pd(b));d=Ib(g,Ee(pd(b),f));AC(b,x[c>>2],x[d>>2]);break c}f=Qc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Pb(b);i=Eb(x[b+4>>2],y[b+11|0]);j=Pb(c);d=-1;h=Eb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!Mp(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Kb(a);break b}dd(a,b)}hb=g+16|0}function bp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Ue(f+16|0,1,0);a:{b:{c:{while(1){d=Pb(c);ts(f+8|0,d,Eb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[f+12>>2]){break c}d=Rf(Eb(x[c+4>>2],y[c+11|0]));x[23604]=0;R(58,c|0,d|0);d=x[23604];x[23604]=0;if((d|0)!=1){continue}break}break b}b=x[f+8>>2];d=Pb(c);x[23604]=0;R(59,c|0,b-d|0);b=x[23604];x[23604]=0;d:{if((b|0)!=1){x[23604]=0;R(60,e|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break b}break b}xb(c);hb=f+32|0;break a}a=P()|0;xb(c);T(a|0);p()}x[23604]=0;R(57,a|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(e);hb=e+16|0;return}a=P()|0;xb(e);T(a|0);p()}function X7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Ue(f+16|0,1,0);a:{b:{c:{while(1){d=Pb(c);ts(f+8|0,d,Eb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[f+12>>2]){break c}d=Rf(Eb(x[c+4>>2],y[c+11|0]));x[23604]=0;R(58,c|0,d|0);d=x[23604];x[23604]=0;if((d|0)!=1){continue}break}break b}b=x[f+8>>2];d=Pb(c);x[23604]=0;R(59,c|0,b-d|0);b=x[23604];x[23604]=0;d:{if((b|0)!=1){x[23604]=0;R(60,e|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break d}break b}break b}xb(c);hb=f+32|0;break a}a=P()|0;xb(c);T(a|0);p()}x[23604]=0;R(57,a|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(e);hb=e+16|0;return}a=P()|0;xb(e);T(a|0);p()}function maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-80|0;hb=d;e=Gf(d+48|0);x[23604]=0;c=Q(746,b|0,e|0)|0;f=x[23604];x[23604]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23604]=0;S(747,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[23604]=0;c=dc(c);c=c?c:-1;U(176,d|0,b|0,c|0);f=x[23604];x[23604]=0;if((f|0)==1){break a}f=kc(d+24|0,d);$c(e+8|0,f);yb(f);yb(d);d:{c=c&1;if(!c){break d}x[23604]=0;Q(174,b|0,2-c|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break d}break a}jl(a,e)}Md(e);hb=d+80|0;return}a=P()|0;Md(e);T(a|0);p()}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;e=x[a+40>>2];f=x[a+36>>2];j=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;k=x[a+32>>2];l=x[a+28>>2];h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=(((x[b+12>>2]&2147483647)<<1|i>>>31)&-2)+j|0;g=0;while(1){if((g|0)!=2){x[(g<<2)+b>>2]=v[g+i|0]<<8;g=g+1|0;continue}break}f=f+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],f>>12);e=e+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],e>>12);Ub(b+8|0,h,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;hb=b+16|0}function d4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-32|0;hb=e;f=Sb(a);a=b;b=z[x[b+24>>2]+480192>>1];x[23604]=0;R(167,f|0,b|0);c=x[23604];x[23604]=0;b=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=b&65535;c=x[a+24>>2];if(d>>>0>z[c+480192>>1]){break b}c=YL(c,d);x[23604]=0;c=Q(54,e|0,c|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){d=x[a+24>>2];x[23604]=0;U(956,e+16|0,d|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break e}x[23604]=0;R(169,f|0,e+16|0);d=x[23604];x[23604]=0;if((d|0)==1){break d}xb(e+16|0);xb(c);b=b+1|0;continue}break}b=P()|0;break a}b=P()|0;break c}b=P()|0;xb(e+16|0)}xb(c);break a}hb=e+32|0;return}b=P()|0}Vd(f);T(b|0);p()}function Su(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;i=a+1|0;e=f+15|0;Zg(b,y[Wb(i,e)|0]);g=y[Wb(a+2|0,e)|0];v[b+13|0]=g;k=b,l=Td(y[a+3|0],g,d),v[k+14|0]=l;e=y[Wb(a+4|0,e)|0];v[b+15|0]=e;k=b,l=Td(y[a+5|0],e,d),v[k+16|0]=l;g=x[b>>2];b=0;while(1){v[f+14|0]=25;if(b>>>0<y[Wb(f+14|0,i)|0]){e=D(b,3)+a|0;h=Yb(y[e+6|0]+c<<24>>24,0,64);d=zb(g,b);v[d+2|0]=h;e=y[e+7|0]|y[e+8|0]<<8;w[d>>1]=e;a:{if(!b){break a}h=zb(g,b-1|0);j=z[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;w[d>>1]=e;if(z[h>>1]<=(e&65535)>>>0){break a}w[d>>1]=e+256}b=b+1|0;continue}break}hb=f+16|0}function Oda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){c=hb-16|0;hb=c;d=hb-16|0;hb=d;x[d+12>>2]=477218588;x[d+8>>2]=2147483647;e=x[Fb(d+12|0,d+8|0)>>2];hb=d+16|0;if(b>>>0>e>>>0){Sc();p()}d=D(b,9);e=Jc(d);x[c+12>>2]=b;x[c+8>>2]=e;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=Cb(a),g=b+D(x[c+12>>2],9)|0,x[f>>2]=g;hb=c+16|0;c=hb-16|0;hb=c;x[c>>2]=a;b=x[a+4>>2];x[c+4>>2]=b;x[c+8>>2]=b+d;b=x[c+4>>2];d=x[c+8>>2];while(1){if((b|0)==(d|0)){ic(c);hb=c+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;continue}break}}return a|0}function _C(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Rb(a,3878,4)){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(b>>>0<36){break a}c=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);if(c>>>0<36){break a}d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);if(d>>>0<36){break a}e=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24);if(D(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function sJ(a,b){var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Ue(f+16|0,1,0);b:{c:{d:{while(1){d=Pb(c);gx(f+8|0,d,Eb(x[c+4>>2],y[c+11|0])+d|0,z[b>>1]);if(!x[f+12>>2]){break d}d=Rf(Eb(x[c+4>>2],y[c+11|0]));x[23604]=0;R(58,c|0,d|0);d=x[23604];x[23604]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=Pb(c);x[23604]=0;R(59,c|0,b-d|0);b=x[23604];x[23604]=0;e:{if((b|0)!=1){x[23604]=0;R(71,e|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break e}break c}break c}xb(c);hb=f+32|0;break b}a=P()|0;xb(c);T(a|0);p()}x[23604]=0;R(70,a|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(e);hb=e+16|0;break a}a=P()|0;xb(e);T(a|0);p()}}function xJ(a,b){var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Ue(f+16|0,1,0);b:{c:{d:{while(1){d=Pb(c);gx(f+8|0,d,Eb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[f+12>>2]){break d}d=Rf(Eb(x[c+4>>2],y[c+11|0]));x[23604]=0;R(58,c|0,d|0);d=x[23604];x[23604]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=Pb(c);x[23604]=0;R(59,c|0,b-d|0);b=x[23604];x[23604]=0;e:{if((b|0)!=1){x[23604]=0;R(71,e|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break e}break c}break c}xb(c);hb=f+32|0;break b}a=P()|0;xb(c);T(a|0);p()}x[23604]=0;R(70,a|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(e);hb=e+16|0;break a}a=P()|0;xb(e);T(a|0);p()}}function G3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-32|0;hb=e;f=Sb(a);a=b;b=z[x[b+24>>2]+480190>>1];x[23604]=0;R(167,f|0,b|0);d=x[23604];x[23604]=0;b=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=b&65535;d=x[a+24>>2];if(c>>>0>z[d+480190>>1]){break b}x[23604]=0;d=Q(54,e|0,ZL(d,c)|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){c=x[a+24>>2];x[23604]=0;U(956,e+16|0,c|0,d|0);c=x[23604];x[23604]=0;if((c|0)==1){break e}x[23604]=0;R(169,f|0,e+16|0);c=x[23604];x[23604]=0;if((c|0)==1){break d}xb(e+16|0);xb(d);b=b+1|0;continue}break}b=P()|0;break a}b=P()|0;break c}b=P()|0;xb(e+16|0)}xb(d);break a}hb=e+32|0;return}b=P()|0}Vd(f);T(b|0);p()}function iS(a){var b=0,c=0,d=0,e=0,f=0;b=hb-32|0;hb=b;e=b,f=dc(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788|0,x[e>>2]=f;x[b+4>>2]=0;e=b,f=dc(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),x[e+8>>2]=f;x[b+12>>2]=0;c=dc(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24));x[b+16>>2]=c?c:52;x[b+20>>2]=0;e=b,f=dc(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+80|0,x[e+24>>2]=f;x[b+28>>2]=0;a=b;d=Ne(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Nu(x[a>>2],x[a+4>>2],x[c>>2],x[c+4>>2])?c:a;continue}}hb=b+32|0;c=x[a>>2];b=c-52|0;lb=x[a+4>>2]-(c>>>0<52)|0;return b}function sH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=hb-208|0;hb=f;x[f+204>>2]=c;c=f+160|0;Zb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((rH(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]>=0;g=x[a>>2];if(x[a+72>>2]<=0){x[a>>2]=g&-33}b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(QB(a)){break b}}c=rH(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){mb[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}hb=f+208|0;return e}function _8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-80|0;hb=d;e=Gf(d+48|0);x[23604]=0;g=Q(821,b|0,e|0)|0;f=x[23604];x[23604]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23604]=0;S(822,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[23604]=0;U(176,d|0,b|0,g|0);f=x[23604];x[23604]=0;if((f|0)==1){break a}f=kc(d+24|0,d);$c(e+8|0,f);yb(f);yb(d);d:{if(!(g&1)|c>>>0<2){break d}x[23604]=0;Q(174,b|0,1)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break d}break a}jl(a,e)}Md(e);hb=d+80|0;return}a=P()|0;Md(e);T(a|0);p()}function oaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-80|0;hb=d;e=Gf(d+48|0);x[23604]=0;c=Q(742,b|0,e|0)|0;f=x[23604];x[23604]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23604]=0;S(743,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[23604]=0;c=dc(c);U(176,d|0,b|0,c|0);f=x[23604];x[23604]=0;if((f|0)==1){break a}f=kc(d+24|0,d);$c(e+8|0,f);yb(f);yb(d);d:{c=c&1;if(!c){break d}x[23604]=0;Q(174,b|0,2-c|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break d}break a}jl(a,e)}Md(e);hb=d+80|0;return}a=P()|0;Md(e);T(a|0);p()}function E5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=Sj(b),x[i>>2]=j;c=hb-16|0;hb=c;g=a;d=Sd(a);a:{if(d){f=jc(g);while(1){a=d;d=a+16|0;if(Rs(b,d)){f=a;d=x[a>>2];if(d){continue}break a}if(!Rs(d,b)){break a}f=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=jc(g);f=a}x[c+12>>2]=a;b=x[f>>2];if(!b){a=hb-16|0;hb=a;b=jc(g);b=ph(c,Jc(40),qh(a+8|0,b));Kb(dd(x[b>>2]+16|0,x[e>>2])+12|0);i=jc(b),j=1,v[i+4|0]=j;hb=a+16|0;Vg(g,x[c+12>>2],f,x[c>>2]);b=Wd(c);a=x[c>>2];x[c>>2]=0;if(a){if(y[jc(c)+4|0]){$l(a+16|0)}Hb(a)}h=1}Ug(e+8|0,x[Ib(c,b)>>2],h);hb=c+16|0;a=sd(x[e+8>>2]);hb=e+16|0;return a+12|0}function cP(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+798|0]=0;return}v[a+798|0]=1;return}v[a+798|0]=2;return}v[a+798|0]=3;return}v[a+730|0]=y[a+730|0]&254;return}v[a+730|0]=y[a+730|0]|1;return}v[a+738|0]=y[a+738|0]&254;return}v[a+738|0]=y[a+738|0]|1;return}v[a+746|0]=y[a+746|0]&254;return}v[a+746|0]=y[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=y[a+746|0];v[c+746|0]=(b|0)==13?a&238|1:a|17}}function P9(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){Fs(a+484344|0);Ve(a+1298308|0);Ve(a+1298320|0);Ve(a+1298332|0);Fc(a+1298408|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){c=a+946300|0;b=a+906300|0;while(1){if((b|0)==(c|0)){break a}oB(b);b=b+160|0;continue}}d=x[b>>2];if(d){Hb(It(d))}x[b>>2]=0;b=b+4|0;continue}}}else{im(c);c=c+104|0;continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0}else{x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+872|0;continue}break}}function Afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0;c=hb-16|0;hb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){f=x[a+4>>2];e=x[b+4>>2];if((f|0)!=(e|0)){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Fb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;e=x[Fb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{k=(D(b,f)+a|0)+i|0;g=Lh(E(Fd(B[Kp(j,a,b)>>2],E(-1))*E(128)));d:{if(E(F(g))<E(2147483648)){h=~~g;break d}h=-2147483648}l=k,m=LR(h),v[l|0]=m;a=a+1|0;continue}}}aa(17184,8885,27,9412);p()}aa(17134,8885,28,9412);p()}hb=c+16|0}function KA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Zg(b,Td(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;f=((c|0)!=0)<<1;h=x[b>>2];j=ie(h,x[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){JA(b,32);hb=e+16|0}else{a=k+(d<<2)|0;w[e+12>>1]=y[a+160|0]|y[a+161|0]<<8;g=Se(e+14|0,e+12|0);i=zb(h,d);g=z[g>>1];w[i>>1]=g;w[e+14>>1]=g+1;v[e+11|0]=(c^y[a+162|0])>>>f;v[e+10|0]=64;l=i,m=y[Wb(e+11|0,e+10|0)|0],v[l+2|0]=m;d=d+1|0;continue}break}}function FK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;zh(e+8|0,b);f=hb-16|0;hb=f;Kg(f+8|0,x[e+8>>2],x[e+12>>2]);g=x[f+8>>2];b=x[f+12>>2];h=hb-16|0;hb=h;k=h,l=Bb(a),x[k+8>>2]=l;a=b;b=hb-16|0;hb=b;j=x[h+8>>2];c=j;d=x[c+8>>2];c=x[c+12>>2];i=c;a:{if((c|0)<0){break a}c=x[j+4>>2];if(!i&c>>>0<d>>>0|i){break a}x[b+8>>2]=c-d;x[b+12>>2]=0-(i+(d>>>0>c>>>0)|0);x[b>>2]=a;x[b+4>>2]=0;c=BB(b+8|0,b);if((Ky(x[c>>2],x[c+4>>2])|0)!=(a|0)){break a}pi(g,a+g|0,d+x[j>>2]|0);d=x[h+8>>2];g=d;c=x[d+8>>2];d=x[d+12>>2];i=a;a=a+c|0;d=i>>>0>a>>>0?d+1|0:d;x[g+8>>2]=a;x[g+12>>2]=d}hb=b+16|0;hb=h+16|0;hb=f+16|0;hb=e+16|0}function V5(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=hb-96|0;hb=d;x[d+88>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];x[d+56>>2]=x[a+8>>2];x[d+60>>2]=f;x[d+48>>2]=c;x[d+52>>2]=e;a=Yd(d+40|0);c=x[d+60>>2];x[d+24>>2]=x[d+56>>2];x[d+28>>2]=c;x[23604]=0;c=x[d+52>>2];x[d+16>>2]=x[d+48>>2];x[d+20>>2]=c;c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;U(884,d- -64|0,d+16|0,d+8|0);a=x[23604];x[23604]=0;a:{b:{if((a|0)!=1){a=x[Mf(d+32|0,d+88|0)>>2];x[23604]=0;b=+xa(885,d- -64|0,+b,a|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}yb(d- -64|0);te(d+88|0);hb=d+96|0;return+b}a=P()|0;break a}a=P()|0;yb(d- -64|0)}te(d+88|0);T(a|0);p()}function y9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;f=c;e=hb-16|0;hb=e;g=b;d=Sd(b);a:{if(d){c=jc(g);while(1){b=d;d=b+16|0;if(Ly(f,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!Ly(d,f)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=jc(g);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=hb-16|0;hb=b;d=jc(g);d=ph(e,Jc(28),qh(b+8|0,d));i=x[d>>2];x[23604]=0;R(799,i+16|0,f|0);f=x[23604];x[23604]=0;b:{if((f|0)!=1){j=jc(d),k=1,v[j+4|0]=k;hb=b+16|0;break b}a=P()|0;FL(d);T(a|0);p()}Vg(g,x[e+12>>2],c,x[e>>2]);b=Wd(e);FL(e);i=1}c=h+8|0;Ug(c,x[Ib(e,b)>>2],i);hb=e+16|0;aP(a,c);hb=h+16|0}function vL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=hb-16|0;hb=h;v[h+15|0]=b;v[h+14|0]=10;Zg(g,y[Wb(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;j=x[g>>2];k=ie(j,x[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=y[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=zb(j,b);l=D(b,3)+f|0;i=(y[l|0]|y[l+1|0]<<8)>>>4|0;w[m>>1]=i;c:{if(b){n=z[zb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=zb(j,b),p=i,w[o>>1]=p}o=m,p=Td(y[l+2|0],0,64),v[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}v[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;hb=h+16|0}function oD(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];d=Eg(c,x[a+4>>2]);if(d>>>0<b>>>0){f=hb-32|0;hb=f;c=b-d|0;b=x[Cb(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=hb-16|0;hb=d;b=Rq(d,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){ic(b);hb=d+16|0}else{tl(a);a=a+8|0;x[b+4>>2]=a;continue}break}break a}b=Cb(a);d=Tq(f+8|0,Uq(a,Eg(x[a>>2],e)+c|0),Eg(x[a>>2],x[a+4>>2]),b);b=hb-16|0;hb=b;x[b>>2]=x[d+8>>2];e=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=(c<<3)+e;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){tl(c);c=x[b>>2]+8|0;x[b>>2]=c;continue}break}Hd(b);hb=b+16|0;xd(a,d);Sq(d)}hb=f+32|0;return}if(b>>>0<d>>>0){Id(a,c+(b<<3)|0)}}function Bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){f=x[a+4>>2];e=x[b+4>>2];if((f|0)!=(e|0)){break b}x[c+12>>2]=d;x[c+8>>2]=d;h=x[Fb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;e=x[Fb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){a=0;if((b|0)==(h|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{g=Lh(E(Fd(B[Kp(j,a,b)>>2],E(-1))*E(32768)));d:{if(E(F(g))<E(2147483648)){d=~~g;break d}d=-2147483648}d=Vc(d);k=MR(i,f,a,b),l=d,w[k>>1]=l;a=a+1|0;continue}}}aa(17184,8885,27,9412);p()}aa(17134,8885,28,9412);p()}hb=c+16|0}function z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb+-64|0;hb=f;c=f+16|0;i=hb-16|0;hb=i;j=gO(i+8|0);while(1){if((k|0)==12){hb=i+16|0}else{g=hb+-64|0;hb=g;e=x[j+4>>2];d=x[j>>2];a:{if((e|0)==(d|0)){break a}h=(e-d|0)+1|0;if(!h){e=ZI(_I(g+8|0,32));break a}d=G(h);e=_I(g+8|0,(h<<d+1?32:31)-d|0);while(1){d=ZI(e);if(h>>>0<=d>>>0){continue}break}e=x[j>>2]+d|0}hb=g- -64|0;l=zb(c,k),m=e,x[l>>2]=m;k=k+1|0;continue}break}c=rO(f,c,vO(c));lO(a,c);gm(c);hb=f- -64|0;c=ax(a+120|0,a,b);v[c+20|0]=1;x[23604]=0;R(1016,a|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){a=P()|0;tn(c);T(a|0);p()}return a|0}function jea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;od(b,0);Ph(d,1,a);c=d+16|0;Dc(c,d);ze(b+43|0,c);xb(c);x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+24>>2]=y[a+62|0]|y[a+63|0]<<8;bq(b,+((y[a+60|0]^8)-120|0)/192);v[d+16|0]=y[a+61|0];v[d|0]=64;f=b,g=y[Wb(c,d)|0]<<2,w[f+30>>1]=g;w[b+34>>1]=0;c=y[a+47|0];if(c&4){w[b+34>>1]=1;x[b>>2]=x[b>>2]>>>1;e=1;c=y[a+47|0]}if(c&32){e=e|4;w[b+34>>1]=e;c=y[a+47|0]}if(c<<24>>24<0){w[b+34>>1]=e|2}hb=d+32|0}function e_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=JF(b);pk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;ok(k,a);Hi(i,k);Gc(k);Ch(k,a);Hi(h,k);Gc(k);l=d,m=Mi(a),x[l>>2]=m;l=e,m=Ni(a),x[l>>2]=m;Jg(k,a);Ab(f,k);xb(k);Dh(k,a);Hi(g,k);Gc(k);a=nk(a);break a}a=IF(b);pk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;ok(k,a);Hi(i,k);Gc(k);Ch(k,a);Hi(h,k);Gc(k);l=d,m=Mi(a),x[l>>2]=m;l=e,m=Ni(a),x[l>>2]=m;Jg(k,a);Ab(f,k);xb(k);Dh(k,a);Hi(g,k);Gc(k);a=nk(a)}x[j>>2]=a;hb=k+16|0}function l_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=MF(b);pk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;ok(k,a);Ab(i,k);xb(k);Ch(k,a);Ab(h,k);xb(k);l=d,m=Mi(a),v[l|0]=m;l=e,m=Ni(a),v[l|0]=m;Jg(k,a);Ab(f,k);xb(k);Dh(k,a);Ab(g,k);xb(k);a=nk(a);break a}a=LF(b);pk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;ok(k,a);Ab(i,k);xb(k);Ch(k,a);Ab(h,k);xb(k);l=d,m=Mi(a),v[l|0]=m;l=e,m=Ni(a),v[l|0]=m;Jg(k,a);Ab(f,k);xb(k);Dh(k,a);Ab(g,k);xb(k);a=nk(a)}x[j>>2]=a;hb=k+16|0}function Vr(a,b,c){var d=0,e=0;d=a,e=Ri(E(E(B[c+1792>>2]*E(75038))+E(E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489))+E(E(E(B[c+1280>>2]+B[c+2304>>2])*E(6574))+E(E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153))+E(E(E(B[c+768>>2]+B[c+2816>>2])*E(2037))+E(E(E(B[c+3072>>2]-B[c+512>>2])*E(459))+E(E(E(B[c+256>>2]+B[c+3328>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))))))))),w[d>>1]=e;d=(b<<5)+a|0,e=Ri(E(E(B[c+8>>2]*E(-5))+E(E(B[c+520>>2]*E(146))+E(E(B[c+1032>>2]*E(-45))+E(E(B[c+1544>>2]*E(-9975))+E(E(B[c+2056>>2]*E(64019))+E(E(B[c+2568>>2]*E(9727))+E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))))))))),w[d>>1]=e}function Cea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=hb-32|0;hb=f;a:{c=x[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=D(Bg(x[x[a+48>>2]+12>>2]),d?b-c|0:c-b|0);e=Bb(x[a+4>>2]);c:{if(d){e=Ib(f+24|0,e);d=f+16|0;sh(d);e=x[e>>2];x[23604]=0;X(587,a|0,e|0,c|0,d|0);c=x[23604];x[23604]=0;if((c|0)!=1){break c}a=V(92520)|0;if((ib|0)!=(da(92520)|0)){break a}_(a|0)|0;$();break b}c=Ib(f+8|0,MA(e,c));e=x[Ib(f,Bb(x[a+4>>2]))>>2];d=hb-16|0;hb=d;g=x[c>>2];c=x[a>>2];c=D(zs(g,Bb(c)),6)+c|0;if(Ob(g,e)){Id(a,rL(c+D(zs(e,g),6)|0,x[a+4>>2],c))}Ib(d+8|0,c);hb=d+16|0}x[a+12>>2]=b}hb=f+32|0;return}T(a|0);p()}function MQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;Oj(a+8|0,0);d=x[b+4>>2];if(d){Fq(a,d);$k(c+8|0,x[b>>2]);hm(c,x[b>>2],x[b+4>>2]);b=hb-32|0;hb=b;d=x[c+8>>2];j=x[c>>2];e=x[a+4>>2];g=x[c+12>>2];k=x[c+4>>2];f=e+KQ(d,g,j,k)|0;x[a+4>>2]=f;a:{b:{if(!e){h=f-1|0;break b}h=f-1|0;if((h^e-1)>>>0>31){break b}x[b+24>>2]=d;x[b+28>>2]=g;i=x[a>>2];break a}i=x[a>>2];x[i+((f>>>0>=33?h>>>5|0:0)<<2)>>2]=0;x[b+24>>2]=d;x[b+28>>2]=g}vo(b+16|0,i,e);d=x[b+28>>2];x[b>>2]=x[b+24>>2];x[b+4>>2]=d;LQ(b+8|0,b,j,k,x[b+16>>2],x[b+20>>2]);hb=b+32|0}hb=c+16|0;return a|0}function $fa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=Sj(b),x[i>>2]=j;f=z[b>>1];d=hb-16|0;hb=d;g=a;c=Sd(a);a:{if(c){b=jc(g);while(1){a=c;c=z[a+14>>1];if(eo(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!eo(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=jc(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=hb-16|0;hb=a;c=jc(g);f=ph(d,Jc(20),qh(a+8|0,c));c=x[f>>2];h=z[x[e>>2]>>1];w[c+16>>1]=0;w[c+14>>1]=h;i=jc(f),j=1,v[i+4|0]=j;hb=a+16|0;Vg(g,x[d+12>>2],b,x[d>>2]);a=Wd(d);cl(d);h=1}Ug(e+8|0,x[Ib(d,a)>>2],h);hb=d+16|0;a=Op(x[e+8>>2]);hb=e+16|0;return a+2|0}function vX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=hb-32|0;hb=k;n=x[c>>2];l=x[c+8>>2];m=x[c+4>>2];c=k;x[c+8>>2]=m;x[c+12>>2]=l;x[c+24>>2]=m;x[c+28>>2]=l;x[c+20>>2]=n;x[c+16>>2]=d;x[23604]=0;d=x[c+20>>2];x[c>>2]=x[c+16>>2];x[c+4>>2]=d;a=Ja(996,a|0,b|0,c|0)|0;b=x[23604];x[23604]=0;a:{b:{if((b|0)==1){_(V(0)|0)|0;x[23604]=0;ia(883,10307,e|0,f|0,g|0,h|0,i|0,j|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}$();a=-255}hb=k+32|0;break a}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}return a|0}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=hb-16|0;hb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>18|0;n=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){g=(e<<1)+n|0;h=w[g>>1];x[(e<<2)+b>>2]=h+((D(w[g+4>>1]-h|0,m)|0)/16384|0);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Ub(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function Vg(a,b,c,d){var e=0,f=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;b=x[x[a>>2]>>2];if(b){x[a>>2]=b;d=x[c>>2]}f=x[jc(a)>>2];v[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=x[d+8>>2];if(y[c+12|0]){break a}b:{if(oh(c)){b=x[c+8>>2];e=x[b+4>>2];if(!(!e|y[e+12|0])){break b}if(!oh(d)){Vp(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Up(b);break a}b=x[c+8>>2];e=x[b>>2];if(!(!e|y[e+12|0])){break b}if(oh(d)){Up(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Vp(b);break a}v[c+12|0]=1;d=b;v[d+12|0]=(d|0)==(f|0);v[e+12|0]=1;continue}break}a=Cb(a);x[a>>2]=x[a>>2]+1}function Faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb+-64|0;hb=c;f=qO(a,1<<b-1);x[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=x[10597];d=c+32|0;x[d+8>>2]=x[10596];x[d+12>>2]=e;e=x[10595];x[d>>2]=x[10594];x[d+4>>2]=e;Wy(d,h*+(b>>>0));kO(c+48|0,C[c+32>>3],C[c+40>>3]);d=bd(x[f>>2],a);e=x[c+60>>2];x[d+8>>2]=x[c+56>>2];x[d+12>>2]=e;e=x[c+52>>2];x[d>>2]=x[c+48>>2];x[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=Uk(c+16|0,1,0);b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;Qx(f,0,g,c);hb=c- -64|0;return f|0}function hk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;f=a+36|0;c=x[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=x[a+20>>2];if(d>>>0>=A[a+24>>2]){fn(e,f,tD(f));qd(e+8|0,a,x[e>>2],x[e+4>>2]);c=x[e+12>>2];x[a+24>>2]=c;x[a+20>>2]=0;if(!c){break c}d=0;c=x[a+32>>2]}x[a+20>>2]=d+1;g=y[(a+d|0)+36|0];d=c+8|0;x[a+32>>2]=d;x[a+28>>2]=x[a+28>>2]|g<<c;c=d;continue}break}a=ba(8)|0;x[23604]=0;b=S(153,a|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break a}b=P()|0;ca(a|0);T(b|0);p()}x[a+32>>2]=c-b;d=a;a=x[a+28>>2];x[d+28>>2]=a>>>b;hb=e+16|0;return a&(-1<<b^-1)}ha(b|0,30848,154);p()}function bm(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function MH(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(Ke(a)){gc(a,31);return 0}g=a,h=Ke(a),v[g+1375|0]=h;d=Qi(a);b=Qi(a);Qi(a);g=a,h=Qi(a),x[g+1112>>2]=h;Qi(a);c=Ke(a);x[a+1116>>2]=c;if(!Kw(a,a+1120|0,c)){gc(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){b=0;e=x[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}x[a- -64>>2]=d;x[a+60>>2]=(x[a+56>>2]+(c+e|0)|0)+27}x[a+1380>>2]=0;return 1}function nn(a,b,c){var d=0,e=0,f=0,g=0;e=hb-32|0;hb=e;v[a|0]=0;a:{d=x[x[b>>2]-12>>2]+b|0;b:{if(!x[d+16>>2]){d=x[d+72>>2];if(d){Aq(d)}c:{if(c){break c}c=x[x[b>>2]-12>>2]+b|0;if(!(y[c+5|0]&16)){break c}Pc(e+24|0,x[c+28>>2]);x[23604]=0;f=S(18,x[e+24>>2])|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}$b(e+24|0);c=um(e+16|0,b);d=zc(e+8|0);while(1){d:{if(Lg(c,d)){break d}g=zk(x[c>>2]);if(!fh(x[f+8>>2],1,g)){break d}Hl(c);continue}break}if(!Lg(c,d)){break c}kj(x[x[b>>2]-12>>2]+b|0,6)}v[a|0]=!x[(x[x[b>>2]-12>>2]+b|0)+16>>2];break b}kj(d,4)}hb=e+32|0;return a}a=P()|0;$b(e+24|0);T(a|0);p()}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=hb-16|0;hb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>10&4194048;n=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){g=e+n|0;h=v[g|0];x[(e<<2)+b>>2]=((D(v[g+2|0]-h|0,m)|0)/16384|0)+(h<<8);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Ub(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function $v(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;Pc(f+8|0,b);x[23604]=0;b=S(1083,x[f+8>>2])|0;g=x[23604];x[23604]=0;a:{if((g|0)==1){break a}x[23604]=0;X(1094,b|0,82128,82160,c|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}x[23604]=0;b=S(1084,x[f+8>>2])|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;c=S(1095,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break a}x[d>>2]=c;x[23604]=0;c=S(1092,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}x[e>>2]=c;x[23604]=0;R(1093,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$b(f+8|0);hb=f+16|0;return}a=P()|0;$b(f+8|0);T(a|0);p()}function fX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=hb+-64|0;hb=g;jk(g+16|0,c);x[23604]=0;c=g+28|0;R(99,c|0,d|0);d=x[23604];x[23604]=0;b:{c:{d:{if((d|0)==1){break d}x[23604]=0;c=g+40|0;R(99,c|0,e|0);d=x[23604];x[23604]=0;if((d|0)==1){break d}x[23604]=0;c=g+52|0;R(99,c|0,f|0);d=x[23604];x[23604]=0;if((d|0)==1){break d}wv(g+8|0,g+16|0);x[23604]=0;X(100,a|0,b|0,x[g+8>>2],x[g+12>>2]);a=x[23604];x[23604]=0;if((a|0)==1){break c}TD(g+16|0);hb=g- -64|0;break a}a=P()|0;while(1){c=xb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=P()|0;TD(g+16|0)}T(a|0);p()}}function eU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){if(!b){break a}c=a;a=c+g|0;f=y[a+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(c+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=c+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=c+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}b=b-1|0;if(!f){continue}c=y[(c+g|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}v[e|0]=0}}function r5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;a:{b:{c:{if((d|0)==1){break c}x[23604]=0;Y(901,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break c}d=x[a+24>>2];b=oc(c+8|0,b);x[23604]=0;e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;X(913,c+16|0,d|0,c|0,1);b=x[23604];x[23604]=0;if((b|0)==1){break c}a=c+16|0;b=Qf(Pb(a));xb(a);break b}_(V(0)|0)|0;b=0;x[23604]=0;X(887,5496,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$()}hb=c+32|0;return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function dw(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;Pc(f+8|0,b);x[23604]=0;b=S(18,x[f+8>>2])|0;g=x[23604];x[23604]=0;a:{if((g|0)==1){break a}x[23604]=0;X(1081,b|0,82128,82160,c|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}x[23604]=0;b=S(1067,x[f+8>>2])|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;c=S(1082,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break a}v[d|0]=c;x[23604]=0;c=S(1079,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}v[e|0]=c;x[23604]=0;R(1080,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$b(f+8|0);hb=f+16|0;return}a=P()|0;$b(f+8|0);T(a|0);p()}function L_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;x[f+24>>2]=b;a:{if(!(v[c+4|0]&1)){c=mb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}Pc(f+8|0,x[c+28>>2]);x[23604]=0;a=S(1084,x[f+8>>2])|0;b=x[23604];x[23604]=0;b:{if((b|0)!=1){$b(f+8|0);c:{if(e){Dh(f+8|0,a);break c}Ch(f+8|0,a)}g=f,h=pd(f+8|0),x[g>>2]=h;while(1){a=uk(f+8|0);b=x[f>>2];if(!Ob(b,a)){c=x[f+24>>2];Gc(f+8|0);break a}a=x[b>>2];x[23604]=0;Q(1098,f+24|0,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){Fe(f);continue}break}c=P()|0;Gc(f+8|0);break b}c=P()|0;$b(f+8|0)}T(c|0);p()}hb=f+32|0;return c|0}function Zg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=rc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Cb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=hb-16|0;hb=c;b=lh(c,a,b);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){ic(b);hb=c+16|0}else{Ru(a);a=a+4|0;x[b+4>>2]=a;continue}break}break a}c=Cb(a);c=Wf(e+8|0,vg(a,rc(x[a>>2],d)+b|0),rc(x[a>>2],x[a+4>>2]),c);f=hb-16|0;hb=f;b=pl(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Ru(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Hd(b);hb=f+16|0;xd(a,c);Vf(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Id(a,d+(b<<2)|0)}}function ZC(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+4>>2]=D(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),5)+(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24));x[b+8>>2]=(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))+((y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))<<3);x[b+12>>2]=(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+((y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24))<<2);a=b+4|0;d=zb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Np(x[a>>2],x[c>>2])?c:a;continue}}hb=b+16|0;return x[a>>2]-36|0}function _d(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a=dh(a,-1,-1);a:{b:{if(ud(y[nn(c+24|0,b,1)|0])){d=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[23604]=0;R(93,c+8|0,d|0);d=x[23604];x[23604]=0;c:{if((d|0)!=1){d=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=d;d=x[c+20>>2];x[a+8>>2]=x[c+16>>2];x[a+12>>2]=d;break c}_(V(0)|0)|0;e=1;mn(x[x[b>>2]-12>>2]+b|0,1);if(x[(x[x[b>>2]-12>>2]+b|0)+20>>2]&1){x[23604]=0;Z(91);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break b}T(a|0);p()}$()}kj(x[x[b>>2]-12>>2]+b|0,e)}hb=c+32|0;return}V(0)|0;Vb()}p()}function V_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;x[f+24>>2]=b;a:{if(!(v[c+4|0]&1)){c=mb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}Pc(f+8|0,x[c+28>>2]);x[23604]=0;a=S(1067,x[f+8>>2])|0;b=x[23604];x[23604]=0;b:{if((b|0)!=1){$b(f+8|0);c:{if(e){Dh(f+8|0,a);break c}Ch(f+8|0,a)}g=f,h=pd(f+8|0),x[g>>2]=h;while(1){a=pf(f+8|0);b=x[f>>2];if(!Ob(b,a)){c=x[f+24>>2];xb(f+8|0);break a}a=v[b|0];x[23604]=0;Q(20,f+24|0,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){Le(f);continue}break}c=P()|0;xb(f+8|0);break b}c=P()|0;$b(f+8|0)}T(c|0);p()}hb=f+32|0;return c|0}function vga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-48|0;hb=e;d=x[a+8>>2];c=x[a>>2];x[23604]=0;d=W(142,c|0,d|0,1)|0;c=x[23604];x[23604]=0;a:{if((c|0)==1){break a}b:{if(!d){break b}x[23604]=0;Y(449,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break a}x[23604]=0;d=S(192,a|0)|0;c=x[23604];x[23604]=0;c:{if((c|0)!=1){while(1){if(!(d&255)){break b}x[23604]=0;c=Q(450,a|0,e+8|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break c}d:{if(!c){break d}c=y[e+8|0];if(c>>>0>63){break d}vc(rS(x[b>>2],c),e+8|0,33)}d=d-1|0;continue}}break a}break a}yb(a);hb=e+48|0;return}b=P()|0;yb(a);T(b|0);p()}function AH(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[464324]){f=464325,g=Ca()|0,v[f|0]=g;v[464324]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[464325]){break c}d=+Ba();break a}x[116080]=28;return-1}d=+Ha()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=~~c>>>0;a=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break e}a=-2147483648}x[b>>2]=e;x[b+4>>2]=a;c=(d-(+(Jia(e,a,1e3,0)>>>0)+ +(lb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function pJ(a,b){var c=0,d=0;c=x[a>>2];x[a>>2]=b;if(c){x[23604]=0;Y(766,c|0);a=x[23604];x[23604]=0;a:{if((a|0)!=1){a=x[c+4>>2];if(a){if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(d|0)){b=b-4|0;bg(b);continue}break}x[a+4>>2]=d;b=x[a>>2];Kh(a);Hb(b)}Hb(a)}x[c+4>>2]=0;uM(c+1298408|0);ky(c+1298344|0);xb(c+1298332|0);xb(c+1298320|0);xb(c+1298308|0);jy(c+1298304|0);iy(c+1298300|0);Os(c+1298264|0);xy(c+1074376|0);b=c+946300|0;a=c+906300|0;while(1){b=Gs(b-160|0);if((a|0)!=(b|0)){continue}break}fz(c+484360|0);nM(c+484344|0);sc(c+480248|0);break a}V(0)|0;Vb();p()}Hb(c)}}function tX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=hb-16|0;hb=c;x[23604]=0;Y(900,a|0);e=x[23604];x[23604]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[23604]=0;Y(901,b|0);e=x[23604];x[23604]=0;if((e|0)==1){break d}e=x[a+24>>2];b=oc(c+8|0,b);x[23604]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;WE(921,e,c,f,d);d=x[23604];x[23604]=0;b=1;if((d|0)!=1){break c}}_(V(0)|0)|0;x[23604]=0;X(887,8544,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break b}$();b=0}hb=c+16|0;break a}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}return b|0}function tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){c=hb-16|0;hb=c;if(bh(715827882)>>>0<b>>>0){Sc();p()}d=Jc(D(b,6));x[c+12>>2]=b;x[c+8>>2]=d;d=x[c+8>>2];x[a+4>>2]=d;x[a>>2]=d;f=Cb(a),g=d+D(x[c+12>>2],6)|0,x[f>>2]=g;hb=c+16|0;d=hb-16|0;hb=d;c=hq(d,a,b);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){ic(c);hb=d+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4;b=b+6|0;x[c+4>>2]=b;continue}break}}v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function AK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=fi(a,b,c,d);v[a+4260|0]=e;x[a>>2]=46772;c=Sb(a+4264|0);d=Sb(a+4276|0);x[a+4328>>2]=0;b=a+4320|0;x[b>>2]=0;x[b+4>>2]=0;x[a+4312>>2]=0;x[a+4316>>2]=0;b=a+4208|0;f=zb(b,0),g=1056964608,x[f>>2]=g;f=zb(b,1),g=1036831949,x[f>>2]=g;f=zb(b,2),g=1038174126,x[f>>2]=g;f=zb(b,3),g=1065353216,x[f>>2]=g;f=zb(b,4),g=1061158912,x[f>>2]=g;f=zb(b,5),g=1059082943,x[f>>2]=g;f=zb(b,6),g=1061997773,x[f>>2]=g;x[23604]=0;R(851,a+44|0,2);b=x[23604];x[23604]=0;if((b|0)!=1){ei(a);return a|0}b=P()|0;sc(d);sc(c);uf(a);T(b|0);p()}function KM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if(x[a+480180>>2]!=1){break a}c=y[b+846|0];if(!c){break a}d=x[b+104>>2];if(!d){break a}if(!Qd(x[d>>2],x[d+20>>2])){break a}f=z[d+34>>1];if(!(f&10)){break a}c=y[b+847|0]+y[(c&15)+33760|0]|0;v[b+847|0]=c;if(c<<24>>24>=0){break a}v[b+847|0]=0;h=f&2;c=x[(h?4:12)+d>>2];g=b;b=x[b+760>>2]+1|0;b=b>>>0<x[(h?8:16)+d>>2]-c>>>0?b:0;x[g+760>>2]=b;g=x[d+20>>2];c=b+c|0;b=gk(f);hc(e+8|0,g+D(c,b)|0,b);b=x[e+8>>2];f=Gb(b,x[e+12>>2]);while(1){if((b|0)==(f|0)){aj(d,a)}else{v[b|0]=y[b|0]^-1;b=b+1|0;continue}break}}hb=e+16|0}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;h=v[e|0];e=((D(v[e+1|0]-h|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(h<<8)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Ub(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;h=w[e>>1];e=h+((D(w[e+2>>1]-h|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Ub(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function P8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=b;a:{if(Es(a)>>>0>=b>>>0){e=x[a>>2];g=ak(e,x[a+4>>2]);x[f+8>>2]=g;d=x[Fb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=pL(e,c)+52|0;continue}break}if(b>>>0>g>>>0){Jx(a,b-g|0,c);break a}nL(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){Fs(a);d=x[a>>2];Es(a);Hb(d);h=Cb(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}e=mL(a,b);d=hb-16|0;hb=d;if(bh(82595524)>>>0<e>>>0){Sc();p()}lL(d+8|0,e);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;h=Cb(a),i=e+D(x[d+12>>2],52)|0,x[h>>2]=i;hb=d+16|0;Jx(a,b,c)}hb=f+16|0}function P5(a){a=a|0;var b=0;b=7934;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21502;break a}b=7967;break a}b=17402;break a;case 0:b=4972;break a;case 9:b=7990;break a;case 10:b=8004;break a;case 11:b=5349;break a;case 12:b=5369;break a;case 19:b=8016;break a;case 20:b=7948;break a;case 21:b=12705;break a;case 22:b=12028;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=5980;break a}b=7901}return Qf(b)|0}function x$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;d=y[a+52|0];a:{if(tc(b,-1)){if(d){break a}b=x[a+48>>2];e=a,f=tc(b,-1)^1,v[e+52|0]=f;break a}b:{if(!d){break b}v[c+19|0]=x[a+48>>2]<<24>>24;c:{d:{e:{d=c+20|0;switch(Ir(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((Gr(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}hb=c+32|0;return b|0}function uX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;x[23604]=0;Y(900,a|0);c=x[23604];x[23604]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[23604]=0;Y(901,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break d}c=x[a+24>>2];b=oc(d+8|0,b);x[23604]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=XE(c,d,1);e=x[23604];x[23604]=0;c=lb;if((e|0)!=1){break c}}_(V(0)|0)|0;x[23604]=0;X(887,8575,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break b}$();b=0;c=0}hb=d+16|0;a=c;break a}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}ib=a;return b|0}function n5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[23604]=0;Y(900,a|0);e=x[23604];x[23604]=0;a:{b:{c:{if((e|0)==1){break c}x[23604]=0;Y(901,b|0);e=x[23604];x[23604]=0;if((e|0)==1){break c}e=x[a+24>>2];b=oc(d+8|0,b);x[23604]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;X(918,e|0,d|0,(c|0)!=0|0,1);c=x[23604];x[23604]=0;b=1;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,9897,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=0}hb=d+16|0;return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function B$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;a:{b:{c:{if(tc(b,-1)){break c}v[c+23|0]=b<<24>>24;if(y[a+44|0]){d=-1;if((Yj(c+23|0,1,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Ir(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Yj(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Yj(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=qw(b);break a}d=-1}hb=c+32|0;return d|0}function Bv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-32|0;hb=h;g=Ib(h+24|0,x[a+4>>2]);e=Ib(h+16|0,x[a>>2]);j=Ib(h+8|0,x[b+4>>2]);k=hb-16|0;hb=k;f=hb-16|0;hb=f;l=hb-16|0;hb=l;m=hb-16|0;hb=m;i=x[g>>2];g=x[e>>2];e=i-g|0;i=D((e|0)/(d|0)|0,c);d=x[j>>2];j=i+d|0;i=ah(j,g,e);e=D((e|0)/(c|0)|0,c);x[m+12>>2]=i+e;yd(l+8|0,e+g|0,m+12|0);hb=m+16|0;yd(f+8|0,g,Ib(l,d+D((j-d|0)/(c|0)|0,c)|0));hb=l+16|0;c=x[f+8>>2];x[f>>2]=x[f+12>>2];yd(k+8|0,c,f);hb=f+16|0;hb=k+16|0;x[b+4>>2]=x[k+12>>2];qc(a,b+4|0);qc(a+4|0,b+8|0);qc(Cb(a),yc(b));x[b>>2]=x[b+4>>2];hb=h+32|0}function h7(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[x[a+16>>2]+24620>>2];b=Ec(Kia(Jia(b,b>>31,3840,0),lb,1e3,0),lb);x[a+4316>>2]=b;x[23604]=0;x[c+12>>2]=0;U(857,a+4264|0,b|0,c+12|0);b=x[23604];x[23604]=0;a:{b:{c:{if((b|0)!=1){d:{if(!y[a+4260|0]){break d}b=x[a+4316>>2];x[23604]=0;x[c+12>>2]=0;U(857,a+4276|0,b|0,c+12|0);b=x[23604];x[23604]=0;if((b|0)!=1){break d}b=V(92520)|0;break c}x[c+12>>2]=0;b=c+12|0;xK(a+4288|0,b);x[c+12>>2]=0;xK(a+4300|0,b);break b}b=V(92520)|0}if((ib|0)!=(da(92520)|0)){break a}_(b|0)|0;x[a+4316>>2]=0;$()}hb=c+16|0;return}T(b|0);p()}function bP(a,b){var c=0,d=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;lz(a+48|0);lz(a+68|0);lz(a+88|0);at(a+492|0);at(a+524|0);Bm(a,0,0);Am(a,0,0);x[a+40>>2]=0;x[a+44>>2]=0;Jt(a,b);b=a+108|0;d=Vz(b);c=1;while(1){if((b|0)!=(d|0)){v[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function b_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=hb-16|0;hb=h;e=Eb(x[a+4>>2],y[a+11|0]);d=Zm(a);g=ie(b,c);a:{if(!g){break a}b:{f=Pb(a);if(f>>>0<=b>>>0){f=(Eb(x[a+4>>2],y[a+11|0])<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(d-e>>>0<g>>>0){HF(a,d,(e+g|0)-d|0,e,e)}d=Pb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}Ad(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=pG(h,b,c);c=Pb(b);e=y[b+11|0];d=x[b+4>>2];x[23604]=0;W(1119,a|0,c|0,Eb(d,e)|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Gc(b);break a}a=P()|0;Gc(b);T(a|0);p()}Ad(d,0);Sg(a,e+g|0)}hb=h+16|0;return a|0}function I$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;a:{b:{c:{if(ln(b)){break c}x[c+20>>2]=b;if(y[a+44|0]){d=-1;if((Yj(c+20|0,4,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Ir(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Yj(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Yj(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=ln(b)?0:b;break a}d=-1}hb=c+32|0;return d|0}function m5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=hb-16|0;hb=e;x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;a:{b:{c:{if((d|0)==1){break c}x[23604]=0;Y(901,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break c}d=x[a+24>>2];b=oc(e+8|0,b);x[23604]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Xa(920,d|0,e|0,+c,1);d=x[23604];x[23604]=0;b=1;if((d|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,5887,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=0}hb=e+16|0;return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Qr(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=hb-240|0;hb=h;x[h+236>>2]=d;x[h+232>>2]=c;x[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-x[(e<<2)+g>>2]|0;if((mb[b|0](i,a)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=x[((e<<2)+g|0)-8>>2];l=j-4|0;if((mb[b|0](l,i)|0)>=0){break e}if((mb[b|0](l-f|0,i)|0)>=0){break e}}x[(k<<2)+h>>2]=i;c=yH(c,d);Rr(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=x[h+236>>2];c=x[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}xH(h,k);Fw(i,b,e,g)}hb=h+240|0}function fR(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1196314451){break a}c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(y[c|0]|y[c+1|0]<<8){break a}b=a+1096|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))-5>>>0<4294967292){break a}if(!ut(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|y[a+32|0]>15|y[a+33|0]>64){break a}b=ut(a);a=a+34|0;if(b){continue}break}}return d}function E$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;d=y[a+52|0];a:{if(ln(b)){if(d){break a}b=x[a+48>>2];e=a,f=ln(b)^1,v[e+52|0]=f;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(Ir(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((Gr(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}hb=c+32|0;return b|0}function ar(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;a=Kb(a);a:{b:{c:{switch(b|0){case 0:x[23604]=0;b=Q(1,d|0,15709)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}Ab(a,b);xb(b);break b;case 1:x[23604]=0;b=Q(1,d|0,15734)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Ab(a,b);xb(b);break b}break a;case 2:x[23604]=0;b=Q(1,d|0,15682)|0;c=x[23604];x[23604]=0;if((c|0)!=1){Ab(a,b);xb(b);break b}break a;case 3:break c;default:break b}}x[23604]=0;b=Q(1,d|0,15656)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}Ab(a,b);xb(b)}hb=d+16|0;return}b=P()|0;xb(a);T(b|0);p()}function EA(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=y[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!y[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=y[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=D(c>>>3|0,b);b=((d|0)==10)<<4}c=b+D(Yp(y[a+1|0]),c)|0}return c}function t8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{e=hb-48|0;hb=e;d=x[a+28>>2];Sm(x[x[d>>2]-12>>2]+d|0,0);h=x[x[b>>2]+4>>2];if(h){i=x[a+28>>2];f=e+32|0;g=x[a+12>>2];d=x[a+8>>2]+h|0;g=h>>>0>d>>>0?g+1|0:g;f=dh(f,d,g);d=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=d;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d;zj(i,e)}d=e+16|0;_d(d,x[a+28>>2]);bz(x[a+28>>2],c,x[x[b>>2]+8>>2]);c=x[b>>2];b=Xm(d,Gb(x[a+32>>2],x[c>>2]),z[c+12>>1]);x[23604]=0;Q(846,a|0,c|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){Db(b);hb=e+48|0;break a}a=P()|0;Db(b);T(a|0);p()}}function Xaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;h=z[c>>1];i=c;e=hb-16|0;hb=e;f=b;d=Sd(b);a:{if(d){c=jc(f);while(1){b=d;d=z[b+14>>1];if(rl(h,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!rl(d,h)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=jc(f);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=hb-16|0;hb=b;d=jc(f);d=ph(e,Jc(16),qh(b+8|0,d));oj(x[d>>2]+14|0,z[i>>1]);k=jc(d),l=1,v[k+4|0]=l;hb=b+16|0;Vg(f,x[e+12>>2],c,x[e>>2]);b=Wd(e);cl(e);j=1}c=g+8|0;Ug(c,x[Ib(e,b)>>2],j);hb=e+16|0;aP(a,c);hb=g+16|0}function sC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;x[f+8>>2]=e;x[f+12>>2]=d;Ve(a);pp(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;x[f+4>>2]=i;g=x[Fb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=hu(Bt(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){x[f+4>>2]=i-g;e=h+1|0;d=x[Fb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=v[uc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=uc(j,e),n=32,v[m|0]=n}e=e+1|0;continue}}break}hb=f+16|0}function Jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;g=z[nl(x[a>>2],x[a+4>>2],b)>>1];a:{b:{if(!jq(a,b)){break b}c=x[a+24>>2];d=Bb(x[c+484360>>2]);x[f+8>>2]=d;h=Bb(x[c+484364>>2]);while(1){if(!Ob(d,h)){break b}e=0;i=il(x[d>>2],x[d+4>>2]);while(1){if((e|0)!=(i|0)){c:{if(!((a|0)!=(d|0)|(b|0)!=(e|0))|z[cc(x[d>>2],e)>>1]!=(g|0)){break c}c=mR(x[a+24>>2]+484344|0,g);if((c|0)==65535){break c}j=nl(x[a>>2],x[a+4>>2],b),k=c,w[j>>1]=k;break a}e=e+1|0;continue}break}d=x[gz(f+8|0)>>2];continue}}c=g}hb=f+16|0;return c&65535}function u5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;a:{b:{c:{if((d|0)==1){break c}x[23604]=0;Y(901,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break c}d=x[a+24>>2];b=oc(c+8|0,b);x[23604]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+qa(911,d|0,c|0,1);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,5924,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();e=0}hb=c+16|0;return+e}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function CM(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Jb(e+8|0,a+1074312|0,3);if(Mb(x[x[e+8>>2]>>2],x[e+12>>2])){break c}if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break a}c=D((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,872)+a|0)+1075843|0]&1){Jb(e+8|0,a+1074312|0,3);if(!Mb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=D(b,872)+a|0;d=x[f+1075648>>2];a=Is(a,x[f+1075080>>2],d);if(!a){break a}mb[x[x[a>>2]+84>>2]](a,c,(d?y[d+33|0]:13)<<24>>24,b)}hb=e+16|0}function x5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;x[23604]=0;Y(900,a|0);c=x[23604];x[23604]=0;a:{b:{c:{if((c|0)==1){break c}x[23604]=0;Y(901,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break c}c=x[a+24>>2];b=oc(d+8|0,b);x[23604]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=W(907,c|0,d|0,1)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,9928,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=0}hb=d+16|0;return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function f4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-32|0;hb=c;a:{f=a+36|0;b=x[f>>2];d=x[a+40>>2];b:{if(Ob(b,d)){zc(c+24|0);break b}b=c+8|0;wn(b,a);x[23604]=0;b=S(959,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}x[c+24>>2]=b;Of(c+8|0);d=x[a+40>>2];b=x[a+36>>2]}b=(g=f,h=x[c+24>>2],i=Ob(b,d),i?g:h);a=x[a+8>>2];c:{if((a|0)==-1){g=c,h=Bb(x[b>>2]),x[g+8>>2]=h;a=Bb(x[b+4>>2]);while(1){b=x[c+8>>2];if(!Ob(b,a)){break c}e=e+C[b>>3];yI(c+8|0);continue}}e=C[bl(x[b>>2],a)>>3]}Dk(c+24|0);hb=c+32|0;return+e}a=P()|0;Of(c+8|0);T(a|0);p()}function Nw(a,b,c){var d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),j=0,k=E(0),l=E(0),m=E(0);e=hb-32|0;hb=e;g=B[a+24>>2];f=B[a+12>>2];h=B[a+48>>2];i=B[a+36>>2];PH(E(-B[a>>2]),E(g+f),E(h+i),e+20|0);PH(B[a+60>>2],E(h-i),E(g-f),e+8|0);B[e+12>>2]=-B[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=B[j>>2];f=B[d+(e+20|0)>>2];h=B[d+70608>>2];i=B[d+70620>>2];k=B[d+(e+8|0)>>2];B[j>>2]=E(f*h)-E(i*k);j=b+d|0;l=B[(0-a<<2)+70616>>2];d=5-a<<2;m=B[d+70608>>2];f=E(E(f*i)+E(k*h));B[j>>2]=E(g*l)-E(m*f);B[b+d>>2]=E(g*m)+E(f*l);a=a+1|0;continue}break}hb=e+32|0}function Lfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){c=hb-16|0;hb=c;if(bh(178956970)>>>0<b>>>0){Sc();p()}d=D(b,24);e=Jc(d);x[c+12>>2]=b;x[c+8>>2]=e;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=Cb(a),g=b+D(x[c+12>>2],24)|0,x[f>>2]=g;hb=c+16|0;b=hb-16|0;hb=b;x[b>>2]=a;c=x[a+4>>2];x[b+4>>2]=c;x[b+8>>2]=c+d;c=x[b+4>>2];d=x[b+8>>2];a:{while(1){if((c|0)==(d|0)){break a}x[23604]=0;Y(527,c|0);e=x[23604];x[23604]=0;if((e|0)!=1){c=c+24|0;x[b+4>>2]=c;continue}break}a=P()|0;ic(b);T(a|0);p()}ic(b);hb=b+16|0}return a|0}function u8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-48|0;hb=f;e=x[a+28>>2];Sm(x[x[e>>2]-12>>2]+e|0,0);i=x[x[b>>2]+4>>2];if(i){j=x[a+28>>2];g=f+32|0;h=x[a+12>>2];e=x[a+8>>2]+i|0;h=i>>>0>e>>>0?h+1|0:h;g=dh(g,e,h);e=x[g+12>>2];x[f+8>>2]=x[g+8>>2];x[f+12>>2]=e;e=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=e;zj(j,f)}e=f+16|0;_d(e,x[a+28>>2]);ZK(d,x[a+28>>2],c);c=x[b>>2];b=Xm(e,Gb(x[a+32>>2],x[c>>2]),z[c+12>>1]);x[23604]=0;Q(846,a|0,c|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){Db(b);hb=f+48|0;return}a=P()|0;Db(b);T(a|0);p()}function s8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-48|0;hb=f;e=x[a+28>>2];Sm(x[x[e>>2]-12>>2]+e|0,0);i=x[x[b>>2]+4>>2];if(i){j=x[a+28>>2];g=f+32|0;h=x[a+12>>2];e=x[a+8>>2]+i|0;h=i>>>0>e>>>0?h+1|0:h;g=dh(g,e,h);e=x[g+12>>2];x[f+8>>2]=x[g+8>>2];x[f+12>>2]=e;e=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=e;zj(j,f)}e=f+16|0;_d(e,x[a+28>>2]);WK(c,x[a+28>>2],d);c=x[b>>2];b=Xm(e,Gb(x[a+32>>2],x[c>>2]),z[c+12>>1]);x[23604]=0;Q(846,a|0,c|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){Db(b);hb=f+48|0;return}a=P()|0;Db(b);T(a|0);p()}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[f>>1],w[e+40242>>1])+D(w[f-2>>1],w[e+40240>>1])|0)+D(w[f+2>>1],w[e+40244>>1])|0)+D(w[f+4>>1],w[e+40246>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Ub(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=x[a>>2];d=Vj(e,x[a+4>>2]);if(d>>>0<b>>>0){e=hb-32|0;hb=e;d=b-d|0;b=x[Cb(a)>>2];f=x[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){BA(a,d,c);break a}b=Cb(a);b=LS(e+8|0,wA(a,Vj(x[a>>2],f)+d|0),Vj(x[a>>2],x[a+4>>2]),b);KS(b,d,c);c=hb-32|0;hb=c;d=Ib(c+24|0,x[a+4>>2]);f=Ib(c+16|0,x[a>>2]);g=Ib(c+8|0,x[b+4>>2]);h=b,i=HS(x[d>>2],x[f>>2],x[g>>2]),x[h+4>>2]=i;qc(a,b+4|0);qc(a+4|0,b+8|0);qc(Cb(a),yc(b));x[b>>2]=x[b+4>>2];hb=c+32|0;JS(b)}hb=e+32|0;return}if(b>>>0<d>>>0){Id(a,e+D(b,6)|0)}}function kQ(a,b,c,d,e){var f=0;f=y[(y[a+3|0]&15)+27392|0];v[a+3|0]=f;a:{b:{switch(f-11|0){case 0:b=y[a+5|0];c=b&15;if(c){v[a+5|0]=c;return}v[a+5|0]=b&240;return;case 3:c=y[a+5|0];c=D(c&240,10)|c&15;v[a+5|0]=c;f=c&255;c=z[d>>1];if(!(f|(c|0)==65535)){v[a+5|0]=c;v[a+3|0]=12;w[d>>1]=65535}wc(e,b);return;case 1:w[d>>1]=y[a+5|0];x[e>>2]=63;v[a+3|0]=0;return;case 5:b=y[a+5|0];if(c>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|D(c,-10)+b;v[a+5|0]=b}if(b&255){break a}v[a+3|0]=0;return;case 7:break a;default:break b}}if(y[a+5|0]){break a}v[a+3|0]=0}}function yk(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;x[a+4>>2]=0;d=4;a:{b:{c:{if(!ud(y[nn(e+8|0,a,1)|0])){break c}d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23604]=0;b=W(92,d|0,b|0,c|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}_(V(0)|0)|0;d=1;mn(x[x[a>>2]-12>>2]+a|0,1);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23604]=0;Z(91);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)==1){break b}T(a|0);p()}$()}kj(x[x[a>>2]-12>>2]+a|0,d);hb=e+16|0;return a}V(0)|0;Vb()}p()}function KK(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0;vx(a);c=Fd(c,E(0));a:{switch(b|0){case 0:B[a+4220>>2]=c;return;case 1:B[a+4224>>2]=c;return;case 2:B[a+4228>>2]=c;vs(a);return;case 3:v[a+4240|0]=c>=E(.5);vs(a);return;case 4:b=hb-16|0;hb=b;e=b,f=Ih(E(c*E(32))),x[e+12>>2]=f;x[b+8>>2]=0;x[b+4>>2]=5;d=x[nj(b+12|0,b+8|0,b+4|0)>>2];hb=b+16|0;x[a+4232>>2]=d;return;case 5:v[a+4241|0]=c>=E(.5);return;case 6:v[a+4242|0]=c>=E(.5);return;case 7:v[a+4244|0]=c>=E(.5);return;case 8:if(c==E(0)){ux(a)}C[a+4256>>3]=c;break;default:break a}}}function RV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=16384;d=x[Fb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=17;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=hk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Jq(c+4|0,hk(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}Jq(c+4|0,d-e|0);break b}MC(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}MC(a,e,0,b)}d=x[a+1072>>2];continue}break}hb=c+16|0}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[f|0],w[e+40242>>1])+D(v[f-1|0],w[e+40240>>1])|0)+D(v[f+1|0],w[e+40244>>1])|0)+D(v[f+2|0],w[e+40246>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Ub(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function eI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;a:{b:{c:{a=x[a+32>>2];e=is(a);d:{if(!e){if(hs(a)>>>0<=b>>>0){break d}a=Rj(a,b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ba(8)|0;x[23604]=0;b=Q(54,d|0,5961)|0;c=x[23604];x[23604]=0;e:{if((c|0)!=1){a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break e}c=P()|0;ca(a|0)}T(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];if(!a){break b}v[a+15|0]=y[a+15|0]&253|(c?2:0)}hb=d+16|0;return}p()}function gM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=16777216;h=e+12|0;d=x[a>>2];c=rc(d,x[a+4>>2]);a:{if(c>>>0<b>>>0){f=hb-32|0;hb=f;b=b-c|0;c=x[Cb(a)>>2];d=x[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){cC(a,b,h);break b}c=Cb(a);c=Wf(f+8|0,vg(a,rc(x[a>>2],d)+b|0),rc(x[a>>2],x[a+4>>2]),c);g=hb-16|0;hb=g;b=pl(g,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Un(d,x[h>>2]);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Hd(b);hb=g+16|0;xd(a,c);Vf(c)}hb=f+32|0;break a}if(b>>>0<c>>>0){Id(a,d+(b<<2)|0)}}dy(a);hb=e+16|0}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-208|0;hb=e;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;qM(a+946304|0);d=e+48|0;Zb(d,0,160);d=xM(d);x[23604]=0;f=a+906300|0;U(773,f|0,f+4e4|0,d|0);f=x[23604];x[23604]=0;a:{if((f|0)!=1){Gs(d);d=ge(e+24|0,b);x[23604]=0;f=x[d+12>>2];x[e+8>>2]=x[d+8>>2];x[e+12>>2]=f;x[e+16>>2]=x[d+16>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;a=W(774,a|0,e|0,c|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){a=P()|0;break a}yb(b);hb=e+208|0;return a|0}a=P()|0;Gs(d)}yb(b);T(a|0);p()}function QV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=32768;d=x[Fb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=9;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=hk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Jq(c+4|0,hk(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}Jq(c+4|0,d-e|0);break b}LC(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}LC(a,e,0,b)}d=x[a+1072>>2];continue}break}hb=c+16|0}function iZ(a){a=a|0;if(y[468e3]){return x[116999]}if(!y[469104]){v[469104]=1}ld(468816,88392);ld(468828,88424);ld(468840,88460);ld(468852,88484);ld(468864,88508);ld(468876,88524);ld(468888,88544);ld(468900,88564);ld(468912,88592);ld(468924,88632);ld(468936,88664);ld(468948,88700);ld(468960,88736);ld(468972,88752);ld(468984,88768);ld(468996,88784);ld(469008,88508);ld(469020,88800);ld(469032,88816);ld(469044,88832);ld(469056,88848);ld(469068,88864);ld(469080,88880);ld(469092,88896);v[468e3]=1;x[116999]=468816;return 468816}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];k=x[a+12>>2];while(1){if(d){g=x[b+8>>2];g=((((x[b+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=w[(e<<1)+g>>1];e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Ub(b+8|0,f,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-48|0;hb=d;c=d+24|0;ij(c,b,1819307379);$c(a+40|0,c);yb(c);ij(c,b,1953721961);$c(a+60|0,c);yb(c);ij(c,b,543520099);$c(a+120|0,c);yb(c);ij(c,b,1414744396);x[23604]=0;c=Q(346,c|0,13629)|0;e=x[23604];x[23604]=0;a:{if((e|0)!=1){b:{if(c){x[23604]=0;U(723,d|0,d+24|0,2);c=x[23604];x[23604]=0;if((c|0)==1){break b}st(a+140|0,d);Xd(d)}x[23604]=0;U(724,d|0,b|0,1634890872);b=x[23604];x[23604]=0;if((b|0)!=1){break a}}}a=P()|0;yb(d+24|0);T(a|0);p()}$c(a+80|0,d);yb(d);yb(d+24|0);hb=d+48|0}function pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;od(b,0);g=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=g;e=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+12>>2]=e;f=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+16>>2]=f;c=y[a+12|0]|y[a+13|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=y[a+14|0];w[b+30>>1]=c?c+1|0:256;d=z[b+34>>1]&32767|!y[a+14|0]<<15;w[b+34>>1]=d;c=y[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;w[b+34>>1]=d;c=y[a+15|0]}if(c&2){x[b+16>>2]=f>>>1;x[b+12>>2]=e>>>1;x[b>>2]=g>>>1;w[b+34>>1]=d|1}}function Ai(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?G(c):G(d)+32|0;vf(f,d,e,0,0,c+49|0);i=x[f>>2];h=x[f+4>>2];e=15372-c<<16;c=x[f+8>>2];d=e|x[f+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;hb=f+16|0}function wV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;od(b,0);Ph(d,1,a+33|0);e=d+16|0;Dc(e,d);ze(b+43|0,e);xb(e);f=y[a+50|0]|y[a+51|0]<<8|(y[a+52|0]<<16|y[a+53|0]<<24);x[b>>2]=f;x[b+24>>2]=y[a+54|0]|y[a+55|0]<<8;v[d+16|0]=y[a+56|0];v[d|0]=64;h=b,i=y[Wb(e,d)|0]<<2,w[h+30>>1]=i;e=y[a+57|0]|y[a+58|0]<<8|(y[a+59|0]<<16|y[a+60|0]<<24);x[b+4>>2]=e;g=y[a+61|0]|y[a+62|0]<<8|(y[a+63|0]<<16|y[a+64|0]<<24);c=c?e?f:g:g;x[b+8>>2]=c;if(!(!y[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0)){w[b+34>>1]=z[b+34>>1]|2}hb=d+32|0}function JC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=y[a+8|0];h=x[a>>2];e=x[a+4>>2];f=Pb(b);a=Eb(x[b+4>>2],y[b+11|0]);b=hb-16|0;hb=b;x[b+8>>2]=a;x[b+12>>2]=e;a=h;g=x[Fb(b+12|0,b+8|0)>>2];c=g;while(1){a:{if(!c){c=0;break a}i=y[f|0];v[a|0]=i;if(!i){break a}f=f+1|0;a=a+1|0;c=c-1|0;continue}break}b:{if((d-1&255)>>>0<=1){v[b+7|0]=0;Ql(a,((a+e|0)-g|0)+c|0,b+7|0);break b}if((d-3&255)>>>0>1){break b}v[b+6|0]=32;Ql(a,((a+e|0)-g|0)+c|0,b+6|0)}c:{switch(d-1|0){case 0:case 3:v[(x[b+12>>2]+h|0)-1|0]=0;break;default:break c}}hb=b+16|0}function rfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=hb-608|0;hb=f;b=hb-16|0;hb=b;d=f+8|0;vR(b+8|0,d);c=x[b+12>>2];kd(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(c|0)){ad(a,x[b+12>>2])}hb=b+16|0;c=(c|0)==(e|0);if(!c){uR(d)}b=-1;a:{if(!c){break a}b=0;if(!wR(f+8|0)){break a}b=-1;if(!Nf(a,1024)){break a}b=0;d=hb-1024|0;hb=d;c=hb-16|0;hb=c;Xz(c+8|0,d);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((e|0)==(g|0)){ad(a,x[c+12>>2])}hb=c+16|0;if((e|0)==(g|0)){b=Yz(d,0)>>>0<17}hb=d+1024|0}hb=f+608|0;return b|0}function paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(x[a+4>>2]!=x[Cb(a)>>2]){c=hb-16|0;hb=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+7;JN(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+7;ic(c);hb=c+16|0;return}f=hb-32|0;hb=f;g=Cb(a);h=f+8|0;d=Ny(x[a>>2],x[a+4>>2])+1|0;c=hb-16|0;hb=c;x[c+12>>2]=d;a:{e=bh(613566756);if(d>>>0<=e>>>0){d=Oy(a);if(d>>>0<e>>>1>>>0){x[c+8>>2]=d<<1;e=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;break a}Sc();p()}c=MN(h,e,Ny(x[a>>2],x[a+4>>2]),g);JN(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+7;LN(a,c);KN(c);hb=f+32|0}function l4(a){a=a|0;var b=0,c=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){a=x[a+24>>2];b=x[a+24>>2];c=z[b+1074448>>1];a:{if(c>>>0>=$i(_b(x[b+484360>>2],y[b+484376|0]))>>>0){a=z[x[a+24>>2]+1074446>>1];break a}a=x[a+24>>2];b=z[cc(x[_b(x[a+484360>>2],y[a+484376|0])>>2],c)>>1];a=wm(x[a+484344>>2],x[a+484348>>2],b)?b:-1}return a|0}_(V(0)|0)|0;x[23604]=0;X(887,9658,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Qt(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;x[g+12>>2]=0;x[g+8>>2]=a;i=hb-16|0;hb=i;b=ec(i+8|0,x[g+8>>2],x[g+12>>2]);e=hb-16|0;hb=e;d=117;x[e+12>>2]=117;c=x[b+4>>2];a:{if(!c){c=x[b>>2];break a}f=32-c|0;x[e+8>>2]=f;d=x[b>>2];j=x[d>>2];h=f;f=x[Fb(e+8|0,e+12|0)>>2];x[d>>2]=(-1<<c&-1>>>h-f^-1)&j;j=x[e+12>>2];c=d+4|0;x[b>>2]=c;d=j-f|0}h=c;c=d>>>5|0;FC(h,c);f=d&31;x[e+12>>2]=f;if((d&-32)!=(d|0)){h=b;b=x[b>>2]+(c<<2)|0;x[h>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-f^-1)}hb=e+16|0;hb=i+16|0;hb=g+16|0;return a}function Mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-80|0;hb=c;d=Gf(c+48|0);x[23604]=0;e=Q(575,b|0,d|0)|0;f=x[23604];x[23604]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23604]=0;S(576,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[23604]=0;U(176,c|0,b|0,(e>>>0>=9?e-8|0:0)|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}a=P()|0;Md(d);T(a|0);p()}b=kc(c+24|0,c);$c(d+8|0,b);yb(b);yb(c);jl(a,d)}Md(d);hb=c+80|0}function kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-80|0;hb=c;d=Gf(c+48|0);x[23604]=0;e=Q(454,b|0,d|0)|0;f=x[23604];x[23604]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23604]=0;S(455,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break a}}break c}e=z[d+2>>1]|z[d+4>>1]<<16;x[23604]=0;U(176,c|0,b|0,e|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}a=P()|0;Md(d);T(a|0);p()}b=kc(c+24|0,c);$c(d+8|0,b);yb(b);yb(c);kS(a,d)}Md(d);hb=c+80|0}function X5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a+4202|0]=1;c=Mj(E(E(A[x[a+16>>2]+24620>>2])*E(.04500000178813934)));d=Mj(E(E(c>>>0)*E(1.1892070770263672)));e=Mj(E(E(d>>>0)*E(1.1892070770263672)));h=Mj(E(E(e>>>0)*E(1.1892070770263672)));f=Mj(E(E(c+e>>>0)*E(.11546666920185089)));g=Mj(E(E(d+h>>>0)*E(.11546666920185089)));b=a+4272|0;i=zb(b,0),j=c-f|0,x[i>>2]=j;i=zb(b,1),j=e-f|0,x[i>>2]=j;i=zb(b,2),j=d-g|0,x[i>>2]=j;i=zb(b,3),j=h-g|0,x[i>>2]=j;i=zb(b,4),j=f,x[i>>2]=j;i=zb(b,5),j=g,x[i>>2]=j;YJ(a);XJ(a)}function ox(a,b){var c=0;if(b>>>0<=999999){if(b>>>0<=9999){if(b>>>0<=99){if(b>>>0<=9){return cp(a,b)}return Ik(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Ik(cp(c,a),D(a,-100)+b|0)}return mx(a,b)}if(b>>>0<=99999){c=a;a=(b>>>0)/1e4|0;return mx(cp(c,a),D(a,-1e4)+b|0)}return lx(a,b)}if(b>>>0<=99999999){if(b>>>0<=9999999){c=a;a=(b>>>0)/1e6|0;return lx(cp(c,a),D(a,-1e6)+b|0)}return ps(a,b)}if(b>>>0<=999999999){c=a;a=(b>>>0)/1e8|0;return ps(cp(c,a),D(a,-1e8)+b|0)}c=a;a=(b>>>0)/1e8|0;return ps(Ik(c,a),D(a,-1e8)+b|0)}function GM(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}e=x[a+480180>>2];c=e&1048580?(b&240?-16:15)&b:b;b=c&255;c=c&15;b:{c:{d:{if(!((c|0)!=15|b>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=b>>>3&30;break d}f=x[a+480208>>2]&4096;g=b&240;if(!(!c|(g|0)!=240)){if(!f){break b}b=0-(c<<1)|0;break c}if(f){break b}if(g){if(c?e&59314208:0){break b}b=b>>>3&30;break d}b=0-(c<<1)|0}if(!b){break b}}a=a+1074456|0;x[d+12>>2]=x[a>>2]+(b<<!(e&59314208));fe(d+12|0,0,256);x[a>>2]=x[d+12>>2]}hb=d+16|0}function j9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=hb-32|0;hb=f;a=Sb(a);b:{c:{d:{e:{while(1){e=x[b+8>>2];g=x[b>>2];x[23604]=0;e=W(142,g|0,e|0,8)|0;g=x[23604];x[23604]=0;if((g|0)==1){break c}if(e){x[23604]=0;U(819,f|0,b|0,c|0);e=x[23604];x[23604]=0;if((e|0)==1){break e}x[23604]=0;R(820,a|0,f|0);e=x[23604];x[23604]=0;if((e|0)==1){break d}Md(f);e=ko(x[a+4>>2]);ti(f,x[e>>2],x[e+4>>2]);if(x[f>>2]!=(d|0)){continue}}break}hb=f+32|0;break a}b=P()|0;break b}b=P()|0;Md(f);break b}b=P()|0}Xd(a);T(b|0);p()}}function VY(a){a=a|0;if(y[467992]){return x[116997]}if(!y[468800]){v[468800]=1}Zc(468512,4995);Zc(468524,4986);Zc(468536,10734);Zc(468548,10482);Zc(468560,5222);Zc(468572,11527);Zc(468584,5079);Zc(468596,5570);Zc(468608,8788);Zc(468620,8771);Zc(468632,8779);Zc(468644,8798);Zc(468656,9965);Zc(468668,13121);Zc(468680,8861);Zc(468692,7632);Zc(468704,5222);Zc(468716,9654);Zc(468728,10370);Zc(468740,10746);Zc(468752,9151);Zc(468764,6424);Zc(468776,5453);Zc(468788,13039);v[467992]=1;x[116997]=468512;return 468512}function YO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=y[a+16|0];k=c?-1:1;l=c?1:-1;e=x[a+8>>2]-1|0;m=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;f=x[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=x[a>>2]+D(f,62)|0;d=b?1:-1;p=D(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=D(c,f);q=x[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{w[(b<<1)+h>>1]=z[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function LX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Hg(a,x[b+8>>2],e)){Qv(b,c,d);return}a:{if(Hg(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];mb[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];mb[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];k=x[a+12>>2];while(1){if(d){g=x[b+8>>2];g=(((x[b+12>>2]&2147483647)<<1|g>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Ub(b+8|0,f,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function z9(a){a=a|0;var b=0,c=0;b=32576;a=Sb(a);a:{b:{while(1){c:{if((b|0)==33152){b=33152;break c}d:{c=x[a+4>>2];if(!tc(x[a>>2],c)){if(!Vi(x[b+8>>2],x[Mk(c)>>2])){break d}}x[23604]=0;R(797,a|0,b+8|0);c=x[23604];x[23604]=0;if((c|0)!=1){break d}break b}b=b+12|0;continue}break}while(1){if((b|0)==33200){break a}e:{c=x[a+4>>2];f:{if(!tc(x[a>>2],c)){if(!Vi(x[b+8>>2],x[Mk(c)>>2])){break f}}x[23604]=0;R(797,a|0,b+8|0);c=x[23604];x[23604]=0;if((c|0)==1){break e}}b=b+12|0;continue}break}}b=P()|0;sc(a);T(b|0);p()}}function v4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;e=Sb(a);a=b;b=0;a:{b:{c:{d:{e:{while(1){d=x[a+24>>2];if(z[d+480188>>1]<=b>>>0){break a}x[23604]=0;R(955,c|0,(d+(b<<5)|0)+480289|0);d=x[23604];x[23604]=0;if((d|0)!=1){d=x[a+24>>2];x[23604]=0;U(956,c+16|0,d|0,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break e}x[23604]=0;R(169,e|0,c+16|0);d=x[23604];x[23604]=0;if((d|0)==1){break d}b=b+1|0;xb(c+16|0);xb(c);continue}break}b=P()|0;break b}b=P()|0;break c}b=P()|0;xb(c+16|0)}xb(c)}Vd(e);T(b|0);p()}hb=c+32|0}function lG(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{b:{if((a|0)!=(b|0)){c:{g=x[116080];x[116080]=0;zd();a=kG(a,e+12|0,d);d=lb;d:{f=x[116080];if(f){if(x[e+12>>2]!=(b|0)){break c}if((f|0)!=68){break d}x[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}break b}x[116080]=g;if(x[e+12>>2]==(b|0)){break d}break c}if((d|0)<0&a>>>0<=2147483647|(d|0)<-1){x[c>>2]=4;break b}if((d|0)>=0&a>>>0>=2147483648|(d|0)>0){x[c>>2]=4;b=2147483647;break a}b=a;break a}}x[c>>2]=4;b=0;break a}b=-2147483648}hb=e+16|0;return b}function afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;hc(c+8|0,b,26);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function Zl(a,b,c,d){var e=0;a:{e=a+1074312|0;if(Tb(e,84)){break a}b:{if(y[a+480209|0]&64){break b}if((d|0)!=8){if(!Tb(e,10)){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+784>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;if(!Tb(e,10)){break a}v[b+831|0]=0;w[b+778>>1]=0}}function mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-80|0;hb=c;d=Gf(c+48|0);x[23604]=0;e=Q(610,b|0,d|0)|0;f=x[23604];x[23604]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23604]=0;S(611,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[23604]=0;U(176,c|0,b|0,e|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}a=P()|0;Md(d);T(a|0);p()}b=kc(c+24|0,c);$c(d+8|0,b);yb(b);yb(c);jl(a,d)}Md(d);hb=c+80|0}function kia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;od(b,0);Ph(c,1,a);d=c+16|0;Dc(d,c);ze(b+43|0,d);xb(d);x[b+24>>2]=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);w[b+34>>1]=z[b+34>>1]&65533|(y[a+13|0]|y[a+14|0]<<8)<<1&2;x[b>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b+4>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[b+8>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);v[c+16|0]=y[a+15|0];v[c|0]=64;e=b,f=y[Wb(d,c)|0]<<2,w[e+30>>1]=f;hb=c+32|0}function Hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=hb-16|0;hb=b;e=x[a+40>>2];f=x[a+36>>2];i=x[a+16>>2];g=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=g;j=x[a+32>>2];k=x[a+28>>2];g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){h=w[(x[b+12>>2]<<1)+i>>1];f=f+k|0;x[c>>2]=x[c>>2]+D(h,f>>12);e=e+j|0;x[c+4>>2]=x[c+4>>2]+D(e>>12,h);Ub(b+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;hb=b+16|0}function yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=hb-32|0;hb=d;a=Sb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[23604]=0;c=W(142,e|0,c|0,8)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}if(c){x[23604]=0;R(604,d|0,b|0);c=x[23604];x[23604]=0;if((c|0)==1){break e}x[23604]=0;R(605,a|0,d|0);c=x[23604];x[23604]=0;if((c|0)==1){break d}Md(d);c=ko(x[a+4>>2]);ti(d,x[c>>2],x[c+4>>2]);if(x[d>>2]!=1413891155){continue}}break}hb=d+32|0;break a}b=P()|0;break b}b=P()|0;Md(d);break b}b=P()|0}Xd(a);T(b|0);p()}}function Ul(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function kl(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(y[a+35|0]&2)){break a}uo(a)}d=z[a+34>>1]&-513|d;w[a+34>>1]=d;if(b){x[a>>2]=4;w[a+34>>1]=d&65470;yg(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}}function L3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0);x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;a:{if((d|0)==1){break a}x[23604]=0;Y(971,c|0);d=x[23604];x[23604]=0;if((d|0)==1){break a}d=x[a+24>>2];e=B[d+48>>2];d=x[d+24>>2];x[23604]=0;b=Wa(972,d|0,E(e),b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}_(V(0)|0)|0;x[23604]=0;X(887,10245,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Gga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+4>>2]!=x[Cb(a)>>2]){c=hb-16|0;hb=c;a=uv(c,a);d=x[a+4>>2];x[23604]=0;R(433,d|0,b|0);b=x[23604];x[23604]=0;a:{if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+12;ic(a);hb=c+16|0;break a}b=P()|0;ic(a);T(b|0);p()}return}d=hb-32|0;hb=d;c=Cb(a);c=wl(d+8|0,Io(a,Dd(x[a>>2],x[a+4>>2])+1|0),Dd(x[a>>2],x[a+4>>2]),c);e=x[c+8>>2];x[23604]=0;R(433,e|0,b|0);b=x[23604];x[23604]=0;b:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+12;tv(a,c);gr(c);hb=d+32|0;break b}a=P()|0;gr(c);T(a|0);p()}}function tO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=Ws(b);x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);Vy(a,2048);g=hb-16|0;hb=g;f=Rq(g,a,2048);d=x[f+4>>2];i=x[f+8>>2];while(1){if((d|0)==(i|0)){ic(f);hb=g+16|0}else{x[d>>2]=0;x[d+4>>2]=0;d=d+8|0;x[f+4>>2]=d;continue}break}while(1){a:{c=1;if((e|0)!=1024){if((e|0)==2048){break a}c=+(e-1024|0);j=Ws(M(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=j*mi(c)/(h*c)}k=Ne(x[a>>2],e),l=c*.011841342921061943,C[k>>3]=l;e=e+1|0;continue}break}}function dI(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;a:{b:{c:{a=x[a+32>>2];c=is(a);d:{if(!c){if(hs(a)>>>0<=b>>>0){break d}c=(y[Rj(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ba(8)|0;x[23604]=0;b=Q(54,d|0,5961)|0;c=x[23604];x[23604]=0;e:{if((c|0)!=1){a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break e}c=P()|0;ca(a|0)}T(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(y[a+15|0]&2)>>>1|0}hb=d+16|0;return c|0}p()}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=hb-16|0;hb=b;e=x[a+40>>2];f=x[a+36>>2];i=x[a+16>>2];g=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=g;j=x[a+32>>2];k=x[a+28>>2];g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){h=v[x[b+12>>2]+i|0]<<8;f=f+k|0;x[c>>2]=x[c>>2]+D(h,f>>12);e=e+j|0;x[c+4>>2]=x[c+4>>2]+D(e>>12,h);Ub(b+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;hb=b+16|0}function M5(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;a:{b:{if(!a){a=Qf(21502);break b}x[23604]=0;c=Q(54,b|0,a|0)|0;a=x[23604];x[23604]=0;c:{d:{if((a|0)!=1){x[23604]=0;R(886,b+16|0,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break d}d=b+16|0;a=Qf(Pb(d));xb(d);xb(c);break b}a=V(0)|0;break c}a=V(0)|0;xb(c)}_(a|0)|0;a=0;x[23604]=0;X(887,10874,0,0,0);c=x[23604];x[23604]=0;if((c|0)==1){break a}$()}hb=b+32|0;return a|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Od(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+4>>2]=1077;x[b>>2]=a;x[b+8>>2]=0;c=hb-16|0;hb=c;if(x[a>>2]!=-1){a:{d=Ib(c,lf(c+8|0,b));while(1){if(x[a>>2]==1){continue}break}b:{if(!x[a>>2]){Ad(a,1);x[23604]=0;Y(1078,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break b}x[a>>2]=-1}break a}_(V(0)|0)|0;Ad(a,0);x[23604]=0;Z(91);a=x[23604];x[23604]=0;c:{if((a|0)==1){a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){break c}V(0)|0;Vb()}p()}T(a|0);p()}}hb=c+16|0;hb=b+16|0;return x[a+4>>2]-1|0}function nE(a,b,c,d){var e=0,f=0,g=0;e=hb-80|0;hb=e;f=Gf(e+48|0);x[23604]=0;d=Q(d|0,b|0,f|0)|0;g=x[23604];x[23604]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23604]=0;S(c|0,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break a}}break c}c=x[f+4>>2];x[23604]=0;U(176,e|0,b|0,dc(c)|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}a=P()|0;Md(f);T(a|0);p()}b=kc(e+24|0,e);$c(f+8|0,b);yb(b);yb(e);jl(a,f)}Md(f);hb=e+80|0}function _H(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=hb-32|0;hb=d;C[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23604]=0;d=Q(54,d+8|0,10598)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,d);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(d);break b}a=x[a+32>>2];x[d+8>>2]=0;x[d+12>>2]=-1074790400;x[d>>2]=0;x[d+4>>2]=1072693248;e=(a+D(b,872)|0)+1075684|0,f=dm(C[wg(d+24|0,d+8|0,d)>>3]*128+128),x[e>>2]=f;hb=d+32|0;return}a=P()|0;ca(b|0)}T(a|0)}p()}function sea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;od(b,0);NA(d,a+1|0);c=d+16|0;Dc(c,d);ze(b+43|0,c);xb(c);x[b+24>>2]=y[a+73|0]|y[a+74|0]<<8|(y[a+75|0]<<16|y[a+76|0]<<24);c=y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);e=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);if(e){x[b+8>>2]=e+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,x[b+8>>2]);hb=d+32|0}function Sn(a){var b=0,c=0,d=0,e=0;d=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;b=((d&3)<<4)+28192|0;x[a+40>>2]=b;e=z[a+24>>1];d=d>>>2|0;c=e+d|0;w[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;w[a+32>>1]=c;w[a+34>>1]=-1<<c^-1;if((e|0)==15){w[a+36>>1]=4095}x[a+52>>2]=b;x[a+64>>2]=b;b=d+z[a+26>>1]|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;w[a+44>>1]=c;b=d+z[a+30>>1]|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+46>>1]=-1<<c^-1;w[a+58>>1]=-1<<b^-1}function ZO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=x[a+8>>2]-1|0;e=x[a+12>>2];f=x[a>>2]+D(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=D(e,g);i=x[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!y[a+16|0]){d=1;c=0;break c}d=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=y[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{v[b+f|0]=y[x[a+4>>2]+(D(c,e)+b|0)|0];b=b+1|0;e=x[a+12>>2];continue}}break}}function t4(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;e=Sb(a);Pd(c+24|0);a=0;b=x[c+28>>2];d=x[c+24>>2];x[23604]=0;R(167,e|0,uI(d,b)|0);b=x[23604];x[23604]=0;a:{if((b|0)!=1){b:{while(1){b=x[c+24>>2];if((uI(b,x[c+28>>2])|0)<=(a|0)){hb=c+32|0;return}b=x[b+(a<<3)>>2];x[23604]=0;b=Q(54,c+8|0,b|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){x[23604]=0;R(169,e|0,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break b}xb(b);a=a+1|0;continue}break}a=P()|0;break a}a=P()|0;xb(b);break a}a=P()|0}Vd(e);T(a|0);p()}function RE(a,b,c,d,e){var f=0,g=0,h=0;g=hb-16|0;hb=g;h=Kb(a);a=0;a:{b:{c:{d:{while(1){f=x[b>>2];if(Dd(f,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){f=Zd(f,0);break e}x[23604]=0;Q(d|0,h|0,c|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break b}f=Zd(x[b>>2],a)}x[23604]=0;R(e|0,g|0,f|0);f=x[23604];x[23604]=0;if((f|0)!=1){x[23604]=0;Q(d|0,h|0,g|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break d}a=a+1|0;xb(g);continue}break}a=P()|0;break a}a=P()|0;xb(g);break a}hb=g+16|0;return}a=P()|0}xb(h);T(a|0);p()}function mz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;f=a+14|0;c=x[a>>2];e=x[a+4>>2];if(tc(c,e)){b=c}else{w[c>>1]=0;mf(c+2|0,b);g=d,h=Pj(Bb(x[a>>2]),1),x[g+8>>2]=h;while(1){e=Bb(x[a+4>>2]);c=x[d+8>>2];if(Ob(c,e)){g=c,h=z[Se(c,Pj(c,-1))>>1],w[g>>1]=h;mf(c+2|0,b);TP(d+8|0);continue}else{e=x[a+4>>2];b=x[a>>2]}break}}mf(f,ie(b,e)-1&255);mf(a+13|0,y[a+14|0]);mf(a+16|0,ie(x[a>>2],x[a+4>>2])-1&255);mf(a+15|0,y[a+16|0]);if(y[a+17|0]!=255){mf(a+17|0,ie(x[a>>2],x[a+4>>2])-1&255)}hb=d+16|0}function SC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;g=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=g;a:{if(!g){break a}e=b+80|0;c=x[b+84>>2];if(c>>>0<=15){d=x[e>>2]}else{x[f+12>>2]=c-16;d=x[_c(e,f+12|0)>>2]}x[a+8>>2]=d;c=x[b+88>>2];if(!(c&2)|!y[b+794|0]){break a}d=c;c=x[b+104>>2];b:{if(!(!QC(d,c)|x[e>>2]!=x[c+12>>2])){e=1;d=x[b+84>>2];if((d|0)==x[c+16>>2]){break b}}e=0;d=x[b+84>>2];if((d|0)!=x[c+8>>2]){break a}}h=a,i=D((x[c>>2]-d|0)+(e?112:48)|0,gk(z[c+34>>1]))+g|0,x[h+4>>2]=i}hb=f+16|0}function WL(a,b){var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;a:{f=b-4e3&65535;if(f>>>0<61537){break a}d=D(b,104)+a|0;e=d+484380|0;if(!Qd(x[e>>2],x[d+484400>>2])){break a}g=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(g|0)){im(e);x[d+484380>>2]=0;a=d+484414|0;w[a>>1]=z[a>>1]&65470;x[c+24>>2]=0;x[c+8>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c>>2]=0;x[c+4>>2]=0;kl(e,0,c);break a}if(x[b+104>>2]==(e|0)){x[b+76>>2]=0;x[b>>2]=0;x[b+4>>2]=0;x[b+16>>2]=0}b=b+872|0;continue}}hb=c+32|0;return f>>>0>61536}function vr(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{b:{if(!a){break b}h=x[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((lo(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=ZF(i,b,f);h=Pb(f);x[23604]=0;h=W(1101,a|0,h|0,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break a}Gc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((lo(a,c,b)|0)!=(b|0)){break b}}lq(e);j=a}hb=i+16|0;return j|0}a=P()|0;Gc(f);T(a|0);p()}function ZI(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=x[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(A[a+12>>2]<=d>>>0)){while(1){f=gy(x[a>>2]);e=lb;c=x[a+36>>2];if((e|0)==(c|0)&A[a+32>>2]<=f>>>0|e>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){f=gy(x[a>>2]);d=lb;c=x[a+28>>2];if((d|0)==(c|0)&A[a+24>>2]<=f>>>0|d>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function RW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=hb-48|0;hb=f;Ho(f+8|0,c);x[23604]=0;c=f+20|0;R(125,c|0,d|0);d=x[23604];x[23604]=0;b:{c:{d:{if((d|0)==1){break d}x[23604]=0;c=f+32|0;R(125,c|0,e|0);d=x[23604];x[23604]=0;if((d|0)==1){break d}ID(f,f+8|0);x[23604]=0;X(100,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[23604];x[23604]=0;if((a|0)==1){break c}br(f+8|0);hb=f+48|0;break a}a=P()|0;while(1){c=xb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;br(f+8|0)}T(a|0);p()}}function Wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;e=c+8|0;f=Sb(e+8|0);x[23604]=0;d=S(188,b|0)|0;g=x[23604];x[23604]=0;a:{b:{if((g|0)==1){break b}x[23604]=0;U(230,e|0,b|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break b}d=x[e>>2];x[23604]=0;Q(174,b|0,d|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break a}}a=P()|0;fc(f);T(a|0);p()}tu(c,e);x[23604]=0;U(408,a|0,x[c>>2],x[c+4>>2]);a=x[23604];x[23604]=0;if((a|0)!=1){Lc(c+8|0);hb=c+32|0;return}a=P()|0;Lc(c+8|0);T(a|0);p()}function vf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function jQ(a){var b=0,c=0;a:{if(Rb(a+60|0,13684,4)){break a}b=y[a+28|0]|y[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=y[a+42|0];if(b>>>0>64&(b|0)!=88|(y[a+48|0]|y[a+49|0]<<8)>>>0>64|(y[a+50|0]|y[a+51|0]<<8)>>>0>96){break a}b=y[a+52|0]|y[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(y[a+30|0]|y[a+31|0]<<8)|(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24)|(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1)){break a}c=mQ(a+20|0)}return c}function VW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;a:{b:{c:{d:{if(f=wd(x[b+4>>2],y[b+11|0]),g=1,h=x[b+12>>2],h?f:g){Kb(a);break d}d=Eb(x[b+4>>2],y[b+11|0]);e=If(14176);gl(Te(Te(Pb(xw(c+16|0,d+e|0)),Pb(b),d)+d|0,14176,e)+e|0,1,0);x[23604]=0;R(118,c|0,b+12|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}x[23604]=0;U(2,a|0,c+16|0,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}xb(c);xb(c+16|0)}hb=c+32|0;return}b=P()|0;break a}b=P()|0;xb(c)}xb(c+16|0);T(b|0);p()}function l2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb-16|0;hb=c;a:{d=Ih(E(B[a+24>>2]*E(65536)));if((d|0)==65536){break a}i=x[b+4>>2];j=x[b+8>>2];k=d>>31;b:while(1){if((g|0)==(j|0)){break a}l=x[b+4>>2];m=x[b>>2];e=0;while(1)if((e|0)==(i|0)){g=g+1|0;continue b}else{h=Gh(m,l,e,g);f=x[h>>2];f=Kia(Jia(f,f>>31,d,k),lb,65536,0);n=h,o=Ec(f,lb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;UI(a,c);hb=c+16|0}function kM(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];d=(g<<3)+a|0;b=((g+7>>>0)%12<<3)+a|0;f=x[b>>2];e=x[b+4>>2];b=x[a+100>>2];j=b;h=x[a+96>>2];a:{if(!(b|h)){c=x[d+4>>2];b=x[d>>2];i=(c|0)==(e|0)&b>>>0>f>>>0|e>>>0<c>>>0;break a}c=x[d+4>>2];b=x[d>>2];i=!(e|f)|((c|0)==(e|0)&b>>>0>=f>>>0|e>>>0<c>>>0)}c=c+j|0;b=b+h|0;c=b>>>0<h>>>0?c+1|0:c;x[d>>2]=f-b;x[d+4>>2]=e-(c+(b>>>0>f>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=i;x[a+100>>2]=0;lb=x[d+4>>2];return x[d>>2]}function c2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb-16|0;hb=c;a:{d=Ih(E(B[a+24>>2]*E(65536)));if((d|0)==65536){break a}i=x[b+4>>2];j=x[b+8>>2];k=d>>31;b:while(1){if((g|0)==(j|0)){break a}l=x[b+4>>2];m=x[b>>2];e=0;while(1)if((e|0)==(i|0)){g=g+1|0;continue b}else{h=Gh(m,l,e,g);f=x[h>>2];f=Kia(Jia(f,f>>31,d,k),lb,65536,0);n=h,o=Ec(f,lb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;NI(a,c);hb=c+16|0}function C1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=Co(a);x[e>>2]=60668;a=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=a;a=c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;b=yc(e);c=hb-16|0;hb=c;d=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=d;d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;d=AI(c);b=Mm(b);v[b+8|0]=0;x[b+4>>2]=d;x[b>>2]=61068;Sb(b+12|0);x[b>>2]=60832;d=x[a+4>>2];x[b+24>>2]=x[a>>2];x[b+28>>2]=d;d=x[a+12>>2];x[b+32>>2]=x[a+8>>2];x[b+36>>2]=d;hb=c+16|0;hb=a+16|0;return e|0}function Qx(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-48|0;hb=e;a:{if(!c){b=bd(x[a>>2],b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;Qx(a,b,f,e+16|0);g=C[d>>3];h=C[d+8>>3];d=bd(x[a>>2],c);ii(e+32|0,g,h,C[d>>3],C[d+8>>3]);d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;Qx(a,b|c,f,e)}hb=e+48|0}function h_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=hb-16|0;hb=g;e=Eb(x[a+4>>2],y[a+11|0]);d=Oc(a);f=ji(b,c);a:{if(!f){break a}b:{if(!Cx(a,b)){if(d-e>>>0<f>>>0){Rl(a,d,(e+f|0)-d|0,e,e,0,0)}d=Pb(a)+e|0;while(1){if((b|0)==(c|0)){break b}id(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=ug(g,b,c);c=Pb(b);e=y[b+11|0];d=x[b+4>>2];x[23604]=0;W(1112,a|0,c|0,Eb(d,e)|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){xb(b);break a}a=P()|0;xb(b);T(a|0);p()}id(d,0);Sg(a,e+f|0)}hb=g+16|0;return a|0}function r4(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=E(0);x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;if((d|0)!=1){a=x[x[a+24>>2]+24>>2];if(!((b|0)<0|z[a+480188>>1]<=b>>>0)){a=a+D(b,872)|0;c=E(E(y[a+1075834|0])*E(.0078125));e=E(c*c);c=E(E(y[a+1075835|0])*E(.0078125));c=E(M(E(e+E(c*c))))}return E(c)}_(V(0)|0)|0;x[23604]=0;X(887,9279,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return E(E(0))}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function ov(a){var b=0,c=0,d=0;if(A[a+4>>2]<A[Cb(a)>>2]){b=hb-16|0;hb=b;a=iD(b,a);c=x[a+4>>2];x[23604]=0;Y(156,c|0);c=x[23604];x[23604]=0;a:{if((c|0)!=1){x[a+4>>2]=x[a+4>>2]+36;ic(a);hb=b+16|0;break a}b=P()|0;ic(a);T(b|0);p()}return}c=hb-32|0;hb=c;b=Cb(a);b=gD(c+8|0,hD(a,Qq(x[a>>2],x[a+4>>2])+1|0),Qq(x[a>>2],x[a+4>>2]),b);d=x[b+8>>2];x[23604]=0;Y(156,d|0);d=x[23604];x[23604]=0;b:{if((d|0)!=1){x[b+8>>2]=x[b+8>>2]+36;fD(a,b);cv(b);hb=c+32|0;break b}a=P()|0;cv(b);T(a|0);p()}}function hJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d+12>>2]=c;a:{if(!b){a=a+120|0;tn(a);g=dJ(a,x[d+12>>2]),h=0,v[g+20|0]=h;break a}e=hb-16|0;hb=e;x[e+12>>2]=c;b:{if((b|0)==1){b=a+120|0;tn(b);g=ax(b,a,x[e+12>>2]),h=1,v[g+20|0]=h;break b}f=hb-16|0;hb=f;x[f+12>>2]=c;c:{if((b|0)==2){a=a+120|0;tn(a);a=dJ(a,x[f+12>>2]);Yd(a+12|0);v[a+20|0]=2;break c}b=hb-16|0;hb=b;x[b+12>>2]=c;c=a+120|0;tn(c);g=ax(c,a,x[b+12>>2]),h=3,v[g+20|0]=h;hb=b+16|0}hb=f+16|0}hb=e+16|0}hb=d+16|0}function e9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;hl(d,2,a+2|0);e=d+16|0;Dc(e,d);Bc(b+492|0,e);f=b+236|0;g=c+1|0;xb(e);c=0;while(1){if((c|0)==120){x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;vL(y[a|0]&15,y[a+1|0]&15,y[a+2|0]&15,y[a+3|0]&15,y[a+4|0]&15,a+5|0,b+48|0);vL(y[a|0]>>>4|0,y[a+1|0]>>>4|0,y[a+2|0]>>>4|0,y[a+3|0]>>>4|0,y[a+4|0]>>>4|0,a+35|0,b+68|0);hb=d+32|0}else{e=y[(a+c|0)+31|0];h=cc(f,c),i=e+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function NR(a,b,c,d){var e=0,f=0,g=0;f=hb-16|0;hb=f;while(1){a:{e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!af(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){e=af(a,f+14|0);if(e){g=y[f+14|0];w[c>>1]=g<<1|1;v[b|0]=g>>>7;w[c>>1]=y[c|0]}if(!e){break a}if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}hb=f+16|0}function Ega(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=Sj(b),x[i>>2]=j;g=z[b>>1];c=hb-16|0;hb=c;f=a;d=Sd(a);a:{if(d){b=jc(f);while(1){a=d;d=z[a+16>>1];if(eo(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!eo(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=jc(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){SS(c,f,e);Vg(f,x[c+12>>2],b,x[c>>2]);a=Wd(c);QS(c);h=1}Ug(e+8|0,x[Ib(c,a)>>2],h);hb=c+16|0;a=sd(x[e+8>>2]);hb=e+16|0;return a+4|0}function dL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=Sj(b),x[i>>2]=j;g=z[b>>1];c=hb-16|0;hb=c;f=a;d=Sd(a);a:{if(d){b=jc(f);while(1){a=d;d=z[a+16>>1];if(Ep(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!Ep(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=jc(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){SS(c,f,e);Vg(f,x[c+12>>2],b,x[c>>2]);a=Wd(c);QS(c);h=1}Ug(e+8|0,x[Ib(c,a)>>2],h);hb=c+16|0;a=sd(x[e+8>>2]);hb=e+16|0;return a+4|0}function yV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;od(b,0);Ph(d,1,a+33|0);c=d+16|0;Dc(c,d);ze(b+43|0,c);xb(c);e=y[a+50|0]|y[a+51|0]<<8;x[b>>2]=e;x[b+24>>2]=y[a+52|0]|y[a+53|0]<<8;v[d+16|0]=y[a+54|0];v[d|0]=64;g=b,h=y[Wb(c,d)|0]<<2,w[g+30>>1]=h;f=y[a+55|0]|y[a+56|0]<<8;x[b+4>>2]=f;c=y[a+57|0]|y[a+58|0]<<8;x[b+8>>2]=c;a:{if((c|0)==65535){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(!y[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}hb=d+32|0}function C8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);e=hb-16|0;hb=e;f=ff(a,c);_d(e,x[a+28>>2]);h=a;a:{if(!f){c=0;if(fd(a,5)){break a}}c=0;d=hb-32|0;hb=d;g=x[a+28>>2];lk(g,d+24|0);i=d,j=Uc(x[d+24>>2],x[d+28>>2]),x[i+16>>2]=j;x[d+12>>2]=256;Gj(b,x[Fb(d+16|0,d+12|0)>>2]);a=x[b>>2];while(1){if(rc(a,x[b+4>>2])>>>0<=c>>>0){hb=d+32|0}else{x[d+16>>2]=0;ep(g,d+16|0);a=x[b>>2];i=zb(a,c),k=B[d+16>>2],B[i>>2]=k;c=c+1|0;continue}break}c=f}_e(h,c);hb=e+16|0}function vj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!re(y[a+11|0])){c=y[b+11|0];if(!re(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Pb(b);b=Eb(x[b+4>>2],c);a:{if(b>>>0<=10){bf(a,b);id(Te(a,d,b)+b|0,0);break a}e=a;a=mj(y[a+11|0]);Jp(e,10,b-10|0,a,0,a,b,d)}return}d=Pb(b);b=Eb(x[b+4>>2],y[b+11|0]);c=ck(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];oe(a,b);id(Te(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];Jp(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function iG(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[116080];x[116080]=0;zd();a=ew(a,e+12|0,d);d=lb;g=x[116080];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}x[116080]=h;if((b|0)!=x[e+12>>2]){break c}if(!d&a>>>0<65536){break b}}x[c>>2]=4;a=65535;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}hb=e+16|0;return a&65535}function Y7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=fi(a,b,c,d);x[a>>2]=44600;b=Sb(a+4208|0);x[a+4236>>2]=-1;x[a+4240>>2]=0;x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;v[a+4244|0]=0;Zb(a+4248|0,0,48);x[23604]=0;Z(763);c=x[23604];x[23604]=0;a:{if((c|0)==1){break a}e=a,f=rM(),x[e+4296>>2]=f;vs(a);us(a);x[23604]=0;R(851,a+44|0,2);c=x[23604];x[23604]=0;if((c|0)==1){break a}ei(a);return a|0}c=P()|0;fc(b);uf(a);T(c|0);p()}function N1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d+4>>2]=1;g=d,h=Jc(56),x[g+8>>2]=h;c=hb-16|0;hb=c;e=Co(x[d+8>>2]);x[e>>2]=61168;f=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=f;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;b=Mm(yc(e));x[b>>2]=61532;Sb(b+4|0);v[b+20|0]=0;x[b+16>>2]=0;x[b>>2]=61332;e=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=e;e=x[c+12>>2];x[b+32>>2]=x[c+8>>2];x[b+36>>2]=e;v[b+40|0]=0;hb=c+16|0;b=a;a=Eo(d);Do(b,yc(a),a);Nm(d);hb=d+16|0}function R3(a,b){a=a|0;b=b|0;var c=0,d=0;x[23604]=0;Y(900,a|0);c=x[23604];x[23604]=0;if((c|0)!=1){a=x[a+24>>2];c=-1;a:{if((b|0)<0){break a}d=x[a+24>>2];if($i(_b(x[d+484360>>2],y[d+484376|0]))>>>0<=b>>>0){break a}a=x[a+24>>2];c=z[cc(x[_b(x[a+484360>>2],y[a+484376|0])>>2],b)>>1]}return c|0}_(V(0)|0)|0;x[23604]=0;X(887,9693,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function $K(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;a:{b:{c:{d=Oc(a);e=ji(b,c);if(d>>>0<e>>>0){if(Cx(a,b)){break c}g=d;h=e-d|0;d=Eb(x[a+4>>2],y[a+11|0]);Rl(a,g,h,d,0,d,0)}d=Pb(a);while(1){if((b|0)==(c|0)){break b}id(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=ug(f,b,c);c=Pb(b);d=y[b+11|0];e=x[b+4>>2];x[23604]=0;U(56,a|0,c|0,Eb(e,d)|0);c=x[23604];x[23604]=0;if((c|0)!=1){xb(b);break a}a=P()|0;xb(b);T(a|0);p()}id(d,0);Sg(a,e)}hb=f+16|0;return a|0}function gN(a,b){var c=0,d=0,e=0,f=0,g=0;a:{if(y[b+791|0]!=27){a=v[b+831|0];break a}e=a+1074312|0;c=Tb(e,21);d=a;a=y[b+821|0];a=_x(d,y[b+828|0],c?a:a+16>>>2|0);b:{if(!(!Tb(e,45)|y[b+828|0]!=3)){c=y[b+821|0];c:{if(!(!c|c>>>0>=y[b+829|0])){a=y[b+832|0];d=c+1|0;break c}v[b+832|0]=a;d=1}v[b+821|0]=d;a=a<<24>>24;break b}v[b+821|0]=y[b+821|0]+y[b+829|0]}if(!Tb(e,47)){break a}v[b+831|0]=a}if(a){f=b,g=Yb(x[b+684>>2]+((D(y[b+830|0],a)+2|0)/8|0)|0,0,256),x[f+684>>2]=g}}
function rq(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((lo(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=Ue(i,b,f);g=Pb(f);x[23604]=0;g=W(22,a|0,g|0,b|0)|0;h=x[23604];x[23604]=0;if((h|0)==1){break a}xb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((lo(a,c,b)|0)!=(b|0)){break b}}lq(e);j=a}hb=i+16|0;return j|0}a=P()|0;xb(f);T(a|0);p()}function Ct(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(!(y[a|0]==(b&255)|c>>>0<4)){d=D(b&255,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function p_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;c=hb-128|0;hb=c;x[c+12>>2]=c+116;d=c+16|0;QF(x[a+8>>2],d,c+12|0,e,f,g);f=hb-16|0;hb=f;h=f+8|0;a=hb-32|0;hb=a;Wo(a+24|0,d,x[c+12>>2]);i=a+16|0;e=x[a+24>>2];g=x[a+28>>2];d=hb-16|0;hb=d;x[d+8>>2]=b;while(1){if((e|0)!=(g|0)){_G(d+8|0,v[e|0]);e=e+1|0;continue}break}hj(i,g,d+8|0);hb=d+16|0;b=x[a+16>>2];x[a+8>>2]=x[a+20>>2];yd(h,b,a+8|0);hb=a+32|0;hb=f+16|0;hb=c+128|0;return x[f+12>>2]}function LL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{if((c|0)<2){break a}i=c-2>>>1|0;e=d-a|0;if((i|0)<e>>1){break a}g=e+1|0;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Lk(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(Lk(b,z[f>>1],z[d>>1])){break a}j=z[d>>1];while(1){b:{e=d;d=f;w[e>>1]=z[f>>1];if((g|0)>(i|0)){break b}e=g<<1;g=e|1;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Lk(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(!Lk(b,z[f>>1],j)){continue}}break}w[d>>1]=j}}function t0(){var a=0,b=0,c=0,d=0,e=0,f=0;c=hb-48|0;hb=c;if(AH(0,c+24|0)){Or(x[116080],12549);p()}b=Jh(c+16|0,x[c+24>>2],x[c+28>>2]);f=nH(c+8|0,x[c+32>>2]/1e3|0);d=hb-16|0;hb=d;e=hb-16|0;hb=e;a=Jh(e+8|0,Jia(x[b>>2],x[b+4>>2],1e6,0),lb);b=x[a>>2];a=x[a+4>>2];hb=e+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];e=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=Jh(d+8|0,e,a>>>0>e>>>0?f+1|0:f);a=x[b>>2];hb=d+16|0;b=Jh(c+40|0,a,x[b+4>>2]);a=x[b>>2];hb=c+48|0;lb=x[b+4>>2];return a|0}function bia(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);b=hb-16|0;hb=b;if(bh(1073741823)>>>0<=8191){Sc();p()}c=Jc(32768);x[b+12>>2]=8192;x[b+8>>2]=c;c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;e=Cb(a),f=c+(x[b+12>>2]<<2)|0,x[e>>2]=f;hb=b+16|0;b=hb-16|0;hb=b;x[b>>2]=a;c=x[a+4>>2];x[b+4>>2]=c;x[b+8>>2]=c+32768;c=x[b+4>>2];d=x[b+8>>2];while(1){if((c|0)==(d|0)){ic(b);hb=b+16|0}else{w[c>>1]=0;w[c+2>>1]=0;c=c+4|0;x[b+4>>2]=c;continue}break}return a|0}function XG(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(mH()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[23604]=0;b=S(1053,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[23604]=0;Y(1054,a+b|0);a=x[23604];x[23604]=0;if((a|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break a}}return}V(0)|0;Vb();p()}function Av(a,b,c,d,e,f,g,h){var i=0;a:{i=hb-48|0;hb=i;jk(i+8|0,c);x[23604]=0;c=i+20|0;R(h|0,c|0,d|0);d=x[23604];x[23604]=0;b:{c:{d:{if((d|0)==1){break d}x[23604]=0;c=i+32|0;R(g|0,c|0,e|0);d=x[23604];x[23604]=0;if((d|0)==1){break d}ID(i,i+8|0);x[23604]=0;X(f|0,a|0,b|0,x[i>>2],x[i+4>>2]);a=x[23604];x[23604]=0;if((a|0)==1){break c}br(i+8|0);hb=i+48|0;break a}a=P()|0;while(1){c=xb(c-12|0);if((c|0)!=(i+8|0)){continue}break}break b}a=P()|0;br(i+8|0)}T(a|0);p()}}function hL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[a>>2];c=rc(d,x[a+4>>2]);if(c>>>0<=127){f=hb-32|0;hb=f;c=128-c|0;e=x[Cb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){Ix(a,c,b);break a}e=Cb(a);d=Wf(f+8|0,vg(a,rc(x[a>>2],d)+c|0),rc(x[a>>2],x[a+4>>2]),e);g=hb-16|0;hb=g;c=pl(g,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){ys(e,B[b>>2]);e=x[c>>2]+4|0;x[c>>2]=e;continue}break}Hd(c);hb=g+16|0;xd(a,d);Vf(d)}hb=f+32|0;return}if((c|0)!=128){Id(a,d+512|0)}}function $j(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(mH()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[23604]=0;b=S(21,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[23604]=0;R(15,a+b|0,1);a=x[23604];x[23604]=0;if((a|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break a}}return}V(0)|0;Vb();p()}function fG(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if((a|0)!=(b|0)){b:{c:{f=y[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=x[116080];x[116080]=0;zd();a=ew(a,e+12|0,d);d=lb;d:{g=x[116080];if(g){if(x[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}x[c>>2]=4;b=-1;a=-1;break a}x[116080]=h;if(x[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}x[c>>2]=4;b=0;a=0}hb=e+16|0;lb=a;return b}function ME(a,b,c,d,e,f,g,h){var i=0,j=0;i=hb-16|0;hb=i;x[23604]=0;Y(900,a|0);j=x[23604];x[23604]=0;a:{b:{if((j|0)!=1){c:{j=x[a+24>>2];x[23604]=0;ia(h|0,i|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}b=Qf(Pb(i));xb(i);break b}}_(V(0)|0)|0;b=0;x[23604]=0;X(887,g|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$()}hb=i+16|0;return b}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function s0(){var a=0,b=0,c=0,d=0,e=0,f=0;c=hb-48|0;hb=c;if(AH(1,c+24|0)){Or(x[116080],12586);p()}b=Jh(c+16|0,x[c+24>>2],x[c+28>>2]);f=nH(c+8|0,x[c+32>>2]);d=hb-16|0;hb=d;e=hb-16|0;hb=e;a=Jh(e+8|0,Jia(x[b>>2],x[b+4>>2],1e9,0),lb);b=x[a>>2];a=x[a+4>>2];hb=e+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];e=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=Jh(d+8|0,e,a>>>0>e>>>0?f+1|0:f);a=x[b>>2];hb=d+16|0;b=Jh(c+40|0,a,x[b+4>>2]);a=x[b>>2];hb=c+48|0;lb=x[b+4>>2];return a|0}function yN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-16|0;hb=d;j=d,k=Sj(b),x[j>>2]=k;c=hb-16|0;hb=c;g=sy(a,c+12|0,y[b|0],x[b+4>>2]);b=x[g>>2];if(!b){e=hb-16|0;hb=e;b=jc(a);h=ph(c,Jc(28),qh(e+8|0,b));b=x[h>>2];f=x[d>>2];i=x[f>>2];f=x[f+4>>2];x[b+24>>2]=0;x[b+16>>2]=i;x[b+20>>2]=f;j=jc(h),k=1,v[j+4|0]=k;hb=e+16|0;Vg(a,x[c+12>>2],g,x[c>>2]);b=Wd(c);cl(c);e=1}Ug(d+8|0,x[Ib(c,b)>>2],e);hb=c+16|0;a=sd(x[d+8>>2]);hb=d+16|0;return a+8|0}function T1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;d=hb-32|0;hb=d;jm(d+24|0,a,b);h=d+16|0;e=x[d+24>>2];g=x[d+28>>2];b=hb-32|0;hb=b;x[b+24>>2]=c;a:{while(1){if((e|0)==(g|0)){break a}c=Xb(b+8|0,x[e>>2]);x[23604]=0;Q(1023,b+24|0,c|0)|0;i=x[23604];x[23604]=0;if((i|0)!=1){xb(c);e=e+4|0;continue}break}a=P()|0;xb(c);T(a|0);p()}hj(h,g,b+24|0);hb=b+32|0;b=x[d+16>>2];x[d+8>>2]=x[d+20>>2];yd(f+8|0,Gx(a,b),d+8|0);hb=d+32|0;hb=f+16|0}function LE(a,b,c,d,e,f,g){var h=0,i=0;h=hb-16|0;hb=h;x[23604]=0;Y(900,a|0);i=x[23604];x[23604]=0;a:{b:{if((i|0)!=1){c:{i=x[x[a+24>>2]+24>>2];x[23604]=0;ma(g|0,h|0,i|0,b|0,c|0,d|0,e|0);b=x[23604];x[23604]=0;if((b|0)==1){break c}b=Qf(Pb(h));xb(h);break b}}_(V(0)|0)|0;b=0;x[23604]=0;X(887,f|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$()}hb=h+16|0;return b}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;f=v[e|0];e=((D(v[e+1|0]-f|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(f<<8)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Ub(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function Lda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;fm(c+48|0,b);ke(c+16|0,x[c+48>>2],x[c+52>>2]);b=Yd(c+8|0);x[23604]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=rg(152,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[23604];x[23604]=0;a:{if((d|0)!=1){d=Sb(a);a=x[c+52>>2];e=x[c+48>>2];x[23604]=0;U(654,b|0,d|0,Rc(e,a)>>>5|0);a=x[23604];x[23604]=0;if((a|0)==1){a=P()|0;ni(d);yb(b);break a}yb(b);fc(c+48|0);hb=c- -64|0;return}a=P()|0}fc(c+48|0);T(a|0);p()}function Hda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;fm(c+48|0,b);ke(c+16|0,x[c+48>>2],x[c+52>>2]);b=Yd(c+8|0);x[23604]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=rg(152,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[23604];x[23604]=0;a:{if((d|0)!=1){d=Sb(a);a=x[c+52>>2];e=x[c+48>>2];x[23604]=0;U(655,b|0,d|0,Rc(e,a)>>>2|0);a=x[23604];x[23604]=0;if((a|0)==1){a=P()|0;sc(d);yb(b);break a}yb(b);fc(c+48|0);hb=c- -64|0;return}a=P()|0}fc(c+48|0);T(a|0);p()}function Gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;fm(c+48|0,b);ke(c+16|0,x[c+48>>2],x[c+52>>2]);b=Yd(c+8|0);x[23604]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=rg(152,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[23604];x[23604]=0;a:{if((d|0)!=1){d=Sb(a);a=x[c+52>>2];e=x[c+48>>2];x[23604]=0;U(656,b|0,d|0,Rc(e,a)>>>8|0);a=x[23604];x[23604]=0;if((a|0)==1){a=P()|0;nt(d);yb(b);break a}yb(b);fc(c+48|0);hb=c- -64|0;return}a=P()|0}fc(c+48|0);T(a|0);p()}function Fda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;fm(c+48|0,b);ke(c+16|0,x[c+48>>2],x[c+52>>2]);b=Yd(c+8|0);x[23604]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=rg(152,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[23604];x[23604]=0;a:{if((d|0)!=1){d=Sb(a);a=x[c+52>>2];e=x[c+48>>2];x[23604]=0;U(657,b|0,d|0,Rc(e,a)>>>4|0);a=x[23604];x[23604]=0;if((a|0)==1){a=P()|0;fl(d);yb(b);break a}yb(b);fc(c+48|0);hb=c- -64|0;return}a=P()|0}fc(c+48|0);T(a|0);p()}function t1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(c){d=hb-16|0;hb=d;if(bh(357913941)>>>0<c>>>0){Sc();p()}OD(d+8|0,c);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;g=Cb(a),h=e+D(x[d+12>>2],12)|0,x[g>>2]=h;hb=d+16|0;e=Zd(b,c);d=hb-16|0;hb=d;c=ot(d,a,c);f=x[c+4>>2];x[23604]=0;b=fa(1031,Cb(a)|0,b|0,e|0,f|0)|0;e=x[23604];x[23604]=0;a:{if((e|0)!=1){x[c+4>>2]=b;ic(c);hb=d+16|0;break a}a=P()|0;ic(c);T(a|0);p()}}return a|0}function hV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a:{b:{if(!Nf(a,7)){break b}c=0;if(!WB(a,17675)){break a}if(!Nf(a,1)){break b}c=-1;if(!ad(a,tq(a))){break a}c=hb-16|0;hb=c;f=d+8|0;po(c+8|0,f);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){ru(f)}c=-1;if(!e){break a}c=0;if(!IB(y[d+8|0],y[d+9|0])){break a}c=De(a,b,HB(d+8|0),lb);break a}c=-1}hb=d+16|0;return c|0}function r0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-32|0;hb=e;x[e+16>>2]=b;d=x[a+48>>2];x[e+20>>2]=c-((d|0)!=0);f=x[a+44>>2];x[e+28>>2]=d;x[e+24>>2]=f;a:{b:{if(Dw(cb(x[a+60>>2],e+16|0,2,e+12|0)|0)){b=32}else{d=x[e+12>>2];if((d|0)>0){break b}b=d?32:16}x[a>>2]=b|x[a>>2];break a}g=d;f=x[e+20>>2];if(f>>>0>=d>>>0){break a}d=x[a+44>>2];x[a+4>>2]=d;x[a+8>>2]=d+(g-f|0);if(x[a+48>>2]){x[a+4>>2]=d+1;v[(b+c|0)-1|0]=y[d|0]}g=c}hb=e+32|0;return g|0}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;f=w[e>>1];e=f+((D(w[e+2>>1]-f|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Ub(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function rea(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-32|0;hb=d;od(b,0);NA(d,a+1|0);c=d+16|0;Dc(c,d);ze(b+43|0,c);xb(c);x[b+24>>2]=y[a+78|0]|y[a+79|0]<<8;c=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);x[b+8>>2]=y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;wc(b+8|0,c);wc(b+4|0,x[b+8>>2]);hb=d+32|0}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=z[a+30>>1];if(d){b=Ex(b<<16>>16,d<<16>>16)}w[e+14>>1]=b;a=a+52|0;a:{if(!wd(x[c+4>>2],y[c+11|0])){vj(dL(a,e+14|0),c);break a}b=Fx(a,e+14|0);if(!xg(b,xf(a))){break a}c=hb-16|0;hb=c;b=x[Ib(c,b)>>2];d=hb-16|0;hb=d;f=Tg(Ib(d+8|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[f>>2]}g=Cb(a);x[g>>2]=x[g>>2]-1;cL(x[jc(a)>>2],b);a=x[f>>2];hb=d+16|0;Tj(sd(b));Hb(b);Ib(c+8|0,a);hb=c+16|0}hb=e+16|0}function zfa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=hb-32|0;hb=g;a:{if(z[a+480192>>1]<b>>>0){break a}b=x[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+16|0;dS(h,b);j=g,k=Bb(x[g+16>>2]),x[j+8>>2]=k;h=Ef(h);i=z[a+480190>>1];while(1){b=x[g+8>>2];if(!Ob(b,h)){jA(g+16|0);break a}b=z[Op(b)>>1];if(b>>>0<=i>>>0){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}Tg(g+8|0);continue}}hb=g+32|0}function eC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Kc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Cb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){ZB(a,b);break a}c=Cb(a);c=pj(e+8|0,qj(a,Kc(x[a>>2],d)+b|0),Kc(x[a>>2],x[a+4>>2]),c);f=hb-16|0;hb=f;b=xo(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Uu(d);d=x[b>>2]+2|0;x[b>>2]=d;continue}break}Hd(b);hb=f+16|0;xd(a,c);yi(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Id(a,d+(b<<1)|0)}}function Gj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=rc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Cb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){pP(a,b);break a}c=Cb(a);c=Wf(e+8|0,vg(a,rc(x[a>>2],d)+b|0),rc(x[a>>2],x[a+4>>2]),c);f=hb-16|0;hb=f;b=pl(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){nP(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Hd(b);hb=f+16|0;xd(a,c);Vf(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Id(a,d+(b<<2)|0)}}function ns(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(x[23474]){b=ns(x[23474])}if(!x[23400]){break a}c=b|c;a=x[23400];continue}break}d=x[a+76>>2]>=0;b:{c:{if(x[a+20>>2]==x[a+28>>2]){break c}mb[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break c}b=-1;if(d){break b}break a}b=x[a+8>>2];e=x[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;mb[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(!d){break a}}}return b|c}function Qf(a){var b=0,c=0,d=0;d=Fp(If(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=y[a|0];break b}if(a&3){while(1){b=y[a|0];v[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=x[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){x[c>>2]=b;b=x[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}v[c|0]=b;if(!(b&255)){break a}while(1){b=y[a+1|0];v[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function nc(a,b){var c=0,d=0,e=0;c=x[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return nc(a,24)+(nc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=Ur(a);d=0;if((e|0)==-1){break a}d=x[a+1396>>2];c=d+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){aa(9969,13065,1632,6791);p()}d=x[a+1392>>2];x[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}x[a+1396>>2]=c}return d}function UW(a,b){a=a|0;b=b|0;var c=0;a=Kb(a);a:{if(y[b+16|0]){x[23604]=0;Q(119,a|0,4906)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[23604]=0;Q(119,a|0,12415)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}}if(wd(x[a+4>>2],y[a+11|0])){x[23604]=0;Q(119,a|0,9959)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[23604]=0;Q(119,a|0,10991)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}}return}b=P()|0;xb(a);T(b|0);p()}function T7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;JK(e+8|0,a,0);c=x[e+12>>2];if(c){b=x[a+20>>2];x[b+148>>2]=-1;a=x[e+8>>2];d=a;a=Gb(a,c);f=hb-16|0;hb=f;g=ji(d,a);b=b+4|0;a:{if(g>>>0<=an(b)>>>0){c=a;h=x[b>>2];i=Rc(h,x[b+4>>2]);j=i>>>0>=g>>>0;if(!j){x[f+12>>2]=d;bM(f+12|0,i);c=x[f+12>>2]}d=pi(d,c,h);if(!j){xA(b,c,a,g-Rc(x[b>>2],x[b+4>>2])|0);break a}Id(b,d);break a}Wt(b);fk(b,qk(b,g));xA(b,d,a,g)}hb=f+16|0}hb=e+16|0}function Ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-4096|0;hb=c;fm(a,b);a:while(1){if(Rc(x[a>>2],x[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){h=f|2048;b=0;while(1){g=x[a>>2];if((b|0)!=2048){d=y[Gb(g,b+h|0)|0]+d|0;i=Gb(c,b<<1),j=d,v[i|0]=j;b=b+1|0;continue}break}lt(c,QP(c),Ee(Bb(g),f));e=e+1|0;continue a}else{d=y[Gb(x[a>>2],b+f|0)|0]+d|0;i=Gb(c,b<<1|1),j=d,v[i|0]=j;b=b+1|0;continue}}break}hb=c+4096|0}function ht(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;e=d+16|0;HP(e,a,a+1|0,a+2|0,a+3|0);HP(d,b,b+1|0,b+2|0,b+3|0);hb=d+32|0;a=y[x[e>>2]];b=y[x[d>>2]];c=1;a:{if(a>>>0<b>>>0){break a}c=0;if(a>>>0>b>>>0){break a}a=v[x[e+4>>2]];b=v[x[d+4>>2]];c=1;b:{if((a|0)<(b|0)){break b}c=0;if((a|0)>(b|0)){break b}f=x[e+12>>2];g=x[d+12>>2];a=y[x[d+8>>2]];b=y[x[e+8>>2]];c=1;c:{if(a>>>0>b>>>0){break c}c=0;if(a>>>0<b>>>0){break c}c=y[f|0]<y[g|0]}}}return c}function dF(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=hb-16|0;hb=i;if(1073741806-b>>>0>=c>>>0){k=Pb(a);if(b>>>0<=536870886){x[i+12>>2]=b<<1;x[i>>2]=b+c;c=El(x[_c(i,i+12|0)>>2])+1|0}else{c=1073741807}dj(i,c);j=x[i>>2];if(e){_h(j,k,e)}if(g){_h(j+(e<<2)|0,h,g)}c=e+f|0;h=d-c|0;if((c|0)!=(d|0)){c=e<<2;_h((c+j|0)+(g<<2)|0,(c+k|0)+(f<<2)|0,h)}if((b|0)!=1){Hb(k)}Ad(a,j);cg(a,x[i+4>>2]);b=a;a=h+(e+g|0)|0;oe(b,a);Ad(j+(a<<2)|0,0);hb=i+16|0;return}dg();p()}function Bw(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[116108]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[116080]=25;a=-1}else{a=1}return a}v[a|0]=b;return 1}function BL(a,b,c,d,e,f,g,h){var i=0,j=0;i=hb-16|0;hb=i;x[i+12>>2]=d;a:{if(!(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))){break a}x[i+8>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);j=b;b=x[Fb(i+8|0,i+12|0)>>2];x[j>>2]=b;b=Td(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),b,d);x[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=z[e>>1]|f;w[e>>1]=b;if((y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1){break a}w[e>>1]=b|g}hb=i+16|0}function Tt(a,b){var c=0,d=0,e=0,f=0,g=0;e=(y[Gb(a,0)|0]&15)<<8|y[Gb(a,1)|0];c=0;a:{if(!e){break a}c=0;if((e|0)==4095){break a}while(1){c=108;if((d|0)==84){break a}b:{c=z[(d<<1)+33200>>1];if(c>>>0<=e>>>0){if(!d|(e|0)==(c|0)|(z[(d<<1)+33198>>1]-e|0)>=(e-c|0)){break b}c=d+24|0;break a}d=d+1|0;continue}break}c=d+25|0}v[b|0]=c;d=y[Gb(a,2)|0];f=b,g=y[Gb(a,0)|0]&16|d>>>4,v[f+1|0]=g;f=b,g=y[Gb(a,2)|0]&15,v[f+3|0]=g;f=b,g=y[Gb(a,3)|0],v[f+5|0]=g}function X2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=hb-48|0;hb=b;x[b+40>>2]=e;x[b+44>>2]=f;c=ec(b+32|0,c,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a:{a=Cs(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ba(8)|0;x[23604]=0;b=Q(54,b+16|0,7975)|0;c=x[23604];x[23604]=0;b:{if((c|0)!=1){a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break b}c=P()|0;ca(a|0)}T(c|0);p()}hb=b+48|0;return a|0}p()}function O8(a,b){a=a|0;b=b|0;var c=0,d=0;a:{x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);c=Vj(x[b>>2],x[b+4>>2]);if(c){Ot(a,c);Lx(a,x[b>>2],x[b+4>>2],c)}x[a+20>>2]=x[b+20>>2];c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;x[23604]=0;c=Q(831,a+24|0,b+24|0)|0;d=x[23604];x[23604]=0;b:{c:{if((d|0)!=1){x[23604]=0;Q(53,a+36|0,b+36|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}x[a+48>>2]=x[b+48>>2];break a}b=P()|0;break b}b=P()|0;sc(c)}Zj(a);T(b|0);p()}}function Fi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Rc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Cb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>>0){VE(a,b);break a}c=Cb(a);c=Bl(e+8|0,qk(a,Rc(x[a>>2],d)+b|0),Rc(x[a>>2],x[a+4>>2]),c);f=hb-16|0;hb=f;b=Lv(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){qg(d);d=x[b>>2]+1|0;x[b>>2]=d;continue}break}Hd(b);hb=f+16|0;xd(a,c);Al(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Id(a,b+d|0)}}function V0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;vj(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){b=Pb(c)+Eb(x[a+36>>2],y[a+43|0])|0;x[a+44>>2]=b;d=Pb(c);jn(a,d,d,b);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Eb(x[a+36>>2],y[a+43|0]);e=a,f=b+Pb(c)|0,x[e+44>>2]=f;sx(c,Oc(c));c=Pb(c);rw(a,c,Eb(x[a+36>>2],y[a+43|0])+c|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){Jr(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}Jr(a,b)}}function xX(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[23604]=0;m=a;a=b;b=0;a=Ka(995,m|b,a|0,c|0,d|0,b|e,f|0)|0;b=x[23604];x[23604]=0;a:{b:{if((b|0)==1){_(V(0)|0)|0;x[23604]=0;ia(883,8745,g|0,h|0,i|0,j|0,k|0,l|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}return a|0}function lk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;Eh(a,e+15|0);c=y[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){x[b>>2]=f;x[b+4>>2]=d;if(!h&(g|0)==(i|0)){hb=e+16|0}else{v[e+15|0]=0;Eh(a,e+15|0);d=x[b>>2];j=x[b+4>>2];f=y[e+15|0];c=h;g=g+1|0;h=g?c:c+1|0;k=d;c=(g<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=f<<d;d=0}else{c=(1<<d)-1&f>>>32-d;d=f<<d}f=k|d;d=c|j;continue}break}}function Y4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[23604]=0;Y(925,a|0);f=x[23604];x[23604]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[23604]=0;b=Sa(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11173,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function TN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;j=e,k=Sj(b),x[j>>2]=k;c=hb-16|0;hb=c;f=Sy(a,c+12|0,z[b>>1],x[b+4>>2]);b=x[f>>2];if(!b){b=hb-16|0;hb=b;d=jc(a);g=ph(c,Jc(36),qh(b+8|0,d));d=x[g>>2]+16|0;h=x[e>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Sb(d+8|0);j=jc(g),k=1,v[j+4|0]=k;hb=b+16|0;Vg(a,x[c+12>>2],f,x[c>>2]);b=Wd(c);YN(c);d=1}Ug(e+8|0,x[Ib(c,b)>>2],d);hb=c+16|0;a=sd(x[e+8>>2]);hb=e+16|0;return a+8|0}function wS(a,b){var c=0,d=0,e=0,f=0;d=x[a>>2];c=rc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Cb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){sA(a,b);break a}c=Cb(a);c=Wf(e+8|0,vg(a,rc(x[a>>2],d)+b|0),rc(x[a>>2],x[a+4>>2]),c);f=hb-16|0;hb=f;b=pl(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){sm(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Hd(b);hb=f+16|0;xd(a,c);Vf(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Id(a,d+(b<<2)|0)}}function zN(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function cE(a,b,c,d,e){var f=0,g=0,h=0;a:{f=hb-32|0;hb=f;h=Sb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[23604]=0;a=W(142,g|0,a|0,8)|0;g=x[23604];x[23604]=0;if((g|0)==1){break c}if(!a){break d}x[23604]=0;U(e|0,f|0,b|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){x[23604]=0;R(d|0,h|0,f|0);a=x[23604];x[23604]=0;if((a|0)==1){break e}Md(f);continue}break}a=P()|0;break b}a=P()|0;Md(f);break b}hb=f+32|0;break a}a=P()|0}Xd(h);T(a|0);p()}}function Naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=_f(e,x[a+4>>2]);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;b=x[Cb(a)>>2];f=x[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){ez(a,d,c);break c}b=Cb(a);b=ft(e+8|0,Dp(a,_f(x[a>>2],f)+d|0),_f(x[a>>2],x[a+4>>2]),b);x[23604]=0;U(710,b|0,d|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}LO(a,b);cz(b)}hb=e+32|0;break a}a=P()|0;cz(b);T(a|0);p()}return}if(b>>>0<d>>>0){NO(a,e+(b<<5)|0)}}function sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;d=Xc(c+8|0,16,1,1,0);x[c+4>>2]=0;od(a,0);xc(b);a:{b:{if(yq(b,13621)){Yc(b,12);if(!rm(b)){to(d,2)}Yc(b,24);break b}if(wh(b,13493)){xc(b);x[c+4>>2]=4;e=1;break a}id(d,8)}e=0}f=a,g=(cf(b)>>>0)/(D(y[d|0],Yp(y[d+1|0]))>>>3>>>0)|0,x[f>>2]=g;b=fg(d,a,b);if(!(!b|!e)){d=x[a+20>>2];f=c,g=lj(x[a>>2],z[a+34>>1]),x[f>>2]=g;Zb(d,0,x[Fb(c+4|0,c)>>2])}hb=c+16|0;return(b|0)!=0|0}function kf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;i=Jia(b,c,h,i);h=lb;e=Jia(d,e,f,g);i=e+i|0;d=lb+h|0;h=e>>>0>i>>>0?d+1|0:d;j=g;e=0;k=c;d=0;c=Jia(g,e,c,d);g=c+i|0;i=lb+h|0;l=g;c=c>>>0>g>>>0?i+1|0:i;g=Jia(f,0,b,0);h=lb;i=0;d=Jia(f,i,k,d);h=h+d|0;f=lb+i|0;f=d>>>0>h>>>0?f+1|0:f;i=f+l|0;d=c;f=f>>>0>i>>>0?d+1|0:d;c=Jia(b,m,j,e)+h|0;e=lb;e=c>>>0<h>>>0?e+1|0:e;h=e+i|0;i=f;x[a+8>>2]=h;x[a+12>>2]=e>>>0>h>>>0?i+1|0:i;x[a>>2]=g;x[a+4>>2]=c}function gG(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[116080];x[116080]=0;zd();a=ew(a,e+12|0,d);d=lb;g=x[116080];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}x[116080]=h;if((b|0)!=x[e+12>>2]){break c}if(!d){break b}}x[c>>2]=4;a=-1;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}hb=e+16|0;return a}function Q1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=d;a=ec(e+32|0,a,b);b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;a:{a=Cs(3,e+8|0,e+40|0);if(a+1>>>0>=3){b=ba(8)|0;x[23604]=0;c=Q(54,e+16|0,7975)|0;a=x[23604];x[23604]=0;b:{if((a|0)!=1){a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}a=P()|0;ca(b|0)}T(a|0);p()}hb=e+48|0;return a|0}p()}function Mo(a,b,c,d,e){var f=0,g=0,h=0;a:{f=hb-32|0;hb=f;h=Sb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[23604]=0;a=W(142,g|0,a|0,e|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break c}if(!a){break d}x[23604]=0;R(d|0,f|0,b|0);a=x[23604];x[23604]=0;if((a|0)!=1){x[23604]=0;R(c|0,h|0,f|0);a=x[23604];x[23604]=0;if((a|0)==1){break e}Md(f);continue}break}a=P()|0;break b}a=P()|0;Md(f);break b}hb=f+32|0;break a}a=P()|0}Xd(h);T(a|0);p()}}function UT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(D(b,6)+a|0)+1072|0,g=hk(a,7),v[f|0]=g;d=hk(a,1);e=hk(a,1);c=x[a+1060>>2];if((c|0)>255){break a}b=x[a+1064>>2]+1|0;x[a+1060>>2]=b;x[a+1064>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1068>>1]=b;UT(a);b=x[a+1064>>2];break b}w[(D(c,6)+a|0)+1068>>1]=65535}x[a+1060>>2]=b;if(e){w[(D(c,6)+a|0)+1070>>1]=b;continue}break}w[(D(c,6)+a|0)+1070>>1]=65535}}function yq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=ec(c+8|0,c+24|0,7);mc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(Rb(c+24|0,b,7)){break b}bc(a,7);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17313,8981,413,13029);p()}aa(17292,8981,411,13029);p()}return d|0}function vE(a,b,c,d,e,f){var g=0,h=0;g=hb-256|0;hb=g;x[g+248>>2]=37;x[g+252>>2]=0;h=g+248|0;xr(h|1,10479,f,x[b+4>>2]);f=zd();x[g>>2]=d;x[g+4>>2]=e;d=g+224|0;e=Ig(d,24,f,h,g)+d|0;f=Li(d,e,x[b+4>>2]);h=g+16|0;Pc(h,x[b+28>>2]);x[23604]=0;ia(1099,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[23604];x[23604]=0;a:{if((d|0)!=1){$b(g+16|0);a=vr(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);hb=g+256|0;break a}a=P()|0;$b(g+16|0);T(a|0);p()}return a}function $4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[23604]=0;Y(925,a|0);e=x[23604];x[23604]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[23604]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11318,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function xE(a,b,c,d,e,f){var g=0,h=0;g=hb-112|0;hb=g;x[g+104>>2]=37;x[g+108>>2]=0;h=g+104|0;xr(h|1,10479,f,x[b+4>>2]);f=zd();x[g>>2]=d;x[g+4>>2]=e;d=g+80|0;e=Ig(d,24,f,h,g)+d|0;f=Li(d,e,x[b+4>>2]);h=g+16|0;Pc(h,x[b+28>>2]);x[23604]=0;ia(1096,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[23604];x[23604]=0;a:{if((d|0)!=1){$b(g+16|0);a=rq(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);hb=g+112|0;break a}a=P()|0;$b(g+16|0);T(a|0);p()}return a}function ms(a,b){var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;c=Sd(a);d=jc(a);f=hb-16|0;hb=f;while(1){if(c){g=Rs(c+16|0,b);d=g?d:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[Ib(f+8|0,d)>>2];hb=f+16|0;a:{if(Ob(c,Ef(a))){if(!Rs(b,sd(c))){break a}}c=Ef(a)}if(!tc(c,Ef(a))){b=x[Ib(e+8|0,c)>>2];c=hb-16|0;hb=c;d=Tg(Ib(c+8|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[d>>2]}d=Cb(a);x[d>>2]=x[d>>2]-1;cL(x[jc(a)>>2],b);hb=c+16|0;$l(sd(b));Hb(b)}hb=e+16|0}function iQ(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+4>>2]=((y[a+48|0]|y[a+49|0]<<8)<<1)+((y[a+32|0]|y[a+33|0]<<8)<<4);x[b+8>>2]=((y[a+50|0]|y[a+51|0]<<8)<<1)+((y[a+34|0]|y[a+35|0]<<8)<<4);x[b+12>>2]=(D(y[a+52|0]|y[a+53|0]<<8,5)+((y[a+36|0]|y[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=zb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Vo(x[a>>2],x[c>>2])?c:a;continue}}hb=b+16|0;a=x[a>>2];lb=a>>31;return a}function _4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[23604]=0;Y(925,a|0);e=x[23604];x[23604]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[23604]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11354,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=Bf(d,x[a+4>>2]);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;b=x[Cb(a)>>2];e=x[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){bC(a,c);break c}b=Cb(a);b=QA(d+8|0,RA(a,Bf(x[a>>2],e)+c|0),Bf(x[a>>2],x[a+4>>2]),b);x[23604]=0;R(453,b|0,c|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}PA(a,b);St(b)}hb=d+32|0;break a}a=P()|0;St(b);T(a|0);p()}return}if(b>>>0<c>>>0){$B(a,d+D(b,20)|0)}}function eaa(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:jh(a,0,c);return;case 1:jh(a,1,c);return;case 2:jh(a,2,c);return;case 3:jh(a,3,c);return;case 4:jh(a,4,c);return;case 5:jh(a,5,c);return;case 6:lN(a,23584,c);return;case 7:lN(a,24608,c);return;case 8:jh(a,6,c);return;case 9:jh(a,7,c);return;case 10:jh(a,8,c);return;case 11:jh(a,9,c);return;case 12:jh(a,10,c);return;case 13:jh(a,11,c);return;default:break a}}Kb(a)}function v3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=hb-16|0;hb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;x[23604]=0;b=Q(54,h|0,8118)|0;c=x[23604];x[23604]=0;if((c|0)==1){break c}a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}d=P()|0;xb(b);break b}Gk(a,b,4);c=Yw(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=h+16|0;return c|0}d=P()|0;ca(a|0)}T(d|0)}p()}function h3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=hb-16|0;hb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;x[23604]=0;b=Q(54,h|0,8118)|0;c=x[23604];x[23604]=0;if((c|0)==1){break c}a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}d=P()|0;xb(b);break b}Gk(a,b,4);c=_w(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=h+16|0;return c|0}d=P()|0;ca(a|0)}T(d|0)}p()}function eg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Wc(43484,d+14|0)>>1];e=x[a>>2];c=Kc(e,x[a+4>>2]);a:{if(b>>>0>c>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Cb(a)>>2];g=x[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){qo(a,b,f);break b}c=Cb(a);c=pj(e+8|0,qj(a,Kc(x[a>>2],g)+b|0),Kc(x[a>>2],x[a+4>>2]),c);pC(c,b,f);xd(a,c);yi(c)}hb=e+32|0;break a}if(b>>>0<c>>>0){Id(a,e+(b<<1)|0)}}hb=d+16|0}function V4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[23604]=0;Y(925,a|0);d=x[23604];x[23604]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[23604]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,6621,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function T4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[23604]=0;Y(925,a|0);d=x[23604];x[23604]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[23604]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,6675,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function IE(a,b,c,d){var e=0,f=E(0);x[23604]=0;Y(900,a|0);e=x[23604];x[23604]=0;if((e|0)!=1){a=x[x[a+24>>2]+24>>2];a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=a+D(b,872)|0;if(!(v[a+1075081|0]&1)){break a}f=E(E(y[a+d|0])*E(.0078125))}return f}_(V(0)|0)|0;x[23604]=0;X(887,c|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return E(0)}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function ws(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function De(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;f=Fg(a);a:{b:{if(!b){i=e,j=Fg(a),x[i+8>>2]=j;x[e+12>>2]=0;break b}g=x[b>>2];b=x[b+4>>2];h=b;x[e+8>>2]=g;x[e+12>>2]=b;a=x[a+12>>2];x[e>>2]=2048;x[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Eq(e+8|0,e);c=x[a>>2];a=x[a+4>>2];if(!a&c>>>0>f>>>0|a){a=-1;if(!d&b>>>0<=f>>>0){break b}break a}a=0;if((d|0)==(h|0)&b>>>0>g>>>0|d>>>0>h>>>0){break a}}a=1}hb=e+16|0;return a}function JE(a,b,c,d){var e=0,f=E(0);x[23604]=0;Y(900,a|0);e=x[23604];x[23604]=0;if((e|0)!=1){a=x[x[a+24>>2]+24>>2];a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=a+D(b,872)|0;if(v[a+1075081|0]&1){break a}f=E(E(y[a+d|0])*E(.0078125))}return f}_(V(0)|0)|0;x[23604]=0;X(887,c|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return E(0)}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function IH(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;c=B[a>>2];i=a-16|0;d=B[i>>2];e=E(c+d);b=a-8|0;f=B[b>>2];j=a-24|0;g=B[j>>2];h=E(f+g);B[a>>2]=e+h;B[b>>2]=e-h;b=a-12|0;h=B[b>>2];k=a-28|0;l=B[k>>2];e=E(h+l);p=b;b=a-4|0;m=B[b>>2];a=a-20|0;n=B[a>>2];o=E(m+n);B[p>>2]=o-e;f=E(f-g);g=E(m-n);B[k>>2]=f+g;c=E(c-d);d=E(h-l);B[i>>2]=c+d;B[j>>2]=c-d;B[b>>2]=e+o;B[a>>2]=g-f}function ix(a,b,c,d,e){var f=0,g=0;a:{if(!Xr(b)){break a}f=x[a+484344>>2];if(!pe(f,x[a+484348>>2],b&65535)){break a}b=ac(f,b);if(x[b+12>>2]<=(c|0)|e>>>0>5|z[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=cd(x[b>>2],x[x[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=y[b|0]}return g}function e0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;f=d;d=x[rd(e+12|0,rd(e+8|0,e+4|0))>>2];b=_h(b,f,d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=mb[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}hb=e+16|0;return g|0}function wE(a,b,c,d,e){var f=0,g=0,h=0;f=hb-160|0;hb=f;x[f+152>>2]=37;x[f+156>>2]=0;g=f+152|0;xr(g|1,10646,e,x[b+4>>2]);e=zd();x[f>>2]=d;d=f+139|0;e=Ig(d,13,e,g,f)+d|0;g=Li(d,e,x[b+4>>2]);h=f+16|0;Pc(h,x[b+28>>2]);x[23604]=0;ia(1099,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=x[23604];x[23604]=0;a:{if((d|0)!=1){$b(f+16|0);a=vr(a,f+32|0,x[f+28>>2],x[f+24>>2],b,c);hb=f+160|0;break a}a=P()|0;$b(f+16|0);T(a|0);p()}return a}function c7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=fi(a,b,c,d);x[a>>2]=45664;c=Sb(a+4256|0);b=a+4208|0;e=zb(b,0),f=1056964608,x[e>>2]=f;e=zb(b,1),f=1017370378,x[e>>2]=f;e=zb(b,2),f=1028670828,x[e>>2]=f;e=zb(b,3),f=1059760811,x[e>>2]=f;e=zb(b,4),f=1017370378,x[e>>2]=f;e=zb(b,5),f=1065353216,x[e>>2]=f;x[23604]=0;R(851,a+44|0,2);b=x[23604];x[23604]=0;if((b|0)!=1){ei(a);return a|0}b=P()|0;sc(c);uf(a);T(b|0);p()}function q0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+16>>2];d=x[a+12>>2];b:{if(g>>>0>d>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=g-d;x[e+4>>2]=c-f;g=d;d=x[rd(e+12|0,rd(e+8|0,e+4|0))>>2];b=Te(b,g,d);x[a+12>>2]=x[a+12>>2]+d;b=b+d|0;break b}d=mb[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b|0]=d<<24>>24;d=1;b=b+1|0}f=d+f|0;continue}break}hb=e+16|0;return f|0}function R4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[23604]=0;Y(925,a|0);d=x[23604];x[23604]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[23604]=0;ta(f|0,d|0,b|0,+c);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11553,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Jp(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=hb-16|0;hb=i;if(2147483630-b>>>0>=c>>>0){k=Pb(a);if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i>>2]=b+c;c=Xj(x[_c(i,i+12|0)>>2])+1|0}else{c=2147483631}si(i,c);j=x[i>>2];if(e){Te(j,k,e)}if(g){Te(e+j|0,h,g)}c=e+f|0;h=d-c|0;if((c|0)!=(d|0)){Te((e+j|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Hb(k)}Ad(a,j);cg(a,x[i+4>>2]);b=a;a=h+(e+g|0)|0;oe(b,a);id(a+j|0,0);hb=i+16|0;return}dg();p()}function G4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[23604]=0;Y(925,a|0);d=x[23604];x[23604]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+96>>2];x[23604]=0;ta(f|0,d|0,b|0,+c);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11491,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function E4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[23604]=0;Y(925,a|0);d=x[23604];x[23604]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+88>>2];x[23604]=0;ta(f|0,d|0,b|0,+c);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,10925,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function bX(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;b=Xb(c,16619);x[23604]=0;U(106,c+16|0,a|0,b|0);a=x[23604];x[23604]=0;a:{if((a|0)!=1){xb(b);a=0;b=0;while(1){d=x[c+16>>2];if(!(b>>>0<=3&Dd(d,x[c+20>>2])>>>0>b>>>0)){Vd(c+16|0);hb=c+32|0;return a|0}x[23604]=0;d=S(107,Zd(d,b)|0)|0;e=x[23604];x[23604]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=P()|0;Vd(c+16|0);break a}a=P()|0;xb(b)}T(a|0);p()}function HH(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){gc(a,21);return-1}if(x[a+1396>>2]<=9){Bk(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Jl(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){gc(a,21)}return c}aa(7484,13065,1793,5711);p()}function _x(a,b,c){if(Tb(a+1074312|0,21)){c=c&255;a:{switch((b&3)-1|0){default:return v[c+33968|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}return NL(Jn(a))+-64|0}if(z[a+480182>>1]&1032){return v[(c>>>1&31)+32480|0]}a=c&63;b:{switch((b&3)-1|0){default:return v[a+33840|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return v[a+33904|0]}function Lw(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!Tr(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}gc(a,32);return 0}aa(15604,13065,1564,5997);p()}function C_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=hb-208|0;hb=a;f=zd();x[a>>2]=e;g=a+176|0;i=Ig(g,20,f,9164,a);e=i+g|0;g=Li(g,e,x[c+4>>2]);Pc(a+8|0,x[c+28>>2]);x[23604]=0;f=S(1083,x[a+8>>2])|0;h=x[23604];x[23604]=0;if((h|0)!=1){$b(a+8|0);h=f;f=a+16|0;$F(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=vr(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);hb=a+208|0;return b|0}b=P()|0;$b(a+8|0);T(b|0);p()}function A8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;c=ff(a,c);_d(f,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!fd(a,5)){break b}break a}d=x[c+8>>2]}g=x[a+28>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=hb-16|0;hb=d;x[d+8>>2]=0;ep(g,d+8|0);B[b>>2]=B[d+8>>2];hb=d+16|0;break c}e=hb-32|0;hb=e;x[e+28>>2]=0;x[e+24>>2]=d;x[e+20>>2]=4;Ar(e+8|0,g,e+28|0,x[Fb(e+24|0,e+20|0)>>2]);x[b>>2]=0;hb=e+32|0}e=c}_e(a,e);hb=f+16|0}function yE(a,b,c,d,e){var f=0,g=0,h=0;f=hb-80|0;hb=f;x[f+72>>2]=37;x[f+76>>2]=0;g=f+72|0;xr(g|1,10646,e,x[b+4>>2]);e=zd();x[f>>2]=d;d=f+59|0;e=Ig(d,13,e,g,f)+d|0;g=Li(d,e,x[b+4>>2]);h=f+16|0;Pc(h,x[b+28>>2]);x[23604]=0;ia(1096,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=x[23604];x[23604]=0;a:{if((d|0)!=1){$b(f+16|0);a=rq(a,f+32|0,x[f+28>>2],x[f+24>>2],b,c);hb=f+80|0;break a}a=P()|0;$b(f+16|0);T(a|0);p()}return a}function X1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;g=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;JI(a,c);a:{if(B[a+24>>2]==E(1)){break a}d=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=x[a+16>>2];k=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Gh(k,j,b,i);B[f>>2]=B[a+24>>2]*B[f>>2];b=b+1|0;continue}}}hb=c+16|0}function O3(a,b){a=a|0;b=b|0;var c=0,d=0;x[23604]=0;Y(900,a|0);c=x[23604];x[23604]=0;if((c|0)!=1){a=x[x[a+24>>2]+24>>2];c=0;a:{if(!Xr(b)){break a}d=x[a+484344>>2];if(!pe(d,x[a+484348>>2],b&65535)){break a}c=x[ac(d,b)+12>>2]}return c|0}_(V(0)|0)|0;x[23604]=0;X(887,6585,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function pV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=-1;if(ig(a,d+8|0)){x[d+4>>2]=y[d+8|0];f=x[Fb(d+4|0,d+12|0)>>2];c=hb+-64|0;hb=c;e=c+40|0;Af(e,a,f);g=x[c+40>>2];a=c+8|0;Kf(a,3,xe(e),g);x[23604]=0;R(208,c+24|0,a|0);a=x[23604];x[23604]=0;a:{if((a|0)!=1){ec(c,b,11);a=c+24|0;ol(c,a);xb(a);Lc(c+40|0);hb=c- -64|0;e=!f|(g|0)!=0;break a}a=P()|0;Lc(c+40|0);T(a|0);p()}}hb=d+16|0;return e|0}function dO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;x[a+4>>2]=0;a:{if(b){b:{if(dt(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}e=Wn(d+16|0);x[23604]=0;f=Q(679,a|0,b|0)|0;g=x[23604];x[23604]=0;if((g|0)==1){break a}x[23604]=0;R(680,e|0,f|0);f=x[23604];x[23604]=0;if((f|0)==1){break a}x[e+4>>2]=b;kt(a,e);He(e)}$k(d+8|0,x[a>>2]);Qu(x[d+8>>2],x[d+12>>2],b,y[c|0])}hb=d+32|0;return}a=P()|0;He(e);T(a|0);p()}function wea(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;v[b+15|0]=128;a=tm(a,127,b+15|0);x[23604]=0;v[b+14|0]=64;d=W(528,a+12|0,127,b+14|0)|0;c=x[23604];x[23604]=0;a:{b:{if((c|0)!=1){x[23604]=0;v[b+13|0]=0;Q(603,a+24|0,b+13|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break b}x[a+36>>2]=-1;x[a+40>>2]=108855296;x[a+44>>2]=0;x[a+48>>2]=0;w[a+52>>1]=0;hb=b+16|0;return a|0}b=P()|0;break a}b=P()|0;fc(d)}fc(a);T(b|0);p()}function e5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+24>>2]=c;c=x[Mf(e+16|0,e+24|0)>>2];x[23604]=0;f=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;fa(894,a+8|0,e|0,c|0,d|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){a=tI(a);b=sI(a+88|0);c=rI(a+92|0);x[a>>2]=61896;x[b>>2]=62008;x[c>>2]=62088;te(e+24|0);hb=e+32|0;return a|0}a=P()|0;te(e+24|0);T(a|0);p()}function Pha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;h=hb-16|0;hb=h;x[h+8>>2]=d;g=Eb(x[a+4>>2],y[a+11|0]);f=Oc(a);a:{if(f-g>>>0>=b>>>0){f=Pb(a);if((c|0)==(g|0)){break a}i=c+f|0;dl(i+b|0,i,g-c|0);break a}Rl(a,f,(b+g|0)-f|0,g,c,0,b);f=x[a>>2]}b=b+g|0;Sg(a,b);id(b+f|0,0);b=c+f|0;while(1){if(Ob(d,e)){id(b,y[d|0]);b=b+1|0;d=x[Le(h+8|0)>>2];continue}break}a=Ee(pd(a),c);hb=h+16|0;return a|0}function Z4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[23604]=0;R(e|0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11183,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function I4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[23604]=0;R(e|0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,12654,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function HN(a,b,c){a:{switch(b|0){case 0:kh(a,0,c);return;case 1:kh(a,1,c);return;case 2:kh(a,2,c);return;case 3:kh(a,3,c);return;case 4:kh(a,4,c);return;case 5:kh(a,5,c);return;case 6:uN(a,23584,c);return;case 7:uN(a,24608,c);return;case 8:kh(a,6,c);return;case 9:kh(a,7,c);return;case 10:kh(a,8,c);return;case 11:kh(a,9,c);return;case 12:kh(a,10,c);return;case 13:kh(a,11,c);return;default:break a}}Kb(a)}function D4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+84>>2];x[23604]=0;R(e|0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,12137,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function C4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+80>>2];x[23604]=0;R(e|0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11015,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function P4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[23604]=0;ra(e|0,c|0,+b);c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11591,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23604]=0;Z(17);d=x[23604];x[23604]=0;if((d|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function J4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[23604]=0;R(e|0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,9214,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function H4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+100>>2];x[23604]=0;d=+sa(e|0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11509,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function ly(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Hj(a,b,b+700|0,0-(c<<2)|0,0);if(x[b+700>>2]<65536){break b}if(Tb(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function fy(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;v[a+1074368|0]=b;iM(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(f|0)){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(mb[x[x[b>>2]+136>>2]](b)|0){d=x[b+16>>2];e=d+1074332|0;c=E(E(c/B[e+8>>2])*E(E(A[d+480232>>2])/B[e+20>>2]))}B[b+4196>>2]=c}a=a+160|0;continue}break}}function S4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[23604]=0;d=+sa(e|0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11572,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function N4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[23604]=0;ra(e|0,c|0,+b);c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,7695,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23604]=0;Z(17);d=x[23604];x[23604]=0;if((d|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function M_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=hb-96|0;hb=a;f=zd();x[a>>2]=e;g=a- -64|0;i=Ig(g,20,f,9164,a);e=i+g|0;g=Li(g,e,x[c+4>>2]);Pc(a+8|0,x[c+28>>2]);x[23604]=0;f=S(18,x[a+8>>2])|0;h=x[23604];x[23604]=0;if((h|0)!=1){$b(a+8|0);h=f;f=a+16|0;dG(h,a- -64|0,e,f);h=b;b=f+i|0;b=rq(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);hb=a+96|0;return b|0}b=P()|0;$b(a+8|0);T(b|0);p()}function K4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[23604]=0;ra(e|0,c|0,+b);c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,7643,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23604]=0;Z(17);d=x[23604];x[23604]=0;if((d|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function F4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+92>>2];x[23604]=0;d=+sa(e|0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,10945,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function y1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;a:{if(y[b+8|0]){f=x[b+12>>2];h=e,i=Rc(f,x[b+16>>2])-c|0,x[h+28>>2]=i;x[e+24>>2]=x[d+4>>2];g=x[Fb(e+28|0,e+24|0)>>2];f=Ee(Bb(f),c);c=Ee(Ee(Bb(x[b+12>>2]),c),g);b=x[d>>2];Xt(f,c,b);hc(a,b,g);break a}g=x[d+4>>2];d=x[d>>2];x[e+16>>2]=d;x[e+20>>2]=g;f=x[x[b>>2]+40>>2];x[e+8>>2]=d;x[e+12>>2]=g;mb[f|0](a,b,c,e+8|0)}hb=e+32|0}function o0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+28>>2];d=x[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=nh(v[b|0]),h=x[x[a>>2]+52>>2],mb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=g-d;x[e+8>>2]=c-f;g=d;d=x[rd(e+12|0,e+8|0)>>2];Te(g,b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}hb=e+16|0;return f|0}function t3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;x[23604]=0;b=Q(54,f|0,8118)|0;c=x[23604];x[23604]=0;if((c|0)==1){break c}a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}e=P()|0;xb(b);break b}Gk(a,b,2);c=Yw(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c|0}e=P()|0;ca(a|0)}T(e|0)}p()}function f3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;x[23604]=0;b=Q(54,f|0,8118)|0;c=x[23604];x[23604]=0;if((c|0)==1){break c}a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}e=P()|0;xb(b);break b}Gk(a,b,2);c=_w(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c|0}e=P()|0;ca(a|0)}T(e|0)}p()}function X4(a,b){a=a|0;b=b|0;var c=0,d=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[23604]=0;b=Q(d|0,c|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,6648,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function U4(a,b){a=a|0;b=b|0;var c=0,d=0;x[23604]=0;Y(925,a|0);c=x[23604];x[23604]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[23604]=0;b=Q(d|0,c|0,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,6699,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Me(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=No(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(_E(a,b)&3){case 0:c=No(C[b>>3],C[b+8>>3]);break a;case 1:c=-Oo(C[b>>3],C[b+8>>3],1);break a;case 2:c=-No(C[b>>3],C[b+8>>3]);break a;default:break b}}c=Oo(C[b>>3],C[b+8>>3],1)}a=c;hb=b+16|0;return a}function uW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+4>>2]=1;i=f,j=Jc(32),x[i+8>>2]=j;e=hb-16|0;hb=e;g=Co(x[f+8>>2]);x[g>>2]=43496;g=yc(g);b=ul(e+8|0,x[b>>2],x[b+4>>2]);d=x[d>>2];c=x[c>>2];h=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=h;b=Mm(g);x[b>>2]=43632;ul(b+4|0,x[e>>2],x[e+4>>2]);x[b+16>>2]=d;x[b+12>>2]=c;be(e);hb=e+16|0;b=a;a=Eo(f);Do(b,yc(a),a);Nm(f);hb=f+16|0}function b9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;We(d,2,a+6|0);e=d+16|0;Dc(e,d);Bc(b+492|0,e);f=b+236|0;g=c+1|0;xb(e);c=0;while(1){if((c|0)==128){x[b>>2]=(y[a+226|0]|y[a+227|0]<<8)<<5;Nx(a+180|0,b+48|0,0);Nx(a+228|0,b+88|0,2);Nx(a+276|0,b+68|0,1);if(!(y[a+324|0]|y[a+325|0]<<8)){tz(f)}hb=d+32|0}else{e=y[(a+c|0)+38|0];h=cc(f,c),i=e+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function EM(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Hj(a,b,b+700|0,0-c|0,0);if(x[b+700>>2]<65536){break b}if(Tb(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function fI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Bg(a)|0)>(b|0)){break d}}b=ba(8)|0;x[23604]=0;c=Q(54,c|0,10598)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}hb=c+16|0;return(x[(a+D(b,872)|0)+1075080>>2]&134218752)!=0|0}a=P()|0;ca(b|0)}T(a|0)}p()}function Xs(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[b+40>>2]=0;x[b+44>>2]=0;f=b- -64|0;x[f>>2]=0;x[f+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=Bb(x[c>>2]);x[e+8>>2]=d;f=Bb(x[c+4>>2]);while(1){if(!Ob(d,f)){break a}g=d,h=iO(b,C[d>>3]),C[g>>3]=h;d=x[Vs(e+8|0)>>2];continue}}}else{iO(b,C[Ne(x[c>>2],0)>>3]);d=d+1|0;continue}break}Qj(a,c);hb=e+16|0}function WB(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=ec(c+8|0,c+24|0,7);kd(c+16|0,a,x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(Rb(c+24|0,b,7)){break b}ad(a,7);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17313,8981,413,13029);p()}aa(17292,8981,411,13029);p()}return d}function GE(a,b,c,d,e,f,g,h,i){var j=0;x[23604]=0;Y(900,a|0);j=x[23604];x[23604]=0;a:{b:{if((j|0)!=1){j=x[a+24>>2];x[23604]=0;b=ua(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,h|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function QE(a,b,c){a=Kb(a);x[23604]=0;R(c|0,a|0,4);c=x[23604];x[23604]=0;a:{b:{if((c|0)==1){break b}x[23604]=0;R(b|0,a|0,32);c=x[23604];x[23604]=0;if((c|0)==1){break b}x[23604]=0;R(b|0,a|0,10);c=x[23604];x[23604]=0;if((c|0)==1){break b}x[23604]=0;R(b|0,a|0,13);c=x[23604];x[23604]=0;if((c|0)==1){break b}x[23604]=0;R(b|0,a|0,9);b=x[23604];x[23604]=0;if((b|0)!=1){break a}}b=P()|0;xb(a);T(b|0);p()}}function Lea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;b=-1;a:{if(!Nf(a,8)){break a}b=hb-32|0;hb=b;x[b+24>>2]=0;x[b+28>>2]=0;d=ec(b+8|0,b+24|0,8);kd(b+16|0,a,x[d>>2],x[d+4>>2]);b:{if(x[b+20>>2]!=8){break b}if(Rb(b+24|0,13996,8)){break b}ad(a,8);e=1}hb=b+32|0;b=0;if(!e){break a}b=-1;if(!sj(a,c+8|0)){break a}b=0;if(!dc(x[c+12>>2])){break a}b=!(dc(x[c+8>>2])&-2139062144)}hb=c+16|0;return b|0}function $Q(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+8|0]){while(1){if((d|0)==8){x[c+24>>2]=0;x[c+28>>2]=0;d=ec(c+8|0,c+24|0,8);e=x[d>>2];mc(c+16|0,x[a>>2],x[a+8>>2],e,x[d+4>>2]);d=0;b:{if(x[c+20>>2]!=8){break b}if(Rb(c+24|0,b,8)){break b}bc(a,8);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17313,8981,413,13029);p()}aa(17292,8981,411,13029);p()}return d|0}function go(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+12>>2]=c;a:{if(!Qb(x[b>>2],x[b+8>>2],c)){break a}wc(f+12|0,65535);eg(a,z[f+12>>1]);c=Bb(x[a>>2]);x[f>>2]=c;h=Bb(x[a+4>>2]);while(1){if(!Ob(c,h)){break a}a=f+11|0;if(!ig(b,a)){qg(a)}a=y[f+11|0];w[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}w[c>>1]=g}c=x[Pe(f)>>2];continue}}hb=f+16|0}function Vca(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Cb(a)>>2]){c=hb-16|0;hb=c;a=pz(c,a);oP(x[a+4>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[a+4>>2]=x[a+4>>2]+4;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Cb(a);c=Wf(d+8|0,vg(a,rc(x[a>>2],x[a+4>>2])+1|0),rc(x[a>>2],x[a+4>>2]),c);oP(x[c+8>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[c+8>>2]=x[c+8>>2]+4;xd(a,c);Vf(c);hb=d+32|0}function Z2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[23604]=0;U(994,d|0,b|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,10213,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function wX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[23604]=0;a=Ia(997,a|0,b|0,c|0,d|0)|0;b=x[23604];x[23604]=0;a:{b:{if((b|0)==1){_(V(0)|0)|0;x[23604]=0;ia(883,11055,e|0,f|0,g|0,h|0,i|0,j|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}return a|0}function s2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if(!c){break a}f=Qc(x[b+4>>2],y[b+11|0]);g=f-1|0;h=d<<24>>24;d=0;while(1){if((d|0)==(f|0)){break a}b:{if(!d|(d>>>0)%(c>>>0)){break b}if((d|0)==(g|0)){if(y[uc(b,0)|0]==(Pf(43)&255)){break b}if(y[uc(b,0)|0]==(Pf(45)&255)){break b}}Zw(b,x[Ib(e+8|0,Ee(pd(b),f-d|0))>>2],1,Pf(h))}d=d+1|0;continue}}dd(a,b);hb=e+16|0}function k2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Mg(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;TI(a,c);hb=c+16|0}function jS(a){var b=0;a:{if(Rb(a,14137,3)|(y[a+3|0]-52&255)>>>0<252){break a}if(dc(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788>>>0<840){break a}if(dc(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))>>>0<52){break a}if(dc(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))-1>>>0<51){break a}b=dc(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))>>>0<4294967216}return b}function hI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Bg(a)|0)>(b|0)){break d}}b=ba(8)|0;x[23604]=0;c=Q(54,c|0,10598)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}hb=c+16|0;return+(+x[(a+D(b,872)|0)+1075740>>2]*.015625)}a=P()|0;ca(b|0)}T(a|0)}p()}function f2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-16|0;hb=c;g=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;PI(a,c);a:{if(B[a+24>>2]==E(1)){break a}d=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Kp(j,b,i);B[f>>2]=B[a+24>>2]*B[f>>2];b=b+1|0;continue}}}hb=c+16|0}function e2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Mg(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;OI(a,c);hb=c+16|0}function bda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;w[b+12>>1]=0;w[b+14>>1]=1;pg(b+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=hb-16|0;hb=d;c=z[b+14>>1];x[d+12>>2]=c;a:{if(Dm(a)>>>0>=c>>>0){g=x[a>>2];f=Kc(g,x[a+4>>2]);x[d+8>>2]=f;Et(g,x[Fb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){qo(a,c-f|0,e);break a}Id(a,x[a>>2]+(c<<1)|0);break a}WO(a);Hp(a,qj(a,c));qo(a,c,e)}hb=d+16|0;hb=b+16|0}function b2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Mg(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;MI(a,c);hb=c+16|0}function W1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Mg(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;II(a,c);hb=c+16|0}function mi(a){var b=0,c=0;b=hb-16|0;hb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Oo(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(_E(a,b)&3){case 0:a=Oo(C[b>>3],C[b+8>>3],1);break a;case 1:a=No(C[b>>3],C[b+8>>3]);break a;case 2:a=-Oo(C[b>>3],C[b+8>>3],1);break a;default:break b}}a=-No(C[b>>3],C[b+8>>3])}hb=b+16|0;return a}function b3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[23604]=0;e=+qa(990,d|0,b|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,5311,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Q4(a){a=a|0;var b=0,c=0,d=0;x[23604]=0;Y(925,a|0);b=x[23604];x[23604]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[23604]=0;c=+na(d|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,11609,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function iV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;if(!Qb(x[b>>2],x[b+8>>2],c)){c=cf(b)}x[a>>2]=c;c=x[b>>2];a:{if(mb[x[x[c>>2]+16>>2]](c)|0){c=a;a=x[b>>2];e=c,f=(mb[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;break a}Fi(a+8|0,x[a>>2]);c=x[a+8>>2];a=x[a+12>>2];if(tc(c,a)){break a}ke(d+8|0,c,a);mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2])}hb=d+16|0}function O4(a){a=a|0;var b=0,c=0,d=0;x[23604]=0;Y(925,a|0);b=x[23604];x[23604]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[23604]=0;c=+na(d|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,7712,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function M4(a){a=a|0;var b=0,c=0,d=0;x[23604]=0;Y(925,a|0);b=x[23604];x[23604]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[23604]=0;c=+na(d|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,7660,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function oB(a){a=a|0;var b=0,c=0,d=0;b=x[a>>2];if(b){mb[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;Fc(a);b=hb-32|0;hb=b;a:{b:{d=an(a);c=Rc(x[a>>2],x[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}x[23604]=0;c=fa(860,b+8|0,c|0,c|0,Cb(a)|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){xd(a,c);Al(c);break c}_(V(0)|0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break b}}hb=b+32|0;break a}V(0)|0;Vb();p()}}function er(a){var b=0,c=0;Jm(a,1,15292);x[23604]=0;b=ga(112)|0;c=x[23604];x[23604]=0;a:{if((c|0)==1){break a}x[a+12>>2]=b;x[23604]=0;b=ga(113)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}v[a+16|0]=b;x[23604]=0;b=ga(114)|0;c=x[23604];x[23604]=0;if((c|0)==1){break a}v[a+18|0]=0;v[a+17|0]=b;x[23604]=0;Y(115,a+20|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}return}b=P()|0;xb(a);T(b|0);p()}function eG(a,b,c){var d=0,e=0,f=E(0),g=0,h=E(0);e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[116080];x[116080]=0;zd();d=hb-16|0;hb=d;iw(d,a,e+12|0,0);f=BD(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);hb=d+16|0;a=x[116080];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[116080]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}hb=e+16|0;return f}function Tw(a,b,c){var d=0,e=0;d=hb-32|0;hb=d;a:{if(y[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=x[a+16>>2];if(b>>>0<=c>>>0){break a}b=DI(b,4096);BI(a,b-c|0);c=x[a+16>>2];b=ec(d+16|0,Gb(x[a+4>>2],c),b-c|0);c=x[x[a>>2]+44>>2];e=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=e;mb[c|0](d+24|0,a,d+8|0);x[a+16>>2]=x[a+16>>2]+x[d+28>>2];if(!(mb[x[x[a>>2]+40>>2]](a)|0)){break a}v[a+20|0]=1}hb=d+32|0}function pM(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];x[a>>2]=b;if(c){d=hb-16|0;hb=d;b=Bb(x[c>>2]);x[d+8>>2]=b;f=Bb(x[c+4>>2]);while(1){a:{b:{if(Ob(b,f)){while(1){a=x[b>>2];e=x[a>>2];if(!e){break b}a=x[x[e>>2]+8>>2];x[23604]=0;Y(a|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){continue}break}V(0)|0;Vb();p()}a=sc(c);hb=d+16|0;break a}Db(a+20|0);Db(a+8|0);Hb(a);b=x[Fe(d+8|0)>>2];continue}break}Hb(a)}}function x3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){a=ba(8)|0;x[23604]=0;c=Q(54,e|0,8118)|0;b=x[23604];x[23604]=0;if((b|0)==1){break c}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}b=P()|0;xb(c);break b}Gk(a,b,1);c=Yw(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=e+16|0;return c|0}b=P()|0;ca(a|0)}T(b|0)}p()}function kB(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(QB(c)){break a}d=x[c+16>>2]}f=x[c+20>>2];if(d-f>>>0<b>>>0){return mb[x[c+36>>2]](c,a,b)|0}b:{if(x[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(y[e+a|0]!=10){continue}break}e=mb[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=x[c+20>>2]}vc(f,a,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function j3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){a=ba(8)|0;x[23604]=0;c=Q(54,e|0,8118)|0;b=x[23604];x[23604]=0;if((b|0)==1){break c}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}b=P()|0;xb(c);break b}Gk(a,b,1);c=_w(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=e+16|0;return c|0}b=P()|0;ca(a|0)}T(b|0)}p()}function P6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=fi(a,b,c,d);x[a>>2]=46272;b=Sb(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=x[c+24620>>2];x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[23604]=0;R(851,a+44|0,2);c=x[23604];x[23604]=0;if((c|0)!=1){ei(a);return a|0}c=P()|0;sc(b);uf(a);T(c|0);p()}function DA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Qb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){d=hb-16|0;hb=d;if(Qb(x[a>>2],x[a+8>>2],b)){while(1){if((c|0)==4){c=x[d+12>>2]}else{v[d+11|0]=0;b:{if(b>>>0>c>>>0){ig(a,d+11|0);e=v[d+11|0];g=e>>>31|0;break b}e=0-g|0}v[(d+12|0)+c|0]=e;c=c+1|0;continue}break}}hb=d+16|0;break a}c=kg(a);bc(a,b-4|0)}v[f|0]=c}function waa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);b=hb-16|0;hb=b;if(bh(2147483647)>>>0<=2303){Sc();p()}Tu(b+8|0,2304);c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;f=Cb(a),g=c+(x[b+12>>2]<<1)|0,x[f>>2]=g;hb=b+16|0;d=hb-16|0;hb=d;c=zi(d,a,2304);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){ic(c);hb=d+16|0}else{Uu(b);b=b+2|0;x[c+4>>2]=b;continue}break}return a|0}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;hc(c+8|0,b,15);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0}}function Pz(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+30|0]=0;v[a+31|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function GR(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function FE(a,b,c,d,e,f,g){var h=0;x[23604]=0;Y(900,a|0);h=x[23604];x[23604]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[23604]=0;b=ja(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,f|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;hc(c+8|0,b,14);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0}}function YH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23604]=0;d=Q(54,d|0,10598)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,d);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(d);break b}e=(x[a+32>>2]+D(b,872)|0)+1075766|0,f=yz(c*32768),w[e>>1]=f;hb=d+16|0;return}a=P()|0;ca(b|0)}T(a|0)}p()}function U2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=hb-32|0;hb=b;c=ec(b+24|0,c,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a:{a=Cs(a,b,0);if(a+1>>>0>=3){a=ba(8)|0;x[23604]=0;b=Q(54,b+8|0,7975)|0;c=x[23604];x[23604]=0;b:{if((c|0)!=1){a=pc(a,b);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break b}c=P()|0;ca(a|0)}T(c|0);p()}hb=b+32|0;return a|0}p()}function U1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;a:{if(!c){break a}g=Qc(x[b+4>>2],y[b+11|0]);h=g-1|0;d=d<<24>>24;while(1){if((e|0)==(g|0)){break a}b:{if(!e|(e>>>0)%(c>>>0)){break b}if((e|0)==(h|0)){if(y[Pb(b)|0]==(Pf(43)&255)){break b}if(y[Pb(b)|0]==(Pf(45)&255)){break b}}FI(b,x[Ib(f+8|0,Ee(pd(b),g-e|0))>>2],1,Pf(d))}e=e+1|0;continue}}dd(a,b);hb=f+16|0}function cG(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[116080];x[116080]=0;zd();d=hb-16|0;hb=d;iw(d,a,e+12|0,1);f=qv(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);hb=d+16|0;a=x[116080];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[116080]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}hb=e+16|0;return f}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];j=x[a+12>>2];while(1){if(d){f=w[(x[b+12>>2]<<1)+i>>1];x[c>>2]=x[c>>2]+D(f,h);x[c+4>>2]=x[c+4>>2]+D(g,f);Ub(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function gE(a,b,c,d,e){var f=0,g=0;a:{f=hb-80|0;hb=f;Ve(b);g=f+56|0;Af(g,a,c);a=x[f+56>>2];c=f+8|0;Kf(c,e,xe(g),a);x[23604]=0;R(208,f+24|0,c|0);a=x[23604];x[23604]=0;b:{c:{if((a|0)!=1){x[23604]=0;U(11,f+40|0,d|0,f+24|0);a=x[23604];x[23604]=0;if((a|0)==1){break c}a=f+40|0;Ab(b,a);xb(a);xb(f+24|0);Lc(f+56|0);hb=f+80|0;break a}a=P()|0;break b}a=P()|0;xb(f+24|0)}Lc(f+56|0);T(a|0);p()}}function e3(a,b){a=a|0;b=b|0;var c=0,d=0;x[23604]=0;Y(900,a|0);c=x[23604];x[23604]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[23604]=0;R(989,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,10759,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function qea(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Jz(a,b);x[23604]=0;c=Q(608,a+12|0,b+12|0)|0;d=x[23604];x[23604]=0;b:{c:{if((d|0)!=1){x[23604]=0;Q(609,a+24|0,b+24|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}c=x[b+40>>2];x[a+36>>2]=x[b+36>>2];x[a+40>>2]=c;w[a+52>>1]=z[b+52>>1];c=x[b+48>>2];x[a+44>>2]=x[b+44>>2];x[a+48>>2]=c;break a}b=P()|0;break b}b=P()|0;fc(c)}fc(a);T(b|0);p()}}function i8(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[23604]=0;R(270,b+4|0,8);b=x[23604];x[23604]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=V(92520)|0;if((ib|0)==(da(92520)|0)){_(b|0)|0;Fc(x[a+20>>2]+4|0);$();return}T(b|0);p()}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];j=x[a+12>>2];while(1){if(d){f=v[x[b+12>>2]+i|0]<<8;x[c>>2]=x[c>>2]+D(f,h);x[c+4>>2]=x[c+4>>2]+D(g,f);Ub(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function wh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=ec(c+8|0,c+28|0,4);mc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=4){break b}if(Rb(c+28|0,b,4)){break b}bc(a,4);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17313,8981,413,13029);p()}aa(17292,8981,411,13029);p()}return d|0}function hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{e=Be(a);b:{if(e>>>0>1){break b}c:{if(e){x[23604]=0;U(313,d|0,a|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){mm(b,d);fc(d);break c}a=V(30848)|0;if((ib|0)!=(da(30848)|0)){break a}_(a|0)|0;$();break b}if(!Qb(x[a>>2],x[a+8>>2],c)){break b}yu(a,b,c)}f=Rc(x[b>>2],x[b+4>>2])>>>0>=c>>>0}hb=d+16|0;return f|0}T(a|0);p()}function b5(a){a=a|0;var b=0;x[23604]=0;Y(925,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){mb[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){Hb(b);x[a+20>>2]=0}Hb(a);return}_(V(0)|0)|0;x[23604]=0;X(887,5012,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Um(a,b,c,d,e,f){var g=0;x[23604]=0;Y(900,a|0);g=x[23604];x[23604]=0;a:{b:{if((g|0)!=1){g=x[a+24>>2];x[23604]=0;b=fa(f|0,g|0,b|0,c|0,d|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,e|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Ji(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+8>>2]=b;b=0;g=6;a:{b:{if(Lg(a,f+8|0)){break b}h=zk(x[a>>2]);g=4;if(!fh(x[d+8>>2],64,h)){break b}b=$m(d,h);while(1){c:{b=b-48|0;h=Hl(a);if(Lg(h,f+8|0)|(e|0)<2){break c}g=zk(x[h>>2]);if(!fh(x[d+8>>2],64,g)){break a}e=e-1|0;b=$m(d,g)+D(b,10)|0;continue}break}g=2;if(!Lg(h,f+8|0)){break a}}x[c>>2]=x[c>>2]|g}hb=f+16|0;return b}function oea(a){a=a|0;var b=0,c=0,d=0,e=0;e=hb-16|0;hb=e;b=Jc(2500);c=hb-2496|0;hb=c;FP(a,c,c+2496|0);a=0;while(1){if((a|0)==624){x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!x[b+d>>2]){continue}break a}break}x[b>>2]=-2147483648}hb=c+2496|0}else{d=a<<2;x[d+b>>2]=x[c+d>>2];a=a+1|0;continue}break}a=x[lf(e+8|0,b)>>2];hb=e+16|0;return a|0}function c0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+24>>2];e=x[a+28>>2];if(d>>>0>=e>>>0){if((mb[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{x[f+12>>2]=e-d>>2;x[f+8>>2]=c-g;e=d;d=x[rd(f+12|0,f+8|0)>>2];_h(e,b,d);e=d<<2;x[a+24>>2]=e+x[a+24>>2];g=g+d|0;b=b+e|0}continue}break}hb=f+16|0;return g|0}function CR(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+5|0]){while(1){if((d|0)==5){d=0;v[c+28|0]=0;x[c+24>>2]=0;e=ec(c+8|0,c+24|0,5);mc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=5){break b}if(Rb(c+24|0,b,5)){break b}bc(a,5);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17313,8981,413,13029);p()}aa(17292,8981,411,13029);p()}return d}function $2(a,b){a=a|0;b=+b;var c=0;x[23604]=0;Y(900,a|0);c=x[23604];x[23604]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[23604]=0;b=+Va(991,c|0,+b);c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,7524,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;if((c|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function U7(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function U3(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;a:{e=a+36|0;b=x[e>>2];d=x[a+40>>2];b:{if(Ob(b,d)){zc(c+24|0);break b}b=c+8|0;wn(b,a);x[23604]=0;b=S(959,b|0)|0;d=x[23604];x[23604]=0;if((d|0)==1){break a}x[c+24>>2]=b;Of(c+8|0);d=x[a+40>>2];b=x[a+36>>2]}if(!Ob(b,d)){e=x[c+24>>2];b=x[e>>2]}a=vn(b,x[e+4>>2]);Dk(c+24|0);hb=c+32|0;return a|0}a=P()|0;Of(c+8|0);T(a|0);p()}function Pca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=x[b+4>>2];if(!c){break a}f=a+480190|0;w[d>>1]=z[f>>1];w[d+14>>1]=c-1;c=z[Wc(d,d+14|0)>>1];while(1){if(!c){break a}b:{if(SQ(x[b>>2],c)){break b}if(WL(a,c&65535)){e=Xb(d,21502);Bc(((c<<5)+a|0)+946304|0,e);xb(e)}if(c>>>0<2){break b}e=z[f>>1];if((e|0)!=(c|0)){break b}w[f>>1]=e-1}c=c-1|0;continue}}hb=d+16|0}function oI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;x[23604]=0;c=Q(54,c|0,7772)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}d=P()|0;xb(c);break b}a=x[a+32>>2];e=a,f=Ge(65536/b),x[e+480244>>2]=f;lp(a);hb=c+16|0;return}d=P()|0;ca(a|0)}T(d|0)}p()}function mI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;x[23604]=0;c=Q(54,c|0,7793)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}d=P()|0;xb(c);break b}a=x[a+32>>2];e=a,f=Ge(b*65536),x[e+480240>>2]=f;lp(a);hb=c+16|0;return}d=P()|0;ca(a|0)}T(d|0)}p()}function PG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Xb(d,c);x[23604]=0;U(1056,d+16|0,b|0,e|0);c=x[23604];x[23604]=0;a:{b:{if((c|0)!=1){x[23604]=0;a=Q(1057,a|0,d+16|0)|0;c=x[23604];x[23604]=0;if((c|0)==1){break b}xb(d+16|0);xb(e);x[a>>2]=91792;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;hb=d+32|0;return a|0}c=P()|0;break a}c=P()|0;xb(d+16|0)}xb(e);T(c|0);p()}function EE(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!d){a=ba(8)|0;x[23604]=0;c=Q(54,f|0,8118)|0;b=x[23604];x[23604]=0;if((b|0)==1){break c}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}b=P()|0;xb(c);break b}Gk(a,b,e);c=AE(a,c,e,d,59840,60612);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c}b=P()|0;ca(a|0)}T(b|0)}p()}function DE(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!d){a=ba(8)|0;x[23604]=0;c=Q(54,f|0,8118)|0;b=x[23604];x[23604]=0;if((b|0)==1){break c}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}b=P()|0;xb(c);break b}Gk(a,b,e);c=AE(a,c,e,d,59012,59784);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c}b=P()|0;ca(a|0)}T(b|0)}p()}function ny(a,b,c){var d=0,e=0,f=0;f=Kb(a);d=y[b+11|0];e=x[b+4>>2];a=0;x[23604]=0;R(47,f|0,Qc(e,d)|0);d=x[23604];x[23604]=0;if((d|0)!=1){a:{while(1){if(Qc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=65533;e=v[uc(b,a)|0];if((e|0)>=-96){d=x[((e&255)<<2)+c>>2]}x[23604]=0;R(48,f|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=P()|0;Gc(f);T(a|0);p()}function iK(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(E(B[a+4228>>2]*E(1999))+E(1))/E(1e3))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(E(B[a+4232>>2]*E(1999))+E(1))/E(1e3))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function bI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23604]=0;c=Q(54,c|0,10598)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}a=x[a+32>>2]+D(b,872)|0;x[a+1075008>>2]=0;x[a+1075068>>2]=0;hb=c+16|0;return}a=P()|0;ca(b|0)}T(a|0)}p()}function V3(a){a=a|0;var b=0,c=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[23604]=0;b=S(967,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,7196,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function qx(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(A[x[a+16>>2]+24620>>2]);c=E(E(E(mb[x[x[a>>2]+204>>2]](a))*b)/E(1e3));d=a,e=E(E(c*E(mb[x[x[a>>2]+196>>2]](a)))*E(2048)),B[d+4248>>2]=e;d=a,f=Ih(E(E(c+E(2))*E(4096))),x[d+4256>>2]=f;c=E(mb[x[x[a>>2]+208>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(mb[x[x[a>>2]+192>>2]](a)|0)){b=rK(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function ax(a,b,c){var d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(c){bk(a,c);d=hb-16|0;hb=d;e=lh(d,a,c);c=x[e+4>>2];f=x[e+8>>2];while(1){if((c|0)==(f|0)){ic(e);hb=d+16|0}else{x[c>>2]=0;zc(c);c=c+4|0;x[e+4>>2]=c;continue}break}}c=0;e=0;d=hb-16|0;hb=d;f=d+8|0;while(1){if(c>>>0<32){c=c+48|0;e=lM(b);continue}break}x[f>>2]=e;Hn(f);hb=d+16|0;x[a+12>>2]=x[f>>2];return a}function tv(a,b){var c=0,d=0,e=0,f=0,g=0;f=hb-32|0;hb=f;d=Ib(f+24|0,x[a+4>>2]);g=Ib(f+16|0,x[a>>2]);e=Ib(f+8|0,x[b+4>>2]);d=x[d>>2];g=x[g>>2];c=hb-16|0;hb=c;x[c>>2]=x[e>>2];x[c+8>>2]=d;while(1){e=x[c>>2];if(og(d,g)){hr(Bi(e),Bi(d));e=vl(c+8|0);vl(c);d=x[e>>2];continue}break}hb=c+16|0;x[b+4>>2]=e;qc(a,b+4|0);qc(a+4|0,b+8|0);qc(Cb(a),yc(b));x[b>>2]=x[b+4>>2];hb=f+32|0}function g4(a){a=a|0;var b=0,c=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[23604]=0;c=+na(958,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23604]=0;X(887,7596,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function fD(a,b){var c=0,d=0,e=0,f=0,g=0;f=hb-32|0;hb=f;d=Ib(f+24|0,x[a+4>>2]);g=Ib(f+16|0,x[a>>2]);e=Ib(f+8|0,x[b+4>>2]);d=x[d>>2];g=x[g>>2];c=hb-16|0;hb=c;x[c>>2]=x[e>>2];x[c+8>>2]=d;while(1){e=x[c>>2];if(og(d,g)){av(Uh(e),Uh(d));e=dD(c+8|0);dD(c);d=x[e>>2];continue}break}hb=c+16|0;x[b+4>>2]=e;qc(a,b+4|0);qc(a+4|0,b+8|0);qc(Cb(a),yc(b));x[b>>2]=x[b+4>>2];hb=f+32|0}function ZH(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23604]=0;c=Q(54,c|0,10598)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}hb=c+16|0;return+(+(x[(x[a+32>>2]+D(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=P()|0;ca(b|0)}T(a|0)}p()}function PA(a,b){var c=0,d=0,e=0,f=0,g=0;f=hb-32|0;hb=f;d=Ib(f+24|0,x[a+4>>2]);g=Ib(f+16|0,x[a>>2]);e=Ib(f+8|0,x[b+4>>2]);d=x[d>>2];g=x[g>>2];c=hb-16|0;hb=c;x[c>>2]=x[e>>2];x[c+8>>2]=d;while(1){e=x[c>>2];if(og(d,g)){SA(DT(e),DT(d));e=CT(c+8|0);CT(c);d=x[e>>2];continue}break}hb=c+16|0;x[b+4>>2]=e;qc(a,b+4|0);qc(a+4|0,b+8|0);qc(Cb(a),yc(b));x[b>>2]=x[b+4>>2];hb=f+32|0}function LO(a,b){var c=0,d=0,e=0,f=0,g=0;f=hb-32|0;hb=f;d=Ib(f+24|0,x[a+4>>2]);g=Ib(f+16|0,x[a>>2]);e=Ib(f+8|0,x[b+4>>2]);d=x[d>>2];g=x[g>>2];c=hb-16|0;hb=c;x[c>>2]=x[e>>2];x[c+8>>2]=d;while(1){e=x[c>>2];if(og(d,g)){dz(_s(e),_s(d));e=JO(c+8|0);JO(c);d=x[e>>2];continue}break}hb=c+16|0;x[b+4>>2]=e;qc(a,b+4|0);qc(a+4|0,b+8|0);qc(Cb(a),yc(b));x[b>>2]=x[b+4>>2];hb=f+32|0}function XH(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23604]=0;c=Q(54,c|0,10598)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}hb=c+16|0;return+(+w[(x[a+32>>2]+D(b,872)|0)+1075766>>1]*30517578125e-15)}a=P()|0;ca(b|0)}T(a|0)}p()}function Kl(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+72048|0]}if(a>>>0<=511){return v[(a>>>5|0)+72048|0]+5|0}return v[(a>>>10|0)+72048|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+72048|0]+15|0}return v[(a>>>20|0)+72048|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+72048|0]+25|0}a=v[(a>>>30|0)+72048|0]+30|0}else{a=0}return a}function q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;a:{b:{if((Ej(y[a+140|0])|0)!=1){break b}if((iJ(a)|0)!=(b|0)){break b}d=a+120|0;cs(y[d+20|0]);b=hb-16|0;hb=b;x[b+8>>2]=c+8;a=hb-16|0;hb=a;e=x[14307];x[a+8>>2]=x[14306];x[a+12>>2]=e;e=x[14305];x[a>>2]=x[14304];x[a+4>>2]=e;mb[x[$o(a,Ej(y[d+20|0]))>>2]](b+8|0,d);hb=a+16|0;hb=b+16|0;break a}hJ(a,1,b)}hb=c+16|0}function xC(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if(Rb(a,11012,2)){if(Rb(a,13638,2)){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}while(1){d=(b|0)==128;if(d){break a}c=a+b|0;e=v[c+113|0];if((e|0)<-2){break a}f=y[c+241|0];if(!f&(e|0)>=0|f>>>0>15){break a}b=b+1|0;if(y[c+369|0]<64){continue}break}}return d}function wr(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function lg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!re(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=hb-16|0;hb=e;a:{b:{d=x[b+4>>2];c:{if(io(d)){bf(c,d);break c}if(d>>>0>=2147483632){break b}si(e+8|0,Xj(d)+1|0);b=x[e+8>>2];Ad(c,b);cg(c,x[e+12>>2]);oe(c,d);c=b}Te(c,f,d+1|0);hb=e+16|0;break a}dg();p()}return a|0}function iP(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=Kb(a);a=y[b+11|0];e=x[b+4>>2];x[23604]=0;R(45,d|0,Qc(e,a)|0);a=x[23604];x[23604]=0;a:{if((a|0)!=1){a=pd(b);x[c+8>>2]=a;b=pf(b);while(1){if(!Ob(a,b)){break a}a=y[a|0];x[23604]=0;R(46,d|0,((a|0)==13?10:a)<<24>>24);a=x[23604];x[23604]=0;if((a|0)!=1){a=x[Le(c+8|0)>>2];continue}break}}a=P()|0;xb(d);T(a|0);p()}hb=c+16|0}function tV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=-1;a:{if(!Nf(a,7)){break a}c=0;if(!WB(a,11649)){break a}c=hb-16|0;hb=c;TB(c+8|0,d);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){SB(d)}c=-1;if(!e){break a}c=0;if(!VB(y[d+1|0])){break a}c=De(a,b,UB(d),lb)}hb=d+16|0;return c|0}function W6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=fi(a,b,c,d);x[a>>2]=45900;b=a+4208|0;e=zb(b,0),f=1060320051,x[e>>2]=f;e=zb(b,1),f=1041865114,x[e>>2]=f;e=zb(b,2),f=1065353216,x[e>>2]=f;e=zb(b,3),f=1049951732,x[e>>2]=f;e=zb(b,4),f=1049951732,x[e>>2]=f;x[23604]=0;R(851,a+44|0,2);b=x[23604];x[23604]=0;if((b|0)!=1){ei(a);return a|0}b=P()|0;uf(a);T(b|0);p()}function SZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!re(y[f+11|0])){b=x[f+4>>2];x[a>>2]=x[f>>2];x[a+4>>2]=b;x[a+8>>2]=x[f+8>>2];break a}e=x[f>>2];d=hb-16|0;hb=d;b:{c:{c=x[f+4>>2];d:{if(Uo(c)){bf(a,c);break d}if(c>>>0>=1073741808){break c}dj(d+8|0,El(c)+1|0);b=x[d+8>>2];Ad(a,b);cg(a,x[d+12>>2]);oe(a,c);a=b}_h(a,e,c+1|0);hb=d+16|0;break b}dg();p()}}}function Ii(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+8>>2]=b;b=0;g=6;a:{b:{if(Fh(a,f+8|0)){break b}g=4;h=xk(x[a>>2]);if(!wk(d,64,h)){break b}b=_m(d,h);while(1){c:{b=b-48|0;h=kn(a);if(Fh(h,f+8|0)|(e|0)<2){break c}g=xk(x[h>>2]);if(!wk(d,64,g)){break a}e=e-1|0;b=_m(d,g)+D(b,10)|0;continue}break}g=2;if(!Fh(h,f+8|0)){break a}}x[c>>2]=x[c>>2]|g}hb=f+16|0;return b}function v2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{if(!(c&1024)){break a}f=e,g=pd(b),x[f+8>>2]=g;c=Qc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[uc(b,0)|0]!=(Pf(43)&255)){if(y[uc(b,0)|0]!=(Pf(45)&255)){break b}}d=d+1|0;WI(e+8|0)}if(c>>>0>=d>>>0){break a}Zw(b,x[Ib(e,x[e+8>>2])>>2],d-Qc(x[b+4>>2],y[b+11|0])|0,Pf(48))}dd(a,b);hb=e+16|0}function kI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{b:{c:{if(b<0|b>1){a=ba(8)|0;x[23604]=0;c=Q(54,c|0,11627)|0;d=x[23604];x[23604]=0;if((d|0)==1){break c}a=pc(a,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}d=P()|0;xb(c);break b}e=x[a+32>>2]+1074456|0,f=Ge(b*256),x[e>>2]=f;hb=c+16|0;return}d=P()|0;ca(a|0)}T(d|0)}p()}function YK(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0);c=hb-16|0;hb=c;d=0;a:{if(x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){break a}x[c+12>>2]=0;Uj(a,c+12|0);e=x[c+12>>2];d=0;if(e>>>0>65535){break a}Gj(b,e);while(1){if((f|0)==(e|0)){d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}else{x[c+8>>2]=0;ep(a,c+8|0);g=zb(x[b>>2],f),h=B[c+8>>2],B[g>>2]=h;f=f+1|0;continue}break}}a=d;hb=c+16|0;return a}function Tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;c=ff(a,c);_d(f,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!fd(a,5)){break b}break a}d=x[c+8>>2]}e=x[a+28>>2];c:{d:{switch(d+1|0){case 0:case 2:d=hb-32|0;hb=d;v[d+24|0]=0;Cj(d+8|0,d+24|0);gn(d+16|0,e,x[d+8>>2],x[d+12>>2]);v[b|0]=y[d+24|0];hb=d+32|0;break c;default:break d}}PS(e,b,d)}e=c}_e(a,e);hb=f+16|0}function r8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=Jc(64);x[23604]=0;e=S(788,c|0)|0;f=x[23604];x[23604]=0;a:{if((f|0)!=1){c=lf(d,e);e=x[c>>2];x[23604]=0;a=W(849,e|0,a|0,b|0)|0;b=x[23604];x[23604]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}zc(d+8|0);break b}a=P()|0;bg(c);break a}Mf(d+8|0,c)}bg(c);hb=d+16|0;return x[d+8>>2]}a=P()|0;Hb(c)}T(a|0);p()}function Nn(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+810|0]=y[b+810|0]&15|c<<4;break a}c=y[b+810|0]>>>4|0;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function kU(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){a=hb-16|0;hb=a;c=ba(16)|0;b=hb-16|0;hb=b;if(!y[464456]){v[464456]=1}ec(b+8|0,1,93604);d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;hb=b+16|0;b=x[a+12>>2];a=x[a+8>>2];x[23604]=0;a=UE(1058,c,8845,a,b);b=x[23604];x[23604]=0;if((b|0)!=1){ha(a|0,77532,1059);p()}a=P()|0;ca(c|0);T(a|0);p()}}function oL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)!=(b|0)){d=hb-16|0;hb=d;c=x[b>>2];b=x[b+4>>2];e=ie(c,b);a:{if(e>>>0<=Kh(a)>>>0){f=b;g=x[a>>2];h=rc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=c;YR(d+12|0,h);f=x[d+12>>2]}c=pi(c,f,g);if(!i){Mx(a,f,b,e-rc(x[a>>2],x[a+4>>2])|0);break a}Id(a,c);break a}Ft(a);bk(a,vg(a,e));Mx(a,c,b,e)}hb=d+16|0}return a}function jZ(a){a=a|0;if(y[467984]){return x[116995]}if(!y[468504]){v[468504]=1}ld(468336,88052);ld(468348,88080);ld(468360,88108);ld(468372,88140);ld(468384,88180);ld(468396,88216);ld(468408,88244);ld(468420,88280);ld(468432,88296);ld(468444,88312);ld(468456,88328);ld(468468,88344);ld(468480,88360);ld(468492,88376);v[467984]=1;x[116995]=468336;return 468336}function Z1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{if(!(c&1024)){break a}f=e,g=pd(b),x[f+8>>2]=g;c=Qc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[Pb(b)|0]!=(Pf(43)&255)){if(y[Pb(b)|0]!=(Pf(45)&255)){break b}}d=d+1|0;WI(e+8|0)}if(c>>>0>=d>>>0){break a}FI(b,x[Ib(e,x[e+8>>2])>>2],d-Qc(x[b+4>>2],y[b+11|0])|0,Pf(48))}dd(a,b);hb=e+16|0}function jG(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{if((a|0)!=(b|0)){g=x[116080];x[116080]=0;zd();a=kG(a,e+12|0,d);d=lb;f=x[116080];b:{if(f){if(x[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}x[c>>2]=4;b=!!a&(d|0)>=0|(d|0)>0;a=b?-1:0;d=b?2147483647:-2147483648;break a}x[116080]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;a=0;d=0}hb=e+16|0;lb=d;return a}function Uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Sb(a);a=Bb(x[b>>2]);x[d+24>>2]=a;b=Bb(x[b+4>>2]);a:{while(1){if(Ob(a,b)){ti(d,x[a>>2],x[a+4>>2]);if((dc(x[d>>2])|0)==(c|0)){qm(d,a);x[23604]=0;R(336,e|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break a}yb(d)}a=x[pm(d+24|0)>>2];continue}break}hb=d+32|0;return}a=P()|0;yb(d);jd(e);T(a|0);p()}function zE(a,b,c){var d=0;d=hb-16|0;hb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23604]=0;c=Q(54,d|0,10598)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}a=(x[a+32>>2]+D(b,872)|0)+1075080|0;x[a>>2]=x[a>>2]|c;hb=d+16|0;return}a=P()|0;ca(b|0)}T(a|0)}p()}function pI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ba(8)|0;x[23604]=0;c=Q(54,c|0,9265)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);hb=c+16|0;return}a=P()|0;ca(b|0)}T(a|0)}p()}function k5(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){b=x[a+24>>2];if(b){Hb(ls(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){Hb(b);x[a+20>>2]=0}Hb(a);return}_(V(0)|0)|0;x[23604]=0;X(887,5039,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Rl(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=hb-16|0;hb=h;if(2147483631-b>>>0>=c>>>0){i=Pb(a);if(b>>>0<=1073741798){x[h+12>>2]=b<<1;x[h>>2]=b+c;c=Xj(x[_c(h,h+12|0)>>2])+1|0}else{c=2147483631}si(h,c);j=x[h>>2];if(e){Te(j,i,e)}c=e+f|0;if((c|0)!=(d|0)){Te((e+j|0)+g|0,(e+i|0)+f|0,d-c|0)}if((b|0)!=10){Hb(i)}Ad(a,j);cg(a,x[h+4>>2]);hb=h+16|0;return}dg();p()}function J2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Kb(a);c=y[b+11|0];e=x[b+4>>2];a=0;x[23604]=0;R(72,d|0,Qc(e,c)|0);c=x[23604];x[23604]=0;if((c|0)!=1){a:{b:{while(1){if(Qc(x[b+4>>2],y[b+11|0])>>>0<=a>>>0){break b}c=v[uc(b,a)|0];x[23604]=0;R(50,d|0,Pf(c)|0);c=x[23604];x[23604]=0;if((c|0)!=1){a=a+1|0;continue}break}break a}return}}a=P()|0;xb(d);T(a|0);p()}function vQ(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=ec(c+8|0,c+28|0,4);kd(c+16|0,a,x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=4){break b}if(Rb(c+28|0,b,4)){break b}ad(a,4);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17313,8981,413,13029);p()}aa(17292,8981,411,13029);p()}return d}function u$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){vc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){vc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function g5(a,b){a=a|0;b=b|0;var c=0;x[23604]=0;Y(900,a|0);c=x[23604];x[23604]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}Hb(b);x[a+20>>2]=0;return}_(V(0)|0)|0;x[23604]=0;X(887,5621,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$()}return}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function qI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ba(8)|0;x[23604]=0;c=Q(54,c|0,5809)|0;a=x[23604];x[23604]=0;if((a|0)==1){break c}a=pc(b,c);x[23604]=0;U(105,a|0,62120,904);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}x[x[a+32>>2]+1074416>>2]=b;hb=c+16|0;return}a=P()|0;ca(b|0)}T(a|0)}p()}function caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=b;c=hb-16|0;hb=c;d=Jc(223888);x[23604]=0;b=Q(755,d|0,b+1074376|0)|0;e=x[23604];x[23604]=0;a:{if((e|0)!=1){b=x[lf(c+8|0,b)>>2];hb=c+16|0;break a}a=P()|0;Hb(d);T(a|0);p()}x[a+4>>2]=b;b=Sb(a+8|0);x[23604]=0;Y(536,a|0);c=x[23604];x[23604]=0;if((c|0)!=1){return a|0}c=P()|0;je(b);YM(a+4|0);T(c|0);p()}function QL(a,b){var c=0,d=0,e=0,f=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{c=D(b,872)+a|0;d=y[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;d=v[c+1075785|0];d:{if((d|0)>=0){c=qe(a+901692|0,y[c+1075836|0]);break d}c=qe(a+902204|0,d&127)}hN(a,e,b,f,c,d&255)}}function I6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=AK(a,b,c,d,e^1);x[b>>2]=46500;a=b+4208|0;f=zb(a,0),g=1056964608,x[f>>2]=g;f=zb(a,1),g=1065353216,x[f>>2]=g;f=zb(a,2),g=1020054733,x[f>>2]=g;f=zb(a,3),g=1065353216,x[f>>2]=g;f=zb(a,4),g=1056964608,x[f>>2]=g;f=zb(a,5),g=1048406533,x[f>>2]=g;f=zb(a,6),g=1056964608,x[f>>2]=g;return b|0}function kT(a){var b=0,c=0,d=0;a:{if(Rb(a+60|0,15383,4)|(y[a+32|0]|y[a+33|0]<<8)>>>0>256|(y[a+49|0]<32|(y[a+36|0]|y[a+37|0]<<8)>>>0>255)){break a}if(v[a+51|0]<4|y[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(y[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function baa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Cb(a)>>2]){c=hb-16|0;hb=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+32;NM(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+32;ic(c);hb=c+16|0;return}d=hb-32|0;hb=d;c=Cb(a);c=ft(d+8|0,Dp(a,_f(x[a>>2],x[a+4>>2])+1|0),_f(x[a>>2],x[a+4>>2]),c);NM(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;xd(a,c);DP(c);hb=d+32|0}function WY(a){a=a|0;if(y[467976]){return x[116993]}if(!y[468328]){v[468328]=1}Zc(468160,5201);Zc(468172,5208);Zc(468184,5174);Zc(468196,5182);Zc(468208,5165);Zc(468220,5215);Zc(468232,5192);Zc(468244,9650);Zc(468256,9856);Zc(468268,11169);Zc(468280,12737);Zc(468292,5464);Zc(468304,10656);Zc(468316,6548);v[467976]=1;x[116993]=468160;return 468160}function AC(a,b,c){var d=0,e=0,f=0,g=0;a:{d=de(b,pd(a));b=de(c,b);if(Eb(x[a+4>>2],y[a+11|0])>>>0>=d>>>0){if((b|0)==-1){uS(a,d);break a}e=hb-16|0;hb=e;x[e+12>>2]=b;if(b){f=Eb(x[a+4>>2],y[a+11|0]);g=Pb(a);c=f-d|0;x[e+8>>2]=c;b=x[Fb(e+12|0,e+8|0)>>2];b:{if((c|0)==(b|0)){b=c;break b}d=d+g|0;dl(d,b+d|0,c-b|0)}qA(a,g,f-b|0)}hb=e+16|0;break a}Rp();p()}}function Ro(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;Pc(d+8|0,b);x[23604]=0;b=S(1084,x[d+8>>2])|0;e=x[23604];x[23604]=0;a:{if((e|0)==1){break a}x[23604]=0;e=S(1092,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break a}x[c>>2]=e;x[23604]=0;R(1093,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$b(d+8|0);hb=d+16|0;return}a=P()|0;$b(d+8|0);T(a|0);p()}function Oz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Sb(a);a=Bb(x[b>>2]);x[d+24>>2]=a;b=Bb(x[b+4>>2]);a:{while(1){if(Ob(a,b)){ti(d,x[a>>2],x[a+4>>2]);if(x[d>>2]==(c|0)){qm(d,a);x[23604]=0;R(336,e|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break a}yb(d)}a=x[pm(d+24|0)>>2];continue}break}hb=d+32|0;return}a=P()|0;yb(d);jd(e);T(a|0);p()}function Mn(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+810|0];if(c){v[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function uu(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if(!(y[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=42;break b}if(y[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}v[a|0]=42;v[b|0]=y[d|0]}v[c|0]=0}}function To(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;Pc(d+8|0,b);x[23604]=0;b=S(1067,x[d+8>>2])|0;e=x[23604];x[23604]=0;a:{if((e|0)==1){break a}x[23604]=0;e=S(1079,b|0)|0;f=x[23604];x[23604]=0;if((f|0)==1){break a}v[c|0]=e;x[23604]=0;R(1080,a|0,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$b(d+8|0);hb=d+16|0;return}a=P()|0;$b(d+8|0);T(a|0);p()}function Rv(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function rf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Eb(x[a+4>>2],y[a+11|0])|(c-b|0)<5){break a}zr(b,c);e=Pb(a);g=e+Eb(x[a+4>>2],y[a+11|0])|0;a=c-4|0;b:{while(1){c:{c=v[e|0];f=c-127|0;if(a>>>0<=b>>>0){break c}if((c|0)!=x[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;e=((g-e|0)>1)+e|0;continue}break}if((f&255)>>>0<130|c>>>0>x[a>>2]-1>>>0){break a}}x[d>>2]=4}}function rV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;Au(e+8|0,c);c=y[d|0];x[23604]=0;R(229,e+20|0,c|0);c=x[23604];x[23604]=0;b:{c:{if((c|0)!=1){xl(e,e+8|0);x[23604]=0;X(100,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[23604];x[23604]=0;if((a|0)==1){break c}yh(e+8|0);hb=e+32|0;break a}a=P()|0;xb(e+8|0);break b}a=P()|0;yh(e+8|0)}T(a|0);p()}}function AI(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}d=x[a+12>>2];if(!d){break b}a=mb[d|0](b)|0;e=lb;if((e|0)<0){break b}if((mb[c|0](b,0,0,0)|0)<0){break a}if((mb[c|0](b,0,0,2)|0)<0){break a}d=mb[d|0](b)|0;f=lb;mb[c|0](b,a,e,0)|0;if((f|0)<0){break b}g=Ky(d,f)}return g}mb[c|0](b,a,e,0)|0;return 0}function kk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+8>>2]=a;x[f+12>>2]=b;h=x[a+8>>2]+120|0;cs(y[h+20|0]);g=hb-16|0;hb=g;x[g+8>>2]=f+8;e=hb-16|0;hb=e;i=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=i;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;mb[x[$o(e,Ej(y[h+20|0]))>>2]](g+8|0,h);hb=e+16|0;hb=g+16|0;x[a+4>>2]=x[a+4>>2]+x[b+8>>2];hb=f+16|0}function j5(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}Hb(b);x[a+20>>2]=0;return}_(V(0)|0)|0;x[23604]=0;X(887,8818,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$()}return}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Nha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-112|0;hb=d;c=hb-16|0;hb=c;f=d+8|0;zT(c+8|0,f);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){yT(f)}c=-1;a:{if(!e){break a}c=0;if(!BT(d+8|0)){break a}c=De(a,b,AT(y[d+55|0]|y[d+56|0]<<8),lb)}hb=d+112|0;return c|0}function E9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;w[a>>1]=0;c=Sb(a+4|0);d=Sb(a+16|0);x[a+36>>2]=0;e=Kb(a+40|0);f=ag(a+52|0);Fc(c);w[a+28>>1]=65472;x[23604]=0;x[b+12>>2]=1065353216;R(792,c|0,b+12|0);g=x[23604];x[23604]=0;if((g|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Fc(d);hb=b+16|0;return a|0}a=P()|0;TS(f);xb(e);sc(d);sc(c);T(a|0);p()}function h5(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return Qf(a)|0}_(V(0)|0)|0;x[23604]=0;X(887,12050,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();return 0}return Qf(21502)|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function JV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-512|0;hb=d;c=hb-16|0;hb=c;f=d+8|0;uC(c+8|0,f);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){tC(f)}c=-1;a:{if(!e){break a}c=0;if(!xC(d+8|0)){break a}c=De(a,b,wC(y[d+118|0],y[d+119|0]),lb)}hb=d+512|0;return c|0}function uj(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function it(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;c=D(a,b);Jia(b,0,a,0);a=lb?0:c}else{a=0}a:{if(!a){break a}x[23604]=0;b=S(703,a|0)|0;c=x[23604];x[23604]=0;b:{c:{if((c|0)==1){_(V(0)|0)|0;x[23604]=0;Z(17);c=x[23604];x[23604]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;Vb();p()}if(!b){break a}d=Zb(b,0,a)- -64|0}return d}function NX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=hb+-64|0;hb=e;d=1;a:{if(Hg(a,b,0)){break a}d=0;if(!b){break a}b=uy(b,92128,92176);d=0;if(!b){break a}d=e+8|0;Zb(d|4,0,52);x[e+56>>2]=1;x[e+20>>2]=-1;x[e+16>>2]=a;x[e+8>>2]=b;mb[x[x[b>>2]+28>>2]](b,d,x[c>>2],1);a=x[e+32>>2];if((a|0)==1){x[c>>2]=x[e+24>>2]}d=(a|0)==1}hb=e- -64|0;return d|0}function BN(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;i=x[d+20>>2];h=x[d+52>>2];g=!h|e;v[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}x[(D(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}x[d+24>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+48>>2]=h;w[d+72>>1]=z[d+74>>1];$s(a,i>>>0>1&e&(b|0)==1,f+15|0);hb=f+16|0}function dga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=zb(b,c);d=hb-16|0;hb=d;e=ie(b,c);a:{if(e>>>0<=Kh(a)>>>0){f=c;g=x[a>>2];h=rc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;YR(d+12|0,h);f=x[d+12>>2]}b=pi(b,f,g);if(!i){XR(a,f,c,e-rc(x[a>>2],x[a+4>>2])|0);break a}Id(a,b);break a}Ft(a);bk(a,vg(a,e));XR(a,b,c,e)}hb=d+16|0}function Xy(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Vl(a,b,c){var d=0,e=0,f=0;e=Kb(a);d=y[b+11|0];f=x[b+4>>2];a=0;x[23604]=0;R(47,e|0,Qc(f,d)|0);d=x[23604];x[23604]=0;if((d|0)!=1){a:{while(1){if(Qc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=x[(y[uc(b,a)|0]<<2)+c>>2];x[23604]=0;R(48,e|0,d|0);d=x[23604];x[23604]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=P()|0;Gc(e);T(a|0);p()}function tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+11|0;QQ(a,c);if(Rb(c,13445,4)){a=1}else{QQ(a,d+11|0);v[b|0]=1;a=0}c=hb-16|0;hb=c;a:{b:{a=(d+11|0)+a|0;c:{if(!a){a=0;break c}b=Xb(c,a);x[23604]=0;a=S(606,b|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break b}xb(b)}hb=c+16|0;break a}a=P()|0;xb(b);T(a|0);p()}hb=d+16|0;return a|0}function tY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=hb-16|0;hb=g;k=Yh(g+8|0,x[a+8>>2]);i=Er(0,c,d-c|0,b?b:467692);Xh(k);hb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function nW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;f=x[b+16>>2];a:{if(f>>>0<=c>>>0){hc(a,x[d>>2],0);break a}g=x[b+12>>2];b=x[b+4>>2];x[e+20>>2]=x[d+4>>2];x[e+16>>2]=f-c;hc(e+24|0,x[d>>2],x[Fb(e+20|0,e+16|0)>>2]);d=x[x[b>>2]+28>>2];f=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=f;mb[d|0](a,b,c+g|0,e+8|0)}hb=e+32|0}function N3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[23604]=0;Y(900,a|0);f=x[23604];x[23604]=0;if((f|0)!=1){return ix(x[x[a+24>>2]+24>>2],b,c,d,e)|0}_(V(0)|0)|0;x[23604]=0;X(887,12293,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function HG(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=mb[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((Yj(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=ns(x[a+32>>2])?-1:0}hb=b+16|0;return d|0}function qy(a,b,c,d){var e=0;a:{if(x[a+1074392>>2]!=(c|0)){break a}c=D(b,872)+a|0;e=c+1075080|0;b:{if(d){x[c+1075688>>2]=0;d=c+1075e3|0;x[d>>2]=0;x[d+4>>2]=0;d=x[c+1075080>>2]|4096;break b}x[c+1075680>>2]=0;d=x[c+1075080>>2]}x[e>>2]=d|2097152;Wl(a,b,255,0);if(!(y[c+1075081|0]&2)){break a}a=x[a+1298300>>2];if(!td(a)){break a}Zi(a,b,0)}}function J1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;g=x[d+4>>2];Tw(b,c,g);f=x[b+16>>2];a:{if(f>>>0<=c>>>0){hc(a,x[d>>2],0);break a}x[e+12>>2]=f-c;x[e+8>>2]=g;d=x[d>>2];f=x[Fb(e+12|0,e+8|0)>>2];eq(e,d,g,0,f);h=x[e>>2];i=x[e+4>>2];Xt(Ee(Bb(x[b+4>>2]),c),Ee(Ee(Bb(x[b+4>>2]),c),i),h);eq(a,d,g,0,f)}hb=e+16|0}function H5(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;a=Sb(a);x[23604]=0;Y(890,b+16|0);c=x[23604];x[23604]=0;a:{b:{if((c|0)!=1){c=Bb(x[b+16>>2]);d=Bb(x[b+20>>2]);e=x[Ib(b+8|0,a)>>2];x[23604]=0;U(891,c|0,d|0,e|0);c=x[23604];x[23604]=0;if((c|0)==1){break b}sc(b+16|0);hb=b+32|0;return}c=P()|0;break a}c=P()|0;sc(b+16|0)}Vd(a);T(c|0);p()}function L$(a){a=a|0;a:{x[23604]=0;S(1061,466712)|0;a=x[23604];x[23604]=0;b:{if((a|0)==1){break b}x[23604]=0;S(1061,467048)|0;a=x[23604];x[23604]=0;if((a|0)==1){break b}x[23604]=0;S(1062,466796)|0;a=x[23604];x[23604]=0;if((a|0)==1){break b}x[23604]=0;S(1062,467132)|0;a=x[23604];x[23604]=0;if((a|0)==1){break b}break a}V(0)|0;Vb();p()}}function w7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=fi(a,b,c,d);x[a>>2]=45408;c=Sb(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=1056964608;b=a+4228|0;v[b+4|0]=0;v[b+5|0]=4;v[b|0]=69;v[b+1|0]=99;v[b+2|0]=104;v[b+3|0]=111;v[b+6|0]=1;x[23604]=0;R(851,a+44|0,2);b=x[23604];x[23604]=0;if((b|0)!=1){ei(a);rs(a);return a|0}b=P()|0;sc(c);uf(a);T(b|0);p()}function ufa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb+-64|0;hb=c;b=-1;a:{if(!(mb[x[x[a>>2]+32>>2]](a,0,1084)|0)){break a}al(a,1080);d=c+60|0;KR(a,d);e=d;d=JR(c+40|0);b=0;if(!IR(e,d)){break a}al(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=A[d+4>>2]>=f>>>0}else{e=c+8|0;HR(a,e);b=b+1|0;f=bA(e)+f|0;continue}break}}hb=c- -64|0;return b|0}function qu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;AB(e+8|0,c);x[23604]=0;R(99,e+20|0,d|0);c=x[23604];x[23604]=0;b:{c:{if((c|0)!=1){xl(e,e+8|0);x[23604]=0;X(100,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[23604];x[23604]=0;if((a|0)==1){break c}yh(e+8|0);hb=e+32|0;break a}a=P()|0;xb(e+8|0);break b}a=P()|0;yh(e+8|0)}T(a|0);p()}}function HF(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;if(1073741807-b>>>0>=c>>>0){g=Pb(a);if(b>>>0<=536870886){x[f+12>>2]=b<<1;x[f>>2]=b+c;c=El(x[_c(f,f+12|0)>>2])+1|0}else{c=1073741807}dj(f,c);h=x[f>>2];if(e){_h(h,g,e)}if((d|0)!=(e|0)){c=e<<2;_h(h+c|0,c+g|0,d-e|0)}if((b|0)!=1){Hb(g)}Ad(a,h);cg(a,x[f+4>>2]);hb=f+16|0;return}dg();p()}function Xx(a,b,c,d,e,f){var g=0,h=0;g=hb-16|0;hb=g;if(2147483631-b>>>0>=c>>>0){h=Pb(a);if(b>>>0<=1073741798){x[g+12>>2]=b<<1;x[g>>2]=b+c;c=Xj(x[_c(g,g+12|0)>>2])+1|0}else{c=2147483631}si(g,c);c=x[g>>2];if(e){Te(c,h,e)}if((d|0)!=(e|0)){Te((c+e|0)+f|0,e+h|0,d-e|0)}if((b|0)!=10){Hb(h)}Ad(a,c);cg(a,x[g+4>>2]);hb=g+16|0;return}dg();p()}function qq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Bb(x[b>>2]);g=Bb(x[b+4>>2]);e=hb-16|0;hb=e;x[e+8>>2]=d;while(1){a:{if(!Ob(d,g)){break a}f=hb-16|0;hb=f;ti(f+8|0,x[d>>2],x[d+4>>2]);h=dc(x[f+8>>2]);hb=f+16|0;if((c|0)==(h|0)){break a}d=x[pm(e+8|0)>>2];continue}break}hb=e+16|0;if(tc(d,Bb(x[b+4>>2]))){xh(a);return}qm(a,d)}function o9(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;x[b+16>>2]=0;x[b+20>>2]=0;c=ec(b,b+16|0,15);mc(b+8|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);c=0;a:{if(x[b+12>>2]!=15){break a}if(Rb(b+16|0,8443,15)){break a}bc(a,15);c=1}hb=b+32|0;return c|0}function Y3(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){a=x[x[a+24>>2]+24>>2];return $i(_b(x[a+484360>>2],y[a+484376|0]))|0}_(V(0)|0)|0;x[23604]=0;X(887,6846,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function x1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=0;a:{if(!x[b+28>>2]){break a}e=0;if((mb[x[b+32>>2]](x[b+24>>2],c,0,0)|0)<0){break a}e=x[d+4>>2];c=x[d>>2];while(1){b:{if(!e){break b}f=mb[x[b+28>>2]](x[b+24>>2],c,e)|0;if(!f){break b}e=e-f|0;c=c+f|0;g=f+g|0;h=g>>>0<f>>>0?h+1|0:h;continue}break}e=g}hc(a,x[d>>2],e)}function Saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=hb-32|0;hb=d;vA(d+8|0,c);x[23604]=0;R(407,d+20|0,43740);c=x[23604];x[23604]=0;b:{c:{if((c|0)!=1){xl(d,d+8|0);x[23604]=0;X(100,a|0,b|0,x[d>>2],x[d+4>>2]);a=x[23604];x[23604]=0;if((a|0)==1){break c}yh(d+8|0);hb=d+32|0;break a}a=P()|0;xb(d+8|0);break b}a=P()|0;yh(d+8|0)}T(a|0);p()}}function Rd(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;Km(b);f=lf(e+8|0,b);a:{d=a+8|0;b=x[d>>2];if(rc(b,x[a+12>>2])>>>0<=c>>>0){x[23604]=0;R(1157,d|0,c+1|0);a=x[23604];x[23604]=0;if((a|0)==1){break a}b=x[d>>2]}a=zb(b,c);b=x[a>>2];if(b){Om(b);a=zb(x[d>>2],c)}g=a,h=Wd(f),x[g>>2]=h;xF(f);hb=e+16|0;return}a=P()|0;xF(f);T(a|0);p()}function xp(a){var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;d=Bb(x[a>>2]);e=a;f=Bb(x[a+4>>2]);a=hb-16|0;hb=a;x[a+8>>2]=d;while(1){if(Ob(d,f)){b=b+C[d>>3];d=x[Vs(a+8|0)>>2];continue}break}hb=a+16|0;a=Bb(x[e>>2]);x[c+8>>2]=a;b=-b;e=Bb(x[e+4>>2]);while(1){if(Ob(a,e)){b=b+C[a>>3];C[a>>3]=b;a=x[Vs(c+8|0)>>2];continue}else{hb=c+16|0}break}}function TU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;hc(c+8|0,b,10);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0}return a|0}function od(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;im(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;d=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?d|32:d;b=Xb(c,21502);ze(a+43|0,b);xb(b);KP(a);hb=c+16|0}function mK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[x[a+16>>2]+24620>>2]/5|0;b=Ec(b,b>>31);x[a+4272>>2]=b;x[23604]=0;x[c+12>>2]=0;U(857,a+4256|0,b<<1,c+12|0);b=x[23604];x[23604]=0;a:{if((b|0)==1){b=V(92520)|0;if((ib|0)!=(da(92520)|0)){break a}_(b|0)|0;x[a+4272>>2]=0;$()}x[a+4276>>2]=0;x[a+4268>>2]=0;hb=c+16|0;return}T(b|0);p()}function X3(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){a=x[x[a+24>>2]+24>>2];return Us(x[a+484344>>2],x[a+484348>>2])|0}_(V(0)|0)|0;x[23604]=0;X(887,6914,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function L2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);c=ch(x[b+4>>2],x[b+8>>2]);if(c){hO(a,c);e=x[b+4>>2];f=x[b+8>>2];d=hb-16|0;hb=d;b=Jo(d,a,c);c=x[b+4>>2];x[23604]=0;a=fa(1006,Cb(a)|0,e|0,f|0,c|0)|0;c=x[23604];x[23604]=0;a:{if((c|0)!=1){x[b+4>>2]=a;ic(b);hb=d+16|0;break a}a=P()|0;ic(b);T(a|0);p()}}}function cM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;e=ji(b,c);a:{if(e>>>0<=an(a)>>>0){f=c;g=x[a>>2];h=Rc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;bM(d+12|0,h);f=x[d+12>>2]}b=pi(b,f,g);if(!i){Iz(a,f,c,e-Rc(x[a>>2],x[a+4>>2])|0);break a}Id(a,b);break a}Wt(a);fk(a,qk(a,e));Iz(a,b,c,e)}hb=d+16|0}function Z$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=x[a+44>>2];c=x[a+24>>2];if(e>>>0<c>>>0){x[a+44>>2]=c;e=c}c=x[a+12>>2];f=x[a+8>>2];d=-1;a:{if(c>>>0<=f>>>0){break a}if(tc(b,-1)){jn(a,f,c-1|0,e);return qw(b)|0}g=b<<24>>24;if(!(x[a+48>>2]&16)){d=-1;if(!tc(g,v[c-1|0])){break a}}jn(a,f,c-1|0,e);v[x[a+12>>2]]=g;d=b}return d|0}function DW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;c=hb-16|0;hb=c;b=hb-16|0;hb=b;x[b+4>>2]=1;g=b,h=Jc(24),x[g+8>>2]=h;e=Co(x[b+8>>2]);x[e>>2]=61588;xD(yc(e),x[d>>2],x[d+4>>2]);e=c+8|0;f=Eo(b);Do(e,yc(f),f);Nm(b);hb=b+16|0;mg(a,e);be(e);hb=c+16|0;hb=d+16|0}function AL(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{while(1){x[e+12>>2]=b;x[e+8>>2]=d;if(A[Fb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=gp(v[Gb(a,f)|0]);h=gp(v[Gb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}hb=e+16|0;return a}function iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb+-64|0;hb=d;c=hb-16|0;hb=c;f=d+8|0;hS(c+8|0,f);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){gS(f)}c=-1;a:{if(!e){break a}c=0;if(!jS(d+8|0)){break a}c=De(a,b,iS(d+8|0),lb)}hb=d- -64|0;return c|0}function Zw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=de(b,pd(a));a:{f=Eb(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=Oc(a);b:{if(e-f>>>0>=c>>>0){e=Pb(a);if((b|0)==(f|0)){break b}g=b+e|0;dl(g+c|0,g,f-b|0);break b}Rl(a,e,(c+f|0)-e|0,f,b,0,c);e=x[a>>2]}gl(b+e|0,c,d);b=c+f|0;Sg(a,b);id(b+e|0,0)}break a}Rp();p()}pd(a)}function NF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;i=x[b>>2];h=x[a>>2];e=x[jc(a)>>2]==1104;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g?g:4;g=At(e?0:h,f);if(g){if(!e){Wd(a)}x[d+4>>2]=1071;e=le(d+8|0,g,d+4|0);a=KF(a,e);Mc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=x[a>>2]+(f&-4);hb=d+16|0;return}gw();p()}function HV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-48|0;hb=d;c=hb-16|0;hb=c;f=d+8|0;mC(c+8|0,f);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){kC(f)}c=-1;a:{if(!e){break a}c=0;if(!oC(d+8|0)){break a}c=De(a,b,nC(y[d+43|0]),lb)}hb=d+48|0;return c|0}function Fw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=hb-240|0;hb=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((mb[b|0](a,f)|0)>=0){if((mb[b|0](a,e)|0)>=0){break a}}j=f;f=(mb[b|0](f,e)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}xH(g,h);hb=g+240|0}function Fha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-576|0;hb=d;c=hb-16|0;hb=c;iT(c+8|0,d);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){hT(d)}c=-1;a:{if(!e){break a}c=0;if(!kT(d)){break a}c=De(a,b,jT(z[d+34>>1],z[d+36>>1]),lb)}hb=d+576|0;return c|0}function dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Rc(e,x[a+4>>2]);if(d>>>0<b>>>0){e=hb-32|0;hb=e;b=b-d|0;d=x[Cb(a)>>2];f=x[a+4>>2];a:{if(b>>>0<=d-f>>>0){wo(a,b,c);break a}d=Cb(a);d=Bl(e+8|0,qk(a,Rc(x[a>>2],f)+b|0),Rc(x[a>>2],x[a+4>>2]),d);DS(d,b,c);xd(a,d);Al(d)}hb=e+32|0;return}if(b>>>0<d>>>0){Id(a,b+e|0)}}function Sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;c=ff(a,c);_d(f,x[a+28>>2]);a:{if(!c){e=0;if(fd(a,5)){break a}}h=x[a+28>>2];g=hb-16|0;hb=g;e=Kb(g);x[23604]=0;fa(402,b|0,h|0,e|0,d|0)|0;b=x[23604];x[23604]=0;b:{if((b|0)!=1){xb(e);hb=g+16|0;break b}a=P()|0;xb(e);T(a|0);p()}e=c}_e(a,e);hb=f+16|0}function yC(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(b>>>0<3){if(!b){break a}if(!Qb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==2){d=z[c+14>>1];break a}else{v[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){ig(a,c+13|0);e=y[c+13|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}aa(11098,8981,136,14062);p()}hb=c+16|0;return d&65535}function ug(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=hb-16|0;hb=e;a:{f=ji(b,c);if(f>>>0<2147483632){b:{if(io(f)){bf(d,f);break b}si(e+8|0,Xj(f)+1|0);g=x[e+8>>2];Ad(d,g);cg(d,x[e+12>>2]);oe(d,f);d=g}while(1){if((b|0)!=(c|0)){id(d,y[b|0]);d=d+1|0;b=b+1|0;continue}break}id(d,0);hb=e+16|0;break a}dg();p()}return a|0}function d3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}_(V(0)|0)|0;x[23604]=0;X(887,12914,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Ek(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+8>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=hb-32|0;hb=c;d=oc(c+24|0,x[a>>2]);e=x[f+8>>2];g=x[e>>2];e=x[e+4>>2];x[c+16>>2]=g;x[c+20>>2]=e;h=x[d+4>>2];d=x[d>>2];x[c+8>>2]=g;x[c+12>>2]=e;d=Ic(d,h,c+8|0);hb=c+32|0;if(!d){break a}b=a}hb=f+16|0;return b}a=a+8|0;continue}}function sha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;a:{e=Qb(x[b>>2],x[b+8>>2],c<<2);if(!e){break a}wc(d+12|0,65535);eg(a,z[d+12>>1]);c=Bb(x[a>>2]);x[d>>2]=c;a=Bb(x[a+4>>2]);while(1){if(!Ob(c,a)){break a}f=d+8|0;if(!Ao(b,f)){sm(f)}w[c>>1]=x[d+8>>2];c=x[Pe(d)>>2];continue}}hb=d+16|0;return e|0}function i6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=fi(a,b,c,d);x[a+4272>>2]=1065353216;x[a>>2]=47520;b=a+4208|0;e=zb(b,0),f=1056880300,x[e>>2]=f;e=zb(b,1),f=1050733080,x[e>>2]=f;e=zb(b,2),f=1056964608,x[e>>2]=f;x[23604]=0;R(851,a+44|0,2);b=x[23604];x[23604]=0;if((b|0)!=1){ei(a);return a|0}b=P()|0;uf(a);T(b|0);p()}function b6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=fi(a,b,c,d);x[a>>2]=47752;b=a+4208|0;e=zb(b,0),f=1065353216,x[e>>2]=f;e=zb(b,1),f=1065353216,x[e>>2]=f;e=zb(b,2),f=1051372203,x[e>>2]=f;e=zb(b,3),f=0,x[e>>2]=f;x[23604]=0;R(851,a+44|0,2);b=x[23604];x[23604]=0;if((b|0)!=1){ei(a);return a|0}b=P()|0;uf(a);T(b|0);p()}function j_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;i=x[b>>2];h=x[a>>2];e=x[jc(a)>>2]==1104;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g?g:1;g=At(e?0:h,f);if(g){if(!e){Wd(a)}x[d+4>>2]=1071;e=le(d+8|0,g,d+4|0);a=KF(a,e);Mc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=f+x[a>>2];hb=d+16|0;return}gw();p()}function c5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;x[f+8>>2]=d;d=x[Mf(f,f+8|0)>>2];x[23604]=0;ja(898,a+8|0,b|0,c|0,d|0,e|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){a=tI(a);b=sI(a+88|0);c=rI(a+92|0);x[a>>2]=61896;x[b>>2]=62008;x[c>>2]=62088;te(f+8|0);hb=f+16|0;return a|0}a=P()|0;te(f+8|0);T(a|0);p()}function y8(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Cb(a)>>2]){c=hb-16|0;hb=c;a=lh(c,a,1);ys(x[a+4>>2],B[b>>2]);x[a+4>>2]=x[a+4>>2]+4;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Cb(a);c=Wf(d+8|0,vg(a,rc(x[a>>2],x[a+4>>2])+1|0),rc(x[a>>2],x[a+4>>2]),c);ys(x[c+8>>2],B[b>>2]);x[c+8>>2]=x[c+8>>2]+4;xd(a,c);Vf(c);hb=d+32|0}function tf(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a:{if(A[b+8>>2]<c>>>0){x[23604]=0;X(1022,17230,9012,392,6342);a=x[23604];x[23604]=0;if((a|0)==1){break a}p()}x[d+8>>2]=x[b+8>>2];e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=x[d+4>>2];x[a>>2]=x[d>>2];x[a+4>>2]=b;x[a+8>>2]=x[d+8>>2];x[a+12>>2]=c;hb=d+16|0;return}V(0)|0;Vb();p()}function ZU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-1968|0;hb=e;c=hb-16|0;hb=c;f=e+8|0;yB(c+8|0,f);d=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;d=(d|0)==(g|0);if(!d){xB(f)}c=-1;a:{if(!d){break a}c=0;if(!zB(e+8|0)){break a}c=De(a,b,1024,0)}hb=e+1968|0;return c|0}function K8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d>>2]=x[a+8>>2];e=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,52)+e;b=x[d>>2];a:{while(1){if(x[d+4>>2]==(b|0)){break a}x[23604]=0;R(830,b|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){b=x[d>>2]+52|0;x[d>>2]=b;continue}break}a=P()|0;Hd(d);T(a|0);p()}Hd(d);hb=d+16|0}function DB(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Cb(a)>>2]){c=hb-16|0;hb=c;a=zi(c,a,1);oj(x[a+4>>2],z[b>>1]);x[a+4>>2]=x[a+4>>2]+2;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Cb(a);c=pj(d+8|0,qj(a,Kc(x[a>>2],x[a+4>>2])+1|0),Kc(x[a>>2],x[a+4>>2]),c);oj(x[c+8>>2],z[b>>1]);x[c+8>>2]=x[c+8>>2]+2;xd(a,c);yi(c);hb=d+32|0}function t7(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;x[x[a+20>>2]+148>>2]=-1;po(c+8|0,a+4228|0);d=x[a+20>>2];e=x[c+12>>2];b=x[c+8>>2];x[23604]=0;U(869,d+4|0,b|0,Gb(b,e)|0);b=x[23604];x[23604]=0;a:{if((b|0)==1){b=V(92520)|0;if((ib|0)!=(da(92520)|0)){break a}_(b|0)|0;Fc(x[a+20>>2]+4|0);$()}hb=c+16|0;return}T(b|0);p()}function H7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=33;e=x[a>>2];f=x[a+8>>2];c=x[Fb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=cf(a)}e=d+8|0;pA(e,b);f=ec(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);pA(e,b);Zb(x[d+8>>2]+c|0,0,33-c|0);bc(a,x[d+28>>2]);hb=d+32|0;return c|0}function $i(a){var b=0,c=0,d=0,e=0,f=0;b=x[a+4>>2];if(tc(x[a>>2],b)){a=0}else{b=gj(b);e=gj(x[a>>2]);c=hb-16|0;hb=c;x[c+8>>2]=b;while(1){a:{if(!xg(b,e)){break a}d=hb-16|0;hb=d;x[d+8>>2]=b;f=gu(d+8|0);hb=d+16|0;if(z[x[f>>2]>>1]!=65535){break a}b=x[gu(c+8|0)>>2];continue}break}hb=c+16|0;a=hB(Bb(x[a>>2]),b)}return a&65535}function GX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Hg(a,x[b+8>>2],e)){Qv(b,c,d);return}a:{if(!Hg(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function G9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(!td(x[a+1298300>>2])){d=x[a+24620>>2];e=hb-16|0;hb=e;b=Jc(536);x[23604]=0;d=Q(787,b|0,d|0)|0;f=x[23604];x[23604]=0;a:{if((f|0)!=1){b=x[lf(e+8|0,d)>>2];hb=e+16|0;break a}a=P()|0;Hb(b);T(a|0);p()}x[c+8>>2]=b;b=a+1298300|0;a=c+8|0;oM(b,Wd(a));iy(a)}hb=c+16|0}function EI(a){var b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;if(!y[a+20|0]){while(1){if(!(mb[x[x[a>>2]+40>>2]](a)|0)){BI(a,65536);c=ec(b+16|0,Gb(x[a+4>>2],x[a+16>>2]),65536);d=x[x[a>>2]+44>>2];e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;mb[d|0](b+24|0,a,b+8|0);x[a+16>>2]=x[a+16>>2]+x[b+28>>2];continue}break}v[a+20|0]=1}hb=b+32|0}function BO(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;if(y[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){v[a+534|0]=0}else{Zi(a,d,1);c=c+1|0;continue}break}}v[b+15|0]=0;Mh(a+8|0,18,b+15|0);Et(a+26|0,18,29562);v[b+14|0]=255;Mh(a+62|0,256,b+14|0);Qg(x[a>>2],x[a+4>>2],65535,261,1);Qg(x[a>>2],x[a+4>>2],65535,260,0);hb=b+16|0}function zC(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(b>>>0<5){if(!b){break a}if(!Qb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==4){d=x[c+12>>2];break a}else{v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){ig(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}aa(11098,8981,136,14062);p()}hb=c+16|0;return d}function UK(a){var b=0,c=0,d=0;c=hb-32|0;hb=c;a:{d=Ax(a);b=rj(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[23604]=0;b=fa(855,c+8|0,b|0,b|0,Cb(a)|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){xd(a,b);RK(b);break b}_(V(0)|0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break a}}hb=c+32|0;return}V(0)|0;Vb();p()}function TK(a){var b=0,c=0,d=0;c=hb-32|0;hb=c;a:{d=Kh(a);b=rc(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[23604]=0;b=fa(856,c+8|0,b|0,b|0,Cb(a)|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){xd(a,b);Vf(b);break b}_(V(0)|0)|0;x[23604]=0;Z(17);a=x[23604];x[23604]=0;if((a|0)==1){break a}}hb=c+32|0;return}V(0)|0;Vb();p()}function jia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-32|0;hb=e;c=hb-16|0;hb=c;f=e+8|0;KB(c+8|0,f);d=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;d=(d|0)==(g|0);if(!d){su(f)}c=-1;a:{if(!d){break a}c=0;if(!OT(e+8|0)){break a}c=De(a,b,72,0)}hb=e+32|0;return c|0}function bE(a,b,c,d,e,f){var g=0;a:{g=hb-32|0;hb=g;jk(g+8|0,c);x[23604]=0;R(f|0,g+20|0,d|0);c=x[23604];x[23604]=0;b:{c:{if((c|0)!=1){xl(g,g+8|0);x[23604]=0;X(e|0,a|0,b|0,x[g>>2],x[g+4>>2]);a=x[23604];x[23604]=0;if((a|0)==1){break c}yh(g+8|0);hb=g+32|0;break a}a=P()|0;xb(g+8|0);break b}a=P()|0;yh(g+8|0)}T(a|0);p()}}function Y2(a,b){a=a|0;b=b|0;var c=0;x[23604]=0;Y(900,a|0);c=x[23604];x[23604]=0;if((c|0)!=1){x[x[x[a+24>>2]+24>>2]+480272>>2]=b;return 1}_(V(0)|0)|0;x[23604]=0;X(887,5745,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function SK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}if(b>>>0>=2097152){qi();p()}d=Jc(b<<11);x[e+12>>2]=b;x[e+8>>2]=d;b=x[e+8>>2];x[a>>2]=b;d=x[e+12>>2]}c=(c<<11)+b|0;x[a+4>>2]=c;x[a+8>>2]=c;f=yc(a),g=(d<<11)+b|0,x[f>>2]=g;hb=e+16|0;return a|0}function HI(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=x[a>>2];a:{if(!c){break a}d=x[a+8>>2];if(!d){break a}e=x[a+12>>2];if(!e){break a}a=mb[e|0](c)|0;f=lb;if((f|0)<0){break a}b=0;b:{if((mb[d|0](c,0,0,0)|0)<0){break b}b=0;if((mb[d|0](c,0,0,2)|0)<0){break b}mb[e|0](c)|0;b=lb;b=(b|0)>0|(b|0)>=0}mb[d|0](c,a,f,0)|0}return b|0}function iea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-608|0;hb=d;c=hb-16|0;hb=c;DQ(c+8|0,d);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){CQ(d)}c=-1;a:{if(!e){break a}c=0;if(!FQ(d)){break a}c=De(a,b,EQ(z[d+34>>1]),lb)}hb=d+608|0;return c|0}function UB(a){var b=0,c=0,d=0,e=0;c=y[a+9|0]|y[a+10|0]<<8;d=Jia(y[a+3|0],0,18,0);c=c+d|0;b=lb;e=d>>>0>c>>>0?b+1|0:b;d=y[a+6|0]|y[a+7|0]<<8;b=d>>>31|0;d=d<<1;c=d+c|0;b=b+e|0;d=d>>>0>c>>>0?b+1|0:b;a=y[a+4|0]|y[a+5|0]<<8;b=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+3|0;lb=b>>>0<3?a+1|0:a;return b}function Rx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=H(c,.999);h=c*3.141592653589793;i=Ws(b);while(1){if((e|0)!=32768){f=((e^-1)<<12&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=mi(g)*Ws(M(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=yz(c*d*32768),w[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function IQ(a){var b=0,c=0;a:{if(Rb(a,3868,4)|y[a+63|0]!=26){break a}b=y[a+65|0];if(y[a+66|0]|(b|0)!=16&(b|0)!=1|(y[a+64|0]&3|(y[a+78|0]|y[a+79|0]<<8)>>>0>127)){break a}if((y[a+80|0]|y[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=rl(y[a|0]|y[a+1|0]<<8,y[b|0]|y[b+1|0]<<8)?b:a;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function mE(a,b,c,d,e){var f=0;a:{f=hb-32|0;hb=f;Ho(f+8|0,c);x[23604]=0;R(e|0,f+20|0,d|0);c=x[23604];x[23604]=0;b:{c:{if((c|0)!=1){xl(f,f+8|0);x[23604]=0;X(100,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[23604];x[23604]=0;if((a|0)==1){break c}yh(f+8|0);hb=f+32|0;break a}a=P()|0;xb(f+8|0);break b}a=P()|0;yh(f+8|0)}T(a|0);p()}}function jE(a,b,c,d,e){var f=0;a:{f=hb-32|0;hb=f;ET(f+8|0,c);x[23604]=0;R(e|0,f+20|0,d|0);c=x[23604];x[23604]=0;b:{c:{if((c|0)!=1){xl(f,f+8|0);x[23604]=0;X(100,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[23604];x[23604]=0;if((a|0)==1){break c}yh(f+8|0);hb=f+32|0;break a}a=P()|0;xb(f+8|0);break b}a=P()|0;yh(f+8|0)}T(a|0);p()}}function c3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:881;return}_(V(0)|0)|0;x[23604]=0;X(887,12944,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Tca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=4896;e=x[a>>2];f=x[a+8>>2];c=x[Fb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=cf(a)}e=d+8|0;tA(e,b);f=ec(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);tA(e,b);Zb(x[d+8>>2]+c|0,0,4896-c|0);bc(a,x[d+28>>2]);hb=d+32|0}function FQ(a){var b=0;a:{if(Rb(a+44|0,14019,4)|y[a+28|0]!=26|(y[a+40|0]|y[a+41|0]<<8|y[a+30|0]>2)){break a}if(((y[a+38|0]|y[a+39|0]<<8)-33&65535)>>>0<65504|((y[a+32|0]|y[a+33|0]<<8)-257&65535)>>>0<65280|((y[a+34|0]|y[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((y[a+36|0]|y[a+37|0]<<8)-1&65535)>>>0<128}return b}function ol(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;d=Pb(b);e=c,f=Qc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;x[c+8>>2]=x[a+4>>2]-1;pi(d,d+x[Fb(c+12|0,c+8|0)>>2]|0,x[a>>2]);d=x[a>>2];e=c,f=Qc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;a=x[a+4>>2];x[c+8>>2]=a-1;b=x[Fb(c+12|0,c+8|0)>>2];v[c+7|0]=0;Ql(b+d|0,a+d|0,c+7|0);hb=c+16|0}function gR(a){var b=0,c=0,d=0,e=0,f=0;f=y[a+28|0]|y[a+29|0]<<8;c=Jia(y[a+30|0],0,37,0);d=lb;b=Jia(y[a+24|0]|y[a+25|0]<<8,0,192,0);c=b+c|0;d=lb+d|0;b=b>>>0>c>>>0?d+1|0:d;a=y[a+26|0];d=a>>>26|0;e=c;c=a<<6;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+f|0;a=b>>>0<e>>>0?a+1|0:a;b=b+192|0;lb=b>>>0<192?a+1|0:a;return b}function Hea(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Cb(a)>>2]){c=hb-16|0;hb=c;a=Eu(c,a,1);_Q(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Cb(a);c=QA(d+8|0,RA(a,Bf(x[a>>2],x[a+4>>2])+1|0),Bf(x[a>>2],x[a+4>>2]),c);_Q(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;PA(a,c);St(c);hb=d+32|0}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+8>>2]=c;x[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Eb(x[a+4>>2],y[a+11|0]),x[f>>2]=g;e=x[Fb(d+12|0,d)>>2];x[d+4>>2]=e;a=Dn(Pb(a),b,x[Fb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}hb=d+16|0;return a|0}Rp();p()}function Fx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;h=z[b>>1];c=Sd(a);e=jc(a);f=hb-16|0;hb=f;while(1){if(c){g=Ep(z[c+16>>1],h);e=g?e:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[Ib(f+8|0,e)>>2];hb=f+16|0;a:{if(Ob(c,Ef(a))){if(!Ep(z[b>>1],z[sd(c)>>1])){break a}}c=Ef(a)}a=x[Ib(d+8|0,c)>>2];hb=d+16|0;return a}function $ca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=263;e=x[a>>2];f=x[a+8>>2];c=x[Fb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=cf(a)}e=d+8|0;lP(e,b);f=ec(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);lP(e,b);Zb(x[d+8>>2]+c|0,0,263-c|0);bc(a,x[d+28>>2]);hb=d+32|0}function lU(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Cb(a)>>2]){c=hb-16|0;hb=c;a=aU(c,a,1);$T(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+48;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Cb(a);c=ZT(d+8|0,_T(a,gq(x[a>>2],x[a+4>>2])+1|0),gq(x[a>>2],x[a+4>>2]),c);$T(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+48;YT(a,c);XT(c);hb=d+32|0}function h4(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){return A[x[x[a+24>>2]+24>>2]+1074420>>2]/1e4|0}_(V(0)|0)|0;x[23604]=0;X(887,9232,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Taa(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Cb(a)>>2]){c=hb-16|0;hb=c;a=sz(c,a,1);dz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+32;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Cb(a);c=ft(d+8|0,Dp(a,_f(x[a>>2],x[a+4>>2])+1|0),_f(x[a>>2],x[a+4>>2]),c);dz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;LO(a,c);cz(c);hb=d+32|0}function Qha(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Cb(a)>>2]){c=hb-16|0;hb=c;a=Eu(c,a,1);SA(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Cb(a);c=QA(d+8|0,RA(a,Bf(x[a>>2],x[a+4>>2])+1|0),Bf(x[a>>2],x[a+4>>2]),c);SA(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;PA(a,c);St(c);hb=d+32|0}function v_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=x[20591];x[g+24>>2]=x[20590];x[g+28>>2]=h;h=x[20589];x[g+16>>2]=x[20588];x[g+20>>2]=h;h=x[20587];x[g+8>>2]=x[20586];x[g+12>>2]=h;h=x[20585];x[g>>2]=x[20584];x[g+4>>2]=h;h=a;a=g+32|0;b=Aj(h,b,c,d,e,f,g,a);hb=a;return b|0}function lga(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c>>2]=x[a+8>>2];d=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=D(b,20)+d;b=x[c>>2];a:{while(1){if(x[c+4>>2]==(b|0)){break a}x[23604]=0;Y(214,b|0);a=x[23604];x[23604]=0;if((a|0)!=1){b=x[c>>2]+20|0;x[c>>2]=b;continue}break}a=P()|0;Hd(c);T(a|0);p()}Hd(c);hb=c+16|0}function ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=22;e=x[a>>2];f=x[a+8>>2];c=x[Fb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=cf(a)}e=d+8|0;Ut(e,b);f=ec(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Ut(e,b);Zb(x[d+8>>2]+c|0,0,22-c|0);bc(a,x[d+28>>2]);hb=d+32|0}function cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=40;e=x[a>>2];f=x[a+8>>2];c=x[Fb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=cf(a)}e=d+8|0;gA(e,b);f=ec(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);gA(e,b);Zb(x[d+8>>2]+c|0,0,40-c|0);bc(a,x[d+28>>2]);hb=d+32|0}function Pda(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Cb(a)>>2]){c=hb-16|0;hb=c;a=uv(c,a);Dz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Cb(a);c=wl(d+8|0,Io(a,Dd(x[a>>2],x[a+4>>2])+1|0),Dd(x[a>>2],x[a+4>>2]),c);Dz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;aQ(a,c);$P(c);hb=d+32|0}function xV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=65;e=x[a>>2];f=x[a+8>>2];c=x[Fb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=cf(a)}e=d+8|0;Du(e,b);f=ec(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Du(e,b);Zb(x[d+8>>2]+c|0,0,65-c|0);bc(a,x[d+28>>2]);hb=d+32|0}function fK(a){var b=0,c=E(0),d=0,e=0;e=x[x[a+16>>2]+24620>>2];b=hb-16|0;hb=b;x[b+12>>2]=0;x[b+8>>2]=1065353216;c=Lh(E(B[Sp(a+4208|0,b+12|0,b+8|0)>>2]*E(999)));a:{if(c<E(4294967296)&c>=E(0)){d=~~c>>>0;break a}d=0}hb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;wc(a+4224|0,b)}function Tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=hb-32|0;hb=d;e=hb-16|0;hb=e;f=e,g=Lb(c&65535),w[f+14>>1]=g;c=d+16|0;sJ(c,e+14|0);hb=e+16|0;Cj(d+8|0,c);x[23604]=0;X(100,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23604];x[23604]=0;if((a|0)!=1){Db(d+16|0);hb=d+32|0;break a}a=P()|0;Db(d+16|0);T(a|0);p()}}
function Sea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-1120|0;hb=d;c=hb-16|0;hb=c;cR(c+8|0,d+8|0);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!fR(d+8|0)){break a}c=De(a,b,dR(x[d+1112>>2]),lb)}hb=d+1120|0;return c|0}function ZV(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Cb(a)>>2]){c=hb-16|0;hb=c;a=iD(c,a);av(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+36;ic(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Cb(a);c=gD(d+8|0,hD(a,Qq(x[a>>2],x[a+4>>2])+1|0),Qq(x[a>>2],x[a+4>>2]),c);av(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+36;fD(a,c);cv(c);hb=d+32|0}function XK(a,b){var c=0,d=0,e=0,f=0,g=E(0);c=hb-16|0;hb=c;if(!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){w[c+14>>1]=0;Ff(a,c+14|0);e=z[c+14>>1];Gj(b,e);while(1){if((d|0)!=(e|0)){x[c+8>>2]=0;ep(a,c+8|0);f=zb(x[b>>2],d),g=B[c+8>>2],B[f>>2]=g;d=d+1|0;continue}break}d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}hb=c+16|0;return d}function Lha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-224|0;hb=d;c=hb-16|0;hb=c;qT(c+8|0,d);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!sT(d)){break a}c=De(a,b,rT(y[d+216|0],y[d+217|0]),lb)}hb=d+224|0;return c|0}function dq(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;e=x[b+4>>2];f=Ib(d+24|0,c);g=Ib(d+16|0,x[a>>2]);h=Ib(d+8|0,x[b+4>>2]);i=b,j=eP(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=Vt(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;qc(a,b+4|0);qc(a+4|0,b+8|0);qc(Cb(a),yc(b));x[b>>2]=x[b+4>>2];hb=d+32|0;return e}function Xda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb+-64|0;hb=d;c=hb-16|0;hb=c;du(c+8|0,d);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){Zt(d)}c=-1;a:{if(!e){break a}c=0;if(!jQ(d)){break a}c=De(a,b,iQ(d),lb)}hb=d- -64|0;return c|0}function I5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;Pc(a,x[b+28>>2]);x[23604]=0;U(65,d+8|0,b|0,c|0);e=x[23604];x[23604]=0;a:{if((e|0)==1){break a}$b(d+8|0);b=x[b+24>>2];if(b){x[23604]=0;U(66,d|0,b|0,c|0);b=x[23604];x[23604]=0;if((b|0)==1){break a}$b(d)}hb=d+16|0;return}b=P()|0;$b(a);T(b|0);p()}function F1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(y[b+40|0]){break a}if(!x[b+28>>2]){v[b+40|0]=1;break a}d=x[c+4>>2];f=x[c>>2];while(1){b:{if(d){e=mb[x[b+28>>2]](x[b+24>>2],f,d)|0;if(e){break b}v[b+40|0]=1}d=g;break a}d=d-e|0;f=e+f|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}}hc(a,x[c>>2],d)}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-192|0;hb=d;c=hb-16|0;hb=c;sq(c+8|0,d);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){cT(d)}c=-1;a:{if(!e){break a}c=0;if(!eT(d)){break a}c=De(a,b,dT(d),lb)}hb=d+192|0;return c|0}function vs(a){var b=0,c=0,d=0;b=wj(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b>45e-5){c=Po(b)/.6931471805599453;b=c-J(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=wj(d+c)*.5}else{b=0}C[a+4248>>3]=b}us(a)}function sl(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=D(c,872)+b|0;f=RM(x[d+720>>2],x[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return QM(a,b,c,e);case 1:break b;default:break a}}f=QM(a,b,c,e);if((f+5&255)>>>0>5){break a}a=D(c,872)+b|0;f=RM(x[a+720>>2],x[a+1272>>2],e)}return f}function NK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[23604]=0;x[c+12>>2]=0;U(857,a+4208|0,b<<1,c+12|0);b=x[23604];x[23604]=0;a:{if((b|0)==1){b=V(92520)|0;if((ib|0)!=(da(92520)|0)){break a}_(b|0)|0;x[a+4220>>2]=0;$()}x[a+4224>>2]=0;hb=c+16|0;return}T(b|0);p()}function pG(a,b,c){var d=0,e=0,f=0,g=0;d=a;e=hb-16|0;hb=e;a:{f=ie(b,c);if(f>>>0<1073741808){b:{if(Uo(f)){bf(d,f);break b}dj(e+8|0,El(f)+1|0);g=x[e+8>>2];Ad(d,g);cg(d,x[e+12>>2]);oe(d,f);d=g}while(1){if((b|0)!=(c|0)){Ad(d,x[b>>2]);d=d+4|0;b=b+4|0;continue}break}Ad(d,0);hb=e+16|0;break a}dg();p()}return a}function QX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;a:{e=x[b>>2];if(td(e)){if(!wd(x[c+4>>2],y[c+11|0])){sv(c,17617);e=x[b>>2]}b=x[b+4>>2];mb[x[x[b>>2]+24>>2]](d,b,e);x[23604]=0;Q(753,c|0,d|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}xb(d)}dd(a,c);hb=d+16|0;return}a=P()|0;xb(d);T(a|0);p()}function Gm(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(x[c>>2]|x[d>>2]){while(1){if((b|0)==(f|0)){break a}e=x[d>>2];g=x[c>>2];h=c,i=g-gd((gd(0-g|0,31)&255)+g|0,8)|0,x[h>>2]=i;h=d,i=x[d>>2]-gd(e+(gd(0-e|0,31)&255)|0,8)|0,x[h>>2]=i;e=(f<<3)+a|0;x[e>>2]=x[c>>2];x[e+4>>2]=x[d>>2];f=f+1|0;continue}}Zb(a,0,b<<3)}}function yia(a,b){a=a|0;b=b|0;var c=0;eu(a,b);Hf(b);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}v[b+3|0]=45;v[b+5|0]=a&15;return}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;return}v[b+3|0]=20;v[b+5|0]=a&15|160;return}v[b+3|0]=0}}function xr(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function vY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;x[e>>2]=c;a=Vv(f+12|0,0,x[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-x[e>>2]>>>0){break a}b=f+12|0;while(1){if(c){a=y[b|0];d=x[e>>2];x[e>>2]=d+1;v[d|0]=a;c=c-1|0;b=b+1|0;continue}break}b=0}hb=f+16|0;return b|0}function dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-80|0;hb=d;c=hb-16|0;hb=c;AS(c+8|0,d);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){uA(d)}c=-1;a:{if(!e){break a}c=0;if(!sP(d)){break a}c=De(a,b,rP(d),lb)}hb=d+80|0;return c|0}function OU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;a:{if(!Qb(x[b>>2],x[b+8>>2],c<<1)){break a}wc(d+12|0,65535);eg(a,z[d+12>>1]);c=Bb(x[a>>2]);x[d>>2]=c;a=Bb(x[a+4>>2]);while(1){if(!Ob(c,a)){break a}wu(b,d+8|0);e=c,f=Lb(z[d+8>>1]),w[e>>1]=f;c=x[Pe(d)>>2];continue}}hb=d+16|0}function ifa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-128|0;hb=d;c=hb-16|0;hb=c;pR(c+8|0,d);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){oR(d)}c=-1;a:{if(!e){break a}c=0;if(!qR(d)){break a}c=De(a,b,256,0)}hb=d+128|0;return c|0}function ct(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[116090]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=ow(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=ow(a)}Wd(b)}return a}function xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Bb(x[b>>2]);g=Bb(x[b+4>>2]);e=hb-16|0;hb=e;x[e+8>>2]=d;while(1){a:{if(!Ob(d,g)){break a}f=hb-16|0;hb=f;ES(f+8|0,d);hb=f+16|0;if(z[f+8>>1]==(c|0)){break a}d=x[pm(e+8|0)>>2];continue}break}hb=e+16|0;if(tc(d,Bb(x[b+4>>2]))){xh(a);return}qm(a,d)}function uL(a){var b=0,c=0;a:{if(Rb(a,14053,4)){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))}return c}function FI(a,b,c,d){var e=0,f=0,g=0;b=de(b,pd(a));a:{f=Eb(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=Oc(a);b:{if(e-f>>>0>=c>>>0){e=Pb(a);if((b|0)==(f|0)){break b}g=b+e|0;dl(g+c|0,g,f-b|0);break b}Xx(a,e,(c+f|0)-e|0,f,b,c);e=x[a>>2]}gl(b+e|0,c,d);b=c+f|0;Sg(a,b);id(b+e|0,0)}break a}Rp();p()}pd(a)}function dB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;x[f+8>>2]=c;g=f,h=cf(b),x[g+28>>2]=h;c=f+8|0;Af(c,b,x[Fb(c,f+28|0)>>2]);b=xe(c);x[23604]=0;ea(222,a|0,b|0,x[f+8>>2],d|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){Lc(f+8|0);hb=f+32|0;return}a=P()|0;Lc(f+8|0);T(a|0);p()}function Zp(a){var b=0,c=0;b=hb-32|0;hb=b;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;c=a+288|0;nz(c,c+512|0,b);x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;a=a+800|0;nz(a,QP(a),b);hb=b+32|0}function l7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Fd(c,E(0));a:{b:{switch(b-3|0){case 0:c=Lh(c);if(c==B[zb(a+4208|0,3)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 1:break b;default:break a}}c=E(Lh(E(c*E(4)))*E(.25))}d=zb(a+4208|0,b),e=c,B[d>>2]=e;qx(a)}}function QU(a){a=a|0;var b=0,c=0,d=0;c=hb-32|0;hb=c;b=255;a:{if(_i(x[a>>2],x[a+4>>2])>>>0<=49){b=hz(c,x[a+12>>2]);x[23604]=0;R(274,a|0,b|0);d=x[23604];x[23604]=0;if((d|0)==1){break a}Wk(b);ui(a,_i(x[a>>2],x[a+4>>2])-1&255);b=_i(x[a>>2],x[a+4>>2])-1|0}hb=c+32|0;return b&255}a=P()|0;Wk(b);T(a|0);p()}function Jx(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(b,52);b=x[d+4>>2];a=x[d+8>>2];a:{while(1){if((a|0)==(b|0)){break a}x[23604]=0;R(830,b|0,c|0);e=x[23604];x[23604]=0;if((e|0)!=1){b=b+52|0;x[d+4>>2]=b;continue}break}a=P()|0;ic(d);T(a|0);p()}ic(d);hb=d+16|0}function G6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Fd(c,E(0));a:{b:{switch(b-1|0){case 0:c=Lh(c);if(c==B[zb(a+4208|0,1)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 3:break b;default:break a}}c=E(Lh(E(c*E(4)))*E(.25))}d=zb(a+4208|0,b),e=c,B[d>>2]=e;qx(a)}}function uf(a){a=a|0;var b=0,c=0;x[a>>2]=44832;b=x[a+12>>2];if(x[b>>2]==(a|0)){x[b>>2]=x[a+4>>2]}b=x[a+20>>2];if(b){x[b>>2]=0;x[a+20>>2]=0}b=x[a+4>>2];if(b){x[b+8>>2]=x[a+8>>2]}c=x[a+8>>2];if(c){x[c+4>>2]=b}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;GK(a+44|0);return a|0}function oo(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;a:{b:{while(1){h=g&255;if(h>>>0>3){break b}if(!uq(b,c,h>>>0>1)){Xg(b,d);Xg(c,e);g=g+1|0;continue}break}v[f+15|0]=0;$s(a,0,f+15|0);break a}g=a;a=y[b|0];if(vi(a)>>>0>vi(y[d|0])>>>0){Xg(b,d);Xg(c,e);a=y[b|0]}$s(g,a,c);v[b|0]=0;v[c|0]=0}hb=f+16|0}function o8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=fi(a,b,c,d);x[a>>2]=44364;b=Sb(a+4208|0);x[a+4228>>2]=0;x[a+4220>>2]=0;x[a+4224>>2]=0;x[a+4232>>2]=x[c+24620>>2];mB(a+4260|0,80,150,80,255);x[23604]=0;R(851,a+44|0,2);c=x[23604];x[23604]=0;if((c|0)!=1){ei(a);return a|0}c=P()|0;sc(b);uf(a);T(c|0);p()}function _3(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){return Bg(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[23604]=0;X(887,7039,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Z3(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){return is(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[23604]=0;X(887,6748,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function W3(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){return hs(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[23604]=0;X(887,7398,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function IX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Hg(a,x[b+8>>2],0)){Pv(b,c,d);return}e=x[a+12>>2];f=a+16|0;aF(x[f>>2],x[a+20>>2],b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){aF(x[a>>2],x[a+4>>2],b,c,d);if(y[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function HK(a){a=a|0;var b=0,c=0,d=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];a:{if(F(b)<0x8000000000000000){d=~~b>>>0;c=F(b)>=1?~~(b>0?H(J(b*2.3283064365386963e-10),4294967295):K((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}C[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function n4(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){return+aM(x[x[a+24>>2]+24>>2])}_(V(0)|0)|0;x[23604]=0;X(887,10041,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function Ly(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;ve(d+8|0,b);f=x[d+8>>2];b=x[d+12>>2];c=hb-16|0;hb=c;e=Eb(x[a+4>>2],y[a+11|0]);x[c+12>>2]=e;x[c+8>>2]=b;g=Fb(c+12|0,c+8|0);a=Dn(Pb(a),f,x[g>>2]);a:{if(a){break a}a=-1;if(b>>>0>e>>>0){break a}a=b>>>0<e>>>0}hb=c+16|0;hb=d+16|0;return a>>>31|0}function Ll(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;a:{if(!(c&32)){break a}c=pd(b);x[d+8>>2]=c;g=pf(b);while(1){if(!Ob(c,g)){break a}f=Pf(97);e=v[c|0];b:{if((f|0)>(e|0)){break b}if((Pf(122)|0)<(e|0)){break b}h=c,i=(Pf(65)-f|0)+e|0,v[h|0]=i}c=x[Le(d+8|0)>>2];continue}}dd(a,b);hb=d+16|0}function Kv(a,b,c){var d=0;x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;if((d|0)!=1){return x[x[x[a+24>>2]+24>>2]+c>>2]}_(V(0)|0)|0;x[23604]=0;X(887,b|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function HE(a,b,c){var d=0;x[23604]=0;Y(900,a|0);d=x[23604];x[23604]=0;if((d|0)!=1){return z[x[x[a+24>>2]+24>>2]+c>>1]}_(V(0)|0)|0;x[23604]=0;X(887,b|0,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function kO(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=pr(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);Uk(e,b,+n());return}a:{if(!$e(b)){break a}d=F(c)<O;if(b<0){c=d?c:1;break a}if(d){break a}Uk(a,b,$e(c)?N:c);return}b=pr(b);g=mi(c);Uk(a,b*Me(c),g*b)}function Gg(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);vf(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;hb=d+16|0}function Daa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);c=Eg(x[b>>2],x[b+4>>2]);if(c){Vy(a,c);d=x[b>>2];f=x[b+4>>2];e=hb-16|0;hb=e;c=Rq(e,a,c);b=x[c+4>>2];while(1){if((d|0)!=(f|0)){C[b>>3]=C[d>>3];b=b+8|0;d=d+8|0;continue}break}x[c+4>>2]=b;ic(c);hb=e+16|0}return a|0}function CB(a,b,c){var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=192;e=x[a>>2];f=x[a+8>>2];c=x[Fb(d+28|0,d+8|0)>>2];if(!Qb(e,f,c)){c=cf(a)}e=d+8|0;sq(e,b);f=ec(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);sq(e,b);Zb(x[d+8>>2]+c|0,0,192-c|0);bc(a,x[d+28>>2]);hb=d+32|0}function PE(a,b,c,d,e){var f=0;f=hb-32|0;hb=f;b=lg(f,b);x[23604]=0;U(e|0,f+16|0,b|0,c|0);e=x[23604];x[23604]=0;a:{b:{if((e|0)!=1){x[23604]=0;U(d|0,a|0,f+16|0,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}xb(f+16|0);xb(b);hb=f+32|0;return}c=P()|0;break a}c=P()|0;xb(f+16|0)}xb(b);T(c|0);p()}function MP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=6553600;i=e,j=dc(b),x[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=cq(f*+A[Fb(g,b)>>2]);x[e+8>>2]=6553600;i=e,j=dc(c),x[i+4>>2]=j;i=e,j=cq(f*+A[Fb(b,e+4|0)>>2]),x[i+12>>2]=j;x[e+8>>2]=d-h;hj(a,h,Fb(b,g));hb=e+16|0}function Hk(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;ih(c,b);x[23604]=0;R(1004,c+16|0,c|0);b=x[23604];x[23604]=0;a:{b:{if((b|0)!=1){x[23604]=0;U(1005,a|0,0,c+16|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}Gc(c+16|0);xb(c);hb=c+32|0;return}b=P()|0;break a}b=P()|0;Gc(c+16|0)}xb(c);T(b|0);p()}function pv(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function or(a,b,c,d,e,f){var g=0,h=0,i=0;g=hb-16|0;hb=g;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}if(b>>>0>=f>>>0){qi();p()}d=Jc(D(b,e));x[g+12>>2]=b;x[g+8>>2]=d;b=x[g+8>>2];x[a>>2]=b;d=x[g+12>>2]}c=D(c,e)+b|0;x[a+4>>2]=c;x[a+8>>2]=c;h=yc(a),i=D(d,e)+b|0,x[h>>2]=i;hb=g+16|0;return a}function iw(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-160|0;hb=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;Zh(f,0,0);BG(e,f,d,1);d=x[e+8>>2];g=x[e+12>>2];f=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=((x[e+20>>2]+x[e+136>>2]|0)-x[e+60>>2]|0)+b}x[a+8>>2]=d;x[a+12>>2]=g;x[a>>2]=f;x[a+4>>2]=h;hb=e+160|0}function M3(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){return+C[x[a+24>>2]+16>>3]}_(V(0)|0)|0;x[23604]=0;X(887,7560,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function FT(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function F3(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){return x[x[a+24>>2]+8>>2]}_(V(0)|0)|0;x[23604]=0;X(887,10789,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return-1}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function my(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Hj(a,b,b+700|0,c<<2,0)}}function lJ(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=x[a>>2];d=If(e);b:{c:{if((Eb(x[c+4>>2],y[c+11|0])|0)==(d|0)){x[23604]=0;d=W(345,c|0,e|0,d|0)|0;e=x[23604];x[23604]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}V(0)|0;Vb();p()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function Z9(a,b){a=a|0;b=b|0;var c=0,d=0;c=vc(a,b,614);a=0;while(1){d=D(a,872);qp((d+c|0)+616|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=Jz(c+223848|0,b+223848|0);x[23604]=0;Q(756,c+223860|0,b+223860|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){return c|0}b=P()|0;fc(a);T(b|0);p()}function TC(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=x[a+92>>2];e=x[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){x[a+96>>2]=e;x[a+92>>2]=d}else{f=(g<<3)+b|0;h=x[f>>2];d=d-gd((gd(0-d|0,31)&255)+d|0,8)|0;x[f>>2]=h+d;h=x[f+4>>2];e=e-gd((gd(0-e|0,31)&255)+e|0,8)|0;x[f+4>>2]=h+e;g=g+1|0;continue}break}}}function hK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[23604]=0;x[c+12>>2]=0;U(857,a+4208|0,b<<2,c+12|0);b=x[23604];x[23604]=0;a:{if((b|0)==1){b=V(92520)|0;if((ib|0)!=(da(92520)|0)){break a}_(b|0)|0;x[a+4240>>2]=0;$()}x[a+4244>>2]=0;hb=c+16|0;return}T(b|0);p()}function NG(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a=fs(a);x[a+32>>2]=b;x[a>>2]=77820;Pc(d+8|0,x[a+4>>2]);x[23604]=0;b=S(1063,x[d+8>>2])|0;e=x[23604];x[23604]=0;if((e|0)!=1){$b(d+8|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=hn(b),v[f+44|0]=g;hb=d+16|0;return}b=P()|0;$b(d+8|0);yn(a);T(b|0);p()}function LG(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a=ZG(a);x[a+32>>2]=b;x[a>>2]=78188;Pc(d+8|0,x[a+4>>2]);x[23604]=0;b=S(1064,x[d+8>>2])|0;e=x[23604];x[23604]=0;if((e|0)!=1){$b(d+8|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=hn(b),v[f+44|0]=g;hb=d+16|0;return}b=P()|0;$b(d+8|0);Kr(a);T(b|0);p()}function Fga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;Ve(b);x[d+12>>2]=0;a:{if(!Uj(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}v[d+11|0]=0;if(Eh(a,d+11|0)){np(b,v[d+11|0]);e=e+1|0;continue}break}e=0}hb=d+16|0;return e|0}function XA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;x[e+8>>2]=c;f=e,g=cf(b),x[f+28>>2]=g;c=e+8|0;Af(c,b,x[Fb(c,e+28|0)>>2]);b=xe(c);x[23604]=0;X(321,a|0,b|0,x[e+8>>2],d|0);a=x[23604];x[23604]=0;if((a|0)!=1){Lc(e+8|0);hb=e+32|0;return}a=P()|0;Lc(e+8|0);T(a|0);p()}function DM(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Hj(a,b,b+700|0,c,0)}}function dS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;a=ag(a);b=b+236|0;e=aq(b);a:{while(1){if((b|0)!=(e|0)){d=z[b>>1];w[c+14>>1]=d;if(d){x[23604]=0;U(486,c|0,a|0,c+14|0);d=x[23604];x[23604]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}hb=c+16|0;return}b=P()|0;jA(a);T(b|0);p()}function X9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(ud(y[b+24|0])){a=ag(a);c=gj(x[b>>2]);d=xf(b);x[23604]=0;U(759,a|0,c|0,d|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}x[23604]=0;Q(758,a+12|0,b+12|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}v[a+24|0]=1}return}b=P()|0;WM(a);T(b|0);p()}function So(a,b){var c=0,d=0;c=hb-16|0;hb=c;Pc(c+8|0,a);x[23604]=0;a=S(1083,x[c+8>>2])|0;d=x[23604];x[23604]=0;a:{b:{if((d|0)==1){break b}x[23604]=0;X(1094,a|0,82128,82154,b|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}$b(c+8|0);hb=c+16|0;break a}a=P()|0;$b(c+8|0);T(a|0);p()}return b}function Ez(a,b,c,d,e){var f=0;a:{f=x[a>>2];if(!Qd(f,x[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}im(b);b=_n(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!yg(b)){break a}if(x[a>>2]!=(d|0)){Nq(b+68|0)}vc(x[b+20>>2],x[a+20>>2]+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}}function bL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{if(Kh(a)>>>0>=b>>>0){f=x[a>>2];e=rc(f,x[a+4>>2]);x[d+8>>2]=e;aL(f,x[Fb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Ix(a,b-e|0,c);break a}Id(a,x[a>>2]+(b<<2)|0);break a}Ft(a);bk(a,vg(a,b));Ix(a,b,c)}hb=d+16|0}function Paa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+24>>2]=d;c=ff(a,c);_d(e+8|0,x[a+28>>2]);f=a;a:{if(!c){d=0;if(fd(a,5)){break a}}d=x[a+28>>2];a=0;eC(b,x[e+24>>2]);while(1){if(A[e+24>>2]>a>>>0){IO(d,cc(x[b>>2],a));a=a+1|0;continue}break}d=c}_e(f,d);hb=e+32|0}function nV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;a:{if(!Qb(x[b>>2],x[b+8>>2],c<<1)){break a}wc(d+12|0,65535);eg(a,z[d+12>>1]);c=Bb(x[a>>2]);x[d>>2]=c;a=Bb(x[a+4>>2]);while(1){if(!Ob(c,a)){break a}wu(b,d+8|0);w[c>>1]=z[d+8>>1];c=x[Pe(d)>>2];continue}}hb=d+16|0}function iJ(a){var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=a+120|0;cs(y[b+20|0]);c=hb-16|0;hb=c;x[c+8>>2]=d+8;a=hb-16|0;hb=a;e=x[14303];x[a+8>>2]=x[14302];x[a+12>>2]=e;e=x[14301];x[a>>2]=x[14300];x[a+4>>2]=e;b=mb[x[$o(a,Ej(y[b+20|0]))>>2]](c+8|0,b)|0;hb=a+16|0;hb=c+16|0;hb=d+16|0;return b}function Nc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=b-d|0;lb=a-(c+(b>>>0<d>>>0)|0)|0;return e}function Dr(a,b,c,d){var e=0,f=0;e=hb-160|0;hb=e;f=-1;x[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;x[e+144>>2]=a;e=Zb(e,0,144);x[e+76>>2]=-1;x[e+36>>2]=1066;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+144;a:{if((b|0)<0){x[116080]=61;break a}v[a|0]=0;f=sH(e,c,d,1040,1041)}hb=e+160|0;return f}function i5(a){a=a|0;var b=0;x[23604]=0;Y(900,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){return x[a+16>>2]}_(V(0)|0)|0;x[23604]=0;X(887,5651,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)!=1){$();return-1}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function ZF(a,b,c){var d=0,e=0,f=0;d=a;f=hb-16|0;hb=f;a:{if(b>>>0<1073741808){b:{if(Uo(b)){bf(d,b);break b}dj(f+8|0,El(b)+1|0);e=x[f+8>>2];Ad(d,e);cg(d,x[f+12>>2]);oe(d,b);d=e}e=hb-16|0;hb=e;x[e+12>>2]=c;GC(d,b,e+12|0);hb=e+16|0;Ad((b<<2)+d|0,0);hb=f+16|0;break a}dg();p()}return a}function VJ(a,b,c){v[a+12|0]=0;x[c>>2]=0;x[b>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;w[a+24>>1]=0;x[a+36>>2]=0;x[a+40>>2]=0;x[a+44>>2]=0;x[a+48>>2]=0;UJ(a+60|0);UJ(a+52|0);mp(a+49956|0);mp(a+58148|0);mp(a+66340|0);mp(a+74532|0);Zb(a+228|0,0,32768);Zb(a+32996|0,0,512);Zb(a+33508|0,0,16384)}function Uaa(a,b){a=a|0;b=b|0;var c=0;a:{x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);c=Kc(x[b>>2],x[b+4>>2]);if(c){Hp(a,c);MO(a,x[b>>2],x[b+4>>2],c)}x[23604]=0;Q(3,a+12|0,b+12|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){x[a+24>>2]=x[b+24>>2];w[a+28>>1]=z[b+28>>1];break a}b=P()|0;nd(a);T(b|0);p()}}function ON(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-16|0;hb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Pb(d);ug(b,a,Eb(x[d+4>>2],y[d+11|0])+a|0);break c}HN(e,c,d);x[23604]=0;U(43,a|0,b|0,e|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}Gc(e)}hb=e+16|0;break a}a=P()|0;Gc(e);T(a|0);p()}}function Dl(a,b){x[a>>2]=0;x[a+4>>2]=0;x[a+20>>2]=0;w[a+16>>1]=65535;x[a+8>>2]=0;x[a+12>>2]=0;x[a+24>>2]=11;x[a+28>>2]=b;Sb(a+32|0);Sb(a+44|0);x[a+72>>2]=0;x[a+76>>2]=0;x[a+64>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;x[a+80>>2]=0;x[a+84>>2]=0;x[a+88>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;return a}function B4(a){a=a|0;var b=0;x[23604]=0;Y(925,a|0);b=x[23604];x[23604]=0;a:{if((b|0)==1){_(V(0)|0)|0;x[23604]=0;X(887,11849,a|0,0,0);a=x[23604];x[23604]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;if((b|0)!=1){T(a|0);p()}V(0)|0;Vb();p()}function zaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{if(an(a)>>>0>=b>>>0){f=x[a>>2];e=Rc(f,x[a+4>>2]);x[d+8>>2]=e;Mh(f,x[Fb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){wo(a,b-e|0,c);break a}Id(a,x[a>>2]+b|0);break a}Wt(a);fk(a,qk(a,b));wo(a,b,c)}hb=d+16|0}function Ki(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=d;g=Yh(e+8|0,b);b=hb-16|0;hb=b;d=x[e+12>>2];x[b+12>>2]=d;x[b+8>>2]=d;f=-1;d=Dr(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Ld(d);x[h>>2]=a;if(!a){break a}f=Dr(a,d,c,x[b+12>>2])}hb=b+16|0;Xh(g);hb=e+16|0;return f}function Hs(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!b){break a}i=Tb(a+1074312|0,73)?c- -64|0:c;c=120;g=Xi(a);j=g^-1;e=1;while(1){if(!c){break a}k=c;c=c>>>1|0;h=e+c|0;f=Og(a,h,i,d);if(!(f>>>0>b>>>0&j)&(!(!f|g)|b>>>0<=f>>>0)){continue}e=h+1|0;c=(c^-1)+k|0;continue}}return e}function uJ(a,b){var c=0;c=hb-32|0;hb=c;ih(c,b);x[23604]=0;U(1009,c+16|0,0,c|0);b=x[23604];x[23604]=0;a:{b:{if((b|0)!=1){x[23604]=0;R(1010,a|0,c+16|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}Gc(c+16|0);xb(c);hb=c+32|0;return}b=P()|0;break a}b=P()|0;Gc(c+16|0)}xb(c);T(b|0);p()}function Lh(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function w1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=ks(c);x[a>>2]=77280;x[d>>2]=77300;x[a+60>>2]=77340;x[a>>2]=77320;x[a+4>>2]=0;e=c;c=a+8|0;xn(e,c);x[a>>2]=77280;x[d>>2]=77300;x[23604]=0;Q(80,c|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){return a|0}a=P()|0;Ak(d);T(a|0);p()}function vW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-32|0;hb=e;x[e+24>>2]=d;x[e+28>>2]=c;x[23604]=0;X(159,e+8|0,b|0,e+28|0,e+24|0);c=x[23604];x[23604]=0;if((c|0)!=1){c=e+16|0;dv(c,x[e+8>>2],x[e+12>>2]);mg(a,c);be(c);be(e+8|0);be(b);hb=e+32|0;return}a=P()|0;be(b);T(a|0);p()}function p9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;Ve(b);e=d+40|0;Af(e,a,c);a=x[d+40>>2];c=d+8|0;Kf(c,1,xe(e),a);x[23604]=0;R(208,d+24|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){a=d+24|0;Ab(b,a);xb(a);Lc(d+40|0);hb=d- -64|0;break a}a=P()|0;Lc(d+40|0);T(a|0);p()}}function lO(a,b){var c=0,d=0,e=0,f=0;c=hb-96|0;hb=c;FP(b,c,c+96|0);b=0;while(1){if((b|0)==12){x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;hb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;continue}break}x[a+112>>2]=0}function Wl(a,b,c,d){var e=0,f=0,g=0;a:{f=D(b,872)+a|0;e=x[f+1075648>>2];if(!e){break a}if(!bj(y[e+31|0])){break a}g=y[e+34|0];if((g-1&255)>>>0>249){break a}a=x[(D(g,160)+a|0)+906140>>2];if(!a){break a}mb[x[x[a>>2]+92>>2]](a,e,c,d,b);if(c>>>0>250){break a}w[f+1075834>>1]=65535}}function MC(a,b,c,d){var e=0,f=0,g=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;e=d;d=x[a+1068>>2];w[e+(d<<1)>>1]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;f=a,g=Gd(z[x[a+1060>>2]+34>>1])+d|0,x[f+1068>>2]=g;x[a+1072>>2]=x[a+1072>>2]-1}function Bq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;c=f+12|0;wc(c,256);wc(c,65535);h=z[f+12>>1];eg(a,h);c=0;while(1){if((c|0)==(h|0)){hb=f+16|0}else{g=y[b+c|0];i=nl(x[a>>2],x[a+4>>2],c),j=(d|0)==(g|0)?-1:(e|0)==(g|0)?-2:g,w[i>>1]=j;c=c+1|0;continue}break}}function ZS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=hb+-64|0;hb=c;d=c+40|0;Af(d,a,32);a=x[c+40>>2];e=c+8|0;Kf(e,2,xe(d),a);x[23604]=0;R(208,c+24|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){Cm(c,b);a=c+24|0;ol(c,a);xb(a);Lc(c+40|0);hb=c- -64|0;break a}a=P()|0;Lc(c+40|0);T(a|0);p()}}function Or(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=ba(16)|0;if(!y[469681]){v[469681]=1}a=ec(c+8|0,a,93904);x[23604]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a=W(1042,d|0,c|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){ha(a|0,91828,1043);p()}a=P()|0;ca(d|0);T(a|0);p()}function $R(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=Ge(+(D(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){wc(e+12|0,10);a=D(y[x[e+12>>2]+27168|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Ge(733.8401379310345/f*1e4);break a}a=Ge(f/.264*1e4)}hb=e+16|0;return a}function Qe(a){var b=0,c=0;b=hb-32|0;hb=b;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;qC(b+9|0);x[a>>2]=x[b>>2];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;c=x[b+24>>2];x[a+20>>2]=x[b+20>>2];x[a+24>>2]=c;v[a+28|0]=y[b+28|0];hb=b+32|0}function DU(a){var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;e=Gb(a,31),f=0,v[e|0]=f;d=gi(a,Vn(a),0);v[c+15|0]=0;d=ji(a,d);Ql(d+a|0,Vn(a),c+15|0);while(1){if((b|0)!=(d|0)){a:{if(v[Gb(a,b)|0]>=32){if(y[Gb(a,b)|0]!=127){break a}}e=Gb(a,b),f=32,v[e|0]=f}b=b+1|0;continue}break}hb=c+16|0}function lea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-160|0;hb=b;d=-1;c=hb-16|0;hb=c;e=b+8|0;HQ(c+8|0,e);f=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(f|0)==(g|0);if(!a){GQ(e)}if(a){d=IQ(b+8|0)}hb=b+160|0;return d|0}function h8(a,b){a=a|0;b=b|0;var c=0;a:{b:{c=x[a+20>>2];b=x[c+4>>2];if((Rc(b,x[c+8>>2])|0)!=8){break b}if(Rb(b,9458,4)){break b}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;break a}yx(a,a)}ws(a)}function Cia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-624|0;hb=b;d=-1;c=hb-16|0;hb=c;e=b+8|0;tU(c+8|0,e);f=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(f|0)==(g|0);if(!a){sU(e)}if(a){d=uU(b+8|0)}hb=b+624|0;return d|0}function qR(a){var b=0;a:{if(Rb(a,15353,4)|((y[a+8|0]|y[a+9|0]<<8)-768&65535)>>>0<65280|(((y[a+112|0]|y[a+113|0]<<8)-65&65535)>>>0<65472|(y[a+106|0]|y[a+107|0]<<8)>>>0>256)){break a}if((y[a+122|0]|y[a+123|0]<<8)>>>0>255){break a}b=(y[a+124|0]|y[a+125|0]<<8)>>>0<4e3}return b}function JB(a,b,c){var d=0,e=0,f=0;d=hb+-64|0;hb=d;Ve(b);e=d+40|0;Af(e,a,c);a=x[d+40>>2];f=d+8|0;Kf(f,3,xe(e),a);x[23604]=0;R(208,d+24|0,f|0);e=x[23604];x[23604]=0;if((e|0)!=1){e=b;b=d+24|0;Ab(e,b);xb(b);Lc(d+40|0);hb=d- -64|0;return!c|(a|0)!=0}a=P()|0;Lc(d+40|0);T(a|0);p()}function xU(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=b;c=hb-16|0;hb=c;x[c+12>>2]=153391689;x[c+8>>2]=2147483647;e=Fb(c+12|0,c+8|0);hb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=iB(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[_c(d+8|0,d+12|0)>>2]}hb=d+16|0;return b}Sc();p()}function oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;e=d+40|0;Af(e,a,c);a=x[d+40>>2];c=d+8|0;Kf(c,2,xe(e),a);x[23604]=0;R(208,d+24|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){a=d+24|0;vm(b,a);xb(a);Lc(d+40|0);hb=d- -64|0;break a}a=P()|0;Lc(d+40|0);T(a|0);p()}}function aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-32|0;hb=b;d=-1;c=hb-16|0;hb=c;e=b+8|0;Ut(c+8|0,e);f=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(f|0)==(g|0);if(!a){FT(e)}if(a){d=GT(b+8|0)}hb=b+32|0;return d|0}function BK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[x[a+16>>2]+1074404>>2];x[23604]=0;x[c+12>>2]=0;U(857,a+4208|0,D(b,254)|0,c+12|0);b=x[23604];x[23604]=0;a:{if((b|0)==1){b=V(92520)|0;if((ib|0)!=(da(92520)|0)){break a}_(b|0)|0;$()}x[a+4220>>2]=0;hb=c+16|0;return}T(b|0);p()}function Aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;d=-1;c=hb-16|0;hb=c;e=b+8|0;nu(c+8|0,e);f=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(f|0)==(g|0);if(!a){sS(e)}if(a){d=tS(b+8|0)}hb=b+16|0;return d|0}function u1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-32|0;hb=e;Kg(e+24|0,b,c);b=mg(e+16|0,d);x[23604]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;rg(155,a,x[e+24>>2],x[e+28>>2],e+8|0);a=x[23604];x[23604]=0;if((a|0)!=1){be(d);hb=e+32|0;return}a=P()|0;be(d);T(a|0);p()}function rU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;e=d+40|0;Af(e,a,c);a=x[d+40>>2];c=d+8|0;Kf(c,2,xe(e),a);x[23604]=0;R(208,d+24|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){a=d+24|0;Bc(b,a);xb(a);Lc(d+40|0);hb=d- -64|0;break a}a=P()|0;Lc(d+40|0);T(a|0);p()}}function qB(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function m9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;e=d+40|0;Af(e,a,c);a=x[d+40>>2];c=d+8|0;Kf(c,1,xe(e),a);x[23604]=0;R(208,d+24|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){a=d+24|0;ze(b,a);xb(a);Lc(d+40|0);hb=d- -64|0;break a}a=P()|0;Lc(d+40|0);T(a|0);p()}}function _T(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=b;c=hb-16|0;hb=c;x[c+12>>2]=89478485;x[c+8>>2]=2147483647;e=Fb(c+12|0,c+8|0);hb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=WT(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[_c(d+8|0,d+12|0)>>2]}hb=d+16|0;return b}Sc();p()}function VR(a,b){var c=0,d=0;a:{c=x[b>>2];d=x[b+20>>2];if(!Qd(c,d)){break a}if(x[a+20>>2]==(d|0)){x[a+20>>2]=0;c=x[b>>2]}wc(a,c);c=z[a+34>>1]&-2|w[b+34>>1]&1;w[a+34>>1]=c;w[a+34>>1]=c&65471|z[b+34>>1]&64;if(!yg(a)){break a}vc(x[a+20>>2],x[b+20>>2],lj(x[a>>2],z[a+34>>1]))}}function CD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;g=x[b+8>>2];f=x[b>>2];Kg(e+16|0,c,d);c=x[x[f>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;mb[c|0](e+24|0,f,g,e+8|0);Kg(a,x[e+24>>2],x[e+28>>2]);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];hb=e+32|0}function xh(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;b=hb-16|0;hb=b;x[b+4>>2]=1;f=b,g=Jc(16),x[f+8>>2]=g;c=Co(x[b+8>>2]);x[c>>2]=43256;f=Mm(yc(c)),g=43388,x[f>>2]=g;c=d+8|0;e=Eo(b);Do(c,yc(e),e);Nm(b);hb=b+16|0;mg(a,c);be(c);hb=d+16|0;x[a+8>>2]=0;Yd(a+12|0);return a}function t$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function on(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Mia(a,b,10,0);e=lb;a=Jia(d,e,246,0)+a|0;c=c-1|0;v[c|0]=a|48;f=b>>>0>9;a=d;b=e;if(f){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;v[c|0]=D(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function np(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(re(c)){c=x[a+4>>2];d=ck(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=mj(c);if((c|0)!=10){break b}}Rl(a,d,1,d,d,0,0);c=d}d=x[a>>2];oe(a,c+1|0);break a}bf(a,c+1|0);d=a}a=c+d|0;id(a,b);id(a+1|0,0)}function LC(a,b,c,d){var e=0,f=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;v[x[a+1068>>2]+d|0]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;e=a,f=x[a+1068>>2]+Gd(z[x[a+1060>>2]+34>>1])|0,x[e+1068>>2]=f;x[a+1072>>2]=x[a+1072>>2]-1}function B2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;wn(c,a);if(x[b>>2]){Fc(b);a=x[b>>2];zt(b);Hb(a);d=Cb(b),e=0,x[d>>2]=e;x[b>>2]=0;x[b+4>>2]=0}x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=Cb(c);d=Cb(b),e=x[a>>2],x[d>>2]=e;x[a>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Of(c);hb=c+16|0}function jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=hb+-64|0;hb=c;d=c+40|0;Af(d,a,32);a=x[c+40>>2];e=c+8|0;Kf(e,1,xe(d),a);x[23604]=0;R(208,c+24|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){a=c+24|0;Bc(b,a);xb(a);Lc(c+40|0);hb=c- -64|0;break a}a=P()|0;Lc(c+40|0);T(a|0);p()}}function ee(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function Q9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(re(c)){c=x[a+4>>2];d=ck(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=1;c=mj(c);if((c|0)!=1){break b}}HF(a,d,1,d,d);c=d}d=x[a>>2];oe(a,c+1|0);break a}bf(a,c+1|0);d=a}a=(c<<2)+d|0;Ad(a,b);Ad(a+4|0,0)}function Kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;a=BP(d,a+8|0,b);b=x[a>>2];a:{while(1){if(x[a+4>>2]==(b|0)){break a}x[23604]=0;R(706,b|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){b=x[a>>2]+32|0;x[a>>2]=b;continue}break}b=P()|0;Hd(a);T(b|0);p()}Hd(a);hb=d+16|0}function G7(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=4104;a=0;d=x[b+8>>2];a:{if(d>>>0<4096){break a}c=x[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}x[b+12>>2]=e;x[b+8>>2]=d-c;a=e}if(!a){aa(6014,8916,88,7318);p()}hb=b+16|0;return a|0}function A9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(re(c)){c=x[a+4>>2];d=ck(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=mj(c);if((c|0)!=10){break b}}Xx(a,d,1,d,d,0);c=d}d=x[a>>2];oe(a,c+1|0);break a}bf(a,c+1|0);d=a}a=c+d|0;id(a,b);id(a+1|0,0)}function rs(a){var b=0,c=0,d=E(0);b=a+4232|0;c=y[b|0];if(c>>>0>=5){v[b|0]=0;c=0}if(v[a+4233|0]<0){v[a+4233|0]=127}b=v[a+4234|0];if((b|0)<0){v[a+4234|0]=127;b=127}a:{if((c|0)==3){d=E(E(1)-me(E(2),E(-E((b&255)+1|0))));break a}d=me(E(2),E(-E((b&255)>>>0)))}B[a+4224>>2]=d}function MB(a,b,c){var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;Af(e,a,c);a=x[d+40>>2];f=d+8|0;Kf(f,3,xe(e),a);x[23604]=0;R(208,d+24|0,f|0);e=x[23604];x[23604]=0;if((e|0)!=1){e=b;b=d+24|0;Bc(e,b);xb(b);Lc(d+40|0);hb=d- -64|0;return!c|(a|0)!=0}a=P()|0;Lc(d+40|0);T(a|0);p()}function Dv(a,b,c,d,e){var f=0,g=0;a:{f=hb+-64|0;hb=f;g=f+40|0;Af(g,a,e);a=x[f+40>>2];e=f+8|0;Kf(e,d,xe(g),a);x[23604]=0;R(208,f+24|0,e|0);a=x[23604];x[23604]=0;if((a|0)!=1){ec(f,b,c);a=f+24|0;ol(f,a);xb(a);Lc(f+40|0);hb=f- -64|0;break a}a=P()|0;Lc(f+40|0);T(a|0);p()}}function lQ(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;b=Bb(x[a>>2]);x[c+8>>2]=b;e=Bb(x[a+4>>2]);while(1){a:{d=Ob(b,e);if(!d){break a}a=z[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){w[b>>1]=65535;break b}if(a>>>0>63){break a}}b=x[Pe(c+8|0)>>2];continue}break}hb=c+16|0;return d^1}function IC(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;e=x[a+4>>2];f=e+b|0;x[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=x[a>>2];break a}a=x[a>>2];x[a+((f>>>0>=33?g>>>5|0:0)<<2)>>2]=0}vo(d+8|0,a,e);Qu(x[d+8>>2],x[d+12>>2],b,c);hb=d+16|0}function Hga(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c+8>>2]=b;a:{if(rc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!td(b)){break a}x[23604]=0;R(432,a|0,c+8|0);a=x[23604];x[23604]=0;d=b;if((a|0)!=1){break a}a=P()|0;bg(c+8|0);T(a|0);p()}bg(c+8|0);hb=c+16|0;return d|0}function qE(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=c;c=e+12|0;wc(c,d);wc(c,65535);f=z[e+12>>1];eg(a,f);c=0;while(1){if((c|0)==(f|0)){hb=e+16|0}else{d=y[b+c|0];g=nl(x[a>>2],x[a+4>>2],c),h=(d|0)==255?-1:(d|0)==254?-2:d,w[g>>1]=h;c=c+1|0;continue}break}}function ij(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Bb(x[b>>2]);f=Bb(x[b+4>>2]);e=hb-16|0;hb=e;x[e+8>>2]=d;while(1){a:{if(!Ob(d,f)){break a}if(bU(c,x[d>>2],x[d+4>>2])){break a}d=x[pm(e+8|0)>>2];continue}break}hb=e+16|0;if(tc(d,Bb(x[b+4>>2]))){xh(a);return}qm(a,d)}function fU(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[Ye(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[Ye(d+13|0,d+12|0)|0]}hb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function Oo(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function Oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=ff(a,c);_d(e,x[a+28>>2]);a:{b:{if(!f){c=-1;if(!fd(a,5)){break b}break a}c=x[f+8>>2]}d=x[a+28>>2];c:{d:{switch(c+1|0){case 0:case 2:$h(d,b);break c;default:break d}}PS(d,b,c)}d=f}_e(a,d);hb=e+16|0}function C$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=nh(v[b|0]),e=x[x[a>>2]+52>>2],mb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=Yj(b,1,c,x[a+32>>2])}return c|0}function uh(a,b){var c=0,d=0,e=0;a:{if(!(v[a+480180|0]&1|b)){break a}e=x[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function _$(a){a=a|0;var b=0,c=0,d=0;c=x[a+44>>2];b=x[a+24>>2];if(c>>>0<b>>>0){x[a+44>>2]=b;c=b}d=-1;a:{if(!(y[a+48|0]&8)){break a}b=x[a+16>>2];if(b>>>0<c>>>0){jn(a,x[a+8>>2],x[a+12>>2],c);b=x[a+16>>2]}a=x[a+12>>2];if(a>>>0>=b>>>0){break a}d=nh(v[a|0])}return d|0}function Gr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]>=0;b:{c=x[b+4>>2];c:{if(!c){Aw(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function lC(a,b){var c=0,d=0;c=hb-16|0;hb=c;Pc(c+8|0,a);x[23604]=0;a=S(18,x[c+8>>2])|0;d=x[23604];x[23604]=0;a:{if((d|0)==1){break a}x[23604]=0;a=Q(19,a|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}$b(c+8|0);hb=c+16|0;return a}a=P()|0;$b(c+8|0);T(a|0);p()}function t_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;Pc(g,x[d+28>>2]);x[23604]=0;b=S(1083,x[g>>2])|0;d=x[23604];x[23604]=0;if((d|0)!=1){$b(g);TF(a,f+24|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=P()|0;$b(g);T(a|0);p()}function s_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;Pc(g,x[d+28>>2]);x[23604]=0;b=S(1083,x[g>>2])|0;d=x[23604];x[23604]=0;if((d|0)!=1){$b(g);SF(a,f+16|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=P()|0;$b(g);T(a|0);p()}function UC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=hb-16|0;hb=d;b:{c:{if(!b){b=a;a=Pb(c);ug(b,a,Eb(x[c+4>>2],y[c+11|0])+a|0);break c}IL(d,c);x[23604]=0;U(43,a|0,b|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}Gc(d)}hb=d+16|0;break a}a=P()|0;Gc(d);T(a|0);p()}}function tj(a,b){var c=0,d=0,e=0,f=0,g=0;g=x[a+8>>2];while(1){if((b|0)!=(e|0)){d=x[a>>2];if(d){c=x[a+4>>2]}else{x[a>>2]=8;c=g;d=x[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;x[a+12>>2]=c}d=8;c=y[c|0]}x[a>>2]=d-1;x[a+4>>2]=c>>>1;f=c&1|f<<1;e=e+1|0;continue}break}return f}function ez(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;a=sz(d,a,b);b=x[a+4>>2];e=x[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[23604]=0;R(706,b|0,c|0);f=x[23604];x[23604]=0;if((f|0)!=1){b=b+32|0;x[a+4>>2]=b;continue}break}b=P()|0;ic(a);T(b|0);p()}ic(a);hb=d+16|0}function bO(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=94424;x[a+20>>2]=0;x[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;x[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;x[a+8>>2]=d;x[a+32>>2]=d>>>0>=31?-1:-1>>>31-d|0;x[a+28>>2]=b>>>0>=c>>>0?-1>>>32-d|0:0;x[a+16>>2]=(D(c,d)-b|0)+c;return a}function Wf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}dj(e+8|0,b);b=x[e+8>>2];x[a>>2]=b;d=x[e+12>>2]}c=(c<<2)+b|0;x[a+4>>2]=c;x[a+8>>2]=c;f=yc(a),g=(d<<2)+b|0,x[f>>2]=g;hb=e+16|0;return a|0}function Bk(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=Ur(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;Pc(g,x[d+28>>2]);x[23604]=0;b=S(18,x[g>>2])|0;d=x[23604];x[23604]=0;if((d|0)!=1){$b(g);XF(a,f+24|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=P()|0;$b(g);T(a|0);p()}function y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;Pc(g,x[d+28>>2]);x[23604]=0;b=S(18,x[g>>2])|0;d=x[23604];x[23604]=0;if((d|0)!=1){$b(g);WF(a,f+16|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=P()|0;$b(g);T(a|0);p()}function y7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;x[a+4>>2]=b;x[a>>2]=0;b=Zs(a+8|0,d);x[23604]=0;Q(867,a+20|0,c|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&224|25;return a|0}a=P()|0;Db(b);T(a|0);p()}function vC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=hb-16|0;hb=d;b:{c:{if(!b){b=a;a=Pb(c);ug(b,a,Eb(x[c+4>>2],y[c+11|0])+a|0);break c}HN(d,b,c);x[23604]=0;R(49,a|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}Gc(d)}hb=d+16|0;break a}a=P()|0;Gc(d);T(a|0);p()}}function dT(a){var b=0,c=0,d=0,e=0;d=y[a+32|0]|y[a+33|0]<<8;e=y[a+38|0]|y[a+39|0]<<8;c=y[a+34|0]|y[a+35|0]<<8;b=c+(y[a+36|0]|y[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=(c>>>0>b>>>0?a+1|0:a)<<2|b>>>30;c=d;d=b<<2;b=c+d|0;lb=b>>>0<d>>>0?a+1|0:a;return b}function _z(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-1024|0;hb=e;d=hb-16|0;hb=d;Xz(d+8|0,e);f=x[d+12>>2];mc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){bc(a,x[d+12>>2])}hb=d+16|0;if((f|0)==(g|0)){h=Yz(e,c)>>>0<=b>>>0}hb=e+1024|0;return h}function Vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-208|0;hb=b;d=-1;c=hb-16|0;hb=c;gQ(c+8|0,b);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(e|0)==(f|0);if(!a){fQ(b)}if(a){d=hQ(b)}hb=b+208|0;return d|0}function Qm(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(!b){b=0;break a}d=b;b=G(b);vf(c,d,0,0,0,b+81|0);d=0+x[c+8>>2]|0;b=(x[c+12>>2]^65536)+(16414-b<<16)|0;f=e>>>0>d>>>0?b+1|0:b;e=x[c+4>>2];b=x[c>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+8>>2]=d;x[a+12>>2]=f;hb=c+16|0}function Iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-160|0;hb=b;d=-1;c=hb-16|0;hb=c;nT(c+8|0,b);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(e|0)==(f|0);if(!a){mT(b)}if(a){d=oT(b)}hb=b+160|0;return d|0}function e8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0),f=0,g=E(0);d=hb-16|0;hb=d;f=d,g=E(E(mb[x[x[a>>2]+48>>2]](a,b))+c),B[f+12>>2]=g;c=E(0);e=B[d+12>>2];a:{if(!(e<E(0))){c=E(1);if(!(e>E(1))){break a}}B[d+12>>2]=c}mb[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);hb=d+16|0}function ZR(a,b,c){var d=0,e=0;e=Eb(x[a+4>>2],y[a+11|0]);d=Oc(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Pb(a);if(e){dl(c+d|0,d,e);b=(b>>>0>=d>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}b=dl(d,b,c);c=c+e|0;Sg(a,c);id(b+c|0,0);return a}Jp(a,d,(c+e|0)-d|0,e,0,0,c,b)}return a}function Sy(a,b,c,d){var e=0,f=0,g=0;e=Sd(a);a:{if(e){f=jc(a);while(1){a=e;e=z[a+16>>1];g=x[a+20>>2];if(Tk(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Tk(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=jc(a);f=a}x[b>>2]=a;return f}function BM(a,b,c,d){var e=0,f=0,g=0;v[c+851|0]=y[c+851|0]|64;e=a?y[c+813|0]:0;g=(d|0)<0?e:0-e|0;f=(+(a>>>0)+1)*+(d|0)/+(b>>>0);a:{if(F(f)<2147483648){e=~~f;break a}e=-2147483648}x[c+852>>2]=g+(e+x[c+852>>2]|0);b=(a+1|0)==(b|0)?d:e;a=b>>31;v[c+813|0]=(a^b)-a}function yp(a,b,c,d){var e=0,f=0,g=0;a:{e=Vk(a,b);if((e|0)==255){break a}g=x[a>>2];if(Lj(g)){break a}f=Zd(a+318|0,e);e=zO(e);if(v[Gb(f,10)|0]&1|d){Qg(g,x[a+4>>2],b,e- -64|0,yO(c,y[Gb(f,2)|0]))}if(d){break a}Qg(x[a>>2],x[a+4>>2],b,e+67|0,yO(c,y[Gb(f,3)|0]))}}function sy(a,b,c,d){var e=0,f=0,g=0;e=Sd(a);a:{if(e){f=jc(a);while(1){a=e;e=y[a+16|0];g=x[a+20>>2];if(Fn(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Fn(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=jc(a);f=a}x[b>>2]=a;return f}function BW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;f=x[b+8>>2];a:{if(f>>>0<=c>>>0){c=x[d>>2];b=0;break a}x[e+12>>2]=f-c;x[e+8>>2]=x[d+4>>2];c=x[b+4>>2]+c|0;f=c;b=x[Fb(e+12|0,e+8|0)>>2];g=c+b|0;c=x[d>>2];pi(f,g,c)}hc(a,c,b);hb=e+16|0}function kE(a,b,c,d){var e=0,f=0;a:{e=hb+-64|0;hb=e;f=e+40|0;Af(f,a,d);a=x[e+40>>2];d=e+8|0;Kf(d,c,xe(f),a);x[23604]=0;R(208,e+24|0,d|0);a=x[23604];x[23604]=0;if((a|0)!=1){a=e+24|0;ze(b,a);xb(a);Lc(e+40|0);hb=e- -64|0;break a}a=P()|0;Lc(e+40|0);T(a|0);p()}}function FV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-48|0;hb=b;d=-1;c=hb-16|0;hb=c;hC(c+8|0,b);e=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(e|0)==(f|0);if(!a){gC(b)}if(a){d=iC(b)}hb=b+48|0;return d|0}function Dga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;Ve(b);v[c+15|0]=0;a:{if(!Eh(a,c+15|0)){break a}f=y[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}v[c+14|0]=0;if(Eh(a,c+14|0)){np(b,v[c+14|0]);e=e+1|0;continue}break}d=0}hb=c+16|0;return d|0}function A6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=fi(a,b,c,d);x[a>>2]=46996;b=a+4208|0;e=zb(b,0),f=1017370378,x[e>>2]=f;e=zb(b,1),f=0,x[e>>2]=f;x[23604]=0;R(851,a+44|0,2);b=x[23604];x[23604]=0;if((b|0)!=1){ei(a);return a|0}b=P()|0;uf(a);T(b|0);p()}function q$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function lB(a,b,c){var d=0,e=0;d=hb+-64|0;hb=d;Ve(b);e=d+40|0;Af(e,a,c);a=x[d+40>>2];c=d+8|0;Kf(c,2,xe(e),a);x[23604]=0;R(208,d+24|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){a=d+24|0;Ab(b,a);xb(a);Lc(d+40|0);hb=d- -64|0;return}a=P()|0;Lc(d+40|0);T(a|0);p()}function Ofa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){c=hb-16|0;hb=c;if(bh(1073741823)>>>0<b>>>0){Sc();p()}HC(c+8|0,b);d=x[c+8>>2];x[a+4>>2]=d;x[a>>2]=d;e=Cb(a),f=(x[c+12>>2]<<2)+d|0,x[e>>2]=f;hb=c+16|0;sA(a,b)}return a|0}function O1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=hb-16|0;hb=c;x[c+4>>2]=1;e=c,f=Jc(52),x[e+8>>2]=f;d=x[c+8>>2];x[23604]=0;Q(1030,d|0,b|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){b=a;a=Eo(c);Do(b,yc(a),a);Nm(c);hb=c+16|0;break a}a=P()|0;Nm(c);T(a|0);p()}}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;v[c+40|0]=b;b=c+40|0;Dq(c+16|0,b);d=x[c+16>>2];Dq(c+8|0,b);b=ug(c+24|0,d,x[c+8>>2]+1|0);x[23604]=0;Q(709,a|0,b|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){xb(b);hb=c+48|0;return}a=P()|0;xb(b);T(a|0);p()}function I8(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;w[c+40>>1]=b;b=c+40|0;ql(c+16|0,b);d=x[c+16>>2];ql(c+8|0,b);b=ug(c+24|0,d,x[c+8>>2]+2|0);x[23604]=0;Q(709,a|0,b|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){xb(b);hb=c+48|0;return}a=P()|0;xb(b);T(a|0);p()}function bC(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;a=Eu(c,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[23604]=0;Y(214,b|0);e=x[23604];x[23604]=0;if((e|0)!=1){b=b+20|0;x[a+4>>2]=b;continue}break}b=P()|0;ic(a);T(b|0);p()}ic(a);hb=c+16|0}function AV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){c=hb-16|0;hb=c;if(bh(214748364)>>>0<b>>>0){Sc();p()}_B(c+8|0,b);d=x[c+8>>2];x[a+4>>2]=d;x[a>>2]=d;e=Cb(a),f=D(x[c+12>>2],20)+d|0,x[e>>2]=f;hb=c+16|0;bC(a,b)}return a|0}function Aw(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){mb[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function iU(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[Ye(d+15|0,d+14|0)|0]}a=e;hb=d+16|0;return a&255}function Jea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(!Qb(x[b>>2],x[b+8>>2],8)){w[c>>1]=0;b=4;while(1){if(b){d=y[c|0]|y[c+1|0]<<8;v[a|0]=d;v[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}break a}Im(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function r_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=hb-16|0;hb=a;x[a+8>>2]=b;Pc(a,x[d+28>>2]);x[23604]=0;b=S(1083,x[a>>2])|0;d=x[23604];x[23604]=0;if((d|0)!=1){$b(a);RF(f+20|0,a+8|0,c,e,b);hb=a+16|0;return x[a+8>>2]}b=P()|0;$b(a);T(b|0);p()}function m2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[b+8>>2];e=x[b+4>>2];f=x[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(e|0)){break b}while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{c=x[(a<<2)+f>>2]+(b<<3)|0;x[c>>2]=0;x[c+4>>2]=0;b=b+1|0;continue}}break}}function lA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fS(a,b);Yc(a,dc(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))+504|0);eS(a,d);a:{b=dc(y[b+32|0]|y[b+33|0]<<8|(y[b+34|0]<<16|y[b+35|0]<<24));if(!b){break a}if(!Yc(a,b)){break a}nA(a,c);return}Zb(c,0,80)}function Ue(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;e=hb-16|0;hb=e;a:{if(b>>>0<2147483632){b:{if(io(b)){bf(d,b);break b}si(e+8|0,Xj(b)+1|0);f=x[e+8>>2];Ad(d,f);cg(d,x[e+12>>2]);oe(d,b);d=f}id(gl(d,b,c)+b|0,0);hb=e+16|0;break a}dg();p()}return a|0}function z1(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;if(!y[a+8|0]){Fi(a+12|0,x[a+4>>2]);ke(b+24|0,x[a+12>>2],x[a+16>>2]);c=x[x[a>>2]+40>>2];d=x[b+28>>2];x[b+8>>2]=x[b+24>>2];x[b+12>>2]=d;mb[c|0](b+16|0,a,0,b+8|0);v[a+8|0]=1}hb=b+32|0;return x[a+12>>2]}function x9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{if((b|0)!=437){if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}c:{if((b|0)!=28591){if((b|0)==28605){break c}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=5;break a}d=8}vC(a,d,c)}function If(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!y[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function Bl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}si(e+8|0,b);b=x[e+8>>2];x[a>>2]=b;d=x[e+12>>2]}c=b+c|0;x[a+4>>2]=c;x[a+8>>2]=c;f=yc(a),g=b+d|0,x[f>>2]=g;hb=e+16|0;return a|0}function x_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=hb-16|0;hb=a;x[a+8>>2]=b;Pc(a,x[d+28>>2]);x[23604]=0;b=S(18,x[a>>2])|0;d=x[23604];x[23604]=0;if((d|0)!=1){$b(a);VF(f+20|0,a+8|0,c,e,b);hb=a+16|0;return x[a+8>>2]}b=P()|0;$b(a);T(b|0);p()}function OB(a,b,c){var d=0,e=0;d=hb+-64|0;hb=d;e=d+40|0;Af(e,a,c);a=x[d+40>>2];c=d+8|0;Kf(c,3,xe(e),a);x[23604]=0;R(208,d+24|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){a=d+24|0;vm(b,a);xb(a);Lc(d+40|0);hb=d- -64|0;return}a=P()|0;Lc(d+40|0);T(a|0);p()}function s7(a,b){a=a|0;b=b|0;var c=0,d=0;b=hb-16|0;hb=b;a:{b:{d=x[a+20>>2];c=x[d+4>>2];if((Rc(c,x[d+8>>2])|0)!=7){break b}if(Rb(c,9458,4)){break b}c=Bb(c);d=Bb(x[x[a+20>>2]+8>>2]);po(b+8|0,a+4228|0);Xt(c,d,x[b+8>>2]);break a}yx(a,a)}rs(a);hb=b+16|0}function hF(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[b>>2]=0;v[c+15|0]=0;Eh(a,c+15|0);d=y[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){x[b>>2]=e;if((d|0)==(f|0)){hb=c+16|0}else{v[c+15|0]=0;Eh(a,c+15|0);d=d+1|0;e=x[b>>2]|y[c+15|0]<<(d<<3)-2;continue}break}}function hQ(a){var b=0;a:{if(Rb(a,14860,4)){break a}if(Lb(y[a+4|0]|y[a+5|0]<<8)>>>0>2|y[a+6|0]>128){break a}if(Lb(y[a+200|0]|y[a+201|0]<<8)>>>0>3999){break a}if(!Lb(y[a+140|0]|y[a+141|0]<<8)){break a}b=(Lb(y[a+148|0]|y[a+149|0]<<8)|0)==50}return b}function KD(){var a=0,b=0,c=0;b=hb-16|0;hb=b;a=Xb(b,14892);a:{if(!Qc(x[a+4>>2],y[a+11|0])){break a}c=1;if((ng(a,14506)|0)!=-1){break a}if((ng(a,16647)|0)!=-1){break a}if((ng(a,13572)|0)!=-1){break a}c=(ng(a,13615)|0)!=-1}xb(a);hb=b+16|0;return c|0}function tH(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=tH(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function cN(a,b,c,d){var e=0;e=-2147483648;e=!c|!(v[c+15|0]&1)?e:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){e=z[d+28>>1];break b}if((e|0)==-2147483648){break a}}Bp(b,e,a);if(!Tb(a+1074312|0,10)|y[a+480209|0]&64){break a}x[b+88>>2]=x[b+88>>2]&-257}}function HS(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-16|0;hb=d;f=hb-16|0;hb=f;g=a;a=D((a-b|0)/-6|0,6)+c|0;FS(f+8|0,b,g,a);yd(d+8|0,b,Ib(f,Tp(c,a)));hb=f+16|0;a=x[d+8>>2];x[d>>2]=x[d+12>>2];yd(e+8|0,a,d);hb=d+16|0;hb=e+16|0;return x[e+12>>2]}function ND(a,b,c,d){var e=0,f=0,g=0;a:{if((c|0)==(d|0)){break a}b:{d=d-c|0;if((d|0)>(b-a|0)){break b}f=1-d|0;g=y[c|0];while(1){e=b-a|0;if((d|0)>(e|0)){break b}a=Mp(a,f+e|0,g);if(!a){break b}if(!Dn(a,c,d)){break a}a=a+1|0;continue}}a=b}return a}function xd(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;d=Ib(c+24|0,x[a+4>>2]);e=Ib(c+16|0,x[a>>2]);f=Ib(c+8|0,x[b+4>>2]);g=b,h=eP(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;qc(a,b+4|0);qc(a+4|0,b+8|0);qc(Cb(a),yc(b));x[b>>2]=x[b+4>>2];hb=c+32|0}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=ff(a,c);_d(e,x[a+28>>2]);a:{b:{if(!f){c=-1;if(!fd(a,5)){break b}break a}c=x[f+8>>2]}d=x[a+28>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){Uj(d,b);break c}gH(d,b,c)}d=f}_e(a,d);hb=e+16|0}function mO(a){var b=0,c=0,d=0,e=0,f=0;b=hb-16|0;hb=b;c=a;d=x[a>>2];f=ch(d,x[a+4>>2]);a=Bb(d);x[b+8>>2]=a;e=+(f>>>0);c=Bb(x[c+4>>2]);while(1){if(Ob(a,c)){C[a>>3]=C[a>>3]/e;C[a+8>>3]=C[a+8>>3]/e;a=x[Yn(b+8|0)>>2];continue}else{hb=b+16|0}break}}function kD(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function hi(a){var b=0,c=0,d=0,e=0;b=Be(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=Be(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}a=(e|0)<0;b=a?-2147483648:c;return a?(c|0)>=0?0-c|0:b:b}function No(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}
function Zz(a,b,c){var d=0;d=hb-16|0;hb=d;w[d+12>>1]=c;w[d+14>>1]=b;b=Bb(x[a>>2]);c=Bb(x[a+4>>2]);a=hb-16|0;hb=a;x[a+8>>2]=b;while(1){if(Ob(b,c)){if(z[b>>1]==z[d+14>>1]){w[b>>1]=z[d+12>>1]}b=x[Pe(a+8|0)>>2];continue}break}hb=a+16|0;hb=d+16|0}function Vb(){var a=0;a=x[23477];x[23604]=0;Z(a|0);a=x[23604];x[23604]=0;a:{if((a|0)!=1){x[23604]=0;Z(1173);a=x[23604];x[23604]=0;if((a|0)!=1){break a}}_(V(0)|0)|0;x[23604]=0;Z(1173);a=x[23604];x[23604]=0;if((a|0)!=1){break a}V(0)|0;Vb()}p()}function rN(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=x[a+104>>2];a:{if(!c){break a}c=x[c>>2];if(!c){break a}x[a+76>>2]=c;x[a+88>>2]=x[a+88>>2]&-131|128;x[d+12>>2]=b<<8;x[d+8>>2]=c-1;b=c+(x[Fb(d+12|0,d+8|0)>>2]^-1)|0;x[a>>2]=0;x[a+4>>2]=b}hb=d+16|0}function nK(a,b,c){var d=0,e=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return E((e?b^-1|e:b)|0)}function VC(a){var b=0,c=0;a:{if(Rb(a,14038,4)){break a}if(Rb(a+8|0,13959,4)){break a}b=dc(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24));if(!b){break a}c=(dc(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function Ng(a,b){var c=0,d=0,e=0;d=y[a+11|0];c=Eb(x[a+4>>2],d);a:{if((c|0)!=(Eb(x[b+4>>2],y[b+11|0])|0)){break a}a=Pb(a);b=Pb(b);if(!re(d)){while(1){e=!c;if(!c|y[a|0]!=y[b|0]){break a}b=b+1|0;a=a+1|0;c=c-1|0;continue}}e=!Dn(a,b,c)}return e}function yM(a,b){a=tM(a);tM(a+368680|0);if(b){sM(a,1);return}if(!y[463288]){yM(94584,1);v[463288]=1}Zk(225696,291232,a+131112|0);Zk(291232,356768,a+196648|0);Zk(356768,422304,a+262184|0);Zk(94608,225696,a+24|0);vc(a+327720|0,422304,40960)}function uha(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;v[b+30|0]=0;w[b+28>>1]=0;c=ec(b+8|0,b+28|0,3);mc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=3){break a}if(Rb(b+28|0,14610,3)){break a}bc(a,3);d=1}hb=b+32|0;return d|0}function oda(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;w[b+28>>1]=0;x[b+24>>2]=0;c=ec(b+8|0,b+24|0,6);mc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=6){break a}if(Rb(b+24|0,3856,6)){break a}bc(a,6);d=1}hb=b+32|0;return d|0}function oQ(a){var b=0,c=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=mQ(a+20|0)}return c}function lE(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=c;c=e+12|0;wc(c,d);wc(c,65535);d=z[e+12>>1];eg(a,d);c=0;while(1){if((c|0)==(d|0)){hb=e+16|0}else{f=y[b+c|0];g=nl(x[a>>2],x[a+4>>2],c),h=f,w[g>>1]=h;c=c+1|0;continue}break}}function fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;vA(e,c);Cj(d+8|0,e);x[23604]=0;X(100,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23604];x[23604]=0;if((a|0)!=1){Db(d+16|0);hb=d+32|0;break a}a=P()|0;Db(d+16|0);T(a|0);p()}}function cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;bp(e,c);Cj(d+8|0,e);x[23604]=0;X(280,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23604];x[23604]=0;if((a|0)!=1){Db(d+16|0);hb=d+32|0;break a}a=P()|0;Db(d+16|0);T(a|0);p()}}function bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;Ho(e,c);Cj(d+8|0,e);x[23604]=0;X(100,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23604];x[23604]=0;if((a|0)!=1){Db(d+16|0);hb=d+32|0;break a}a=P()|0;Db(d+16|0);T(a|0);p()}}function ae(a,b){var c=0,d=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if(x[a+8>>2]>=(d|0)){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=y[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function JN(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+3|0]|y[b+4|0]<<8|(y[b+5|0]<<16|y[b+6|0]<<24);v[a+3|0]=b;v[a+4|0]=b>>>8;v[a+5|0]=b>>>16;v[a+6|0]=b>>>24}function DV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;Au(e,c);Cj(d+8|0,e);x[23604]=0;X(100,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23604];x[23604]=0;if((a|0)!=1){Db(d+16|0);hb=d+32|0;break a}a=P()|0;Db(d+16|0);T(a|0);p()}}
function AA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Sb(a+8|0);x[23604]=0;d=S(188,b|0)|0;e=x[23604];x[23604]=0;b:{if((e|0)==1){break b}x[23604]=0;U(230,a|0,b|0,d|0);a=x[23604];x[23604]=0;if((a|0)==1){break b}break a}a=P()|0;fc(c);T(a|0);p()}}function mU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;AB(e,c);Cj(d+8|0,e);x[23604]=0;X(100,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23604];x[23604]=0;if((a|0)!=1){Db(d+16|0);hb=d+32|0;break a}a=P()|0;Db(d+16|0);T(a|0);p()}}function iv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;Kg(e+8|0,b,c);x[23604]=0;Na(157,a|0,x[e+8>>2],x[e+12>>2]);b=x[23604];x[23604]=0;if((b|0)!=1){x[a+8>>2]=0;mg(a+12|0,d);be(d);hb=e+16|0;return a|0}a=P()|0;be(d);T(a|0);p()}function Uv(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;w[b>>1]=0;v[c+15|0]=0;Eh(a,c+15|0);d=y[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){w[b>>1]=e;if(d>>>0>=f>>>0){hb=c+16|0}else{v[c+15|0]=0;Eh(a,c+15|0);e=z[b>>1]|y[c+15|0]<<7;d=1;continue}break}}function wl(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}OD(e+8|0,b);b=x[e+8>>2];x[a>>2]=b;d=x[e+12>>2]}c=D(c,12)+b|0;x[a+4>>2]=c;x[a+8>>2]=c;f=yc(a),g=D(d,12)+b|0,x[f>>2]=g;hb=e+16|0;return a}function mia(a,b){a=a|0;b=b|0;var c=0;b=hb-32|0;hb=b;c=-1;a:{if(!_A(a,b+16|0)){break a}c=0;if(!TT(b+16|0)){break a}if(!Rb(b+16|0,14024,4)){c=-1;if(!ad(a,4)){break a}}c=-1;if(!sj(a,b+8|0)){break a}c=!Rb(b+8|0,14e3,4)}hb=b+32|0;return c|0}function QA(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}_B(e+8|0,b);b=x[e+8>>2];x[a>>2]=b;d=x[e+12>>2]}c=D(c,20)+b|0;x[a+4>>2]=c;x[a+8>>2]=c;f=yc(a),g=D(d,20)+b|0,x[f>>2]=g;hb=e+16|0;return a}function HB(a){var b=0,c=0,d=0,e=0;c=y[a+2|0];b=c+(y[a+5|0]|y[a+6|0]<<8)|0;c=(b>>>0<c>>>0?1:d)<<1|b>>>31;d=b<<1;b=c;a=y[a+3|0]|y[a+4|0]<<8;c=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+47|0;lb=b>>>0<47?a+1|0:a;return b}function Gz(a,b){var c=0,d=0,e=0,f=0;c=a&16711680;d=c>>>8|0;e=c<<24;c=a&-16777216;f=c>>>24|0;c=e|c<<8;e=d|f|(a<<24|(a&65280)<<8);d=0;lb=e|(d|d);return((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|c}function $M(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;_u(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){v[b+2|0]=0;v[b|0]=0;v[b+1|0]=0}}function qN(a,b){var c=0,d=0;a:{if(!(v[a+851|0]&1)){break a}c=x[a+104>>2];if(!c){break a}d=x[c>>2];if(!d){break a}x[a+76>>2]=d;x[a>>2]=0;x[a+4>>2]=d-1;c=x[a+88>>2];x[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}x[a+84>>2]=d;x[a+80>>2]=0}}function Zh(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function pj(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}Tu(e+8|0,b);b=x[e+8>>2];x[a>>2]=b;d=x[e+12>>2]}c=(c<<1)+b|0;x[a+4>>2]=c;x[a+8>>2]=c;f=yc(a),g=(d<<1)+b|0,x[f>>2]=g;hb=e+16|0;return a}function ft(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}CP(e+8|0,b);b=x[e+8>>2];x[a>>2]=b;d=x[e+12>>2]}c=(c<<5)+b|0;x[a+4>>2]=c;x[a+8>>2]=c;f=yc(a),g=(d<<5)+b|0,x[f>>2]=g;hb=e+16|0;return a}function Tq(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}mD(e+8|0,b);b=x[e+8>>2];x[a>>2]=b;d=x[e+12>>2]}c=(c<<3)+b|0;x[a+4>>2]=c;x[a+8>>2]=c;f=yc(a),g=(d<<3)+b|0,x[f>>2]=g;hb=e+16|0;return a}function LS(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}IS(e+8|0,b);b=x[e+8>>2];x[a>>2]=b;d=x[e+12>>2]}c=D(c,6)+b|0;x[a+4>>2]=c;x[a+8>>2]=c;f=yc(a),g=D(d,6)+b|0,x[f>>2]=g;hb=e+16|0;return a}function Cv(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;Df(a+12|0,d);a:{if(!b){b=0;x[a>>2]=0;d=0;break a}_D(e+8|0,b);b=x[e+8>>2];x[a>>2]=b;d=x[e+12>>2]}c=(c<<4)+b|0;x[a+4>>2]=c;x[a+8>>2]=c;f=yc(a),g=(d<<4)+b|0,x[f>>2]=g;hb=e+16|0;return a}function n2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[b+8>>2];d=x[b+4>>2];e=x[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(d|0)){break b}while(1)if((b|0)==(c|0)){a=a+1|0;continue a}else{f=Kp(e,a,b),g=0,x[f>>2]=g;b=b+1|0;continue}}break}}function Jga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;while(1){a:{d=x[a>>2];if(rc(d,x[a+4>>2])>>>0>e>>>0){lg(c,x[zb(d,e)>>2]+40|0);d=Xp(c,b);xb(c);if(!d){break a}f=x[zb(x[a>>2],e)>>2]}hb=c+16|0;return f|0}e=e+1|0;continue}}function qO(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){hO(a,b);d=hb-16|0;hb=d;c=Jo(d,a,b);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){ic(c);hb=d+16|0}else{Uk(b,0,0);b=b+16|0;x[c+4>>2]=b;continue}break}}return a}function pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;tA(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Zb(b,0,4896)}return a|0}function o7(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if(Rb(b,9458,4)){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4228>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4232>>2]=c;rs(a)}}function _7(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if(Rb(b,9458,4)){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;ws(a)}}function H2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-32|0;hb=d;Hk(d,c);c=d+16|0;x[c>>2]=b;dd(c+4|0,d);x[23604]=0;R(1008,a+4|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){Tj(d+16|0);xb(d);hb=d+32|0;return}a=P()|0;Tj(d+16|0);xb(d);T(a|0);p()}function Af(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Sb(a+8|0);x[23604]=0;U(230,a|0,b|0,c|0);c=x[23604];x[23604]=0;a:{if((c|0)!=1){a=x[a>>2];x[23604]=0;Q(174,b|0,a|0)|0;a=x[23604];x[23604]=0;if((a|0)!=1){break a}}a=P()|0;fc(d);T(a|0);p()}}function AN(a,b,c){var d=0;d=x[b+48>>2]+1|0;x[b+52>>2]=d;a:{if(A[ac(x[a+484344>>2],z[b+70>>1])+12>>2]>d>>>0){break a}if(!c){w[b+74>>1]=z[b+72>>1]+1}x[b+52>>2]=0;if(!Tb(a+1074312|0,63)){break a}a=x[b+56>>2];x[b+56>>2]=0;x[b+52>>2]=a}}function a_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Zm(a);e=Eb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Pb(a);_h(d+(e<<2)|0,b,c);b=c+e|0;Sg(a,b);Ad(d+(b<<2)|0,0);return a|0}dF(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function J$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((mb[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=Yj(b,4,c,x[a+32>>2])}return c|0}function IG(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;f=Ib(e+8|0,x[x[b>>2]-12>>2]+b|0),g=b,x[f+4>>2]=g;yk(x[e+12>>2],c,d);b=hb-16|0;hb=b;x[b+12>>2]=x[x[e+12>>2]+4>>2];x[b+8>>2]=0;d=x[Je(b+8|0,b+12|0)>>2];hb=b+16|0;hc(a,c,d);hb=e+16|0}function vz(a,b){var c=0,d=0,e=0,f=0;w[a+24>>1]=0;x[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(F(d)<2147483648){b=~~d;break a}b=-2147483648}x[a+16>>2]=b;x[a>>2]=0;x[a+4>>2]=0;e=a,f=NP(c-+(b<<2)),x[e+8>>2]=f;x[a+12>>2]=lb;return a}function ty(a,b,c){var d=0,e=0;d=Sd(a);a:{if(d){e=jc(a);while(1){a=d;d=y[a+16|0];if(Gn(c,d)){e=a;d=x[a>>2];if(d){continue}break a}if(!Gn(d,c)){break a}e=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=jc(a);e=a}x[b>>2]=a;return e}function eP(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-16|0;hb=d;f=hb-16|0;hb=f;g=a;a=(b-a|0)+c|0;SO(f+8|0,b,g,a);yd(d+8|0,b,Ib(f,a));hb=f+16|0;a=x[d+8>>2];x[d>>2]=x[d+12>>2];yd(e+8|0,a,d);hb=d+16|0;hb=e+16|0;return x[e+12>>2]}function Ym(a,b){var c=0,d=0,e=0;a:{c=tG(b);d=hb-16|0;hb=d;if(c>>>0<1073741808){b:{if(Uo(c)){bf(a,c);break b}dj(d+8|0,El(c)+1|0);e=x[d+8>>2];Ad(a,e);cg(a,x[d+12>>2]);oe(a,c);a=e}Ad(_h(a,b,c)+(c<<2)|0,0);hb=d+16|0;break a}dg();p()}}function XL(a){var b=0,c=0,d=0;c=hb-544|0;hb=c;a:{if(!(y[a+480210|0]&128)|!x[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=vz(c,x[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}vc(b+112|0,a,538);b=b+872|0;continue}}hb=c+544|0}function RO(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=zi(e,a,c-f>>1);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){ic(g);UA(b,f,h);hb=e+16|0}else{oj(d,z[a>>1]);d=d+2|0;x[g+4>>2]=d;a=a+2|0;continue}break}}function ED(a){var b=0;if(!(Rb(a,13216,8)|(y[a+8|0]|y[a+9|0]<<8)!=14|(!(y[a+12|0]|y[a+13|0]<<8)|(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))<=0))){b=(y[a+18|0]|y[a+19|0]<<8|(y[a+20|0]<<16|y[a+21|0]<<24))>>>0>23}return b}function CV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;Du(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Zb(b,0,65)}return a|0}function Aea(a,b){a=a|0;b=b|0;var c=0;b=hb-32|0;hb=b;c=-1;a:{if(!_A(a,b+16|0)){break a}c=0;if(!UQ(b+16|0)){break a}c=-1;if(!sj(a,b+8|0)){break a}c=0;if(!x[b+12>>2]){break a}a=x[b+8>>2];c=(a&2139062143)==(a|0)}hb=b+32|0;return c|0}function dQ(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=e>>>8|0;g=(e&255)<<24|d>>>8;d=(((y[b|0]^d)&255)<<3)+21528|0;e=x[d>>2];d=x[d+4>>2]^f;x[a>>2]=e^g;x[a+4>>2]=d;b=b+1|0;continue}break}return a}function cV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Qb(x[a>>2],x[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){qg(a+b|0);a=a+1|0;continue}break}break a}hc(c+8|0,b,120);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function Zha(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Qb(x[a>>2],x[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){zq((a<<1)+b|0);a=a+1|0;continue}break}break a}du(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function Tf(a,b){var c=0,d=0,e=0,f=0;d=z[a+22>>1];e=d+z[a+20>>1]|0;c=z[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-D(x[zb(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;continue}break}return a}function KT(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=tk(e,a,c-f|0);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){ic(g);UA(b,f,h);hb=e+16|0}else{sk(d,y[a|0]);d=d+1|0;x[g+4>>2]=d;a=a+1|0;continue}break}}function tq(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;b=hb-16|0;hb=b;Dq(b+8|0,c+15|0);d=x[b+12>>2];kd(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(d|0)){ad(a,x[b+12>>2])}hb=b+16|0;hb=c+16|0;return((d|0)==(e|0)?y[c+15|0]:0)&255}function kfa(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;w[b+30>>1]=0;c=ec(b+8|0,b+30|0,2);mc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=2){break a}if(Rb(b+30|0,13480,2)){break a}bc(a,2);d=1}hb=b+32|0;return d|0}function cB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=x[a>>2];f=ak(e,x[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=Jf(e,c);if(!Ob(x[c>>2],x[c+4>>2])){break a}d=d+1|0;continue}break}return(Yg(a,d&65535,b)?d:-1)&65535}function JL(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Ec(Kia(Jia(d,d>>31,g,h),lb,256,0),lb);x[a+4>>2]=f-d;x[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function xN(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(!c){break a}x[b+40>>2]=c;if(!c|x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[_c(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=Fz(c&255),x[e+44>>2]=f}hb=d+16|0}function mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;pA(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){rA(b)}return a|0}function ida(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=nf(x[b>>2],x[b+4>>2]);c=yP(d+8|0,c);x[23604]=0;X(678,a|0,b|0,e-1&65535,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){He(c);hb=d+32|0;return}a=P()|0;He(c);T(a|0);p()}function Kia(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Mia(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;lb=(g^lb)-((a>>>0<f>>>0)+g|0)|0;return b}function Haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;uO(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Xy(b)}return a|0}function zu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;TB(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){SB(b)}return a|0}function tt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;VQ(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){WQ(b)}return a|0}function qd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;g=x[b+8>>2];f=x[b>>2];x[e+8>>2]=c;x[e+12>>2]=d;h=x[x[f>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;mb[h|0](a,f,g,e);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];hb=e+16|0}function fC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;hC(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){gC(b)}return a|0}function Li(a,b,c){c=c&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function Jd(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+22>>1];g=d+z[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0<2048){break a}w[a+20>>1]=c-d}return}c=c+1|0;continue}}function Ds(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=44348;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=44200;break a;case 2:c=44196;break a;case 1:break b;case 0:break c}}c=44192;break a}c=44188}x[a>>2]=x[c>>2]}function wp(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(C[b-8>>3]-C[a>>3]);b=0;while(1){if((b|0)!=2048){d=-ee(f*C[Ne(a,b)>>3]);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=zb(c,b),h=e,x[g>>2]=h;b=b+1|0;continue}break}}function wha(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a+480180>>2]=b;Bz(c,_p(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;Ds(a+8|0,_p(a));hb=c+16|0}function pE(a,b,c,d,e){var f=0;f=hb-32|0;hb=f;x[f+24>>2]=a;x[f+28>>2]=b;x[f+16>>2]=d;x[f+20>>2]=e;x[f+8>>2]=c;x[f+12>>2]=0;a=BB(f+24|0,f+8|0);b=f+16|0;a=YD(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?a:b;hb=f+32|0;return x[a>>2]}function dJ(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){fk(a,b);d=hb-16|0;hb=d;b=tk(d,a,b);c=x[b+4>>2];e=x[b+8>>2];while(1){if((c|0)==(e|0)){ic(b);hb=d+16|0}else{c=c+1|0;x[b+4>>2]=c;continue}break}}return a}function Vea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Qb(x[a>>2],x[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){qg(a+b|0);a=a+1|0;continue}break}break a}TA(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function SE(a,b,c,d){var e=0,f=0;a:{e=hb-32|0;hb=e;f=e+16|0;jk(f,c);Cj(e+8|0,f);x[23604]=0;X(d|0,a|0,b|0,x[e+8>>2],x[e+12>>2]);a=x[23604];x[23604]=0;if((a|0)!=1){Db(e+16|0);hb=e+32|0;break a}a=P()|0;Db(e+16|0);T(a|0);p()}}function Bt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Oc(a);e=Eb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Pb(a);Te(d+e|0,b,c);b=c+e|0;Sg(a,b);id(b+d|0,0);return a|0}Jp(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function st(a,b){var c=0,d=0,e=0;if(x[a>>2]){CU(a);c=x[a>>2];iB(a);Hb(c);d=Cb(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Cb(b);d=Cb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0}function qQ(a,b,c){var d=0;d=hb-16|0;hb=d;v[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){v[d+14|0]=(z[(b<<1)+33150>>1]-z[(c<<1)+33150>>1]|0)/5;a=y[Wb(d+15|0,d+14|0)|0]}hb=d+16|0;return a&255}function Ur(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!Lw(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=Ke(a)}return b}aa(15561,13065,1578,5390);p()}function UM(a,b){var c=0,d=0,e=0,f=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];d=Cb(a);c=jc(a);a:{if(!x[d>>2]){x[a>>2]=c;break a}x[x[c>>2]+8>>2]=c;c=jc(b);x[b>>2]=c;x[c>>2]=0;e=Cb(b),f=0,x[e>>2]=f}return a}function Jv(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;g=mg(f+8|0,d);x[23604]=0;h=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=h;a=rg(e,a,b,c,f);b=x[23604];x[23604]=0;if((b|0)!=1){be(d);hb=f+16|0;return a}a=P()|0;be(d);T(a|0);p()}function yj(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;hc(d+8|0,b,c);e=x[d+12>>2];mc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){bc(a,x[d+12>>2])}hb=d+16|0;a=(e|0)==(f|0);if(!a){Zb(b,0,c)}return a}function nS(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function i7(a){a=a|0;var b=0;mb[x[x[a>>2]+128>>2]](a);qx(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=mb[x[x[a>>2]+192>>2]](a)|0;x[a+4328>>2]=0;x[a+4312>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4324>>2]=b;x[a+4320>>2]=b}function bs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;d=x[b>>2];b=rc(d,x[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){hb=c+16|0}else{x[c+8>>2]=0;e=zc(c+8|0);f=zb(d,a),g=x[e>>2],x[f>>2]=g;a=a+1|0;continue}break}}function Bga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=-1;a:{if(!sj(a,d+8|0)){break a}e=x[d+12>>2];c=0;if(!(x[d+8>>2]==(ym(8880)|0)&e>>>0>255&e>>>0<260)){break a}c=De(a,b,e>>>0<259?80:76,0)}hb=d+16|0;return c|0}function BC(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Qb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;ig(a,c+15|0);d=y[c+15|0]}hb=c+16|0;a=d<<24>>24;break a}aa(11098,8981,136,14062);p()}return a}function Dy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=x[b+480180>>2];if(f&64671904){b=y[(d&15)+44272|0];v[a+2|0]=0;w[a>>1]=b;return}g=a;a=(c&255)==4&(f|0)==4;c=(d&255)<<a<<4;bo(g,(h=Tb(b+1074312|0,66)?0:c,i=c,j=e,j?h:i),a)}function DO(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function pN(a,b,c,d){var e=0;e=(D(b,872)+c|0)+616|0;b=Vc(Ln(a,z[c+70>>1],x[c+48>>2],b,0)-32768|0);a:{if(!d){break a}a=Pk(c)-x[c+16>>2]|0;if((a|0)<2){break a}c=b;b=w[e+774>>1];b=Vc(((c-b|0)/(a|0)|0)+b|0)}w[e+774>>1]=b}function eT(a){var b=0;a:{b:{if(Rb(a,13699,4)){if(Rb(a,16128,4)){break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0<=255){break b}break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0>255){break a}}b=(y[a+36|0]|y[a+37|0]<<8)>>>0<4e3}return b}function bz(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:IO(a,b);return;default:break a}}d=hb-32|0;hb=d;x[d+28>>2]=c;w[d+24>>1]=0;x[d+12>>2]=2;Ar(d+16|0,a,d+24|0,x[Fb(d+28|0,d+12|0)>>2]);w[b>>1]=z[d+24>>1];hb=d+32|0}function Jia(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;lb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function Ey(a,b,c){var d=0,e=0;e=z[a+480192>>1];a:{if(e){if(!Tc(b)|c>>>0>e>>>0){break a}c=x[((c<<2)+a|0)+900380>>2];if(!c){break a}d=z[cc(c+236|0,b-1|0)>>1];break a}d=c}return(z[a+480190>>1]>=(d&65535)>>>0?d:0)&65535}function xH(a,b){var c=0,d=0,e=0;c=hb-256|0;hb=c;if((b|0)>=2){x[(b<<2)+a>>2]=c;vc(c,x[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;vc(x[e>>2],x[(d<<2)+a>>2],4);x[e>>2]=x[e>>2]+4;if((b|0)!=(d|0)){continue}break}}hb=c+256|0}function Iw(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!Tr(a)){break a}if(!(v[a+1375|0]&1)){continue}break}gc(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function iO(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=e*C[a+16>>3]+(C[a>>3]*b+c*C[a+8>>3])-d*C[a+24>>3]-f*C[a+32>>3];C[a+56>>3]=b;return b}function QM(a,b,c,d){var e=0,f=0;b=D(c,872)+b|0;e=x[b+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=z[(b+616|0)+786>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=y[((b<<5)+a|0)+480288|0]}return f}function qp(a,b){a=vc(a,b,88);x[a+88>>2]=x[b+88>>2];vc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];vc(a+672|0,b+672|0,52);wy(a+724|0,b+724|0);wy(a+732|0,b+732|0);wy(a+740|0,b+740|0);vc(a+748|0,b+748|0,123);return a}function pn(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function fP(a){var b=0;b=w[a+784>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+784>>1]=0}b=y[a+795|0];if(b){v[a+795|0]=0;v[a+838|0]=b-1}b=y[a+796|0];if(b){v[a+796|0]=0;v[a+837|0]=b-1}}function XO(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;f=zi(e,a,d);a=x[f+4>>2];d=hb-16|0;hb=d;x[d+8>>2]=b;while(1){if(Ob(b,c)){oj(a,z[b>>1]);a=a+2|0;b=x[Pe(d+8|0)>>2];continue}break}hb=d+16|0;x[f+4>>2]=a;ic(f);hb=e+16|0}function KS(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;x[d>>2]=x[a+8>>2];e=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,6)+e;b=x[d>>2];while(1){if(x[d+4>>2]!=(b|0)){Nt(b,c);b=x[d>>2]+6|0;x[d>>2]=b;continue}break}Hd(d);hb=d+16|0}function fS(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;hS(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){gS(b)}return a}function ek(a){wc(a+16|0,x[a>>2]);wc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function Tl(a,b){var c=E(0),d=0,e=0;c=E(1);d=w[a+28>>1];a:{if((d|0)>(b|0)){break a}e=x[a+4>>2];if((rc(e,x[a+8>>2])+d|0)-1<<16>>16<(b|0)){break a}c=B[zb(e,b-d|0)>>2];c=c<=E(10000000036274937e-31)?E(1):c}return c}function OA(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;tT(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){uT(b)}return a}function Lq(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;if(c>>>0<2147483632){a:{if(io(c)){bf(a,c);break a}si(d+8|0,Xj(c)+1|0);e=x[d+8>>2];Ad(a,e);cg(a,x[d+12>>2]);oe(a,c);a=e}id(Te(a,b,c)+c|0,0);hb=d+16|0;return}dg();p()}function wt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;iR(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){Pz(b)}}function s9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(Kh(a)>>>0<b>>>0){if(bh(1073741823)>>>0<b>>>0){break a}d=Cb(a);e=a;a=Wf(c+8|0,b,rc(x[a>>2],x[a+4>>2]),d);xd(e,a);Vf(a)}hb=c+32|0;return}Sc();p()}function raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(Oy(a)>>>0<b>>>0){if(bh(613566756)>>>0<b>>>0){break a}d=Cb(a);e=a;a=MN(c+8|0,b,Ny(x[a>>2],x[a+4>>2]),d);LN(e,a);KN(a)}hb=c+32|0;return}Sc();p()}function aS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(Dm(a)>>>0<b>>>0){if(bh(2147483647)>>>0<b>>>0){break a}d=Cb(a);e=a;a=pj(c+8|0,b,Kc(x[a>>2],x[a+4>>2]),d);xd(e,a);yi(a)}hb=c+32|0;return}Sc();p()}function UG(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=mb[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!ln(b)){break a}x[a>>2]=0}return a|0}function Qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(ik(a)>>>0<b>>>0){if(bh(357913941)>>>0<b>>>0){break a}d=Cb(a);e=a;a=wl(c+8|0,b,Dd(x[a>>2],x[a+4>>2]),d);aQ(e,a);$P(a)}hb=c+32|0;return}Sc();p()}function Baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(Pm(a)>>>0<b>>>0){if(bh(536870911)>>>0<b>>>0){break a}d=Cb(a);e=a;a=Tq(c+8|0,b,Eg(x[a>>2],x[a+4>>2]),d);xd(e,a);Sq(a)}hb=c+32|0;return}Sc();p()}function $x(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;RL(a+24648|0);XL(a)}function u9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(ik(a)>>>0<b>>>0){if(bh(357913941)>>>0<b>>>0){break a}d=Cb(a);e=a;a=wl(c+8|0,b,Dd(x[a>>2],x[a+4>>2]),d);tv(e,a);gr(a)}hb=c+32|0;return}Sc();p()}function l9(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;a:{if(!sj(a,b+8|0)){break a}c=0;if(!yL(x[b+8>>2],x[b+12>>2])){break a}a=sQ(a,b);if(!a){sm(b)}c=-1;if(!a){break a}c=xL(x[b>>2])}a=c;hb=b+16|0;return a|0}function by(a,b){var c=0;c=x[b+24>>2];x[a+24628>>2]=c?c>>>0>=512?512:c:1;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}vc(a+24604|0,b,40);SL(a,c)}function Qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;c=ff(a,c);_d(e,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!fd(a,5)){break b}break a}d=x[c+8>>2]}bz(x[a+28>>2],b,d);f=c}a=_e(a,f);hb=e+16|0;return a|0}function Pv(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function P7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=Fj(a);if(d){e=x[b+4>>2];b=x[b>>2];x[c+8>>2]=b;x[c+12>>2]=e;a=x[x[d>>2]+72>>2];x[c>>2]=b;x[c+4>>2]=e;a=mb[a|0](d,c)|0}else{a=1}hb=c+16|0;return a|0}function FF(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Wo(d+24|0,a,b);el(d+16|0,x[d+24>>2],x[d+28>>2],c);a=IT(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];yd(e+8|0,a,d+12|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function EF(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Wo(d+24|0,a,b);el(d+16|0,x[d+24>>2],x[d+28>>2],c);a=Gx(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];yd(e+8|0,a,d+12|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function vv(a,b,c){var d=0,e=0;d=Pb(a);a=Eb(x[a+4>>2],y[a+11|0]);e=Pb(b);b=Eb(x[b+4>>2],y[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}a=a+d|0;b=ND(c+d|0,a,e,b+e|0);c=(a|0)==(b|0)?-1:b-d|0}else{c=-1}}return c}function Yz(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=tD(a);a:while(1){if((a|0)!=(e|0)){f=sd(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((y[Gb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function Yx(a,b,c){var d=0,e=0;d=x[b+656>>2];if(!d){return 0}d=Ju(d,c);a=a+1074312|0;if(!Tb(a,31)){e=Tb(a,93)^1}a:{if(!(v[ML(b,c)+6|0]&1)){a=0;if(!(v[d+12|0]&1)|e){break a}}a=tc(x[d>>2],x[d+4>>2])^1}return a}function YV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;d=-1;a:{if(!WC(a,c+8|0)){break a}d=0;if(!VC(c+8|0)){break a}if(b){a=x[b>>2];if(!x[b+4>>2]&a>>>0<dc(x[c+12>>2])-8>>>0){break a}}d=1}hb=c+48|0;return d|0}function U8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=hb-16|0;hb=f;c=ff(a,c);_d(f,x[a+28>>2]);a:{b:{if(!c){e=-1;if(!fd(a,5)){break b}break a}e=x[c+8>>2]}mb[d|0](x[a+28>>2],b,e);g=c}_e(a,g);hb=f+16|0}function NP(a){a=a*4294967296;if(F(a)<0x8000000000000000){lb=F(a)>=1?~~(a>0?H(J(a*2.3283064365386963e-10),4294967295):K((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}lb=-2147483648;return 0}function vd(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Qb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;ig(a,c+15|0);d=y[c+15|0]}hb=c+16|0;break a}aa(11098,8981,136,14062);p()}return d}function su(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function NM(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function M9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){cM(d,x[c+4>>2],x[c+8>>2])}vc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function Ei(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;hc(d+8|0,b,c);e=x[d+12>>2];mc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){bc(a,x[d+12>>2])}hb=d+16|0;if((e|0)!=(f|0)){Zb(b,0,c)}}function Caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Sb(a);d=ag(a+12|0);v[a+32|0]=c;x[a+28>>2]=0;x[a+24>>2]=b;x[23604]=0;R(718,a|0,1);b=x[23604];x[23604]=0;if((b|0)!=1){return a|0}b=P()|0;aO(d);fO(a);T(b|0);p()}function zia(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[a>>2],x[a+8>>2],64)){a=0;while(1){if((a|0)!=64){qg(a+b|0);a=a+1|0;continue}break}break a}du(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function lt(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;jm(d+24|0,a,b);el(d+16|0,x[d+24>>2],x[d+28>>2],c);a=x[d+16>>2];f=d,g=HT(c,x[d+20>>2]),x[f+8>>2]=g;yd(e+8|0,a,d+8|0);hb=d+32|0;hb=e+16|0}function Kda(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;fm(a,b);b=Bb(x[a>>2]);x[c+8>>2]=b;a=Bb(x[a+4>>2]);while(1){if(Ob(b,a)){d=y[b|0]+(d&255)|0;v[b|0]=d;b=x[Le(c+8|0)>>2];continue}else{hb=c+16|0}break}}function Gaa(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[a>>2],x[a+8>>2],27)){a=0;while(1){if((a|0)!=27){qg(a+b|0);a=a+1|0;continue}break}break a}uO(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function FO(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=x[c>>2];if(d){Sn(d);EO(x[c>>2])}b=b+1|0;continue}break}}function sf(a,b,c,d,e){var f=0;f=hb-256|0;hb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Zb(f,b&255,c?d:256);if(!c){while(1){gf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}gf(a,f,d)}hb=f+256|0}function lR(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[a>>2],x[a+8>>2],32)){a=0;while(1){if((a|0)!=32){qg(a+b|0);a=a+1|0;continue}break}break a}iR(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function v5(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=x[b+52>>2];if(c&16){d=x[b+48>>2];c=x[b+28>>2];if(d>>>0<c>>>0){x[b+48>>2]=c;d=c}ug(a,x[b+24>>2],d);break a}if(c&8){ug(a,x[b+12>>2],x[b+20>>2]);break a}Kb(a)}}function t6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;b=Ec(Kia(Jia(d,d>>31,b,0),lb,1e3,0),lb);x[a+16>>2]=0;x[a+12>>2]=b+c;eK(a,e);b=x[a+12>>2];x[f+12>>2]=0;bL(a,b,f+12|0);hb=f+16|0}function oT(a){var b=0;a:{if(Rb(a,3873,4)|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(Rb(a+71|0,13560,4)|y[a+75|0]!=1|y[a+76|0]){break a}b=((y[a+116|0]|y[a+117|0]<<8)-1&65535)>>>0<9}return b}function lS(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;TA(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)|0}function fda(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if((b|0)>=0){d=2147483647;a=dt(a);if(a>>>0<=1073741822){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[_c(c+12|0,c+8|0)>>2]}hb=c+16|0;return d|0}Sc();p()}function _h(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Wo(d+24|0,b,(c<<2)+b|0);el(d+16|0,x[d+24>>2],x[d+28>>2],a);b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];yd(e+8|0,b,d+12|0);hb=d+32|0;hb=e+16|0;return a}function Sh(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;Im(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)|0}function Pfa(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[a>>2],x[a+8>>2],2)){a=0;while(1){if((a|0)!=2){qg(a+b|0);a=a+1|0;continue}break}break a}ql(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function Jm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;a:{if(c){Xb(d,c);break a}Kb(d)}x[23604]=0;U(11,a|0,b|0,d|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(d);hb=d+16|0;return}a=P()|0;xb(d);T(a|0);p()}function $d(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Ld(b)}return c}function pB(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[a>>2],x[a+8>>2],8)){a=0;while(1){if((a|0)!=8){qg(a+b|0);a=a+1|0;continue}break}break a}Im(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function dn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(an(a)>>>0<b>>>0){if(bh(-1)>>>0<b>>>0){break a}d=Cb(a);e=a;a=Bl(c+8|0,b,Rc(x[a>>2],x[a+4>>2]),d);xd(e,a);Al(a)}hb=c+32|0;return}Sc();p()}function Rf(a){var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;c=2;if(a>>>0>=2){x[b+12>>2]=a>>>1;x[b+8>>2]=a^-1;d=b,e=x[Fb(b+12|0,b+8|0)>>2]+a|0,x[d+12>>2]=e;x[b+8>>2]=-1;c=x[Fb(b+12|0,b+8|0)>>2]}hb=b+16|0;return c}function QF(a,b,c,d,e,f){var g=0,h=0,i=0;g=hb-16|0;hb=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){Xg(g+13|0,g+14|0)}h=c,i=($a(b|0,Rc(b,x[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,x[h>>2]=i;hb=g+16|0}function mR(a,b){a=a|0;b=b|0;var c=0,d=0;d=x[a>>2];c=65535;a:{if(!pe(d,x[a+4>>2],b)){break a}d=cB(a,x[Jf(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=x[a>>2];a=Jf(c,b);pL(Jf(c,d),a);c=d}return c|0}function k1(a,b){a=a|0;b=b|0;var c=0;a=fs(a);x[a>>2]=76600;c=Kb(a+32|0);x[a+44>>2]=0;x[a+48>>2]=8;x[23604]=0;R(81,a|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){return a|0}b=P()|0;xb(c);yn(a);T(b|0);p()}function jX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;f=x[x[b>>2]+20>>2];e=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=e;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;mb[f|0](a,b,d,8);hb=d+16|0}function wB(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[a>>2],x[a+8>>2],512)){a=0;while(1){if((a|0)!=128){sm((a<<2)+b|0);a=a+1|0;continue}break}break a}lu(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function ir(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=Eb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){Rp();p()}b=Pb(b);x[e+8>>2]=d-c;Lq(a,b+c|0,x[Fb(e+12|0,e+8|0)>>2]);hb=e+16|0}function _L(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(c|0)){b=x[a>>2];a:{if(!b){break a}if(!(mb[x[x[b>>2]+116>>2]](b)|0)){break a}mb[x[x[b>>2]+96>>2]](b)}a=a+160|0;continue}break}}function TJ(a){var b=0,c=0,d=E(0);if(!a){return E(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(F(c)<2147483648){a=~~c;break a}a=-2147483648}d=E(wj(b-+(a|0)))}else{d=E(0)}return d}function Jaa(a){a=a|0;var b=0;b=hb-16|0;hb=b;a:{if($p(a,10157)){kJ(b,17421,a);a=Pb(b);x[23604]=0;R(40,44,a|0);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;xb(b);T(a|0);p()}hb=b+16|0;return}p()}function F2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;uJ(d,c);a=x[a+1298464>>2];x[23604]=0;U(351,a|0,b|0,d|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(d);hb=d+16|0;return}a=P()|0;xb(d);T(a|0);p()}function Ak(a){a=a|0;var b=0;x[a>>2]=77796;x[23604]=0;R(69,a|0,0);b=x[23604];x[23604]=0;if((b|0)!=1){$b(a+28|0);Hb(x[a+32>>2]);Hb(x[a+36>>2]);Hb(x[a+48>>2]);Hb(x[a+60>>2]);return a|0}V(0)|0;Vb();p()}function A7(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;a:{if(Kh(a)>>>0<=12){if(bh(1073741823)>>>0<=12){break a}c=Cb(a);d=a;a=Wf(b+8|0,13,rc(x[a>>2],x[a+4>>2]),c);xd(d,a);Vf(a)}hb=b+32|0;return}Sc();p()}function zR(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;FR(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){GR(b)}}function hu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;if(b){e=Oc(a);d=Eb(x[a+4>>2],y[a+11|0]);f=d+b|0;if(e-d>>>0<b>>>0){Rl(a,e,f-e|0,d,d,0,0)}e=d;d=Pb(a);gl(e+d|0,b,c);Sg(a,f);id(d+f|0,0)}return a|0}function Gu(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[a>>2],x[a+8>>2],256)){a=0;while(1){if((a|0)!=256){qg(a+b|0);a=a+1|0;continue}break}break a}hc(c+8|0,b,256);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function sT(a){var b=0,c=0,d=0;a:{if(Rb(a,21491,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|y[a+16|0]>3|y[a+17|0]>3){break a}d=a;a=a+19|0;if(y[d+18|0]<16){continue}break}}return b}function jO(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function Kd(a,b){var c=0,d=0,e=0;d=z[a+24>>1];if((d|0)!=(b&65535)){c=z[a+22>>1]-1&127;w[a+22>>1]=c;e=z[a+20>>1];if(e>>>0<=127){w[a+20>>1]=e+1}c=(c<<2)+a|0;w[c+26>>1]=b-d;w[c+28>>1]=0;w[a+24>>1]=b}}function Ri(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function sj(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;Im(c+8|0,b);d=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){tl(b)}return a}function qU(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;cu(c+8|0,b);d=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){fB(b)}return a}function pQ(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;tT(c+8|0,b);d=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){uT(b)}return a}function _A(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;ZA(c+8|0,b);d=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){ST(b)}return a}function ZQ(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;VQ(c+8|0,b);d=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){WQ(b)}return a}function WC(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;Mq(c+8|0,b);d=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Nq(b)}return a}function HR(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;FR(c+8|0,b);d=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){GR(b)}return a}function FD(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;DD(c+8|0,b);d=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){pv(b)}return a}function B8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;c=ff(a,c);_d(e,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!fd(a,5)){break b}break a}d=x[c+8>>2]}bz(x[a+28>>2],b,d);f=c}_e(a,f);hb=e+16|0}function $t(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function rL(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-16|0;hb=d;FS(d+8|0,a,b,c);a=Tp(a,x[d+8>>2]);f=d,g=Tp(c,x[d+12>>2]),x[f+4>>2]=g;yd(e+8|0,a,d+4|0);hb=d+16|0;hb=e+16|0;return x[e+12>>2]}function pu(a,b,c){var d=0;a=(a&65535)>>>D(c,3)|0;d=a>>>2&1|y[b+12|0]&-8;v[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=a;v[b+16|0]=a>>>8;v[b+12|0]=d|4}}function aB(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Yb(128/(D(x[Je(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=y[Ye(c+7|0,c+6|0)|0];hb=c+16|0;return a|b<<4&240}function qH(a){var b=0,c=0,d=0;d=x[a>>2];while(1){c=v[d|0];if(Dj(c)){d=d+1|0;x[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=D(b,10);b=(c|0)>(b^2147483647)?-1:c+b|0}else{b=-1}continue}break}return b}function SJ(a,b){var c=0,d=0,e=0,f=0;if(a>E(.9999989867210388)){d=0}else{a=E(a*a);c=+a;e=32768/(1-c);f=c;c=Me(31415.926535897932/+b);d=dm(e*(1-(f*c+M(+E(a+a)*(1-c)-+E(a*a)*(1-c*c)))))}return d}function cy(a,b){var c=0;a=VP(a,b);v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function vg(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(1073741823);if(d>>>0<=b>>>0){a=Kh(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function rJ(){var a=0,b=0,c=0,d=0;a=hb-16|0;hb=a;b=Jc(1298472);x[23604]=0;c=S(1012,b|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){b=x[lf(a+8|0,c)>>2];hb=a+16|0;return b|0}a=P()|0;Hb(b);T(a|0);p()}function qj(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(2147483647);if(d>>>0<=b>>>0){a=Dm(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function ne(a,b){var c=0;a:{c=If(b);if((c|0)==(Eb(x[a+4>>2],y[a+11|0])|0)){x[23604]=0;a=W(345,a|0,b|0,c|0)|0;b=x[23604];x[23604]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;Vb();p()}function eF(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=82376;d=a+8|0;while(1){b=x[a+8>>2];if(rc(b,x[a+12>>2])>>>0>c>>>0){b=x[zb(b,c)>>2];if(b){Om(b)}c=c+1|0;continue}break}xb(a+152|0);CF(d);return a|0}function Zi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Vk(a,b);if((d|0)==255){break a}Kj(a,b);yp(a,b,0,0);if(!c){break a}e=cc(a+26|0,d),f=65535,w[e>>1]=f;a=Gb(a+62|0,b);v[a|0]=y[a|0]|128}}function Xt(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;jm(d+24|0,a,b);el(d+16|0,x[d+24>>2],x[d+28>>2],c);a=IT(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];yd(e+8|0,a,d+12|0);hb=d+32|0;hb=e+16|0}function wA(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(715827882);if(d>>>0<=b>>>0){a=_t(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function kR(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=(Po(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),C[d+8>>3]=e;FN(c+8|0,127);a=ao(C[c+8>>3]);hb=c+16|0;return a}function hD(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(119304647);if(d>>>0<=b>>>0){a=bv(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function aA(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;f=x[b+12>>2];x[e+8>>2]=c;x[e+12>>2]=d;g=x[x[b>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;mb[g|0](a,b,f,e);x[b+12>>2]=x[b+12>>2]+x[a+4>>2];hb=e+16|0}function Uq(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(536870911);if(d>>>0<=b>>>0){a=Pm(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function RA(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(214748364);if(d>>>0<=b>>>0){a=aC(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function Io(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(357913941);if(d>>>0<=b>>>0){a=ik(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function Gv(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(268435455);if(d>>>0<=b>>>0){a=lr(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function Dp(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(134217727);if(d>>>0<=b>>>0){a=$n(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function zG(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function yR(a,b){var c=0,d=0;c=hb-16|0;hb=c;xR(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function rP(a){var b=0,c=0,d=0;c=y[a+64|0]|y[a+65|0]<<8;b=y[a+72|0]|y[a+73|0]<<8;a=y[a+70|0]|y[a+71|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<2|b>>>30;b=b<<2;c=b+c|0;lb=b>>>0>c>>>0?a+1|0:a;return c}function ou(a,b){var c=0,d=0;c=hb-16|0;hb=c;nu(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function mu(a,b){var c=0,d=0;c=hb-16|0;hb=c;po(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function mL(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(82595524);if(d>>>0<=b>>>0){a=Es(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function jt(a){var b=0;a:{if(Rb(a,13460,4)|y[a+4|0]){break a}if(Lb(y[a+6|0]|y[a+7|0]<<8)>>>0>1){break a}if(Lb(y[a+12|0]|y[a+13|0]<<8)){break a}b=(Lb(y[a+16|0]|y[a+17|0]<<8)|0)==20}return b}function ig(a,b){var c=0,d=0;c=hb-16|0;hb=c;Dq(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function dU(a,b){var c=0,d=0;c=hb-16|0;hb=c;Bu(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function bR(a,b){var c=0,d=0;c=hb-16|0;hb=c;gA(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function bD(a,b){var c=0,d=0;c=hb-16|0;hb=c;DD(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function XC(a,b){var c=0,d=0;c=hb-16|0;hb=c;Mq(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function VT(a,b){var c=0,d=0;c=hb-16|0;hb=c;cu(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function S2(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;uJ(c,b);a=x[a+1298464>>2];x[23604]=0;U(351,a|0,1,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(c);hb=c+16|0;return}a=P()|0;xb(c);T(a|0);p()}function QT(a,b){var c=0,d=0;c=hb-16|0;hb=c;du(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function QB(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function PT(a,b){var c=0,d=0;c=hb-16|0;hb=c;ZA(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function PM(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=Rq(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);hb=d+16|0}else{OM(b,x[c>>2],x[c+4>>2]);b=b+8|0;x[a+4>>2]=b;continue}break}}function LB(a,b){var c=0,d=0;c=hb-16|0;hb=c;KB(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function Iv(a,b,c){var d=0;d=hb-16|0;hb=d;hc(d+8|0,b,c);b=x[d+12>>2];mc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);c=x[d+4>>2];if((b|0)==(c|0)){bc(a,x[d+12>>2])}hb=d+16|0;return(b|0)==(c|0)}function Iq(a,b){var c=0,d=0;c=hb-16|0;hb=c;ql(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function C9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;e=z[a+28>>1];w[d+8>>1]=e;f=d,g=(rc(x[a+4>>2],x[a+8>>2])+e|0)-1|0,w[f+10>>1]=g;a=eL(a,b,c,d+8|0);hb=d+16|0;return a|0}function Bs(a){var b=0;x[23604]=0;a=S(765,a|0)|0;b=x[23604];x[23604]=0;a:{if((b|0)==1){_(V(0)|0)|0;x[23604]=0;Z(17);b=x[23604];x[23604]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;Vb();p()}function BS(a,b){var c=0,d=0;c=hb-16|0;hb=c;AS(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function Ao(a,b){var c=0,d=0;c=hb-16|0;hb=c;zh(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){bc(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function AQ(a){var b=0,c=0,d=0;c=y[a+32|0]|y[a+33|0]<<8;b=y[a+36|0]|y[a+37|0]<<8;a=y[a+34|0]|y[a+35|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<1|b>>>31;b=b<<1;c=b+c|0;lb=b>>>0>c>>>0?a+1|0:a;return c}function Zv(a,b,c,d,e,f,g,h,i){var j=0;j=hb-16|0;hb=j;tg(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;hb=j+16|0}function QO(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;v[a+16|0]=0;c=hz(b,x[a+12>>2]);x[23604]=0;R(705,a|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){Wk(c);hb=b+32|0;return}a=P()|0;Wk(c);T(a|0);p()}function Cz(a,b){var c=0,d=0;d=hb-32|0;hb=d;c=Cb(a);c=Wf(d+8|0,vg(a,rc(x[a>>2],x[a+4>>2])+1|0),rc(x[a>>2],x[a+4>>2]),c);Un(x[c+8>>2],x[b>>2]);x[c+8>>2]=x[c+8>>2]+4;xd(a,c);Vf(c);hb=d+32|0}function kP(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function UF(a,b){var c=0,d=0;d=hb-32|0;hb=d;c=Cb(a);c=Bl(d+8|0,qk(a,Rc(x[a>>2],x[a+4>>2])+1|0),Rc(x[a>>2],x[a+4>>2]),c);sk(x[c+8>>2],y[b|0]);x[c+8>>2]=x[c+8>>2]+1;xd(a,c);Al(c);hb=d+32|0}function v$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=Ct(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;vc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function gg(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb+-64|0;hb=c;d=Kx(c+8|0,a);x[23604]=0;U(187,a|0,b|0,d|0);a=x[23604];x[23604]=0;if((a|0)!=1){Nk(d);hb=c- -64|0;return}a=P()|0;Nk(d);T(a|0);p()}function Vi(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function MS(a,b,c,d){var e=0;e=hb-16|0;hb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=Dn(a,c,x[Fb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}hb=e+16|0;return c}function ux(a){var b=0,c=0,d=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Hn(d)|b<<15;continue}break}C[c+4280>>3]=E(E(b|0)*E(-4.656612873077393e-10))}function px(a,b,c,d){var e=0,f=0,g=0;e=c-b|0;a:{if((e|0)<=9){g=e;e=D(32-G(d|1)|0,1233)>>12;f=61;if((g|0)<(e+(A[(e<<2)+91296>>2]<=d>>>0)|0)){break a}}c=ox(b,d);f=0}x[a+4>>2]=f;x[a>>2]=c}function _S(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;Ff(a,c+14|0);e=z[c+14>>1];gM(b,e);while(1){if((d|0)==(e|0)){dy(b);hb=c+16|0}else{Uj(a,zb(x[b>>2],d));d=d+1|0;continue}break}}function Kj(a,b){var c=0,d=0,e=0;a:{c=Vk(a,b);if((c|0)==255){break a}if(Lj(x[a>>2])){break a}e=a+8|0;d=Gb(e,c);v[d|0]=y[d|0]&223;d=Ys(c);c=Gb(e,c);Qg(x[a>>2],x[a+4>>2],b,d|176,y[c|0])}}function F5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=KJ(f,b,c,d,0,0,0,0,e);hb=f+16|0;return a|0}function B_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-16|0;hb=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=Bj(h,b,c,d,e,f,g+8|0,a);hb=a;return b|0}function tn(a){var b=0,c=0;b=hb-16|0;hb=b;a:{if(!gJ(y[a+20|0])){x[23604]=0;R(1015,b+8|0,a|0);c=x[23604];x[23604]=0;if((c|0)==1){break a}}v[a+20|0]=255;hb=b+16|0;return}V(0)|0;Vb();p()}function t2(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=x[14311];x[c+8>>2]=x[14310];x[c+12>>2]=d;d=x[14309];x[c>>2]=x[14308];x[c+4>>2]=d;mb[x[$o(c,Ej(y[b+20|0]))>>2]](a,b);hb=c+16|0}function mha(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Qb(x[a>>2],x[a+8>>2],12);a:{if(!d){v[c|0]=0;Mh(b,12,c);break a}ZA(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function _r(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=x[a+4>>2];d=((b<<2)+(Ou(x[a>>2],1)^270549120)|0)+2019860093|0;x[a>>2]=d;b=b+D(Ou(d,16),5)|0;x[a+4>>2]=b;continue}break}return b}function u_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=mb[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Pb(a);return Aj(g,h,c,d,e,f,b,b+(Eb(x[a+4>>2],y[a+11|0])<<2)|0)|0}function th(a,b){var c=0;b=Od(b);c=x[a+8>>2];if(rc(c,x[a+12>>2])>>>0>b>>>0){a=x[zb(c,b)>>2]!=0}else{a=0}if(!a){a=Ml(ba(4)|0);x[a>>2]=92976;ha(a|0,93112,1055);p()}return x[zb(c,b)>>2]}function qk(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=bh(-1);if(d>>>0<=b>>>0){a=an(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Sc();p()}function _g(a,b,c){a:{if(b>>>0<=c>>>0){a=ba(8)|0;x[23604]=0;b=S(179,a|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){break a}b=P()|0;ca(a|0);T(b|0);p()}return y[a+c|0]}ha(b|0,26440,154);p()}function PD(a,b){var c=0,d=0;d=hb-32|0;hb=d;c=Cb(a);c=wl(d+8|0,Io(a,Dd(x[a>>2],x[a+4>>2])+1|0),Dd(x[a>>2],x[a+4>>2]),c);hr(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;tv(a,c);gr(c);hb=d+32|0}function Ih(a){var b=0;a=Lh(a);b=2147483647;a:{if(a>=E(2147483648)){break a}b=-2147483648;if(a<=E(-2147483648)){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function v8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;f=1;g=x[c>>2];if(g>>>0<Rc(a,b)>>>0){a=Xm(e,Gb(a,g),z[c+12>>1]);b=Wv(d,a);Db(a);f=b^1}hb=e+16|0;return f|0}function rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;wS(b,c);c=Qb(x[a>>2],x[a+8>>2],c<<2);if(c){vS(d+8|0,x[b>>2],x[b+4>>2]);qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0;return c|0}function nda(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Qb(x[a>>2],x[a+8>>2],4);a:{if(!d){v[c|0]=0;xT(b,4,c);break a}zh(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function gP(a,b){var c=0;c=y[a+800|0];a:{if(c){break a}c=ri(y[a+797|0]-w[a+770>>1]|0);if(!b|c-1<<24>>24<0){break a}a=x[a+656>>2];if(!a){break a}c=y[Gb(a+108|0,c-1|0)|0]}return c&255}function bk(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;if(bh(1073741823)>>>0<b>>>0){Sc();p()}dj(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Cb(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;hb=c+16|0}function QJ(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=PJ(f,b,c,d,e,0,0,0,0);hb=f+16|0;return+c}function Jw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+D(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((D(b,306)+5<<16>>16)/10<<16>>16)|0)-1|0}function Hp(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;if(bh(2147483647)>>>0<b>>>0){Sc();p()}Tu(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Cb(a),e=b+(x[c+12>>2]<<1)|0,x[d>>2]=e;hb=c+16|0}function Fq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;if((b|0)<0){Sc();p()}HC(c+8|0,(b-1>>>5|0)+1|0);b=x[c+8>>2];x[a+4>>2]=0;x[a>>2]=b;d=Cb(a),e=x[c+12>>2],x[d>>2]=e;hb=c+16|0}function xW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=mb[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Fb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function hO(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;if(bh(268435455)>>>0<b>>>0){Sc();p()}_D(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Cb(a),e=b+(x[c+12>>2]<<4)|0,x[d>>2]=e;hb=c+16|0}function Vy(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;if(bh(536870911)>>>0<b>>>0){Sc();p()}mD(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Cb(a),e=b+(x[c+12>>2]<<3)|0,x[d>>2]=e;hb=c+16|0}function Ty(a){var b=0,c=0;b=x[a>>2];c=x[b>>2];a:{if(!c){while(1){c=oh(b);b=x[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=x[b+4>>2];if(c){continue}break}}x[a>>2]=b;return a}function Ot(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;if(bh(715827882)>>>0<b>>>0){Sc();p()}IS(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Cb(a),e=b+D(x[c+12>>2],6)|0,x[d>>2]=e;hb=c+16|0}function HW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;oD(b,c);c=Qb(x[a>>2],x[a+8>>2],c<<3);if(c){nD(d+8|0,x[b>>2],x[b+4>>2]);qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0;return c|0}function $r(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+12>>2]=12;while(1){x[b+8>>2]=32;if(A[Fb(b+12|0,b+8|0)>>2]<=c>>>0){hb=b+16|0;a=d&4095}else{c=c+15|0;d=Hn(a);continue}break}return a}function tN(a,b,c,d){a:{if((a|0)!=67108864){break a}a=D(d,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=D(a,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129}}function qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;UP(b,c);if(Qb(x[a>>2],x[a+8>>2],c<<8)){c=x[b>>2];hc(d+8|0,c,mh(c,x[b+4>>2])<<8);qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0}function GW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(Rc(x[c>>2],x[c+4>>2])>>>0>=a>>>0){break a}Fi(c,a)}return!d|0}function qo(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=zi(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);hb=d+16|0}else{oj(b,z[c>>1]);b=b+2|0;x[a+4>>2]=b;continue}break}}function ld(a,b){var c=0,d=0,e=0;a:{c=tG(b);d=Zm(a);if(c>>>0<=d>>>0){e=b;b=c<<2;d=ah(Pb(a),e,b);Sg(a,c);Ad(b+d|0,0);break a}e=a;a=Eb(x[a+4>>2],y[a+11|0]);dF(e,d,c-d|0,a,0,a,c,b)}}function cC(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=lh(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);hb=d+16|0}else{Un(b,x[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function SH(a,b){var c=0,d=0,e=E(0),f=E(0),g=0;g=(b|0)>0?b:0;while(1){if((c|0)!=(g|0)){b=(c<<2)+a|0;d=b+2304|0;e=B[b>>2];f=B[d>>2];B[d>>2]=e-f;B[b>>2]=e+f;c=c+1|0;continue}break}}function NL(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;while(1){x[b+12>>2]=7;x[b+8>>2]=32;if(A[Fb(b+12|0,b+8|0)>>2]<=c>>>0){hb=b+16|0;a=d&127}else{c=c+15|0;d=Hn(a);continue}break}return a}function Ix(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=lh(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);hb=d+16|0}else{ys(b,B[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function ES(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+4|0]|y[b+5|0]<<8;v[a+4|0]=b;v[a+5|0]=b>>>8}function wo(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=tk(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);hb=d+16|0}else{sk(b,y[c|0]);b=b+1|0;x[a+4>>2]=b;continue}break}}function pY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+82448>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function iC(a){var b=0,c=0;a:{if(Rb(a,14034,3)){break a}b=y[a+3|0];b:{if(b>>>0<=7){if((b|0)==1){break b}break a}if(b>>>0>14){break a}}c=(y[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function eha(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;ZS(b,c);YS(a,c);hb=c+32|0}function _e(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!b){b=1;if(fd(a,5)){break a}_d(c,x[a+28>>2])}x[a>>2]=x[a>>2]|134217728;x[a+20>>2]=x[a+20>>2]+1;b=0}hb=c+16|0;return b|0}function Xn(a){var b=0,c=0;b=x[23360];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>nb()<<16>>>0){if(!(eb(a|0)|0)){break a}}x[23360]=a;return b}x[116080]=48;return-1}function Rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;c=ff(a,c);_d(e,x[a+28>>2]);a:{if(!c){f=0;if(fd(a,5)){break a}}WS(x[a+28>>2],b,d,0);f=c}_e(a,f);hb=e+16|0}function Qj(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Cb(b);d=Cb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function A_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=mb[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Pb(a);return Bj(g,h,c,d,e,f,b,Eb(x[a+4>>2],y[a+11|0])+b|0)|0}function n6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=12){c=Fd(c,E(0));d=a+4208|0;if((b|0)==12){c=E(Lh(E(c*E(3)))/E(3));b=12}e=zb(d,b),f=c,B[e>>2]=f;v[a+5046|0]=1}}function Z8(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;d=-1;a:{if(!FD(a,c+8|0)){break a}d=0;if(!uL(c+8|0)|(x[c+16>>2]!=x[b>>2]|x[b+4>>2]?b:0)){break a}d=1}hb=c+32|0;return d|0}function VN(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;while(1){if(c){f=Tk(z[c+16>>1],x[c+20>>2],a,b);d=f?d:c;c=x[(f?c+4|0:c)>>2];continue}break}a=x[Ib(e+8|0,d)>>2];hb=e+16|0;return a}function RD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Oc(a);d=Eb(x[a+4>>2],y[a+11|0]);e=d+1|0;if((c|0)==(d|0)){Xx(a,c,e-c|0,c,c,0)}c=Pb(a);gl(c+d|0,1,b);Sg(a,e);id(c+e|0,0);return a|0}function MD(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function ls(a){var b=0;b=x[a+24>>2];x[23604]=0;Y(766,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){Vd(a+68|0);Of(a+36|0);ds(a+32|0);Ti(a+24|0);Si(a+4|0);return te(a)}V(0)|0;Vb();p()}function Yha(a,b){a=a|0;b=b|0;if(!PT(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0}}function H1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;Tw(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Fb(d+8|0,d+12|0)>>2]}hb=d+16|0;return c|0}function fM(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;dM(c,b+80|0);x[23604]=0;U(11,a|0,0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){xb(c);hb=c+16|0;return}a=P()|0;xb(c);T(a|0);p()}function XQ(a){var b=0,c=0,d=0,e=0;d=y[a+4|0];e=y[a+92|0];c=y[a+94|0]|y[a+95|0]<<8;b=c+y[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=d;d=b<<2;b=a+d|0;b=b-96|0;lb=0;return b}function VX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;mb[x[x[a>>2]+12>>2]](d+8|0,a,b);a=x[d+8>>2];b=x[c>>2];a=tc(x[d+12>>2],x[c+4>>2])&(a|0)==(b|0);hb=d+16|0;return a|0}function Nda(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;b=-1;a:{if(!sj(a,c+8|0)){break a}b=0;if(!WP(c+8|0)){break a}b=-1;if(!Nf(a,4)){break a}b=tQ(a)>>>31|0}hb=c+16|0;return b|0}function E8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;c=ff(a,c);_d(e,x[a+28>>2]);a:{if(!c){f=0;if(fd(a,5)){break a}}ZK(d,x[a+28>>2],b);f=c}_e(a,f);hb=e+16|0}function tha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;a:{if(a){mb[x[x[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}jM(d,9055,10750,140,42);vD(a,d,b,a,c)}hb=d+16|0}function jq(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];d=x[a+4>>2];if(Kc(c,d)>>>0>b>>>0){a=x[a+24>>2];b=nl(c,d,b);a=pe(x[a+484344>>2],x[a+484348>>2],z[b>>1])}else{a=0}return a|0}function yu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;Fi(b,c);if(Qb(x[a>>2],x[a+8>>2],c)){c=x[b>>2];hc(d+8|0,c,Rc(c,x[b+4>>2]));qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0}function sQ(a,b){var c=0,d=0;c=hb-16|0;hb=c;zh(c+8|0,b);b=x[c+12>>2];kd(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){ad(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function jg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=_g(x[d>>2],x[d+4>>2],a);return((_g(x[d>>2],x[d+4>>2],a+1|0)<<8|e<<16|_g(x[d>>2],x[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+8>>2]=b;while(1){if(Ob(b,c)){x[d+4>>2]=x[b>>2];Nz(a,d+4|0);b=x[Fe(d+8|0)>>2];continue}else{hb=d+16|0}break}}function GT(a){var b=0;a:{if(Rb(a,16565,4)){break a}if(dc(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Lb(y[a+8|0]|y[a+9|0]<<8)}return b}function BA(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=hq(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){ic(a);hb=d+16|0}else{Nt(b,c);b=b+6|0;x[a+4>>2]=b;continue}break}}function qfa(){var a=0,b=0,c=0;a=hb-16|0;hb=a;b=Jc(1);x[23604]=0;Z(31);c=x[23604];x[23604]=0;if((c|0)!=1){b=x[lf(a+8|0,b)>>2];hb=a+16|0;return b|0}a=P()|0;Hb(b);T(a|0);p()}function Eh(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=0;Cj(c+8|0,c+24|0);gn(c+16|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+20>>2];v[b|0]=y[c+24|0];hb=c+32|0;return(a|0)==1|0}function via(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Im(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);if((b|0)==x[c+4>>2]){bc(a,x[c+12>>2])}hb=c+16|0}function nY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+82448>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function Oe(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+8>>2]=c;x[d+4>>2]=31;e=d,f=BU(b,c),x[e+12>>2]=f;c=b;b=jB(d+4|0);pi(c,c+b|0,a);e=Gb(a,b),f=0,v[e|0]=f;DU(a);hb=d+16|0}function $W(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;UC(b,0,a);x[23604]=0;a=S(111,b|0)|0;c=x[23604];x[23604]=0;if((c|0)!=1){xb(b);hb=b+16|0;return a|0}a=P()|0;xb(b);T(a|0);p()}function yW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=mb[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function faa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Qb(x[a>>2],x[a+8>>2],16);a:{if(!d){XB(b);break a}Bu(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function NE(a,b,c){var d=0;a:{if(!a){a=ba(8)|0;x[23604]=0;c=S(c|0,a|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){break a}b=P()|0;ca(a|0);T(b|0);p()}return}ha(c|0,b|0,904);p()}function Mv(a,b,c,d,e){var f=0;a:{f=Bs(4332);if(f){x[23604]=0;ja(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break a}}return f}a=P()|0;Hb(f);T(a|0);p()}function sA(a,b){var c=0,d=0;c=hb-16|0;hb=c;a=lh(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);hb=c+16|0}else{sm(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function pP(a,b){var c=0,d=0;c=hb-16|0;hb=c;a=lh(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);hb=c+16|0}else{nP(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function oY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+82448>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function kN(a,b,c){var d=0;d=c&15;if(d){v[b+824|0]=d}c=c&240;if(c){v[b+823|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;if(!(!d|!Tb(a+1074312|0,80))){v[b+824|0]=y[b+824|0]<<2}}function fk(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;if(bh(-1)>>>0<b>>>0){Sc();p()}si(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Cb(a),e=b+x[c+12>>2]|0,x[d>>2]=e;hb=c+16|0}function ZB(a,b){var c=0,d=0;c=hb-16|0;hb=c;a=zi(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);hb=c+16|0}else{Uu(b);b=b+2|0;x[a+4>>2]=b;continue}break}}function VE(a,b){var c=0,d=0;c=hb-16|0;hb=c;a=tk(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);hb=c+16|0}else{qg(b);b=b+1|0;x[a+4>>2]=b;continue}break}}function Il(a){a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function BF(a,b){var c=0,d=0;c=hb-16|0;hb=c;a=lh(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){ic(a);hb=c+16|0}else{wF(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function ut(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=y[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function fo(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Qb(x[a>>2],x[a+8>>2],4);a:{if(!d){yS(b);break a}zh(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function W9(a,b){a=a|0;b=b|0;var c=0;a=ag(a);c=gj(x[b>>2]);b=xf(b);x[23604]=0;U(760,a|0,c|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){return a|0}b=P()|0;XM(a);T(b|0);p()}function TH(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function pC(a,b,c){var d=0;d=hb-16|0;hb=d;a=xo(d,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){oj(b,z[c>>1]);b=x[a>>2]+2|0;x[a>>2]=b;continue}break}Hd(a);hb=d+16|0}function Zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;oD(b,c);if(Qb(x[a>>2],x[a+8>>2],c<<3)){nD(d+8|0,x[b>>2],x[b+4>>2]);qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0}function Zda(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;d=-1;a:{if(!pQ(a,c)){break a}d=0;if(!oQ(c)){break a}d=De(a,b,nQ(y[c+31|0],y[c+33|0]),lb)}hb=c+48|0;return d|0}function Mx(a,b,c,d){var e=0;e=hb-16|0;hb=e;d=lh(e,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){Un(a,x[b>>2]);a=a+4|0;b=b+4|0;continue}break}x[d+4>>2]=a;ic(d);hb=e+16|0}function MO(a,b,c,d){var e=0;e=hb-16|0;hb=e;d=zi(e,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){oj(a,z[b>>1]);a=a+2|0;b=b+2|0;continue}break}x[d+4>>2]=a;ic(d);hb=e+16|0}function rQ(a,b){var c=0;c=hb-32|0;hb=c;aR(c+24|0,a);ve(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=Ic(x[c+24>>2],x[c+28>>2],c+8|0);hb=c+32|0;return a}function mA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;wS(b,c);if(Qb(x[a>>2],x[a+8>>2],c<<2)){vS(d+8|0,x[b>>2],x[b+4>>2]);qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0}function lW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Fb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function Vt(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;d=hb-16|0;hb=d;SO(d+8|0,a,b,c);a=x[d+8>>2];x[d+4>>2]=x[d+12>>2];yd(e+8|0,a,d+4|0);hb=d+16|0;hb=e+16|0;return x[e+12>>2]}function Iz(a,b,c,d){var e=0;e=hb-16|0;hb=e;d=tk(e,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){sk(a,y[b|0]);a=a+1|0;b=b+1|0;continue}break}x[d+4>>2]=a;ic(d);hb=e+16|0}function DS(a,b,c){var d=0;d=hb-16|0;hb=d;a=Lv(d,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){sk(b,y[c|0]);b=x[a>>2]+1|0;x[a>>2]=b;continue}break}Hd(a);hb=d+16|0}function zW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Fb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function x0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a=Dw(Qa(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);hb=e+16|0;lb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function w0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Eb(x[b+4>>2],y[b+11|0]);e=a;a=Eb(x[c+4>>2],y[c+11|0]);b=Te(Pb(xw(e,d+a|0)),Pb(b),d)+d|0;gl(Te(b,Pb(c),a)+a|0,1,0)}function jP(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function VO(a,b,c,d){var e=0;e=hb-32|0;hb=e;jm(e+24|0,b,c);el(e+16|0,x[e+24>>2],x[e+28>>2],d);b=UO(b,x[e+16>>2]-b>>1);x[e+12>>2]=x[e+20>>2];yd(a,b,e+12|0);hb=e+32|0}function SS(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;b=jc(b);a=ph(a,Jc(32),qh(d+8|0,b));b=x[a>>2]+16|0;w[b>>1]=z[x[c>>2]>>1];Kb(b+4|0);e=jc(a),f=1,v[e+4|0]=f;hb=d+16|0}function R8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;c=ff(a,c);_d(d,x[a+28>>2]);a:{if(!c){e=0;if(fd(a,5)){break a}}_S(x[a+28>>2],b);e=c}_e(a,e);hb=d+16|0}function Nz(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Cb(a)>>2]){c=hb-16|0;hb=c;a=lh(c,a,1);Un(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;ic(a);hb=c+16|0;return}Cz(a,b)}function I1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Tw(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function bH(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=nh(b),d=x[x[a>>2]+52>>2],mb[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return nh(b)}function Rea(){var a=0,b=0,c=0;a=hb-16|0;hb=a;b=Xb(a,10157);x[23604]=0;Y(35,b|0);c=x[23604];x[23604]=0;if((c|0)!=1){xb(b);hb=a+16|0;return}a=P()|0;xb(b);T(a|0);p()}function Tha(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[b>>2],x[b+8>>2],6)){v[c|0]=0;Mh(a,6,c);break a}TA(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function EP(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;vz(a+112|0,48e3);x[a+668>>2]=0;uz(a+724|0);uz(a+732|0);uz(a+740|0);Oh(a+788|0);return a}function Bea(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[b>>2],x[b+8>>2],5)){v[c|0]=0;Mh(a,5,c);break a}nu(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function xm(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[b>>2],x[b+8>>2],4)){v[c|0]=0;Mh(a,4,c);break a}zh(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function jB(a){var b=0,c=0;a:{c=zb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=Np(x[b>>2],x[a>>2])?b:a;continue}}return x[a>>2]}function O$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e>>2]=c;x[e+4>>2]=d;x[e+8>>2]=c;x[e+12>>2]=d;a=PG(a,e,b);x[a>>2]=77476;hb=e+16|0;return a|0}function DX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=x[c>>2];a=mb[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}hb=d+16|0;return a|0}function Cp(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function mP(a,b){var c=0;c=x[a+4>>2];a:{if((b|0)>=0){b=b+c|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+c|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function lM(a){var b=0,c=0,d=0;b=x[a+112>>2];if((b|0)>=11){b=378;while(1){if(b|c){kM(a);d=b;b=b-1|0;c=c-!d|0;continue}break}b=0}x[a+112>>2]=b+1;a=kM(a);return a}function Vp(a){var b=0,c=0,d=0,e=0;b=x[a+4>>2];c=x[b>>2];x[a+4>>2]=c;if(c){Nl(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(oh(a)?0:4)|0,e=b,x[d>>2]=e;x[b>>2]=a;Nl(a,b)}function Up(a){var b=0,c=0,d=0,e=0;b=x[a>>2];c=x[b+4>>2];x[a>>2]=c;if(c){Nl(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(oh(a)?0:4)|0,e=b,x[d>>2]=e;x[b+4>>2]=a;Nl(a,b)}function Uj(a,b){var c=0;c=hb-32|0;hb=c;x[c+24>>2]=0;wv(c+8|0,c+24|0);gn(c+16|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+20>>2];x[b>>2]=x[c+24>>2];hb=c+32|0;return(a|0)==4}function Uea(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-80|0;hb=d;c=-1;a:{if(!qU(a,d+8|0)){break a}c=0;if(!hR(d+8|0)){break a}c=De(a,b,gR(d+8|0),lb)}hb=d+80|0;return c|0}function Lx(a,b,c,d){var e=0;e=hb-16|0;hb=e;d=hq(e,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){Nt(a,b);a=a+6|0;b=b+6|0;continue}break}x[d+4>>2]=a;ic(d);hb=e+16|0}function B9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=oi(b),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[nj(c+12|0,c+8|0,44352)>>2],x[d+36>>2]=e;fp(a);hb=c+16|0}function pc(a,b){var c=0;a=Ml(a);x[a+4>>2]=0;x[a>>2]=49600;c=Ld(Qc(x[b+4>>2],y[b+11|0])+1|0);x[a+4>>2]=c;if(c){vc(c,Pb(b),Qc(x[b+4>>2],y[b+11|0])+1|0)}return a}function ah(a,b,c){var d=0;if(a>>>0<b>>>0){return vc(a,b,c)}if(c){d=a+c|0;b=b+c|0;while(1){d=d-1|0;b=b-1|0;v[d|0]=y[b|0];c=c-1|0;if(c){continue}break}}return a}function Tr(a){var b=0;a:{if((Ke(a)|0)!=79){break a}if((Ke(a)|0)!=103){break a}if((Ke(a)|0)!=103){break a}b=(Ke(a)|0)==83}if(!b){gc(a,30);return 0}return MH(a)}function Iaa(a,b){a=a|0;b=b|0;a=zc(a);v[a+534|0]=0;x[a+4>>2]=0;x[23604]=0;R(711,a|0,b|0);b=x[23604];x[23604]=0;if((b|0)!=1){return a|0}b=P()|0;ej(a);T(b|0);p()}function GN(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Cb(a)>>2]){c=hb-16|0;hb=c;a=ot(c,a,1);hr(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;ic(a);hb=c+16|0;return}PD(a,b)}function Fu(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[b>>2],x[b+8>>2],2)){v[c|0]=0;YB(a,c);break a}ql(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Sb(a+8|0);x[23604]=0;U(230,a|0,b|0,c|0);a=x[23604];x[23604]=0;if((a|0)!=1){break a}a=P()|0;fc(d);T(a|0);p()}}function BI(a,b){var c=0,d=0;d=a+4|0;c=Rc(x[d>>2],x[a+8>>2]);a=x[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=Rf(c);if(a>>>0<=b>>>0){break a}}b=DI(a,65536)}Fi(d,b)}}function tJ(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function lV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=-1;if(ig(a,c+8|0)){x[c+4>>2]=y[c+8|0];d=MB(a,b,x[Fb(c+4|0,c+12|0)>>2])}hb=c+16|0;return d|0}function cm(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(F(a)<2147483648){return~~a}b=-2147483648}return b}function RB(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=-1;if(ig(a,c+8|0)){x[c+4>>2]=y[c+8|0];d=JB(a,b,x[Fb(c+4|0,c+12|0)>>2])}hb=c+16|0;return d|0}function OT(a){var b=0;if(!(Rb(a,17696,8)|y[a+8|0]>1|((y[a+9|0]-1&255)>>>0>7|(y[a+10|0]|y[a+11|0]<<8)>>>0>4096))){b=(y[a+12|0]|y[a+13|0]<<8)>>>0<4097}return b}function Fd(a,b){var c=0,d=0,e=E(0);c=hb-16|0;hb=c;x[c+8>>2]=1065353216;B[c+12>>2]=b;d=c,e=wf(a),B[d+4>>2]=e;a=B[Sp(c+4|0,c+12|0,c+8|0)>>2];hb=c+16|0;return a}function yz(a){var b=0;a=ee(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(F(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function o$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function kd(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;f=x[b+12>>2];x[e+8>>2]=c;x[e+12>>2]=d;g=x[x[b>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;mb[g|0](a,b,f,e);hb=e+16|0}function aD(a){var b=0;if(!(Rb(a,15368,4)|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function _W(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Cb(a)>>2]){c=hb-16|0;hb=c;a=uv(c,a);hr(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;ic(a);hb=c+16|0;return}PD(a,b)}function ZJ(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function H$(a,b){a=a|0;b=b|0;var c=0,d=0;b=lw(x[b>>2]);x[a+36>>2]=b;c=a,d=Fg(b),x[c+44>>2]=d;c=a,d=hn(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Fr(5524);p()}}function A$(a,b){a=a|0;b=b|0;var c=0,d=0;b=pw(x[b>>2]);x[a+36>>2]=b;c=a,d=Fg(b),x[c+44>>2]=d;c=a,d=hn(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Fr(5524);p()}}function r$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function lda(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-48|0;hb=d;c=-1;a:{if(!pQ(a,d)){break a}c=0;if(!AP(d)){break a}c=De(a,b,zP(y[d+47|0]),lb)}hb=d+48|0;return c|0}function bc(a,b){a=a|0;b=b|0;var c=0;c=Qb(x[a>>2],x[a+8>>2],b);a:{if(c){b=x[a+8>>2]+b|0;break a}b=x[a>>2];b=mb[x[x[b>>2]+24>>2]](b)|0}x[a+8>>2]=b;return c|0}function RP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;while(1){if((b|0)==(c|0)){hb=d+16|0}else{x[d+12>>2]=x[b>>2];Nz(a,d+12|0);b=b+4|0;continue}break}}function Ie(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[jc(a)>>2];x[23604]=0;Y(a|0,c|0);a=x[23604];x[23604]=0;if((a|0)==1){break a}}return}V(0)|0;Vb();p()}function rM(){var a=0,b=0,c=0,d=0;a=hb-16|0;hb=a;b=a+8|0;while(1){if(c>>>0<32){c=c+48|0;d=gy(94456);continue}break}x[b>>2]=d;Hn(b);hb=a+16|0;return x[b>>2]}function ng(a,b){var c=0,d=0,e=0;c=Pb(a);a=Eb(x[a+4>>2],y[a+11|0]);e=If(b);d=0;a:{if(!e){break a}a=a+c|0;b=ND(c,a,b,b+e|0);d=(a|0)==(b|0)?-1:b-c|0}return d}function hZ(a){a=a|0;if(y[468016]){return x[117003]}if(!y[469176]){v[469176]=1}ld(469152,88912);ld(469164,88924);v[468016]=1;x[117003]=469152;return 469152}function Waa(a,b){a=a|0;b=b|0;a=Sb(a);v[a+16|0]=0;x[a+12>>2]=b;x[23604]=0;Y(704,a|0);b=x[23604];x[23604]=0;if((b|0)!=1){return a|0}b=P()|0;fz(a);T(b|0);p()}function Uz(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+8>>2]=a;c=c&65535;while(1){if(!(!Ob(a,b)|(c|0)==z[a>>1])){a=x[Pe(d+8|0)>>2];continue}break}hb=d+16|0;return a}function UY(a){a=a|0;if(y[468008]){return x[117001]}if(!y[469144]){v[469144]=1}Zc(469120,13722);Zc(469132,13701);v[468008]=1;x[117001]=469120;return 469120}function Js(a,b){var c=0,d=0,e=E(0);c=hb-16|0;hb=c;B[c+12>>2]=b;x[c+8>>2]=0;x[c+4>>2]=1065353216;d=a,e=B[Sp(c+12|0,c+8|0,c+4|0)>>2],B[d+144>>2]=e;hb=c+16|0}function Jc(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Ld(a);if(b){break a}b=x[117421];if(b){mb[b|0]();continue}break}ha(Ol(ba(4)|0)|0,92520,25);p()}return b|0}function nB(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function mW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function jT(a,b){var c=0;c=Jia(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+lb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;lb=b>>>0<256?a+1|0:a;return b}function Wh(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function Ui(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;C[a>>3]=C[a>>3]-c;C[a+8>>3]=C[a+8>>3]-d}function Ow(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(a*E(B[((c&3)<<2)+65168>>2]*E(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function Fp(a,b){var c=0,d=0;a:{if(!a){break a}c=Jia(a,0,b,0);d=lb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Ld(c);if(!(!a|!(y[a-4|0]&3))){Zb(a,0,c)}return a}function Di(a,b,c,d,e){a:{e=Bs(e);if(e){x[23604]=0;fa(d|0,e|0,a|0,b|0,c|0)|0;a=x[23604];x[23604]=0;if((a|0)==1){break a}}return e}a=P()|0;Hb(e);T(a|0);p()}function $C(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=x[b>>2];d=(mb[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0;a=x[b>>2];ec(c,d,(mb[x[x[a>>2]+24>>2]](a)|0)-x[b+8>>2]|0)}function gH(a,b,c){var d=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+24>>2]=0;x[d+12>>2]=4;Ar(d+16|0,a,d+24|0,x[Fb(d+28|0,d+12|0)>>2]);x[b>>2]=x[d+24>>2];hb=d+32|0}function XS(a,b,c,d){var e=0;e=hb-32|0;hb=e;jm(e+24|0,b,c);el(e+16|0,x[e+24>>2],x[e+28>>2],d);b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];yd(a,b,e+12|0);hb=e+32|0}function AW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function qn(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=Ld(b)}return c}function d6(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=Iy(E(E(E(E(A[x[a+16>>2]+24620>>2])/E(3))+E(-80))/E(15920)),E(0),E(1)),B[b+4272>>2]=c;_J(a);ZJ(a)}function W4(a,b,c){a=a|0;b=b|0;c=c|0;a=gs(a,x[b+28>>2]);BJ(b+28|0,c);x[23604]=0;R(69,b|0,1);b=x[23604];x[23604]=0;if((b|0)==1){b=P()|0;$b(a);T(b|0);p()}}function Tg(a){var b=0,c=0;b=x[a>>2];c=x[b+4>>2];a:{if(!c){while(1){if(!oh(b)){b=x[b+8>>2];continue}break}b=x[b+8>>2];break a}b=_R(c)}x[a>>2]=b;return a}function Rb(a,b,c){var d=0,e=0;a:{while(1){d=y[a|0];e=y[b|0];if((d|0)!=(e|0)){break a}b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break}return 0}return d-e|0}function mm(a,b){var c=0,d=0,e=0;Wt(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Cb(b);d=Cb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function gY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function Yc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(mb[x[x[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}x[a+8>>2]=b;c=1}return c|0}function Vd(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;Db(b);continue}break}x[a+4>>2]=c;b=x[a>>2];ik(a);Hb(b)}}function VP(a,b){var c=0,d=0,e=0;Ft(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Cb(b);d=Cb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function RQ(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-56|0;rt(b);continue}break}x[a+4>>2]=c;b=x[a>>2];PQ(a);Hb(b)}}function QR(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;yb(b);continue}break}x[a+4>>2]=c;b=x[a>>2];zt(a);Hb(b)}}function Is(a,b,c){var d=0;a:{if(b&134218752){break a}if(!Ij(c)){break a}b=y[c+34|0];if((b+5&255)>>>0<6){break a}d=x[(D(b,160)+a|0)+906140>>2]}return d}function $w(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;Tj(b);continue}break}x[a+4>>2]=c;b=x[a>>2];lr(a);Hb(b)}}function xn(a,b){x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Zb(a+32|0,0,40);hH(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function PS(a,b,c){var d=0;d=hb-32|0;hb=d;x[d+28>>2]=c;v[d+24|0]=0;x[d+12>>2]=1;Ar(d+16|0,a,d+24|0,x[Fb(d+28|0,d+12|0)>>2]);v[b|0]=y[d+24|0];hb=d+32|0}function Hv(a,b,c,d){var e=0;e=ba(8)|0;x[23604]=0;a=Q(d|0,e|0,a|0)|0;d=x[23604];x[23604]=0;if((d|0)!=1){ha(a|0,c|0,b|0);p()}a=P()|0;ca(e|0);T(a|0);p()}function B3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-32|0;hb=h;i=h+8|0;vI(i,b,c,d,e,f,g);dd(a,h+20|0);$l(i);hb=h+32|0}function nN(a,b,c){var d=0,e=0;x[b+56>>2]=0;d=b,e=Ln(a,z[b+70>>1],x[b+48>>2],c,0),w[d+68>>1]=e;if(!(!(y[a+480180|0]&5)|x[b+60>>2]==-1)){x[b+60>>2]=0}}function $u(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Qb(x[b>>2],x[b+8>>2],3)){v[c|0]=0;Mh(a,3,c);break a}_u(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function n1(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=lg(a,b);x[23604]=0;Q(53,a+12|0,c|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){break a}b=P()|0;xb(a);T(b|0);p()}}function eea(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-96|0;hb=d;c=-1;a:{if(!ZQ(a,d)){break a}c=0;if(!BQ(d)){break a}c=De(a,b,AQ(d),lb)}hb=d+96|0;return c|0}function _X(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function Wu(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function Hi(a,b){var c=0;if(re(y[a+11|0])){c=x[a>>2];ck(x[a+8>>2]);Hb(c)}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];bf(b,0);Ad(b,0)}function Fea(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-96|0;hb=d;c=-1;a:{if(!ZQ(a,d)){break a}c=0;if(!YQ(d)){break a}c=De(a,b,XQ(d),lb)}hb=d+96|0;return c|0}function vU(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;x[a+8>>2]=b;Md(b);continue}break}c=x[a>>2];if(c){yc(a);Hb(c)}}function kL(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;x[a+8>>2]=b;Nk(b);continue}break}c=x[a>>2];if(c){yc(a);Hb(c)}}function gr(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;Db(b);continue}break}c=x[a>>2];if(c){fr(a);Hb(c)}}function cz(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;Wk(b);continue}break}c=x[a>>2];if(c){fr(a);Hb(c)}}function cv(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;x[a+8>>2]=b;Pq(b);continue}break}c=x[a>>2];if(c){yc(a);Hb(c)}}function aM(a){if(y[a+480224|0]==2){return+A[a+1074420>>2]/1e4}return+A[a+24620>>2]/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))*60}function St(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;x[a+8>>2]=b;yb(b);continue}break}c=x[a>>2];if(c){yc(a);Hb(c)}}function OQ(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;x[a+8>>2]=b;rt(b);continue}break}c=x[a>>2];if(c){yc(a);Hb(c)}}function OJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;c=vJ(Jc(12));x[c+8>>2]=b;x[c+4>>2]=a;x[c>>2]=49500;a=x[lf(d+8|0,c)>>2];hb=d+16|0;return a|0}function MX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Hg(a,x[b+8>>2],f)){Rv(b,c,d,e);return}a=x[a+8>>2];mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function Bp(a,b,c){a:{if(!Tb(c+1074312|0,102)){break a}c=z[a+692>>1]+1|0;w[a+784>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+784>>1]=c|32768}x[a+692>>2]=b}function xO(a){var b=0,c=0,d=0;d=y[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=y[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function rT(a,b){var c=0;c=Jia(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+lb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;lb=b>>>0<11?a+1|0:a;return b}function YE(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function ST(a){v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function N$(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;mb[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function Lia(a,b,c){var d=0;d=b>>31;a=a^d;Hia(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);lb=kb;a=d^jb;b=a-d|0;lb=(d^lb)-((a>>>0<d>>>0)+d|0)|0;return b}function $y(a,b,c){var d=0,e=0,f=0;d=Vk(a,b);if((d|0)!=255){e=cc(a+26|0,d),f=c,w[e>>1]=f;a=a+62|0;e=Gb(a,b),f=255,v[e|0]=f;e=Gb(a,c),f=d,v[e|0]=f}}function z4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-32|0;hb=h;i=h+8|0;vI(i,b,c,d,e,f,g);dd(a,i);$l(i);hb=h+32|0}function y6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=1){c=Fd(c,E(0));if((b|0)==1){d=1;c=Lh(c)}e=zb(a+4208|0,d),f=c,B[e>>2]=f;fK(a)}}function hE(a,b,c){var d=0;d=hb-32|0;hb=d;v[d+24|0]=44;x[d+16>>2]=-1;x[d+20>>2]=0;x[d+8>>2]=1058;x[d+12>>2]=c;dE(a,b,d+8|0,57,74,73,60);hb=d+32|0}function cD(a){a=a|0;var b=0;a=Kb(a);x[23604]=0;S(160,a+12|0)|0;b=x[23604];x[23604]=0;if((b|0)!=1){zc(a+32|0);return a|0}b=P()|0;xb(a);T(b|0);p()}function SB(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0}function xw(a,b){var c=0,d=0;if(b>>>0<2147483632){if(io(b)){hv(a);bf(a,b);return a}c=Xj(b)+1|0;d=Jc(c);cg(a,c);Ad(a,d);oe(a,b);return a}dg();p()}function ow(a){var b=0,c=0;b=hb-16|0;hb=b;c=-1;a:{if(Aw(a)){break a}if((mb[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}hb=b+16|0;return c}function mr(a,b,c,d){var e=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=c;x[e+12>>2]=d;dE(a,b,e+8|0,70,76,75,71);hb=e+32|0}function _K(a){var b=0;b=hb-16|0;hb=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;a=B[Sp(b+12|0,b+8|0,b+4|0)>>2];hb=b+16|0;return a}function Zo(a,b){var c=0;a:{if(!TH(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function LD(){var a=0,b=0,c=0;b=hb-16|0;hb=b;a=Xb(b,14892);if(Qc(x[a+4>>2],y[a+11|0])){c=(ng(a,13723)|0)!=-1}else{c=0}xb(a);hb=b+16|0;return c|0}function Ff(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;w[c+24>>1]=0;xl(c+8|0,c+24|0);gn(c+16|0,a,x[c+8>>2],x[c+12>>2]);w[b>>1]=z[c+24>>1];hb=c+32|0}function fN(a,b){v[a+840|0]=b;v[a+812|0]=b;v[a+811|0]=b;v[a+809|0]=b;v[a+807|0]=b;v[a+806|0]=b;v[a+833|0]=b;v[a+826|0]=b>>>4;v[a+827|0]=b<<2&60}function cQ(a){a=a|0;var b=0,c=0;w[a+34>>1]=0;b=hb-16|0;hb=b;v[b+15|0]=0;c=a+43|0;Ql(c,c+22|0,b+15|0);hb=b+16|0;x[a+20>>2]=0;od(a,0);return a|0}function Yj(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=kB(a,e,d);break a}a=kB(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function N8(a,b){a=a|0;b=b|0;var c=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);c=rc(x[b>>2],x[b+4>>2]);if(c){bk(a,c);Mx(a,x[b>>2],x[b+4>>2],c)}return a|0}function Jz(a,b){a=a|0;b=b|0;var c=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);c=Rc(x[b>>2],x[b+4>>2]);if(c){fk(a,c);Iz(a,x[b>>2],x[b+4>>2],c)}return a|0}function xQ(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}Xc(a,8,1,0,10);return}b=16;if(e){break a}}b=8}Xc(a,b,c&2|1,0,d^1)}function mc(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;x[f+8>>2]=d;x[f+12>>2]=e;g=x[x[b>>2]+28>>2];x[f>>2]=d;x[f+4>>2]=e;mb[g|0](a,b,c,f);hb=f+16|0}function kJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=If(b);e=a;a=Eb(x[c+4>>2],y[c+11|0]);b=Te(Pb(xw(e,d+a|0)),b,d)+d|0;gl(Te(b,Pb(c),a)+a|0,1,0)}function bfa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=kg(b);kg(b);break a}a=Cg(b);Cg(b)}while(1){if(a){if(a&1){bc(b,260)}a=a>>>1|0;continue}break}}function WR(a){var b=0;if(!(Rb(a,14879,3)|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-2147483647>>>0<2147484072)){b=y[a+3|0]<6}return b}function Tm(a,b){var c=0,d=0;d=x[a+4>>2];c=x[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;x[a+8>>2]=c;continue}break}b=x[a>>2];if(b){yc(a);Hb(b)}}function Ry(a){var b=0,c=0;b=hb-16|0;hb=b;x[b+8>>2]=a;c=b+8|0;a=1;while(1){if((a|0)>0){Tg(c);a=a-1|0;continue}break}hb=b+16|0;return x[b+8>>2]}function K5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){hx(a,0,0,0,0,0,0,c,d);return}hx(a,x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2],x[b+24>>2],b,c,d)}function FS(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;f=c-b|0;c=D((f|0)/6|0,6);g=e,h=ah(d,b,f)+c|0,x[g+12>>2]=h;yd(a,b+c|0,e+12|0);hb=e+16|0}function CH(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function qV(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+12>>2]=-1;if(ig(a,c+8|0)){x[c+4>>2]=y[c+8|0];OB(a,b,x[Fb(c+4|0,c+12|0)>>2])}hb=c+16|0}function iE(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){fr(a);Hb(b)}}function Vh(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function Us(a,b){var c=0,d=0;d=nf(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!pe(a,b,d&65535)){continue}}break}return c&65535}function MU(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+12>>2]=-1;if(ig(a,c+8|0)){x[c+4>>2]=y[c+8|0];lB(a,b,x[Fb(c+4|0,c+12|0)>>2])}hb=c+16|0}function Hm(a,b){var c=0;a=Mm(a);x[a>>2]=61724;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function DP(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){fr(a);Hb(b)}}function $P(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){fr(a);Hb(b)}}function z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=g+8|0;wI(h,b,c,d,e,f);dd(a,g+20|0);$l(h);hb=g+32|0}function eB(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;w[c+14>>1]=1;d=c,e=il(a,b),w[d+12>>1]=e;a=z[Se(c+14|0,c+12|0)>>1];hb=c+16|0;return a-1&65535}function Yy(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];x[a>>2]=d<<8^x[((y[b|0]^d>>>24)<<2)+29564>>2];b=b+1|0;continue}break}return a}function Vf(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){iz(a);Hb(b)}}function ye(a,b,c){v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a}function so(a,b){var c=0;a:{if(!b){break a}if(!Qb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=zC(a,b);break a}c=kg(a);bc(a,b-4|0)}return c}function Nb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=117){Qp(12017);p()}e=d+8|0;Jb(e,a,b);sg(e,c);hb=d+16|0;return a|0}function Ku(a,b){var c=0;a:{if(!b){break a}if(!Qb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=1){c=yC(a,1);break a}c=Cg(a);bc(a,b-2|0)}return c}function Ab(a,b){var c=0;if(re(y[a+11|0])){Hb(x[a>>2])}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];bf(b,0);id(b,0);return a}function rY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Fb(a+12|0,a+8|0);hb=a+16|0;return x[b>>2]}function hH(a){var b=0,c=0;x[23604]=0;c=ga(1044)|0;b=x[23604];x[23604]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;Km(a);return}V(0)|0;Vb();p()}function aF(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=Ov(x[d>>2],c)}mb[x[x[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function Pk(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;c=x[a+24>>2];d=x[a+40>>2];x[b+12>>2]=1;a=x[_c(a+20|0,b+12|0)>>2];hb=b+16|0;return D(a,c+d|0)}function PK(a,b,c){var d=0,e=0;d=Oc(a);if(d>>>0>=c>>>0){qA(a,dl(Pb(a),b,c),c);return}e=a;a=Eb(x[a+4>>2],y[a+11|0]);Jp(e,d,c-d|0,a,0,a,c,b)}function naa(a){a=a|0;var b=0;b=x[a>>2];if(mb[x[x[b>>2]+32>>2]](b,0,32)|0){a=x[a>>2];a=mb[x[x[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function Vc(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=w[Je(b+8|0,rd(b+12|0,b+4|0))>>1];hb=b+16|0;return a}function Kz(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=Cb(b),d=0,x[c>>2]=d;return a}function Fz(a){a=50-(D(y[(a>>>4|0)+31904|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Ec((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function Bm(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Wb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;hb=d+16|0}function Am(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Wb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;hb=d+16|0}function uE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=x[a>>2];if(d>>>0<=127){d=x[(d<<2)+c>>2]}x[a>>2]=d;a=a+4|0;continue}break}return b}function S7(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=x[a+20>>2];ke(b,x[c+4>>2],x[c+8>>2]);IK(a,ec(b+8|0,x[b>>2],x[b+4>>2]),0);hb=b+16|0}function MT(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;b=c+8|0;$u(b,a);a=y[Gb(b,0)|0];d=y[Gb(b,1)|0];b=y[Gb(b,2)|0];hb=c+16|0;return a|d<<8|b<<16}function Fj(a){var b=0,c=0;b=Em(x[x[a+20>>2]+28>>2]);if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[(x[a+16>>2]+D(b,160)|0)+906300>>2]}return c}function x4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=g+8|0;wI(h,b,c,d,e,f);dd(a,h);$l(h);hb=g+32|0}function u0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=qv(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function bA(a){var b=0;b=Lb(y[a+26|0]|y[a+27|0]<<8);return((y[a+24|0]>15)+(y[a+25|0]>64)|0)+(Lb(y[a+22|0]|y[a+23|0]<<8)<<1>>>0<b>>>0)|0}function ad(a,b){var c=0,d=0,e=0;c=Nf(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=mb[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function Al(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;x[a+8>>2]=b;continue}break}a=x[a>>2];if(a){Hb(a)}}function m1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ix(x[a+32>>2],b,c,d,2);if(a>>>0<=15){a=y[a+44256|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function gV(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){Aq(b)}v[a|0]=1}return a|0}function b0(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){YG(b)}v[a|0]=1}return a|0}function Y9(a,b){a=a|0;b=b|0;a=vy(a);x[23604]=0;R(757,a|0,b|0);b=x[23604];x[23604]=0;if((b|0)==1){b=P()|0;rp(a);T(b|0);p()}return a|0}function L7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Tc(c&255))){KK(a,8,E(0))}a=Fj(a);if(a){mb[x[x[a>>2]+92>>2]](a,b,c,d,e)}}function ti(a,b,c){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24;v[a+4|0]=c;v[a+5|0]=c>>>8;v[a+6|0]=c>>>16;v[a+7|0]=c>>>24}function tE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a|0];if((d|0)>=0){d=x[(d<<2)+c>>2]}v[a|0]=d;a=a+1|0;continue}break}return b}function qaa(a,b){a=a|0;b=b|0;a=mu(a,b);if(!a){v[b+6|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0}return a|0}function ao(a){var b=0;a=ee(a);b=255;a:{if(a>=255){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b}function LR(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=-128;x[b+4>>2]=127;a=v[Je(b+8|0,rd(b+12|0,b+4|0))|0];hb=b+16|0;return a}function zf(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if(b>>>0>=117){Qp(11982);p()}d=c+8|0;Jb(d,a,b);sg(d,0);hb=c+16|0;return a|0}function vw(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return nh(v[b|0])|0}function Pr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function N6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;if(b>>>0<=4){c=Fd(c,E(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=Lh(c)}B[d>>2]=c;iK(a)}}function Hh(a,b){var c=0,d=0;c=x[a>>2];d=x[a+4>>2];b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Hc(c,d,(b>>31&a)+b|0)>>2]}function p0(a){a=a|0;var b=0;if((mb[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+1;a=nh(v[a|0])}else{a=-1}return a|0}function Rr(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function BH(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}aa(14086,13065,1180,5695);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function ri(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=y[Je(b+8|0,rd(b+12|0,b+4|0))|0];hb=b+16|0;return a}function _9(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if(b>>>0>=250){Qp(12017);p()}d=c+8|0;Jb(d,a,b);km(d);hb=c+16|0;return a|0}function l$(a){a=a|0;var b=0,c=0;b=x[x[a>>2]>>2];c=x[b+8>>2];a=x[b+4>>2];b=x[b>>2]+(c>>1)|0;if(c&1){a=x[a+x[b>>2]>>2]}mb[a|0](b)}function rE(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+8>>2]=a;x[d+12>>2]=b;x[d>>2]=c;x[d+4>>2]=0;a=Eq(d+8|0,d);hb=d+16|0;return x[a>>2]}function oE(a,b,c,d){a=Sb(a);x[23604]=0;U(d|0,a|0,b|0,c|0);b=x[23604];x[23604]=0;if((b|0)!=1){return a}b=P()|0;sc(a);T(b|0);p()}function mN(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(y[a+480180|0]&2){break a}}x[b+56>>2]=0;d=Ln(a,z[b+70>>1],x[b+48>>2],c,0)}return d}function iY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function d0(a){a=a|0;var b=0;if((mb[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+4;a=x[a>>2]}else{a=-1}return a|0}function be(a){var b=0;a=x[a+4>>2];if(a){if(Om(a)){a:{b=a+8|0;if(x[b>>2]){if((gv(b)|0)!=-1){break a}}mb[x[x[a>>2]+16>>2]](a)}}}}function Xp(a,b){var c=0;c=Eb(x[a+4>>2],y[a+11|0]);if((c|0)==(Eb(x[b+4>>2],y[b+11|0])|0)){a=Dn(Pb(a),Pb(b),c)}else{a=1}return!a}function WF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Br(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function Uy(a,b){var c=0;c=x[a+484360>>2];b=b&255;if(_i(c,x[a+484364>>2])>>>0<=b>>>0){return _b(c,y[a+484376|0])}return fj(c,b)}function SQ(a,b){var c=0;c=hb-16|0;hb=c;a=ec(c+8|0,(b>>>3&536870908)+a|0,1<<b);a=Mb(x[x[a>>2]>>2],x[a+4>>2]);hb=c+16|0;return a}function SF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=yr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function Kw(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}vc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function us(a){var b=0;b=C[a+4248>>3]/+A[x[a+16>>2]+24620>>2];C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*(C[a+4288>>3]/60)}}function uY(a){a=a|0;var b=0;b=hb-16|0;hb=b;Xh(Yh(b+8|0,x[a+8>>2]));hb=b+16|0;a=x[a+8>>2];if(!a){return 1}return(iF(a)|0)==1|0}function qJ(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=aJ(Jc(8));x[c+4>>2]=a;x[c>>2]=57256;a=x[lf(b+8|0,c)>>2];hb=b+16|0;return a|0}function el(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;f=c-b|0;if((b|0)!=(c|0)){ah(d,b,f)}x[e+12>>2]=d+f;yd(a,b+f|0,e+12|0);hb=e+16|0}function eE(a,b,c){a=Lh(a);a:{if(a>=b){break a}c=0;if(a<=E(0)){break a}if(a<E(4294967296)&a>=E(0)){c=~~a>>>0;break a}}return c}function cq(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function aY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function PB(a,b){var c=0;c=x[b+4>>2];if(c){hc(a,c,x[b>>2]);return}c=x[b+8>>2];b=x[b+12>>2];if(!tc(c,b)){ke(a,c,b);return}Yd(a)}function HO(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){oe(b,a)}if(c){oe(c,a)}if(d){oe(d,a)}if(e){oe(e,a)}}function xq(a,b){return Np(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24),y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))?b:a}function mS(a,b){var c=0;c=hb-16|0;hb=c;a=lh(c,a,1);Pp(x[a+4>>2],z[b>>1]|z[b+2>>1]<<16);x[a+4>>2]=x[a+4>>2]+4;ic(a);hb=c+16|0}function al(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(mb[x[x[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}x[a+12>>2]=b;c=1}return c}function Tv(a,b){var c=0,d=0,e=0,f=0;c=If(b);d=Jc(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=vc(yc(d),b,c+1|0),x[e>>2]=f}function SO(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;f=b;b=c-b|0;g=e,h=ah(d,f,b)+b|0,x[g+12>>2]=h;yd(a,c,e+12|0);hb=e+16|0}function KX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Hg(a,x[b+8>>2],0)){Pv(b,c,d);return}a=x[a+8>>2];mb[x[x[a>>2]+28>>2]](a,b,c,d)}function JD(a){a=a|0;var b=0;a=Kb(a);x[23604]=0;R(122,a|0,13518);b=x[23604];x[23604]=0;if((b|0)==1){b=P()|0;xb(a);T(b|0);p()}}function bS(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;w[c+14>>1]=b;if((il(x[a>>2],x[a+4>>2])|0)!=65535){DB(a,c+14|0)}hb=c+16|0}function XF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]>>2]](a+8|0)|0;a=Br(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function Uf(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return Rn(a,d)}function TF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]>>2]](a+8|0)|0;a=yr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function Kk(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;Px(a,c,d)}function CN(a){By(a);x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;a=ag(a);ag(a+12|0);v[a+24|0]=1}function BT(a){var b=0;a:{if(Rb(a,3863,4)){break a}if(Rb(a+44|0,17688,3)){break a}b=(y[a+47|0]|y[a+48|0]<<8)>>>0>97}return b}function dK(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=sc(b-24|0);if((c|0)!=(b|0)){continue}break}return uf(a)|0}function v7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=Rg(E(Fd(c,E(0))*E(127))),v[d|0]=e;rs(a)}}function mQ(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((y[a+b|0]-127&255)>>>0>160){continue}}break}return(b|0)==8}function k8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=Rg(E(Fd(c,E(0))*E(255))),v[d|0]=e;ws(a)}}function fE(a,b){x[a>>2]=b;hH(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Qz(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);d=b+c|0;c=ji(b,d);if(c){fk(a,c);xA(a,b,d,c)}}function EL(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function yo(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function fe(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function wC(a,b){var c=0;c=Jia(b&255,0,1536,0);b=lb;a=Jia(a&255,0,25,0);c=a+c|0;b=lb+b|0;lb=a>>>0>c>>>0?b+1|0:b;return c}function _O(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){ZO(a,1);ZO(a,0)}}function VG(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function KR(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Nf(a,4)){yS(b);break a}zh(c+8|0,b);aA(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function KP(a){var b=0;if(!(y[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){x[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function Ig(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;x[f+12>>2]=e;c=Yh(f+8|0,c);a=Dr(a,b,d,x[f+12>>2]);Xh(c);hb=f+16|0;return a}function $O(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){YO(a,1);YO(a,0)}}function nX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return mb[a|0](h|b,c,d,e,b|f,g)|0}function hR(a){var b=0;if(!(Rb(a,13675,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64))){b=(y[a+33|0]-1&255)>>>0<32}return b}function gi(a,b,c){c=c&255;while(1){a:{if((a|0)!=(b|0)){if((c|0)!=y[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function bN(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Yb(x[a>>2]+((D(c<<24>>24,(d^-1|-256)+b|0)|0)/2|0)|0,0,256),x[e>>2]=f}}function Ws(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function Ke(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function xaa(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=lf(b+8|0,Zb(Jc(6668),0,6668));hb=b+16|0;x[a>>2]=x[c>>2];return a|0}function vi(a){var b=0;while(1){a:{if((b|0)!=46){if(y[b+44288|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function aG(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;b=Yh(d+8|0,b);a=yG(a,9164,x[d+12>>2]);Xh(b);hb=d+16|0;return a}function K$(a,b){a=a|0;b=b|0;var c=0,d=0;mb[x[x[a>>2]+24>>2]](a)|0;b=lw(x[b>>2]);x[a+36>>2]=b;c=a,d=hn(b),v[c+44|0]=d}function D$(a,b){a=a|0;b=b|0;var c=0,d=0;mb[x[x[a>>2]+24>>2]](a)|0;b=pw(x[b>>2]);x[a+36>>2]=b;c=a,d=hn(b),v[c+44|0]=d}function yg(a){var b=0;im(a);b=it(x[a>>2],gk(z[a+34>>1]));x[a+20>>2]=b;if(!b){return 0}return lj(x[a>>2],z[a+34>>1])}function x8(a){a=a|0;var b=0;b=hb-16|0;hb=b;if(!fd(a,4)){Sv(a)}a=x[Ib(b+8|0,Bb(x[a+44>>2]))>>2];hb=b+16|0;return a|0}function w8(a){a=a|0;var b=0;b=hb-16|0;hb=b;if(!fd(a,4)){Sv(a)}a=x[Ib(b+8|0,Bb(x[a+48>>2]))>>2];hb=b+16|0;return a|0}function hP(a){x[a+700>>2]=0;w[a+842>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function g6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=2){c=Fd(c,E(0));d=zb(a+4208|0,b),e=c,B[d>>2]=e;_J(a)}}function Vk(a,b){a=a+62|0;if(v[Gb(a,b)|0]<0){return 255}if(y[Gb(a,b)|0]!=255){a=y[Gb(a,b)|0]&127}else{a=255}return a}function U6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=4){c=Fd(c,E(0));d=zb(a+4208|0,b),e=c,B[d>>2]=e;kK(a)}}function Fo(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Pq(b);continue}break}x[a+4>>2]=c}function CU(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Md(b);continue}break}x[a+4>>2]=c}function $6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=5){c=Fd(c,E(0));d=zb(a+4208|0,b),e=c,B[d>>2]=e;oK(a)}}function $5(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=3){c=Fd(c,E(0));d=zb(a+4208|0,b),e=c,B[d>>2]=e;YJ(a)}}function xA(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;a=tk(e,a,d);f=a,g=OS(b,c,x[a+4>>2]),x[f+4>>2]=g;ic(a);hb=e+16|0}function qL(a){var b=0,c=0,d=0;if(x[a>>2]){Fc(a);b=x[a>>2];_t(a);Hb(b);c=Cb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function oi(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=x[Fb(b+12|0,b+8|0)>>2];hb=b+16|0;return a}function bh(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=Fb(b+12|0,b+8|0);hb=b+16|0;return x[a>>2]}function XR(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;a=lh(e,a,d);f=a,g=OS(b,c,x[a+4>>2]),x[f+4>>2]=g;ic(a);hb=e+16|0}function XN(a){var b=0,c=0,d=0;if(x[a>>2]){Fc(a);b=x[a>>2];Pm(a);Hb(b);c=Cb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function WO(a){var b=0,c=0,d=0;if(x[a>>2]){Fc(a);b=x[a>>2];Dm(a);Hb(b);c=Cb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function Ft(a){var b=0,c=0,d=0;if(x[a>>2]){Fc(a);b=x[a>>2];Kh(a);Hb(b);c=Cb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function DG(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function zH(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function vc(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function mB(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function BQ(a){var b=0;if(!(Rb(a+44|0,13684,4)|y[a+29|0]!=16)){b=((y[a+42|0]|y[a+43|0]<<8)-1&65535)>>>0<2}return b}function zr(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}qc(a,b);a=a+4|0;continue}}}function jN(a,b){var c=0;c=b&15;if(c){v[a+827|0]=c<<2}b=b&240;if(b){v[a+826|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function jK(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function _G(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!tc(bH(c,b),-1)){break a}x[a>>2]=0}return a|0}function Ok(a,b){var c=0;c=b&15;if(c){v[a+824|0]=c<<2}b=b&240;if(b){v[a+823|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function HL(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];if((c|0)==(d|0)){a=AL(x[a>>2],c,x[b>>2],d)}else{a=1}return!a}function Cl(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}Xg(a,b);a=a+1|0;continue}}}function WP(a){if(Rb(a,13657,4)){a=0}else{a=(dc(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))|0)==1}return a}function R2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=mb[x[x[b>>2]+8>>2]](b)|0;d=c,e=Qf(a?a:21502),x[d>>2]=e}}function uk(a){var b=0;b=hb-16|0;hb=b;a=x[Ib(b+8|0,Pb(a)+(Eb(x[a+4>>2],y[a+11|0])<<2)|0)>>2];hb=b+16|0;return a}function aw(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(x[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function Qs(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function ym(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function sg(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function sE(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=zb(c,a);a=a+1|0;x[d>>2]=a<<b;continue}break}}function gL(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=w[Fb(b+12|0,b+8|0)>>1];hb=b+16|0;return a}function fd(a,b){var c=0;c=hb-16|0;hb=c;GF(c+8|0,a+24|0,b);a=Mb(x[x[c+8>>2]>>2],x[c+12>>2]);hb=c+16|0;return a}function bu(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=z[Fb(b+12|0,b+8|0)>>1];hb=b+16|0;return a}function au(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=(D(a,b)>>>0)/255;fe(c+12|0,0,15);hb=c+16|0;return y[c+12|0]}function YF(a,b){var c=0;c=hb-16|0;hb=c;a=tk(c,a,1);sk(x[a+4>>2],y[b|0]);x[a+4>>2]=x[a+4>>2]+1;ic(a);hb=c+16|0}function Hg(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!Vi(x[a+4>>2],x[b+4>>2])}function ep(a,b){var c=0;c=hb-32|0;hb=c;zh(c+16|0,b);gn(c+24|0,a,x[c+16>>2],x[c+20>>2]);zh(c+8|0,b);hb=c+32|0}function eM(a,b){var c=0;c=hb-16|0;hb=c;a=pz(c,a);Un(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;ic(a);hb=c+16|0}function Yt(a){var b=0;b=hb-16|0;hb=b;w[b+14>>1]=a;w[b+12>>1]=255;a=y[Wc(b+14|0,b+12|0)|0];hb=b+16|0;return a}function YX(){if(y[467884]){return x[116970]}gs(467876,x[MJ()>>2]);v[467884]=1;x[116970]=467876;return 467876}function Rk(a,b,c,d){var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;x[e+8>>2]=c;ec(a,b,x[Fb(e+12|0,e+8|0)>>2]);hb=e+16|0}function Nv(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=Ov(x[e>>2],h)}mb[x[x[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function ML(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function yaa(){var a=0;a=hb-16|0;hb=a;if(_a(a+12|0,4)|0){Or(x[116080],12517);p()}hb=a+16|0;return x[a+12>>2]}function ei(a){var b=0,c=0;x[x[a+20>>2]>>2]=a;c=x[a+12>>2];b=x[c>>2];x[a+4>>2]=b;if(b){x[b+8>>2]=a}x[c>>2]=a}function dH(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+36>>2]](a)|0}return nh(v[b|0])}function VF(a,b,c,d,e){b=Ji(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function RF(a,b,c,d,e){b=Ii(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function EO(a){var b=0;b=x[a+4>>2];w[a+70>>1]=y[((z[b+20>>1]>>>6|z[b+22>>1]<<4)&65535)+29424|0]>>>z[a+68>>1]}function zm(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=255;a=y[Fb(b+12|0,b+8|0)|0];hb=b+16|0;return a}function fga(a,b){a=a|0;b=b|0;if(!lS(a,b)){v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0}}function Pj(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;a=c+8|0;x[a>>2]=x[a>>2]+(b<<2);hb=c+16|0;return x[a>>2]}function PH(a,b,c,d){B[d+4>>2]=a+c;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=b+a}function Kx(a,b){a=Sb(a);x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Sb(a+24|0);Kb(a+36|0);x[a+48>>2]=b;return a}function DK(a,b){a=a|0;b=b|0;var c=0;c=Eb(x[a+4>>2],y[a+11|0]);if(c>>>0<b>>>0){hu(a,b-c|0,0);return}uS(a,b)}function AR(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(b>=0){C[a+8>>3]=b;x[a+16>>2]=3}return a}function xia(a,b){a=a|0;b=b|0;var c=0;b=hb-80|0;hb=b;c=-1;if(qU(a,b+8|0)){c=pU(b+8|0)}hb=b+80|0;return c|0}function pf(a){var b=0;b=hb-16|0;hb=b;a=x[Ib(b+8|0,Pb(a)+Eb(x[a+4>>2],y[a+11|0])|0)>>2];hb=b+16|0;return a}function nQ(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;lb=a>>>0>c>>>0?b+1|0:b;return c}function YQ(a){var b=0;if(!(Rb(a,17683,4)|y[a+5|0]!=16|(y[a+54|0]-33&255)>>>0<224)){b=y[a+4|0]>95}return b}function Xfa(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(sj(a,b+8|0)){c=WR(b+8|0)}hb=b+16|0;return c|0}function Ns(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Hn(a);continue}break}return a}function Ju(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function Cx(a,b){var c=0;c=Pb(a);if(c>>>0<=b>>>0){a=Eb(x[a+4>>2],y[a+11|0])+c>>>0>=b>>>0}else{a=0}return a}function xk(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function w3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return GE(a,b,c,d,e,f,g,12784,980)|0}function rr(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=Ov(x[d>>2],g)}mb[x[x[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function i3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return GE(a,b,c,d,e,f,g,12852,987)|0}function gF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function eu(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;xm(c+8|0,a);x[c+4>>2]=x[c+8>>2];Tt(c+4|0,b);hb=c+16|0}function eO(a,b){var c=0;c=x[a+484344>>2];if(pe(c,x[a+484348>>2],b)){a=x[ac(c,b)+12>>2]}else{a=1}return a}function WU(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(sj(a,b+8|0)){c=uB(b+8|0)}hb=b+16|0;return c|0}function Tb(a,b){var c=0;c=hb-16|0;hb=c;RC(c+8|0,a,b);a=Mb(x[x[c+8>>2]>>2],x[c+12>>2]);hb=c+16|0;return a}function mM(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Nk(c);continue}break}x[a+4>>2]=b}function ge(a,b){a=ul(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];ul(a+12|0,x[b+12>>2],x[b+16>>2]);return a}function dfa(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){Hp(a,b);qo(a,b,c)}return a|0}function _P(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;ZP(c);continue}break}x[a+4>>2]=b}function _N(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;He(c);continue}break}x[a+4>>2]=b}function YU(a){a=a|0;var b=0;b=x[a+76>>2];if(tc(-1,b)){b=lC(x[a+28>>2],32);x[a+76>>2]=b}return b<<24>>24}function Ub(a,b,c){var d=0;c=c+x[a+4>>2]|0;d=b;b=x[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;x[a>>2]=b;x[a+4>>2]=c}function OO(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Wk(c);continue}break}x[a+4>>2]=b}function $B(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;yb(c);continue}break}x[a+4>>2]=b}function tm(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){fk(a,b);wo(a,b,c)}return a|0}function bt(a,b){b=Jia(a,a>>31,b,b>>31);a=lb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Ec(Kia(b,a,1e6,0),lb)}function aT(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){Ot(a,b);BA(a,b,c)}return a|0}function TT(a){a:{if(Rb(a,14043,4)){break a}if(Rb(a+8|0,14024,4)){break a}return 1}return!Rb(a,14024,4)}function Oi(a){a:{a=a&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function FN(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}C[a>>3]=d}}function BV(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){bk(a,b);cC(a,b,c)}return a|0}function iF(a){var b=0,c=0;b=hb-16|0;hb=b;a=Yh(b+8|0,a);c=x[x[116108]>>2];Xh(a);hb=b+16|0;return c?4:1}function Tk(a,b,c,d){a=a&65535;c=c&65535;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function sP(a){if(((y[a+68|0]|y[a+69|0]<<8)-128&65535)>>>0>=65409){a=Rb(a,17531,17)}else{a=1}return!a}function fW(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=-1;if(sj(a,b+8|0)){c=aD(b+8|0)}hb=b+16|0;return c|0}function Zb(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function Wt(a){var b=0,c=0;if(x[a>>2]){Fc(a);Hb(x[a>>2]);b=Cb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function WA(a,b){if(b>>>0<=126){Qe(((b<<5)+a|0)+480280|0);Tn((D(b,872)+a|0)+1074992|0,a,b,134217728)}}function KW(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;c=-1;if(FD(a,b+8|0)){c=ED(b+8|0)}hb=b+32|0;return c|0}function uP(a){Xd(a+140|0);yb(a+120|0);yb(a+100|0);yb(a+80|0);yb(a+60|0);yb(a+40|0);yb(a+20|0);yb(a)}function tl(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function tM(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function ru(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0}function rm(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Ao(a,b+8|0)){c=dc(x[b+8>>2])}hb=b+16|0;return c|0}function pq(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Iq(a,b+8|0)){c=Lb(z[b+8>>1])}hb=b+16|0;return c|0}function p1(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;NB(c+8|0,b);Gq(a,x[c+8>>2],x[c+12>>2]);hb=c+16|0}function US(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){TS(c+52|0);xb(c+40|0);sc(c+16|0);sc(c+4|0);Hb(c)}}function PV(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Cm(c+8|0,b);Gq(a,x[c+8>>2],x[c+12>>2]);hb=c+16|0}function OV(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Oj(a+8|0,0);Fq(a,127);IC(a,127,y[b|0]);return a|0}function JR(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;w[a+14>>1]=0;return a}function vF(a,b,c){a:{if(!(y[b+120|0]|c>>>0>30)){v[b+120|0]=1;break a}b=KO(c)}x[a+4>>2]=c;x[a>>2]=b}function l1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=qz(ix(x[a+32>>2],b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function dd(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];hv(b);return a}function YL(a,b){if(b>>>0<=255){a=x[((b<<2)+a|0)+900380>>2];a=a?a+492|0:21502}else{a=21502}return a}function mfa(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(_A(a,b)){c=rR(b)}hb=b+16|0;return c|0}function jF(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;e=Yh(f+8|0,e);a=Er(a,b,c,d);Xh(e);hb=f+16|0;return a}function cO(a,b,c){var d=0;d=hb-16|0;hb=d;a=x[Ib(d+8|0,VN(b,c,Sd(a),jc(a)))>>2];hb=d+16|0;return a}function O2(a,b){a=a|0;b=b|0;var c=0;b=Pb(b);c=x[a+4>>2];if(c){mb[c|0](b,x[a+8>>2]);return}os(b,a)}function Lu(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=ig(a,b+15|0);hb=b+16|0;return(a?v[b+15|0]:0)<<24>>24}function Jfa(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Iq(a,b+8|0);hb=b+16|0;return(a?w[b+8>>1]:0)<<16>>16}function J7(a,b,c){a=a|0;b=b|0;c=c|0;a=Fj(a);if(!a){return 0}return mb[x[x[a>>2]+100>>2]](a,b,c)|0}function Fn(a,b,c,d){a=a&255;c=c&255;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function yF(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-4|0;continue}break}x[a+4>>2]=b}function Rw(a,b,c){b=(D(D(Pw(a),Qw(a,b)),125)>>>0)/(WH(a,b)>>>0)|0;a=(a&6)==6?b&-4:b;return a?a:c}function rz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function m0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+12>>2]](a,b,c,d,e,f)|0}function l0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function k0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function j0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function i0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function h0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function gn(a,b,c,d){var e=0;e=hb-16|0;hb=e;Kg(e+8|0,c,d);IG(a,b,x[e+8>>2],x[e+12>>2]);hb=e+16|0}function CE(a,b,c){var d=0;d=hb-16|0;hb=d;c=Xb(d,c);a=pc(a,c);xb(c);x[a>>2]=b;hb=d+16|0;return a}function Ar(a,b,c,d){var e=0;e=hb-16|0;hb=e;hc(e+8|0,c,d);IG(a,b,x[e+8>>2],x[e+12>>2]);hb=e+16|0}function u2(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=x[lf(b+8|0,Qj(Jc(12),a))>>2];hb=b+16|0;return a|0}function jR(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function aV(a,b){a=a|0;b=b|0;if(!ou(a,b)){v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b|0]=0}}function Xu(a,b){a=YC(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];YC(a+12|0,x[b+12>>2],x[b+16>>2])}function V$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function EX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Hg(a,x[b+8>>2],f)){Rv(b,c,d,e)}}function Cga(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Ao(a,b+8|0);hb=b+16|0;return E(a?B[b+8>>2]:E(0))}function C3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ME(a,b,c,d,e,f,10511,977)|0}function A4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return ME(a,b,c,d,e,f,10556,951)|0}function uU(a){var b=0;if(!(Rb(a,26708,20)|(y[a+25|0]-9&255)>>>0<248)){b=v[a+47|0]>=0}return b}function t9(a,b){a=a|0;b=b|0;hi(a);hi(a);a:{if(b>>>0>=60){bc(a,4);break a}hi(a)}return hi(a)|0}function sG(a){var b=0;b=x[116108];if(a){x[116108]=(a|0)==-1?467668:a}return(b|0)==467668?-1:b}function kr(a,b,c,d){var e=0;x[a>>2]=x[b>>2];e=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<d)+e;return a}function gU(a,b){return(Yb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((D(a&15,b)>>>0)/15|0,1,15))&255}function Yca(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){bk(a,b);pP(a,b)}return a|0}function MA(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;a=x[pT(c+8|0,0-b|0)>>2];hb=c+16|0;return a}function DH(a){var b=0;b=+((a&2097151)>>>0);return E(uj(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function ef(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=a;a=Xb(c,b);dd(d,a);xb(a);hb=c+16|0}function YP(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=D(c,12)+d;return a}function VA(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);if(b){fk(a,b);VE(a,b)}return a|0}function Ql(a,b,c){b=b-a|0;while(1){if((b|0)>0){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function Ic(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=MS(a,b,x[c>>2],d)}else{a=1}return!a}function vfa(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;c=a;a=xh(b+8|0);UR(c,a,0,0);yb(a);hb=b+32|0}function tQ(a){var b=0,c=0;b=hb-16|0;hb=b;if(sQ(a,b+8|0)){c=dc(x[b+8>>2])}hb=b+16|0;return c}function tG(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function fF(a){a=a|0;var b=0;x[a>>2]=82396;b=x[a+8>>2];if(!(!b|!y[a+12|0])){Hb(b)}return a|0}function f0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return mb[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function MV(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=ig(a,b+8|0);hb=b+16|0;return(a?y[b+8|0]:0)&255}function Wea(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Sh(a,b+8|0);hb=b+16|0;return+(a?C[b+8>>3]:0)}function UQ(a){a:{if(Rb(a,17476,4)){break a}if(Rb(a+8|0,14081,4)){break a}return 1}return 0}function EC(a,b){if((a&4088)>>>0>=520){b=Ou(0-Nia(b^1230262859,25)|0,4)^1247037516}return b}function Ay(a){var b=0;x[a+84>>2]=0;x[a+88>>2]=0;b=x[a+80>>2];x[a+92>>2]=b;x[a+96>>2]=b<<12}function Ag(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){WA(a,c);b=b+1|0;continue}break}}function $I(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=uK(d);b=b+1|0}QI(a,b,c,d,e)}function yl(a,b,c){var d=E(0);if(b>>>0<=c>>>0){d=B[zb(a+4208|0,b)>>2]}else{d=E(0)}return d}function fv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=x[(b<<2)+21504>>2]}else{b=9634}Xb(a,b)}function eK(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function cH(a){var b=0;b=x[a>>2];if(b){if(!tc(dH(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function YC(a,b,c){var d=0;d=hb-16|0;hb=d;b=ul(d+8|0,b,c);yD(b,a);be(b);hb=d+16|0;return a}function Xj(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function Vv(a,b,c){var d=0;d=hb-16|0;hb=d;c=Yh(d+8|0,c);a=Bw(a,b);Xh(c);hb=d+16|0;return a}function UO(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;a=x[TO(c+8|0,b)>>2];hb=c+16|0;return a}function U5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;hx(a,b,c,d,e,0,0,f,g)}function Ee(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;a=x[GS(c+8|0,b)>>2];hb=c+16|0;return a}function wJ(a){a=a|0;var b=0;x[a>>2]=49600;b=x[a+4>>2];if(b){Hb(b);x[a+4>>2]=0}return a|0}function nC(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;lb=b>>>0<2624?a+1|0:a;return b}function kw(a,b,c,d){var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;a=Dr(a,b,c,d);hb=e+16|0;return a}function bU(a,b,c){var d=0;d=hb-16|0;hb=d;ti(d+8|0,b,c);hb=d+16|0;return x[d+8>>2]==(a|0)}function O7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Fj(a);if(a){mb[x[x[a>>2]+76>>2]](a,b,c,d)}}function Nia(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function N7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Fj(a);if(a){mb[x[x[a>>2]+84>>2]](a,b,c,d)}}function M7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Fj(a);if(a){mb[x[x[a>>2]+88>>2]](a,b,c,d)}}function L4(a,b,c){a=a|0;b=b|0;c=c|0;mb[x[x[b>>2]+8>>2]](b,c);gs(a,x[b+4>>2]);BJ(b+4|0,c)}function Hx(a,b){if((a|0)>=0){return(a>>>0)%(b>>>0)|0}return(((a^-1)>>>0)%(b>>>0)^-1)+b|0}function Cg(a){var b=0;b=hb-16|0;hb=b;a=Iq(a,b+8|0);hb=b+16|0;return(a?z[b+8>>1]:0)&65535}function vM(a){a=Kb(a);Kb(a+12|0);Kb(a+24|0);Kb(a+36|0);Kb(a+48|0);x[a+60>>2]=0;return a}function nv(){var a=0,b=0;a=hb-16|0;hb=a;b=lf(a+8|0,Sb(Jc(12)));hb=a+16|0;return x[b>>2]}function dz(a,b){a=Qj(a,b);dd(a+12|0,b+12|0);w[a+28>>1]=z[b+28>>1];x[a+24>>2]=x[b+24>>2]}function cs(a){if(gJ(a)){a=ba(4)|0;x[a>>2]=0;a=Ml(a);x[a>>2]=92044;ha(a|0,92080,25);p()}}function aR(a,b){var c=0;c=hb-16|0;hb=c;Cm(c+8|0,b);NS(a,x[c+8>>2],x[c+12>>2]);hb=c+16|0}function Be(a){var b=0;b=hb-16|0;hb=b;a=ig(a,b+15|0);hb=b+16|0;return(a?y[b+15|0]:0)&255}function AM(a,b){var c=0;c=y[a+851|0];if(c&1){v[a+851|0]=c|64;x[a+852>>2]=x[a+852>>2]+b}}function xG(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=b;a=yG(a,11051,b);hb=c+16|0;return a}function ts(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=uK(d);b=b+1|0}px(a,b,c,d)}function pW(a){a=a|0;var b=0;b=x[a+4>>2];return(mb[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function op(a,b,c){a=Pk(a)-x[a+16>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function gl(a,b,c){var d=0;d=hb-16|0;hb=d;v[d+15|0]=c;Mh(a,b,d+15|0);hb=d+16|0;return a}function at(a){var b=0;b=hb-16|0;hb=b;v[b+15|0]=0;Ql(a,Vn(a),b+15|0);hb=b+16|0;return a}function WG(a){var b=0;b=x[a>>2];if(b){if(!ln(xk(b))){return!x[a>>2]}x[a>>2]=0}return 1}function Sp(a,b,c){var d=E(0);d=B[a>>2];if(!Lt(d,B[b>>2])){b=Lt(B[c>>2],d)?c:a}return b}function Q7(a,b){a=a|0;b=b|0;a=Fj(a);if(!a){return 1}return mb[x[x[a>>2]+68>>2]](a,b)|0}function Om(a){var b=0;b=gv(a+4|0);if((b|0)==-1){mb[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function Oh(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function Lv(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=c+d;return a}function HA(a){var b=0;b=oz(a);while(1){if((a|0)!=(b|0)){DU(a);a=a+32|0;continue}break}}function zP(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;lb=b>>>0<259?a+1|0:a;return b}function zD(a,b){var c=0;c=hb-16|0;hb=c;b=mg(c+8|0,b);yD(b,a);be(b);hb=c+16|0;return a}function yO(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function vB(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+26656|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function mk(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;zl(e,a+24|0,b);sg(e,c);hb=d+16|0}function SW(){var a=0;a:{if(MD(19924993)){break a}if(LD()){break a}a=KD()^1}return a|0}function Qk(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;Jb(d,a,b);km(d);hb=c+16|0;return a}function DN(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;zl(d,a,b);km(d);hb=c+16|0;return a}function Bc(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;Cm(d,a);ol(d,b);hb=c+16|0;return a}function Au(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;v[c+15|0]=b;xJ(a,c+15|0);hb=c+16|0}function y4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return LE(a,b,c,d,e,12340,952)|0}function qt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function pi(a,b,c){var d=0;d=hb-16|0;hb=d;XS(d+8|0,a,b,c);hb=d+16|0;return x[d+12>>2]}function os(a,b){a=a|0;b=b|0;b=hb-16|0;hb=b;x[b>>2]=a;LJ(17705,b);ns(93456);hb=b+16|0}function nl(a,b,c){a=a|0;b=b|0;c=c|0;if(Kc(a,b)>>>0<=c>>>0){Hu();p()}return(c<<1)+a|0}function eY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+80896>>2]}return b<<24>>24}function cY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+79360>>2]}return b<<24>>24}function ZY(a){a=a|0;a=469176;while(1){a=Gc(a-12|0);if((a|0)!=469152){continue}break}}function YY(a){a=a|0;a=469104;while(1){a=Gc(a-12|0);if((a|0)!=468816){continue}break}}function XY(a){a=a|0;a=468504;while(1){a=Gc(a-12|0);if((a|0)!=468336){continue}break}}function S_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return xE(b,c,d,e,f,1)|0}function Q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return xE(b,c,d,e,f,0)|0}function Ms(a,b){if(!(v[b+851|0]&1&x[a+480180>>2]==8)){Zx(a,b,0);Zx(a,b,1);Zx(a,b,2)}}function LY(a){a=a|0;a=469144;while(1){a=xb(a-12|0);if((a|0)!=469120){continue}break}}function KY(a){a=a|0;a=468800;while(1){a=xb(a-12|0);if((a|0)!=468512){continue}break}}function KF(a,b){var c=0,d=0;Ie(a,Wd(b));b=jc(b);c=jc(a),d=x[b>>2],x[c>>2]=d;return a}function Jt(a,b){var c=0;c=hb-16|0;hb=c;w[c+14>>1]=b;Et(a+236|0,128,c+14|0);hb=c+16|0}function JY(a){a=a|0;a=468328;while(1){a=xb(a-12|0);if((a|0)!=468160){continue}break}}function I_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return vE(b,c,d,e,f,1)|0}function G_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return vE(b,c,d,e,f,0)|0}function El(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function C0(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function B0(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function A3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return LE(a,b,c,d,e,12240,978)|0}function wg(a,b,c){var d=0;d=C[a>>3];if(!tP(d,C[b>>3])){b=tP(C[c>>3],d)?c:a}return b}function u3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FE(a,b,c,d,e,9518,981)|0}function sh(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;Oh(a)}function pe(a,b,c){if(wm(a,b,c)){a=Jf(a,c);a=Ob(x[a>>2],x[a+4>>2])}else{a=0}return a}function nj(a,b,c){var d=0;d=x[a>>2];if(!Vo(d,x[b>>2])){b=Vo(x[c>>2],d)?c:a}return b}function g3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FE(a,b,c,d,e,9590,988)|0}function cf(a){a=a|0;var b=0;b=x[a>>2];return(mb[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function Hn(a){var b=0;b=a;a=x[a>>2];x[b>>2]=D(a,214013)+2531011;return a>>>16&32767}function GP(a,b,c,d,e,f){a=Ib(a,b);Ib(a+4|0,c);Ib(a+8|0,d);Ib(a+12|0,e);Ib(a+16|0,f)}function Fv(a,b){var c=0;while(1){if((b|0)!=(c|0)){qg(a+c|0);c=c+1|0;continue}break}}function Dz(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function vG(a){return(a|0)!=0&(a|0)!=89120&(a|0)!=89144&(a|0)!=467584&(a|0)!=467608}function u7(a,b){a=a|0;b=b|0;return E(b>>>0<=2?E(E(y[(a+b|0)+4232|0])/E(127)):E(0))}function mg(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function kF(a){a=a|0;x[a>>2]=83480;if(x[a+8>>2]!=(zd()|0)){uG(x[a+8>>2])}return a|0}function j8(a,b){a=a|0;b=b|0;return E(b>>>0<=3?E(E(y[(a+b|0)+4264|0])/E(255)):E(0))}function hf(a){a=a|0;x[a+60>>2]=77300;x[a>>2]=77280;js(a+8|0);Ak(a+60|0);return a|0}function bq(a,b){var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=Ge(wj(b)*+(c>>>0)),x[d+24>>2]=e}function ap(a){a=a|0;x[a+56>>2]=77136;x[a>>2]=77116;js(a+4|0);Ak(a+56|0);return a|0}function YN(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[jc(a)+4|0]){ZN(b+16|0)}Hb(b)}}function Qw(a,b){return y[(D(a>>>1&3,15)+D(a>>>3&1,45)+((b&240)>>>4)|0)+64065|0]<<1}function QS(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[jc(a)+4|0]){Tj(b+16|0)}Hb(b)}}function Pd(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=49768;yd(a,49664,b+12|0);hb=b+16|0}function Lk(a,b,c){return x[(D(b,872)+a|0)+1075672>>2]>x[(D(c,872)+a|0)+1075672>>2]}function FL(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[jc(a)+4|0]){Db(b+16|0)}Hb(b)}}function B5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return JJ(a,b,c,d,0,0,0,0,e)|0}function nr(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,d);return a}function kg(a){var b=0;b=hb-16|0;hb=b;a=Ao(a,b+8|0);hb=b+16|0;return a?x[b+8>>2]:0}function iN(a,b){var c=0;c=b&15;if(c){v[a+830|0]=c}b=b&240;if(b){v[a+829|0]=b>>>4}}function gy(a){var b=0;b=hb-16|0;hb=b;Ib(b+8|0,a+116|0);a=lM(a);hb=b+16|0;return a}function a8(a){a=a|0;v[a+4202|0]=1;x[a+4232>>2]=x[x[a+16>>2]+24620>>2];ws(a);NK(a)}function Lo(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<d);return a}function K6(a){a=a|0;v[a+4202|0]=1;x[a+4256>>2]=x[x[a+16>>2]+24620>>2];iK(a);hK(a)}function GH(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function jr(a,b,c,d){if(b>>>0>=d>>>0){qi();p()}c=Jc(D(b,c));x[a+4>>2]=b;x[a>>2]=c}function aL(a,b,c){while(1){if(b){B[a>>2]=B[c>>2];b=b-1|0;a=a+4|0;continue}break}}function _n(a,b){a=vc(a,b,34);w[a+34>>1]=z[b+34>>1];vc(a+36|0,b+36|0,68);return a}function GC(a,b,c){while(1){if(b){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Et(a,b,c){while(1){if(b){w[a>>1]=z[c>>1];b=b-1|0;a=a+2|0;continue}break}}function AP(a){if((y[a+14|0]-53&255)>>>0>=252){a=Rb(a,15415,14)}else{a=1}return!a}function xf(a){var b=0;b=hb-16|0;hb=b;a=x[Ib(b+8|0,Ef(a))>>2];hb=b+16|0;return a}function pd(a){var b=0;b=hb-16|0;hb=b;a=x[Ib(b+8|0,Pb(a))>>2];hb=b+16|0;return a}function pX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=mb[a|0](b,c,d)|0;ib=lb;return a|0}function jl(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;kc(a+8|0,b+8|0)}function gj(a){var b=0;b=hb-16|0;hb=b;a=x[Ib(b+8|0,Bb(a))>>2];hb=b+16|0;return a}function LJ(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=b;sH(93456,a,b,0,0);hb=c+16|0}function Ef(a){var b=0;b=hb-16|0;hb=b;a=x[Ib(b+8|0,jc(a))>>2];hb=b+16|0;return a}function yv(a,b,c,d){if(b>>>0>=d>>>0){qi();p()}c=Jc(b<<c);x[a+4>>2]=b;x[a>>2]=c}function xv(a,b){b=a+b|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function xT(a,b,c){while(1){if(b){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function qY(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<2)+82448>>2]&b)!=0&c>>>0<=127}function ph(a,b,c){a=Ib(a,b);b=x[c+4>>2];x[a+4>>2]=x[c>>2];x[a+8>>2]=b;return a}function oX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[a|0](b,c,d,e,f)}function mda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;Av(a,b,c,d,e,280,526,526)}function jm(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;yd(a,b,d+12|0);hb=d+16|0}function ag(a){var b=0,c=0;zc(a+4|0);Oj(a+8|0,0);b=a,c=jc(a),x[b>>2]=c;return a}function _fa(a,b,c){a=a|0;b=b|0;c=c|0;dd(a,ZR(c,Pb(b),Eb(x[b+4>>2],y[b+11|0])))}function XD(){var a=0;a=hb-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function Wo(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;hj(a,b,d+12|0);hb=d+16|0}function Qh(a){return(rj(x[a>>2],x[a+4>>2])|0)!=(0-rj(x[a+12>>2],x[a+16>>2])|0)}function MZ(){var a=0,b=0,c=0;a=Nd(469232);x[a>>2]=83480;b=a,c=zd(),x[b+8>>2]=c}function Gc(a){var b=0;if(re(y[a+11|0])){b=x[a>>2];ck(x[a+8>>2]);Hb(b)}return a}function xu(a,b){return Ge(wj((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function qC(a){var b=0;b=hb-16|0;hb=b;v[b+15|0]=0;Ql(a,Go(a),b+15|0);hb=b+16|0}function lX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mb[a|0](b,c,d,e)|0}function gZ(a){a=a|0;if(!y[468112]){Ym(468100,83716);v[468112]=1}return 468100}function eZ(a){a=a|0;if(!y[468144]){Ym(468132,83800);v[468144]=1}return 468132}function cZ(a){a=a|0;if(!y[468048]){Ym(468036,83644);v[468048]=1}return 468036}function bea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;Av(a,b,c,d,e,100,99,125)}function Zn(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function U0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return cI(a-88|0,b,c,d,e)|0}function Tx(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Cb(a)>>2]){eM(a,b);return}Cz(a,b)}function Tu(a,b){var c=0;if((b|0)<0){qi();p()}c=Jc(b<<1);x[a+4>>2]=b;x[a>>2]=c}function TY(a){a=a|0;if(!y[468096]){Xb(468084,13356);v[468096]=1}return 468084}function NY(a){a=a|0;if(!y[468064]){Xb(468052,13565);v[468064]=1}return 468052}function JT(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Cb(a)>>2]){YF(a,b);return}UF(a,b)}function $Y(a){a=a|0;if(!y[468080]){Ym(468068,83680);v[468080]=1}return 468068}function ze(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;Pu(d,a);ol(d,b);hb=c+16|0}function yP(a,b){a=MQ(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function vm(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;NB(d,a);ol(d,b);hb=c+16|0}function ps(a,b){var c=0;c=a;a=(b>>>0)/1e6|0;return lx(Ik(c,a),D(a,-1e6)+b|0)}function mx(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Ik(Ik(c,a),D(a,-100)+b|0)}function lx(a,b){var c=0;c=a;a=(b>>>0)/1e4|0;return mx(Ik(c,a),D(a,-1e4)+b|0)}function Xi(a){if(Tb(a+1074312|0,7)){a=lm(x[a+480180>>2])^1}else{a=0}return a}function XX(a,b){a=a|0;b=b|0;a=Ml(a);x[a>>2]=92572;Tv(a+4|0,Pb(b));return a|0}function Ve(a){if(re(y[a+11|0])){id(x[a>>2],0);oe(a,0);return}id(a,0);bf(a,0)}function RY(a){a=a|0;if(!y[468128]){Xb(468116,9155);v[468128]=1}return 468116}function RX(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[469680]){v[469680]=1}ec(a,c,93900)}function RN(a){x[a>>2]=0;x[a+4>>2]=0;x[a>>2]=-2078137563;x[a+4>>2]=-873292572}function Pi(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}Hb(b)}function PY(a){a=a|0;if(!y[468032]){Xb(468020,5226);v[468032]=1}return 468020}function JX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Hg(a,x[b+8>>2],0)){Pv(b,c,d)}}function I9(a,b){a=a|0;b=b|0;if(A[a+4>>2]<A[Cb(a)>>2]){eM(a,b);return}Cz(a,b)}function Gy(a){var b=0;if(!(y[a+2|0]|(y[a|0]|y[a+1|0]))){b=!y[a+3|0]}return b}function Ex(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function Dx(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function Aha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;Av(a,b,c,d,e,100,99,99)}function xe(a){var b=0;b=hb-16|0;hb=b;tu(b+8|0,a);hb=b+16|0;return x[b+8>>2]}function dG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb[x[x[a>>2]+32>>2]](a,b,c,d)|0}function Ud(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];bc(b,c);kv(a,b,d,c)}function Sj(a){var b=0;b=hb-16|0;hb=b;a=x[lf(b+8|0,a)>>2];hb=b+16|0;return a}function RM(a,b,c){var d=0;return!b|!(y[a+35|0]&4?!a|(c|0)!=1:1)?d:y[b+34|0]}function M6(a,b){a=a|0;b=b|0;return E(b>>>0<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function Bb(a){var b=0;b=hb-16|0;hb=b;a=x[Ib(b+8|0,a)>>2];hb=b+16|0;return a}function $F(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb[x[x[a>>2]+48>>2]](a,b,c,d)|0}function zz(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function zK(a){a=a|0;x[a>>2]=46772;sc(a+4276|0);sc(a+4264|0);return uf(a)|0}function tk(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function sO(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);jO(a,b,0,0,b+-1,0)}function s3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Um(a,b,c,d,12741,982)|0}function o3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Um(a,b,c,d,12815,984)|0}function mY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+80896>>2]}return b|0}function kY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+79360>>2]}return b|0}function hg(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function _R(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function WH(a,b){a=a^-1;return x[(b&12)+64068>>2]>>>(a>>>3&1)>>>(a>>>4&1)|0}function U_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return yE(b,c,d,e,1)|0}function TG(a,b,c,d,e,f,g,h){return mb[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function R_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return yE(b,c,d,e,0)|0}function P$(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){QG(a,c);return}Xb(a,7838)}function K_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return wE(b,c,d,e,1)|0}function Ir(a,b,c,d,e,f,g,h){return mb[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function H_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return wE(b,c,d,e,0)|0}function y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Um(a,b,c,d,9322,979)|0}function q3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Um(a,b,c,d,9473,983)|0}function m3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Um(a,b,c,d,9551,985)|0}function k3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Um(a,b,c,d,9353,986)|0}function dh(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function UX(a,b,c){a=a|0;b=b|0;c=c|0;return tc(a,x[b+4>>2])&x[b>>2]==(c|0)}function Nj(a){var b=0;b=z[a+172>>1];a=z[a+156>>1];return(vP(a)?b:a)&65535}function wk(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+12>>2]](a,b,c)|0}function rD(a,b){a=a|0;b=b|0;a=Ml(a);x[a>>2]=92572;Tv(a+4|0,b);return a|0}function qD(a,b){a=mg(a,b);x[a+8>>2]=x[b+8>>2];mg(a+12|0,b+12|0);return a}function lo(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+48>>2]](a,b,c)|0}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=so(a,b),x[d>>2]=e}function Xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Ku(a,b),w[d>>1]=e}function Xc(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function Qb(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+32>>2]](a,b,c)|0}function Pb(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=re(y[a+11|0]),d?b:c}function FC(a,b){while(1){if(b){x[a>>2]=0;b=b-1|0;a=a+4|0;continue}break}}function D7(a,b){a=a|0;b=b|0;a=x[a+20>>2];v[a+24|0]=y[a+24|0]&253|(b?2:0)}function BR(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function $c(a,b){a=zD(a,b);x[a+8>>2]=x[b+8>>2];zD(a+12|0,b+12|0);return a}function oP(a,b){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function nw(a,b){var c=0;c=ks(a+4|0);x[a>>2]=77928;x[c>>2]=77948;xn(c,b)}function mw(a,b){var c=0;c=JG(a+4|0);x[a>>2]=78296;x[c>>2]=78316;xn(c,b)}function kH(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;dh(a,-1,-1)}function zO(a){if(a>>>0<=8){return y[a+29552|0]}return y[a+29543|0]|256}function zA(a,b){if(b){zA(a,x[b>>2]);zA(a,x[b+4>>2]);Tj(b+16|0);Hb(b)}}
function vK(a){a=a|0;return E(E(E(B[zb(a+4208|0,5)>>2]*E(198))+E(-99)))}function sc(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];Kh(a);Hb(b)}return a}function oc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=If(b),x[c+4>>2]=d;return a}function lI(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function jd(a){var b=0;if(x[a>>2]){$B(a,x[a>>2]);b=x[a>>2];aC(a);Hb(b)}}function cU(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function bQ(a){var b=0;if(x[a>>2]){_P(a,x[a>>2]);b=x[a>>2];ik(a);Hb(b)}}function bB(a,b,c){var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function Qo(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function Of(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];zt(a);Hb(b)}return a}function Oc(a){if(re(y[a+11|0])){a=ck(x[a+8>>2])-1|0}else{a=10}return a}function Gw(a){return((gh(a)+(gh(a)<<8)|0)+(gh(a)<<16)|0)+(gh(a)<<24)|0}function GO(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function yA(a,b){if(b){yA(a,x[b>>2]);yA(a,x[b+4>>2]);Tj(b+16|0);Hb(b)}}function wy(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];v[a+6|0]=y[b+6|0]}function vp(a,b){if(b){vp(a,x[b>>2]);vp(a,x[b+4>>2]);ZN(b+16|0);Hb(b)}}function rk(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function rR(a){if(Rb(a,13679,4)){a=1}else{a=Rb(a+8|0,13732,4)}return!a}function qi(){var a=0;a=Ol(ba(4)|0);x[a>>2]=92456;ha(a|0,92532,25);p()}function hz(a,b){a=Sb(a);Kb(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function Zm(a){if(re(y[a+11|0])){a=ck(x[a+8>>2])-1|0}else{a=1}return a}function Ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Jv(a,b,c,d,522)|0}function Sx(a,b){if(b){Sx(a,x[b>>2]);Sx(a,x[b+4>>2]);Db(b+16|0);Hb(b)}}function Qv(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function Oq(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function My(a,b){if(b){My(a,x[b>>2]);My(a,x[b+4>>2]);$l(b+16|0);Hb(b)}}function JU(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){va();p()}}function qX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;mb[a|0](b,c,d,e)}function oJ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){tn(c+120|0);Hb(c)}}function jM(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function Xv(a){a=a|0;if(x[a+8>>2]!=(zd()|0)){uG(x[a+8>>2])}return a|0}function Xq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Jv(a,b,c,d,155)|0}function NT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Jv(a,b,c,d,317)|0}function HP(a,b,c,d,e){a=Ib(a,b);Ib(a+4|0,c);Ib(a+8|0,d);Ib(a+12|0,e)}function Fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;aE(a,b,c,d,283,282,281)}function CX(a){a=a|0;if(!a){return 0}return(uy(a,92128,92272)|0)!=0|0}function wP(a,b){a=Kz(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2]}function oq(a,b){var c=0;c=hb-16|0;hb=c;DC(c,a,64);JC(c,b);hb=c+16|0}function mX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mb[a|0](b,c,d)|0}function m$(a){a=a|0;var b=0;b=x[116972]+1|0;x[116972]=b;x[a+4>>2]=b}function kS(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];kc(a+8|0,b+8|0)}function iu(a,b){var c=0;c=hb-16|0;hb=c;DC(c,a,32);JC(c,b);hb=c+16|0}function eX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;aE(a,b,c,d,103,102,101)}function TZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;lg(a,f)}function zM(a,b){x[a+852>>2]=x[a+852>>2]+b;v[a+851|0]=y[a+851|0]|64}function sS(a){v[a+4|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function r3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return EE(a,b,c,d,4)|0}function p3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return EE(a,b,c,d,2)|0}function n3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return DE(a,b,c,d,4)|0}function l3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return DE(a,b,c,d,2)|0}function dM(a,b){var c=0;c=hb-16|0;hb=c;Sz(c,1,b);Dc(a,c);hb=c+16|0}function Zk(a,b,c){var d=0;d=hb-16|0;hb=d;XS(d+8|0,a,b,c);hb=d+16|0}function Hc(a,b,c){if(rc(a,b)>>>0<=c>>>0){Hu();p()}return(c<<2)+a|0}function Fl(a,b){return b?a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24):a}function Eq(a,b){return Nu(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function BB(a,b){return YD(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function zF(a,b,c){a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}Hb(b)}}function si(a,b){a=a|0;b=b|0;var c=0;c=Jc(b);x[a+4>>2]=b;x[a>>2]=c}function hY(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function ed(a){a=(a|0)>=32767?32767:a;return(a|0)<=-32768?-32768:a}function dj(a,b){a=a|0;b=b|0;var c=0;c=KO(b);x[a+4>>2]=b;x[a>>2]=c}function aP(a,b){var c=0,d=0;c=Ib(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function yH(a,b){a=wH(a-1|0);if(!a){a=wH(b);a=a?a+32|0:0}return a}function w$(a,b){a=a|0;b=b|0;if(!x[23604]){x[23604]=a;x[23605]=b}}function um(a,b){x[a>>2]=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];return a}function ui(a,b){if(_f(x[a>>2],x[a+4>>2])>>>0>b>>>0){v[a+16|0]=b}}function rW(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+12>>2]](a)|0}function qW(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+16>>2]](a)|0}function jI(a){a=a|0;return+(+x[x[a+32>>2]+1074456>>2]*.00390625)}function ev(a,b,c){a=mg(a,b);x[a+8>>2]=0;mg(a+12|0,c);be(c);be(b)}function cn(a,b){if(A[a+4>>2]<A[Cb(a)>>2]){YF(a,b);return}UF(a,b)}function c6(a,b,c){a=a|0;b=b|0;c=c|0;return Di(a,b,c,879,86224)|0}function _q(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+32>>2]](a,0,b)|0}function UR(a,b,c,d){a=ge(a,b);w[a+22>>1]=d;w[a+20>>1]=c;return a}function Rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bE(a,b,c,d,280,526)}function xD(a,b,c){a=Mm(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=61724}function x7(a,b,c){a=a|0;b=b|0;c=c|0;return Di(a,b,c,868,4236)|0}function vha(a,b){a=a|0;b=b|0;a=Pt(a,b);x[a>>2]=92728;return a|0}function sW(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+8>>2]](a)|0}function s6(a,b,c){a=a|0;b=b|0;c=c|0;return Di(a,b,c,876,5048)|0}function rn(a,b,c){return MR(x[a>>2],x[a+4>>2],b,x[a+12>>2]+c|0)}function p8(a,b,c){a=a|0;b=b|0;c=c|0;return Di(a,b,c,850,4268)|0}function ky(a){xb(a+48|0);xb(a+36|0);xb(a+24|0);xb(a+12|0);xb(a)}function j6(a,b,c){a=a|0;b=b|0;c=c|0;return Di(a,b,c,878,4276)|0}function gd(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function d7(a,b,c){a=a|0;b=b|0;c=c|0;return Di(a,b,c,871,4280)|0}function Z7(a,b,c){a=a|0;b=b|0;c=c|0;return Di(a,b,c,858,4304)|0}function Yfa(a,b){a=a|0;b=b|0;a=Pt(a,b);x[a>>2]=92780;return a|0}function YD(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function X6(a,b,c){a=a|0;b=b|0;c=c|0;return Di(a,b,c,872,4276)|0}function Uw(a,b,c){return Gh(x[a>>2],x[a+4>>2],b,x[a+12>>2]+c|0)}function Q6(a,b,c){a=a|0;b=b|0;c=c|0;return Di(a,b,c,873,4268)|0}function Ip(a,b,c){a=Lb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function B6(a,b,c){a=a|0;b=b|0;c=c|0;return Di(a,b,c,875,4228)|0}function $J(a){return E(E(B[zb(a+4208|0,11)>>2]*E(19980))+E(20))}function uM(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];WT(a);Hb(b)}}function te(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){qs(b)}return a}function ss(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];Ax(a);Hb(b)}}function saa(a,b){a=a|0;b=b|0;a=oS(a,b);if(!a){nS(b)}return a|0}function sY(a){a=a|0;a=x[a+8>>2];if(!a){return 1}return iF(a)|0}function rv(a){var b=0;b=hb-16|0;B[b+12>>2]=a;return B[b+12>>2]}function qr(a){var b=0;b=hb-16|0;C[b+8>>3]=a;return C[b+8>>3]*a}function pt(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];Cb(a);Hb(b)}}function nt(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];Az(a);Hb(b)}}function ni(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];$n(a);Hb(b)}}function nd(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];Dm(a);Hb(b)}}function nM(a){var b=0;if(x[a>>2]){Fs(a);b=x[a>>2];Es(a);Hb(b)}}function ll(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+28>>2]](a,b)|0}function je(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];Pm(a);Hb(b)}}function hM(a){var b=0;if(x[a>>2]){Fo(a);b=x[a>>2];bv(a);Hb(b)}}function gX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bE(a,b,c,d,100,99)}function fz(a){var b=0;if(x[a>>2]){PO(a);b=x[a>>2];$n(a);Hb(b)}}function fw(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+12>>2]](a,b)|0}function fl(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];lr(a);Hb(b)}}function fO(a){var b=0;if(x[a>>2]){$N(a);b=x[a>>2];ik(a);Hb(b)}}function co(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];qS(a);Hb(b)}}function aK(a){return E(E(B[zb(a+4208|0,0)>>2]*E(1e4))+E(-1e4))}function Zj(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];_t(a);Hb(b)}}function ZP(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];ik(a);Hb(b)}}function ZM(a,b){a=a|0;b=b|0;a=Pt(a,b);x[a>>2]=92592;return a|0}function Xd(a){var b=0;if(x[a>>2]){CU(a);b=x[a>>2];iB(a);Hb(b)}}function SP(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];bv(a);Hb(b)}}function S5(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function Nu(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function NN(a){var b=0;if(x[a>>2]){Fc(a);b=x[a>>2];Oy(a);Hb(b)}}function Mp(a,b,c){if(!b){return 0}return Ct(a,nh(c<<24>>24),b)}function Hr(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+44>>2]](a,b)|0}function $f(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function yQ(a){return y[a+15|0]<<12|y[a+14|0]<<4|y[a+13|0]<<20}function xt(a,b){a=a|0;b=b|0;a=QT(a,b);if(!a){Zt(b)}return a|0}function sK(a){a=a|0;return Mj(E(B[zb(a+4208|0,4)>>2]*E(4)))|0}function lv(a,b){a=a|0;b=b|0;a=lD(a,b);if(!a){kD(b)}return a|0}function k_(a,b){a=a|0;b=b|0;SM(a,vw(x[b>>2])<<24>>24,x[b>>2])}function kX(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+16>>2]](a,b,0,0,1,8)}function kA(a,b){a=a|0;b=b|0;a=Ao(a,b);if(!a){sm(b)}return a|0}function ho(a,b){a=a|0;b=b|0;a=PT(a,b);if(!a){ST(b)}return a|0}function av(a,b){a=dd(a,b);kc(a+12|0,b+12|0);Mf(a+32|0,b+32|0)}function Zu(a,b){a=a|0;b=b|0;a=XC(a,b);if(!a){Nq(b)}return a|0}function ZL(a,b){return b>>>0>=4e3?21502:((b<<5)+a|0)+946304|0}function Th(a,b){a=a|0;b=b|0;a=Sh(a,b);if(!a){tl(b)}return a|0}function TL(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function Nf(a,b){return mb[x[x[a>>2]+32>>2]](a,x[a+12>>2],b)|0}function Jq(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function IN(a,b){a=a|0;b=b|0;a=dU(a,b);if(!a){$t(b)}return a|0}function GB(a,b){a=a|0;b=b|0;a=mu(a,b);if(!a){ru(b)}return a|0}function GA(a,b){a=a|0;b=b|0;a=BS(a,b);if(!a){uA(b)}return a|0}function E2(a,b,c){a=a|0;b=b|0;c=c|0;ON(a,0,x[b+1298404>>2],c)}function BU(a,b){if(!b){return-1}b=Mp(a,b,0);return b?b-a|0:-1}function $q(a,b){a=a|0;b=b|0;a=bD(a,b);if(!a){pv(b)}return a|0}function $D(a){w[a+12>>1]=0;x[a+8>>2]=-1;x[a>>2]=0;x[a+4>>2]=0}function ul(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){Km(c)}return a}function oM(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Hb(ej(c))}}function n7(a,b,c){a=a|0;b=b|0;c=c|0;return Mv(a,b,c,0,870)|0}function iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jE(a,b,c,d,407)}function fh(a,b,c){return(x[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function dc(a){return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function cl(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){jc(a);Hb(b)}}function Rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jE(a,b,c,d,339)}function KO(a){if(a>>>0>=1073741824){qi();p()}return Jc(a<<2)}function J6(a,b,c){a=a|0;b=b|0;c=c|0;return Mv(a,b,c,0,874)|0}function DI(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function C6(a,b,c){a=a|0;b=b|0;c=c|0;return Mv(a,b,c,1,874)|0}function Aia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mE(a,b,c,d,125)}function AD(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Hb(fc(c))}}function xM(a){x[a>>2]=0;Sb(a+4|0);Zb(a+16|0,0,144);return a}function wH(a){return v[(D(0-a&a,124511785)>>>27|0)+73104|0]}function vx(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function tK(a){a=a|0;return E(E(B[zb(a+4208|0,2)>>2]*E(10)))}function qc(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function nI(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mE(a,b,c,d,99)}function js(a){a=a|0;x[a>>2]=76600;xb(a+32|0);return yn(a)|0}function jW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hc(a,x[d>>2],0)}function e7(a){a=a|0;return E(E(B[zb(a+4208|0,6)>>2]*E(20)))}function KL(a,b){var c=0;c=z[a>>1];w[a>>1]=z[b>>1];w[b>>1]=c}function I2(a,b){a=a|0;b=b|0;x[a>>2]=x[b>>2];lg(a+4|0,b+4|0)}function Dg(a,b,c,d){lb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function Ci(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function zn(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function xz(a,b){if(b){xz(a,x[b>>2]);xz(a,x[b+4>>2]);Hb(b)}}function wz(a,b){if(b){wz(a,x[b>>2]);wz(a,x[b+4>>2]);Hb(b)}}function s4(a,b){a=a|0;b=b|0;return E(JE(a,b,6190,1075834))}function rX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb[a|0](b,c,d)}function q4(a,b){a=a|0;b=b|0;return E(IE(a,b,6233,1075834))}function pea(a,b,c){a=a|0;b=b|0;c=c|0;return oE(a,b,c,36)|0}function pU(a){return!Rb(a,14029,4)&(y[a+4|0]-1&255)>>>0<10}function p4(a,b){a=a|0;b=b|0;return E(IE(a,b,6135,1075835))}function o4(a,b){a=a|0;b=b|0;return E(JE(a,b,6091,1075835))}function lY(a,b,c){a=a|0;b=b|0;c=c|0;return uE(b,c,80896)|0}function jY(a,b,c){a=a|0;b=b|0;c=c|0;return uE(b,c,79360)|0}function iA(a,b){if(b){iA(a,x[b>>2]);iA(a,x[b+4>>2]);Hb(b)}}function hA(a,b){if(b){hA(a,x[b>>2]);hA(a,x[b+4>>2]);Hb(b)}}function gv(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function fq(a){return x[a+20>>2]+(x[a+8>>2]-x[a+24>>2]|0)|0}function dY(a,b,c){a=a|0;b=b|0;c=c|0;return tE(b,c,80896)|0}function cJ(a,b){a=a|0;b=b|0;return ji(x[b>>2],x[b+4>>2])|0}function bY(a,b,c){a=a|0;b=b|0;c=c|0;return tE(b,c,79360)|0}function bJ(a,b){a=a|0;b=b|0;return ie(x[b>>2],x[b+4>>2])|0}function _w(a,b,c,d,e,f){return BE(a,b,c,d,e,f,57316,58112)}function Yw(a,b,c,d,e,f){return BE(a,b,c,d,e,f,58192,58956)}function Yh(a,b){var c=0,d=0;c=a,d=sG(b),x[c>>2]=d;return a}function YM(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Hb(xy(b))}}function VV(a){a=a|0;a=sD(a,13193);x[a>>2]=26460;return a|0}function SR(a){var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b}function Pt(a,b){a=Ml(a);x[a>>2]=92552;Tv(a+4|0,b);return a}function O9(a){a=a|0;a=Pt(a,21502);x[a>>2]=92672;return a|0}function NC(a,b){return Bt(a,Pb(b),Eb(x[b+4>>2],y[b+11|0]))}function M$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb=0;return 0}
function Ls(a,b){if(b){Ls(a,x[b>>2]);Ls(a,x[b+4>>2]);Hb(b)}}function Ks(a,b){if(b){Ks(a,x[b>>2]);Ks(a,x[b+4>>2]);Hb(b)}}function K7(a){a=a|0;a=Fj(a);if(a){mb[x[x[a>>2]+96>>2]](a)}}function Dk(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Hb(Of(b))}}function D6(a){a=a|0;return E(E(B[zb(a+4208|0,6)>>2]*E(4)))}function mJ(a){return(Pb(a)+Eb(x[a+4>>2],y[a+11|0])|0)-1|0}function km(a){var b=0;b=x[a>>2];x[b>>2]=x[b>>2]|x[a+4>>2]}function jn(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function cX(a){a=a|0;a=ZM(a,7874);x[a>>2]=42360;return a|0}function UA(a,b,c){if((a|0)!=(b|0)){b=b-a|0;ah(c-b|0,a,b)}}function Px(a,b,c){C[a>>3]=C[a>>3]+b;C[a+8>>3]=C[a+8>>3]+c}function Gq(a,b,c){a=a|0;b=b|0;c=c|0;ug(a,b,gi(b,b+c|0,0))}function EW(a){a=a|0;a=sD(a,8606);x[a>>2]=30868;return a|0}function D2(a){a=a|0;yJ(a,2,100);ui(x[a+24>>2]+484360|0,0)}function $X(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function zU(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0];return a}function w2(a,b,c){a=a|0;b=b|0;c=c|0;Lq(a,b,c);return a|0}function rw(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function nJ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){qs(c)}}function gp(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function XE(a,b,c){b=Ma(909,a|0,b|0,c|0)|0;lb=ib;return b}function Wn(a){x[a>>2]=0;x[a+4>>2]=0;Oj(a+8|0,0);return a}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;ug(a,b,Rc(b,c)+b|0)}function Sg(a,b){if(re(y[a+11|0])){oe(a,b);return}bf(a,b)}function Rz(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Hb(c)}}function Mw(a,b){return x[((a>>>24^b)<<2)+463296>>2]^a<<8}function LH(a){while(1){if((Ur(a)|0)!=-1){continue}break}}function HC(a,b){var c=0;c=Jc(b<<2);x[a+4>>2]=b;x[a>>2]=c}function Ec(a,b){return pE(a,b,2147483647,-2147483648,-1)}function Co(a){a=wD(a);x[a+8>>2]=0;x[a>>2]=89044;return a}function CF(a){if(x[a>>2]){AF(a);zF(Yv(a),x[a>>2],Kh(a))}}function zI(a){a=a|0;x[a>>2]=61068;fc(a+12|0);return a|0}function sm(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function sF(a){a=a|0;x[a>>2]=83568;xb(a+16|0);return a|0}function rF(a){a=a|0;x[a>>2]=83528;xb(a+12|0);return a|0}function kt(a,b){qc(a,b);qc(a+4|0,b+4|0);qc(Cb(a),Cb(b))}function jH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dh(a,-1,-1)}function Xg(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function Wy(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function VM(a,b){a=UM(a,b);UM(a+12|0,b+12|0);v[a+24|0]=1}function Qi(a){return Ke(a)|Ke(a)<<8|Ke(a)<<16|Ke(a)<<24}function M2(a,b,c){a=a|0;b=b|0;c=c|0;dd(a,ZR(c,b,If(b)))}function J0(a,b,c){a=a|0;b=b|0;c=c|0;return Ld(D(b,c))|0}function It(a){sc(a+88|0);sc(a+68|0);sc(a+48|0);return a}function FW(a,b,c){a=a|0;b=b|0;c=c|0;kv(a,b,x[b+8>>2],c)}function BJ(a,b){Km(x[b>>2]);Om(x[a>>2]);x[a>>2]=x[b>>2]}function yn(a){a=a|0;x[a>>2]=76472;$b(a+4|0);return a|0}function xL(a){return(a|0)==1179012417|(a|0)==538987841}function xF(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Om(b)}}function w4(a,b){a=a|0;b=b|0;return Vm(a,b,11754,953)|0}function v6(a){a=a|0;fK(a);v[a+4202|0]=1;x[a+4224>>2]=0}function rg(a,b,c,d,e){return Oa(a|0,b|0,c|0,d|0,e|0)|0}function pD(a){a=a|0;x[a>>2]=43632;be(a+4|0);return a|0}function mG(a,b,c){a=Ib(a,b);Ib(a+4|0,x[c>>2]);return a}function laa(a,b,c){a=a|0;b=b|0;c=c|0;cE(a,b,c,749,748)}function jv(a){a=a|0;x[a>>2]=92572;$E(a+4|0);return a|0}function hj(a,b,c){x[a>>2]=b;x[a+4>>2]=x[c>>2];return a}function gaa(a,b,c){a=a|0;b=b|0;c=c|0;RE(a,b,c,753,754)}function g7(a){a=a|0;return B[zb(a+4208|0,3)>>2]<E(1)|0}function e4(a,b){a=a|0;b=b|0;return Vm(a,b,11657,960)|0}function c4(a,b){a=a|0;b=b|0;return OE(a,b,13165,961)|0}function bT(a){a=a|0;x[a>>2]=92552;$E(a+4|0);return a|0}function as(a){a=a|0;x[a>>2]=49812;$w(a+4|0);return a|0}function VH(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function UE(a,b,c,d,e){return Fa(a|0,b|0,c|0,d|0,e|0)|0}function Td(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function T3(a,b){a=a|0;b=b|0;return Vm(a,b,11692,968)|0}function Sb(a){x[a>>2]=0;x[a+4>>2]=0;zc(a+8|0);return a}function Q3(a,b){a=a|0;b=b|0;return Vm(a,b,11722,970)|0}function PN(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Hb(b)}}function LA(a){a=a&255;return Tc(a)^1|(a-49&255)>>>0<36}function Kr(a){a=a|0;x[a>>2]=76536;$b(a+4|0);return a|0}function I3(a,b){a=a|0;b=b|0;return Vm(a,b,11818,973)|0}function GI(a){a=a|0;x[a>>2]=61532;fc(a+4|0);return a|0}function F6(a){a=a|0;return B[zb(a+4208|0,1)>>2]<E(1)|0}function Eo(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function E3(a,b){a=a|0;b=b|0;return Vm(a,b,11786,974)|0}function $E(a){a=Bi(x[a>>2]);if((gv(a+8|0)|0)<0){Hb(a)}}function z5(a,b){a=a|0;b=b|0;return OE(a,b,6393,902)|0}function s$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ug(a,c,d)}function p$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;pG(a,c,d)}function mn(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function iaa(a,b,c){a=a|0;b=b|0;c=c|0;PE(a,b,c,55,752)}function i9(a,b,c){a=a|0;b=b|0;c=c|0;cE(a,b,c,820,819)}function gh(a){var b=0;b=Ur(a);x[a+1396>>2]=0;return b}function fH(a){a=a|0;return Mr(x[x[a>>2]-12>>2]+a|0)|0}function d_(a,b){a=a|0;b=b|0;ec(a,VG(x[b>>2]),x[b>>2])}function aH(a){a=a|0;return Lr(x[x[a>>2]-12>>2]+a|0)|0}function Yo(a){return y[a+2|0]&2?(y[a+1|0]&6)==6?4:1:0}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function Wca(a,b){a=a|0;b=b|0;if(!bR(a,b)){Zb(b,0,40)}}function Uga(a,b){a=a|0;b=b|0;return Xb(a,b?b:21502)|0}function UV(a){a=a|0;rC(Pb(a),Eb(x[a+4>>2],y[a+11|0]))}function U$(a){a=a|0;return ap(x[x[a>>2]-12>>2]+a|0)|0}function S$(a){a=a|0;return hf(x[x[a>>2]-12>>2]+a|0)|0}function Pw(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function Jg(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+20>>2]](a,b)}function Ik(a,b){b=(b<<1)+91344|0;return pi(b,b+2|0,a)}function Dh(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+24>>2]](a,b)}function Ch(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+28>>2]](a,b)}function CL(a,b){return D(b&65535,a&65535)+7>>>3&65535}function xy(a){rp(a+223860|0);fc(a+223848|0);return a}function xb(a){if(re(y[a+11|0])){Hb(x[a>>2])}return a}function tL(a,b){return(b>>>0>15?63:y[a+b|0])<<24>>24}function sn(a,b,c,d){return x[(c<<2)+a>>2]+(b+d<<1)|0}function sL(a,b){return(b>>>0>45?63:y[a+b|0])<<24>>24}function p7(a,b,c){a=a|0;b=b|0;c=c|0;ec(a,b+4228|0,7)}function kG(a,b,c){a=qG(a,b,c,0,-2147483648);return a}function fc(a){if(x[a>>2]){Fc(a);Hb(x[a>>2])}return a}function dv(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){Km(c)}}function df(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function _m(a,b){return mb[x[x[a>>2]+52>>2]](a,b,0)|0}function Yq(a,b){a=kc(a,b);Zb(a+20|0,0,1040);return a}function Xb(a,b){a=a|0;b=b|0;Lq(a,b,If(b));return a|0}function S1(a,b){a=a|0;b=b|0;GN(x[a>>2],b);return a|0}function Ni(a){a=a|0;return mb[x[x[a>>2]+16>>2]](a)|0}function NW(a,b,c){a=a|0;b=b|0;c=c|0;RE(a,b,c,87,139)}function Mi(a){a=a|0;return mb[x[x[a>>2]+12>>2]](a)|0}function GK(a){sc(a+36|0);sc(a+24|0);ss(a+12|0);ss(a)}function Fg(a){a=a|0;return mb[x[x[a>>2]+24>>2]](a)|0}function Cf(a,b,c,d){b=b+d|0;lb=a+c>>>0<c>>>0?b+1|0:b}function $m(a,b){return mb[x[x[a>>2]+36>>2]](a,b,0)|0}function $A(a,b){a=ge(a,b);Zb(a+20|0,0,1040);return a}function $7(a,b,c){a=a|0;b=b|0;c=c|0;ec(a,b+4260|0,8)}function wq(a,b,c){if(b){$K(a+36|0,b,gi(b,b+c|0,0))}}function wU(a,b,c,d){return or(a,b,c,d,28,153391690)}function ve(a,b){ec(a,Pb(b),Eb(x[b+4>>2],y[b+11|0]))}function nm(a){a=(a|0)>=120?120:a;return(a|0)<=1?1:a}function lz(a){a=Sb(a);x[a+12>>2]=0;w[a+16>>1]=65280}function jfa(a,b,c){a=a|0;b=b|0;c=c|0;gE(a,b,c,13,2)}function gD(a,b,c,d){return or(a,b,c,d,36,119304648)}function f8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function eq(a,b,c,d,e){ec(a,b+d|0,(e|0)==-1?c-d|0:e)}function dR(a){var b=0;a=a+8|0;lb=a>>>0<8|b;return a}function Yu(a){a=a|0;return mb[x[x[a>>2]+8>>2]](a)|0}function WD(a,b,c,d){return(a|0)==(c|0)&(b|0)==(d|0)}function QC(a,b){return(y[b+34|0]&8)>>>3&(a&2050)==2}function LW(a,b,c){a=a|0;b=b|0;c=c|0;PE(a,b,c,4,140)}function Iia(a){if(a){return 31-G(a-1^a)|0}return 32}function I7(a){a=a|0;v[a+4202|0]=1;us(a);ux(a);HK(a)}function As(a){a=a|0;a=xh(a);x[a+20>>2]=0;return a|0}function yfa(a,b,c){a=a|0;b=b|0;c=c|0;gE(a,b,c,5,3)}function wK(a){a=a|0;return E(B[zb(a+4208|0,0)>>2])}function vo(a,b,c){ec(a,(c>>>3&536870908)+b|0,c&31)}function uz(a){v[a+6|0]=0;w[a+4>>1]=65535;x[a>>2]=0}function sfa(a){a=a|0;ej(94448);ej(94440);xb(94428)}function sX(a){a=a|0;a=mb[a|0]()|0;ib=lb;return a|0}function qZ(){Nd(469464);uF(469472);x[117366]=86416}function pO(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function oZ(){Nd(469480);uF(469488);x[117370]=86572}function nH(a,b){x[a>>2]=b;x[a+4>>2]=b>>31;return a}function jda(a,b,c){a=a|0;b=b|0;c=c|0;dd(a,dr(b,c))}function fn(a,b,c){x[a>>2]=b;x[a+4>>2]=c-b;return a}function f7(a){a=a|0;return E(B[zb(a+4208|0,1)>>2])}function eD(a){return vH(a,E(15845632502852868e13))}function dr(a,b){a=a|0;b=b|0;return Bt(a,b,If(b))|0}function cj(a){if(!a){return 0}return x[a+44>>2]!=0}function bga(a,b,c){a=a|0;b=b|0;c=c|0;lE(a,b,c,256)}function ZT(a,b,c,d){return or(a,b,c,d,48,89478486)}function Z0(a,b,c){a=a|0;b=b|0;c=c|0;gI(a-88|0,b,c)}function Xea(a,b){a=a|0;b=b|0;return yj(a,b,1030)|0}function X0(a,b,c){a=a|0;b=b|0;c=c|0;eI(a-88|0,b,c)}function Wd(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function Sca(a,b){a=a|0;b=b|0;Lq(a,b,12);return a|0}function RC(a,b,c){ec(a,(c>>>3&536870908)+b|0,1<<c)}function Nea(a,b){a=a|0;b=b|0;return Iv(a,b,1100)|0}function N2(a){a=a|0;a=x[a+4>>2];return(a?a:4972)|0}function MN(a,b,c,d){return or(a,b,c,d,7,613566757)}function KC(a){return vH(a,E(2524354896707238e-44))}function Ij(a){if(!a){return 0}return bj(y[a+31|0])}function He(a){var b=0;b=x[a>>2];if(b){Cb(a);Hb(b)}}function E6(a){a=a|0;return E(B[zb(a+4208|0,3)>>2])}function Dw(a){if(!a){return 0}x[116080]=a;return-1}function Dn(a,b,c){if(!c){return 0}return Rb(a,b,c)}function DC(a,b,c){v[a+8|0]=1;x[a+4>>2]=c;x[a>>2]=b}function Bo(a){a=a|0;a=yc(a);mb[x[x[a>>2]>>2]](a)|0}function x2(a,b){a=a|0;b=b|0;return Ko(a,b,1046)|0}function rl(a,b){return(a&65535)>>>0<(b&65535)>>>0}function o1(a,b){a=a|0;b=b|0;return Ko(a,b,1047)|0}function Y0(a,b){a=a|0;b=b|0;return fI(a-88|0,b)|0}function Xl(a){Yi(a+724|0);Yi(a+732|0);Yi(a+740|0)}function W0(a,b){a=a|0;b=b|0;return dI(a-88|0,b)|0}function Vq(a,b,c){a=a|0;b=b|0;c=c|0;dd(a,NC(b,c))}function Tfa(a,b){a=a|0;b=b|0;return yj(a,b,422)|0}function O0(a,b,c){a=a|0;b=b|0;c=+c;_H(a-92|0,b,c)}function Nfa(a,b){a=a|0;b=b|0;return yj(a,b,826)|0}function M0(a,b,c){a=a|0;b=b|0;c=+c;YH(a-92|0,b,c)}function HU(a,b,c){a=a|0;b=b|0;c=c|0;SE(a,b,c,280)}function HD(a,b,c){a=a|0;b=b|0;c=c|0;SE(a,b,c,100)}function H0(a,b){a=a|0;b=b|0;return Ko(a,b,1049)|0}function F0(a,b){a=a|0;b=b|0;return Ko(a,b,1050)|0}function E0(a,b){a=a|0;b=b|0;return Ko(a,b,1051)|0}function $0(a,b,c){a=a|0;b=b|0;c=+c;iI(a-88|0,b,c)}function zt(a){return(x[Cb(a)>>2]-x[a>>2]|0)/24|0}function yL(a,b){return(a|0)==1179011410&b>>>0>80}function wga(a,b){a=a|0;b=b|0;return yj(a,b,91)|0}function wD(a){x[a+4>>2]=0;x[a>>2]=92024;return a}function tp(a,b){x[a+4>>2]=256;x[a>>2]=b;return a}function sD(a,b){a=rD(a,b);x[a>>2]=92832;return a}function rga(a,b){a=a|0;b=b|0;if(!oS(a,b)){nS(b)}}function qia(a,b){a=a|0;b=b|0;if(!dU(a,b)){$t(b)}}function qS(a){return(x[Cb(a)>>2]-x[a>>2]|0)/33|0}function oC(a){return!Rb(a,26544,25)&y[a+34|0]<65}function m6(a,b){a=a|0;b=b|0;return E(yl(a,b,12))}function ik(a){return(x[Cb(a)>>2]-x[a>>2]|0)/12|0}function iB(a){return(x[Cb(a)>>2]-x[a>>2]|0)/28|0}function i4(a){a=a|0;return Kv(a,12672,1074416)|0}function gT(a){if(!(a&255)){return 1}return Tc(a)}function ffa(a,b){a=a|0;b=b|0;if(!mu(a,b)){ru(b)}}function f9(a,b){a=a|0;b=b|0;return yj(a,b,225)|0}function ec(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function c9(a,b){a=a|0;b=b|0;return yj(a,b,326)|0}function bv(a){return(x[Cb(a)>>2]-x[a>>2]|0)/36|0}function am(a,b,c){x[a+4>>2]=c;w[a>>1]=b;return a}function aC(a){return(x[Cb(a)>>2]-x[a>>2]|0)/20|0}function Zfa(a,b){a=a|0;b=b|0;if(!XC(a,b)){Nq(b)}}function ZE(a){return(a<<1)+16777216>>>0<16777217}function WT(a){return(x[Cb(a)>>2]-x[a>>2]|0)/48|0}function Uk(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function PQ(a){return(x[Cb(a)>>2]-x[a>>2]|0)/56|0}function Lg(a,b){a=a|0;b=b|0;return cH(a)^cH(b)^1}function Kp(a,b,c){return x[(b<<2)+a>>2]+(c<<2)|0}function Jh(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function Fh(a,b){a=a|0;b=b|0;return WG(a)^WG(b)^1}function Es(a){return(x[Cb(a)>>2]-x[a>>2]|0)/52|0}function EG(a){return(Dj(a)|0)!=0|(a|32)-97>>>0<6}function Dea(a,b){a=a|0;b=b|0;return yj(a,b,71)|0}function yga(a,b){a=a|0;b=b|0;Mo(a,b,452,451,6)}
function xs(a){a=a|0;sc(a+4208|0);return uf(a)|0}function x6(a,b){a=a|0;b=b|0;return E(yl(a,b,1))}function wu(a,b){a=a|0;b=b|0;if(!Iq(a,b)){zq(b)}}function qK(a){a=a|0;sc(a+4256|0);return uf(a)|0}function pT(a,b){x[a>>2]=x[a>>2]+D(b,6);return a}function oU(a,b){a=VT(a,b);if(!a){fB(b)}return a}function nA(a,b){a=a|0;b=b|0;if(!BS(a,b)){uA(b)}}function n9(a,b){a=a|0;b=b|0;if(!bD(a,b)){pv(b)}}function m4(a){a=a|0;return HE(a,8698,1074448)|0}function kV(a,b){a=a|0;b=b|0;if(!LB(a,b)){su(b)}}function k7(a,b){a=a|0;b=b|0;return E(yl(a,b,6))}function j4(a){a=a|0;return Kv(a,5280,1074424)|0}function iq(a,b){a=a|0;b=b|0;if(!Sh(a,b)){tl(b)}}function hv(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0}function h9(a,b){a=a|0;b=b|0;return yj(a,b,73)|0}function f6(a,b){a=a|0;b=b|0;return E(yl(a,b,2))}function cx(a,b){x[a>>2]=x[b>>2];dd(a+4|0,b+4|0)}function cd(a,b,c,d){return Bd(a,D(Bg(b),c)+d|0)}function bo(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function az(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function a9(a,b){a=a|0;b=b|0;return yj(a,b,60)|0}function _t(a){return(x[Cb(a)>>2]-x[a>>2]|0)/6|0}function _6(a,b){a=a|0;b=b|0;return E(yl(a,b,5))}function _5(a,b){a=a|0;b=b|0;return E(yl(a,b,3))}function _0(a,b){a=a|0;b=b|0;return+hI(a-88|0,b)}function WE(a,b,c,d,e){La(a|0,b|0,c|0,d|0,e|0,1)}function UI(a,b){a=a|0;b=b|0;kk(a,b,58152,58160)}function TO(a,b){x[a>>2]=x[a>>2]+(b<<1);return a}function TI(a,b){a=a|0;b=b|0;kk(a,b,58168,58176)}function T6(a,b){a=a|0;b=b|0;return E(yl(a,b,4))}function SM(a,b,c){x[a+4>>2]=c;v[a|0]=b;return a}function RT(a,b){a=a|0;b=b|0;if(!QT(a,b)){Zt(b)}}function PI(a,b){a=a|0;b=b|0;kk(a,b,58972,58980)}function Oy(a){return(x[Cb(a)>>2]-x[a>>2]|0)/7|0}function OI(a,b){a=a|0;b=b|0;kk(a,b,58988,58996)}function NI(a,b){a=a|0;b=b|0;kk(a,b,59800,59808)}function N0(a,b){a=a|0;b=b|0;return+ZH(a-92|0,b)}function MK(a){a=a|0;fc(a+4208|0);return uf(a)|0}function MI(a,b){a=a|0;b=b|0;kk(a,b,59816,59824)}function L0(a,b){a=a|0;b=b|0;return+XH(a-92|0,b)}function JI(a,b){a=a|0;b=b|0;kk(a,b,60628,60636)}function II(a,b){a=a|0;b=b|0;kk(a,b,60644,60652)}function Eia(a,b){a=a|0;b=b|0;return hu(a,1,b)|0}function EB(a,b){a=a|0;b=b|0;if(!lD(a,b)){kD(b)}}function Do(a,b,c){a=Yd(a);x[a+4>>2]=c;x[a>>2]=b}function xea(a,b){a=a|0;b=b|0;Mo(a,b,605,604,8)}function uF(a){var b=0,c=0;b=a,c=zd(),x[b>>2]=c}function tx(a,b){return Lt(B[a>>2],B[b>>2])?b:a}function tS(a){return!Rb(a,13737,4)&y[a+4|0]<32}function ria(a,b,c){a=a|0;b=b|0;c=c|0;MB(a,b,c)}function rd(a,b){return Vo(x[b>>2],x[a>>2])?b:a}function oH(a,b){if(!a){return 0}return Bw(a,b)}function nk(a){return mb[x[x[a>>2]+36>>2]](a)|0}function lH(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function k4(a){a=a|0;return HE(a,7071,480214)|0}function hn(a){return mb[x[x[a>>2]+28>>2]](a)|0}function _ha(a,b){a=a|0;b=b|0;Mo(a,b,338,337,8)}function _c(a,b){return Np(x[a>>2],x[b>>2])?b:a}function Wc(a,b){return rl(z[b>>1],z[a>>1])?b:a}function Se(a,b){return rl(z[a>>1],z[b>>1])?b:a}function Q2(a){a=a|0;return CE(a,49560,12396)|0}function Pl(a,b){return Lt(B[b>>2],B[a>>2])?b:a}function Pea(a,b){a=a|0;b=b|0;Mo(a,b,574,573,8)}function PR(a){var b=0;b=x[a>>2];Le(a);return b}function Mt(a,b){a=a|0;b=b|0;return Qb(a,b,1)^1}function LV(a,b){a=a|0;b=b|0;np(a,b);return a|0}function Je(a,b){return Vo(x[a>>2],x[b>>2])?b:a}function J3(a){a=a|0;return Kv(a,5777,480272)|0}function IB(a,b){return(b&255)==2&(a&255)>>>0<3}function Fb(a,b){return Np(x[b>>2],x[a>>2])?b:a}function By(a){if(y[a+24|0]){_M(a);v[a+24|0]=0}}function Ah(a,b,c){return Ga(914,a|0,b|0,c|0)|0}function y2(a,b){a=a|0;b=b|0;dd(a,dr(b,17491))}function wO(a){Xy(a);Zb(a+27|0,0,255);return a}function uB(a){return!Rb(a,15258,4)&y[a+4|0]<4}function qz(a){return a>>>0<=45?y[a+44208|0]:0}function qh(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function l8(a,b,c){a=a|0;b=b|0;c=c|0;PK(a,b,c)}function ku(a,b,c){a=a|0;b=b|0;c=c|0;lB(a,b,c)}function k6(a){a=a|0;bK(a);kx(a);v[a+4202|0]=1}function gf(a,b,c){if(!(y[a|0]&32)){kB(b,c,a)}}function gO(a){x[a>>2]=0;x[a+4>>2]=-1;return a}function Ys(a){return(a>>>0<9?a:a-9|256)&65535}function Y6(a){a=a|0;v[a+4202|0]=1;mK(a);oK(a)}function Xf(a,b,c){a=Kia(a,b,c,c>>31);return a}function Wm(a,b,c,d,e){Pa(a|0,b|0,c|0,d|0,e|0)}function WX(a,b,c){a=a|0;b=b|0;c=c|0;ec(a,c,b)}function UU(a,b){a=a|0;b=b|0;Mo(a,b,279,278,8)}function Rj(a,b){return(D(b,104)+a|0)+484380|0}function R6(a){a=a|0;v[a+4202|0]=1;kK(a);jK(a)}function P2(a){a=a|0;return CE(a,49580,8109)|0}function Oea(a,b){a=a|0;b=b|0;return bR(a,b)|0}function Em(a){return(a>>>0<=127?-1:a^128)&255}function Cr(a,b){return(a&255)>>>0<(b&255)>>>0}function CA(a,b,c){a=a|0;b=b|0;c=c|0;JB(a,b,c)}function wc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function wW(a){a=a|0;x[a>>2]=61588;return a|0}function vJ(a){a=a|0;x[a>>2]=49644;return a|0}function v1(a){a=a|0;x[a>>2]=60668;return a|0}function sv(a,b){a=a|0;b=b|0;return dr(a,b)|0}function qga(a,b){a=a|0;b=b|0;Dv(a,b,17,3,16)}function pg(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function ks(a){a=AJ(a);x[a>>2]=77768;return a}function kW(a){a=a|0;x[a>>2]=43496;return a|0}function jU(a){v[a+12|0]=y[a+12|0]|2;return a}function iW(a){a=a|0;x[a>>2]=43256;return a|0}function ew(a,b,c){a=qG(a,b,c,-1,-1);return a}function eQ(a){return Ge(443250/+(a>>>0)*1e4)}function eH(a){a=a|0;ww(x[x[a>>2]-12>>2]+a|0)}function dX(a,b){a=a|0;b=b|0;return RD(a,b)|0}function _k(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function Zs(a,b){a=a|0;b=b|0;return lg(a,b)|0}function Ye(a,b){return Cr(y[a|0],y[b|0])?b:a}function Yd(a){x[a>>2]=0;x[a+4>>2]=0;return a}function Wb(a,b){return Cr(y[b|0],y[a|0])?b:a}function T$(a){a=a|0;SG(x[x[a>>2]-12>>2]+a|0)}function Sr(a,b){a=a|0;b=b|0;return NC(a,b)|0}function Rh(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function R$(a){a=a|0;RG(x[x[a>>2]-12>>2]+a|0)}function Q8(a,b){a=a|0;b=b|0;dy(oL(a+24|0,b))}function Ol(a){a=Ml(a);x[a>>2]=92436;return a}function Oha(a,b){a=a|0;b=b|0;nE(a,b,342,341)}function Nd(a){a=wD(a);x[a>>2]=83856;return a}function Mia(a,b,c,d){a=Hia(a,b,c,d);return a}function JG(a){a=AJ(a);x[a>>2]=78160;return a}function EU(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function EQ(a){a=Jia(a&65535,0,80,0);return a}function Dia(a,b){a=a|0;b=b|0;nE(a,b,285,284)}function DF(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function D1(a){a=a|0;x[a>>2]=61168;return a|0}function Ax(a){return x[Cb(a)>>2]-x[a>>2]>>11}function AT(a){a=(a&65535)-98|0;lb=0;return a}function $G(a){a=a|0;uw(x[x[a>>2]-12>>2]+a|0)}function zo(a,b,c,d){a=Kia(a,b,c,d);return a}function zZ(a){a=a|0;Rd(a,469376,Od(467784))}function z0(a){a=a|0;return gb(x[a+60>>2])|0}function yZ(a){a=a|0;Rd(a,469384,Od(467792))}function xZ(a){a=a|0;Rd(a,469392,Od(467800))}function wx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function wZ(a){a=a|0;Rd(a,469400,Od(467808))}function vy(a){v[a+24|0]=0;v[a|0]=0;return a}function vZ(a){a=a|0;Rd(a,469408,Od(467816))}function uZ(a){a=a|0;Rd(a,469416,Od(467824))}function u4(a){a=a|0;return KE(a,7015,957)|0}function tZ(a){a=a|0;Rd(a,469424,Od(467832))}function sZ(a){a=a|0;Rd(a,469432,Od(467744))}function rZ(a){a=a|0;Rd(a,469448,Od(467752))}function pZ(a){a=a|0;Rd(a,469464,Od(467760))}function oh(a){return x[x[a+8>>2]>>2]==(a|0)}function nx(a){return E(E(a*E(7900))+E(100))}function nZ(a){a=a|0;Rd(a,469480,Od(467768))}function mZ(a){a=a|0;Rd(a,469496,Od(467840))}function lr(a){return x[Cb(a)>>2]-x[a>>2]>>4}function lZ(a){a=a|0;Rd(a,469504,Od(467848))}function iz(a){return x[yc(a)>>2]-x[a>>2]>>2}function gw(){ha(Ol(ba(4)|0)|0,92520,25);p()}function gea(a,b){a=a|0;b=b|0;Ev(a,b,1042,2)}function cF(a,b,c){a=a|0;b=b|0;c=c|0;QG(a,c)}function aha(a,b){a=a|0;b=b|0;mr(a,b,1042,2)}function a4(a){a=a|0;return KE(a,6552,965)|0}function XI(a){v[a+4|0]=0;v[a|0]=0;return a}
function Tp(a,b){return D((b-a|0)/6|0,6)+a|0}function RZ(a){a=a|0;Rd(a,469184,Od(467696))}function RU(a,b){a=a|0;b=b|0;Dv(a,b,44,2,44)}function QZ(a){a=a|0;Rd(a,469192,Od(467704))}function Pm(a){return x[Cb(a)>>2]-x[a>>2]>>3}function PZ(a){a=a|0;Rd(a,469200,Od(467900))}function OZ(a){a=a|0;Rd(a,469216,Od(467892))}function NZ(a){a=a|0;Rd(a,469224,Od(467908))}function NS(a,b,c){ec(a,b,gi(b,b+c|0,0)-b|0)}function Mj(a){return eE(a,E(4294967296),-1)}function Mg(a,b,c,d){return(D(b,d)+c<<3)+a|0}function MR(a,b,c,d){return(D(b,d)+c<<1)+a|0}function LZ(a){a=a|0;Rd(a,469232,Od(467916))}function Kh(a){return x[Cb(a)>>2]-x[a>>2]>>2}function KZ(a){a=a|0;Rd(a,469248,Od(467924))}function K1(a){a=a|0;EI(a);return x[a+16>>2]}function JZ(a){a=a|0;Rd(a,469256,Od(467940))}function IZ(a){a=a|0;Rd(a,469264,Od(467932))}function HZ(a){a=a|0;Rd(a,469272,Od(467948))}function Gh(a,b,c,d){return(D(b,d)+c<<2)+a|0}function GZ(a){a=a|0;Rd(a,469280,Od(467956))}function FZ(a){a=a|0;Rd(a,469304,Od(467964))}function Ej(a){a=a&255;return(a|0)==255?-1:a}function Eb(a,b){if(!re(b)){a=mj(b)}return a}function EZ(a){a=a|0;Rd(a,469336,Od(467712))}function Dm(a){return x[Cb(a)>>2]-x[a>>2]>>1}function DZ(a){a=a|0;Rd(a,469344,Od(467720))}function CZ(a){a=a|0;Rd(a,469352,Od(467728))}function BZ(a){a=a|0;Rd(a,469360,Od(467736))}function Az(a){return x[Cb(a)>>2]-x[a>>2]>>8}function AZ(a){a=a|0;Rd(a,469368,Od(467776))}function $n(a){return x[Cb(a)>>2]-x[a>>2]>>5}function wm(a,b,c){return nf(a,b)>>>0>c>>>0}function qs(a){a=a|0;mb[x[x[a>>2]+4>>2]](a)}function mf(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function kn(a){a=a|0;VG(x[a>>2]);return a|0}function hX(a,b){a=a|0;b=b|0;zv(a,b,1058,2)}function dV(a,b){a=a|0;b=b|0;Ev(a,b,1025,2)}function ci(a,b){a=a|0;b=b|0;return E(E(0))}function an(a){return x[Cb(a)>>2]-x[a>>2]|0}function Yk(a,b){return a<<24>>24<b<<24>>24}function RJ(a){return Ih(E(TJ(a)*E(32768)))}function Pp(a,b){w[a>>1]=b;w[a+2>>1]=b>>>16}function L1(a){a=a|0;EI(a);return x[a+4>>2]}function Hl(a){a=a|0;vw(x[a>>2]);return a|0}function GS(a,b){x[a>>2]=x[a>>2]+b;return a}function G8(a,b){a=a|0;b=b|0;mr(a,b,1058,1)}function Ep(a,b){return a<<16>>16<b<<16>>16}function D0(a,b){a=a|0;b=b|0;mr(a,b,1025,4)}function A0(a,b){a=a|0;b=b|0;mr(a,b,1025,2)}function $s(a,b,c){v[a|0]=b;v[a+1|0]=y[c|0]}function vt(a){x[a>>2]=x[a>>2]+52;return a}function vl(a){x[a>>2]=x[a>>2]-12;return a}function vH(a,b){return E(rv(a?E(-b):b)*b)}function sw(a){a=a|0;return th(a,467892)|0}function sr(a,b){mb[x[x[b>>2]+40>>2]](a,b)}function rt(a){He(a+24|0);fc(a+12|0);fc(a)}function pw(a){a=a|0;return th(a,467908)|0}function pm(a){x[a>>2]=x[a>>2]+28;return a}function pk(a,b){mb[x[x[b>>2]+44>>2]](a,b)}function ok(a,b){mb[x[x[b>>2]+32>>2]](a,b)}function n0(a){a=a|0;return th(a,467712)|0}function lw(a){a=a|0;return th(a,467916)|0}function im(a){jz(x[a+20>>2]);x[a+20>>2]=0}function iX(a,b){a=a|0;b=b|0;zv(a,b,290,0)}function iL(a){x[a>>2]=x[a>>2]-52;return a}function hw(a){a=a|0;return th(a,467956)|0}function gz(a){x[a>>2]=x[a>>2]+32;return a}function g0(a){a=a|0;return th(a,467728)|0}function fu(a){x[a>>2]=x[a>>2]-28;return a}function ex(a){x[a>>2]=x[a>>2]-16;return a}function dW(a,b){a=a|0;b=b|0;zv(a,b,257,0)}function dD(a){x[a>>2]=x[a>>2]-36;return a}function d8(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function bw(a){a=a|0;return th(a,467964)|0}function Ze(a,b,c){a=Jia(c,0,a,b);return a}function Zc(a,b){a=a|0;b=b|0;PK(a,b,If(b))}function Yn(a){x[a>>2]=x[a>>2]+16;return a}function Xr(a){return(a|0)<=65535&(a|0)>=0}function Wp(a){x[a>>2]=x[a>>2]+12;return a}function WJ(a){return E(E(a*E(96))+E(-96))}function TM(a,b){return rE(a,b,2147483647)}function Sda(a,b){a=a|0;b=b|0;kE(a,b,2,31)}function SU(a,b){a=a|0;b=b|0;Ev(a,b,274,0)}function Pq(a){Zq(a+32|0);yb(a+12|0);xb(a)}function PP(a,b,c,d){ec(a,b,(d|0)==-1?c:d)}function Nk(a){xb(a+36|0);sc(a+24|0);Zj(a)}function NQ(a){x[a>>2]=x[a>>2]-56;return a}function JO(a){x[a>>2]=x[a>>2]-32;return a}function Cu(a){a=a|0;return th(a,467900)|0}function CW(a){a=a|0;return x[a+4>>2]!=0|0}function CT(a){x[a>>2]=x[a>>2]-20;return a}function C7(a,b,c){a=a|0;b=b|0;c=c|0;Yd(a)}function zk(a){a=a|0;return dH(a)<<24>>24}function xI(a,b){a=a|0;b=b|0;lg(a,b+12|0)}function oia(a,b){a=a|0;b=b|0;kE(a,b,3,8)}function h1(a,b){a=a|0;b=b|0;qI(a-88|0,b)}function gu(a){x[a>>2]=x[a>>2]-2;return a}function gs(a,b){x[a>>2]=b;Km(b);return a}function g1(a,b){a=a|0;b=b|0;pI(a-88|0,b)}function efa(a,b){a=a|0;b=b|0;Ei(a,b,274)}function dk(a){x[a>>2]=x[a>>2]+6;return a}function cp(a,b){v[a|0]=b+48;return a+1|0}function aI(a,b){a=a|0;b=b|0;zE(a,b,2048)}function _ea(a,b){a=a|0;b=b|0;Ei(a,b,106)}function XJ(a){a=a|0;Zb(a+4296|0,0,81928)}function Ww(a,b,c,d){return Kp(a,c,b+d|0)}function Wr(a){a=a|0;ls(a+8|0);return a|0}function Vs(a){x[a>>2]=x[a>>2]+8;return a}function VK(a){x[a>>2]=x[a>>2]-4;return a}function Te(a,b,c){pi(b,b+c|0,a);return a}function TE(a){a=Da(a|0)|0;lb=ib;return a}function T0(a,b){a=a|0;b=b|0;bI(a-88|0,b)}function Q0(a,b){a=a|0;b=b|0;aI(a-92|0,b)}function Pe(a){x[a>>2]=x[a>>2]+2;return a}function PU(a,b){a=a|0;b=b|0;vj(a+12|0,b)}function P0(a,b){a=a|0;b=b|0;$H(a-92|0,b)}function Mr(a){a=a|0;Ak(a+8|0);return a|0}function Lr(a){a=a|0;Ak(a+4|0);return a|0}function Le(a){x[a>>2]=x[a>>2]+1;return a}function LU(a,b){a=a|0;b=b|0;vj(a+36|0,b)}function J8(a,b){a=a|0;b=b|0;lg(a,b+36|0)}function Gf(a){a=a|0;xh(a+8|0);return a|0}function GY(a,b){a=a|0;b=b|0;lg(a,b+16|0)}function Fe(a){x[a>>2]=x[a>>2]+4;return a}function EN(a,b){if(B[a>>2]>b){B[a>>2]=b}}function D9(a,b){a=a|0;b=b|0;vj(a+40|0,b)}function $H(a,b){a=a|0;b=b|0;zE(a,b,4096)}function zY(a,b){a=a|0;b=b|0;Xb(a,11272)}function yD(a,b){qc(a,b);qc(a+4|0,b+4|0)}function vk(a){return(a|0)==32|a-9>>>0<5}function q7(a){a=a|0;v[a+4202|0]=1;BK(a)}function pga(a,b){a=a|0;b=b|0;wq(a,b,17)}function p6(a){a=a|0;return x[a+4260>>2]}function mo(a,b){v[a|0]=b;v[a+1|0]=b>>>8}function j1(a){a=a|0;return Wr(a-88|0)|0}function ic(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function gk(a){return D(Fm(a),Gd(a))&255}function f1(a,b){a=a|0;b=+b;oI(a-88|0,b)}function eS(a,b){a=a|0;b=b|0;Ei(a,b,284)}function d1(a,b){a=a|0;b=+b;mI(a-88|0,b)}function cg(a,b){x[a+8>>2]=b|-2147483648}function b1(a,b){a=a|0;b=+b;kI(a-88|0,b)}function aga(a,b){a=a|0;b=b|0;Ei(a,b,42)}function Yi(a){w[a+4>>1]=65535;x[a>>2]=0}function Yea(a,b){a=a|0;b=b|0;Ei(a,b,72)}function Vha(a,b){a=a|0;b=b|0;Ei(a,b,34)}function S0(a){a=a|0;return Wr(a-92|0)|0}function Qd(a,b){return(b|0)!=0&(a|0)!=0}function OM(a,b,c){x[a>>2]=b;x[a+4>>2]=c}function Jr(a,b){x[a+24>>2]=x[a+24>>2]+b}function GU(a,b){a=a|0;b=b|0;Ei(a,b,136)}function Fr(a){a=a|0;Hv(a,154,92880,954)}function FY(a,b){a=a|0;b=b|0;Ym(a,83600)}function EY(a,b){a=a|0;b=b|0;Ym(a,83620)}function AY(a,b){a=a|0;b=b|0;Xb(a,11155)}function zV(a,b){a=a|0;b=b|0;Ei(a,b,59)}function sB(a,b){a=a|0;b=b|0;Ei(a,b,50)}function oga(a,b){a=a|0;b=b|0;OB(a,b,8)}function oV(a,b){a=a|0;b=b|0;wq(a,b,11)}function c8(a){a=a|0;return y[a+4201|0]}function b8(a){a=a|0;return y[a+4202|0]}function YS(a,b){a=a|0;b=b|0;wq(a,b,32)}function YR(a,b){x[a>>2]=x[a>>2]+(b<<2)}function Xm(a,b,c){return ug(a,b,b+c|0)}function Ug(a,b,c){v[a+4|0]=c;x[a>>2]=b}function RS(a,b){a=a|0;b=b|0;return b|0}function Q5(a){a=a|0;return(a|0)==277|0}function PF(a,b){a=a|0;b=b|0;Ue(a,1,45)}function Oca(a,b){a=a|0;b=b|0;hE(a,b,3)}function OF(a,b){a=a|0;b=b|0;ZF(a,1,45)}function Nm(a){a=x[a+8>>2];if(a){Hb(a)}}function Nh(a){return(a&65535)>>>0<3999}function MM(a,b){return(Vk(a,b)|0)!=255}function Lb(a){return(a<<8|a>>>8)&65535}function KQ(a,b,c,d){return _k(c,d,a,b)}function Jj(a,b){return zy(a&255,b&255)}function Iy(a,b,c){return a<b?b:a>c?c:a}function Hy(a,b,c){return a<b?b:a>c?c:a}function Ew(a){return(q(a),j(2))>>>20|0}function CI(a){x[a+4>>2]=x[a+4>>2]|8192}function xl(a,b){x[a+4>>2]=2;x[a>>2]=b}function wv(a,b){x[a+4>>2]=4;x[a>>2]=b}function tr(a){a=a|0;return 2147483647}function rO(a,b,c){return oE(a,b,c,41)}function qA(a,b,c){Sg(a,c);id(b+c|0,0)}function ot(a,b,c){return nr(a,b,c,12)}function oW(a){a=a|0;return x[a+16>>2]}function ke(a,b,c){fn(a,b,Rc(b,c)+b|0)}function jJ(a){return a?(a|0)==2?3:2:1}function fA(a,b){a=a|0;b=b|0;hE(a,b,2)}function e1(a){a=a|0;return+nI(a-88|0)}function c1(a){a=a|0;return+lI(a-88|0)}function aU(a,b,c){return nr(a,b,c,48)}function a6(a){a=a|0;return-2013527448}function a1(a){a=a|0;return+jI(a-88|0)}function Wi(a,b){return Pb(a)+(b<<2)|0}function W7(a){a=a|0;return 542066252}
function Rg(a){return eE(a,E(255),255)}function QK(a){a=a|0;return 1869112133}function Nca(a){a=a|0;zQ(a);return a|0}function Ky(a,b){return pE(a,b,-1,0,0)}function ID(a,b){x[a+4>>2]=3;x[a>>2]=b}function Hd(a){x[x[a+8>>2]>>2]=x[a>>2]}function HY(a){a=a|0;return x[a+12>>2]}function Eu(a,b,c){return nr(a,b,c,20)}function Cj(a,b){x[a+4>>2]=1;x[a>>2]=b}function zi(a,b,c){return Lo(a,b,c,1)}function z6(a){a=a|0;return-620920304}function z$(a){a=a|0;return FG(a,0)|0}function y$(a){a=a|0;return FG(a,1)|0}function xx(a,b){a=a|0;b=b|0;return 1}function xo(a,b,c){return kr(a,b,c,1)}function wQ(a){return(a|0)>=120?120:a}function wN(a,b){return(0-b|0)!=(a|0)}function wL(a,b){Xc(a,b&4?16:8,1,0,0)}function vS(a,b,c){hc(a,b,rc(b,c)<<2)}function vP(a){return(a&65535)==65534}function uD(a){a=a|0;return x[a+8>>2]}function tI(a){x[a>>2]=62360;return a}function sz(a,b,c){return Lo(a,b,c,5)}function sI(a){x[a>>2]=62384;return a}function rI(a){x[a>>2]=62464;return a}function q6(a){a=a|0;return-275227023}function pl(a,b,c){return kr(a,b,c,2)}function of(a,b,c){return cd(a,b,c,0)}function nf(a,b){return ak(a,b)&65535}function nD(a,b,c){hc(a,b,Eg(b,c)<<3)}function m7(a){a=a|0;return-270114148}function lm(a){return(a&740327453)!=0}function lh(a,b,c){return Lo(a,b,c,2)}function jo(a,b){w[a+8>>1]=b;return a}function hq(a,b,c){return nr(a,b,c,6)}function h6(a){a=a|0;return 302837129}function bj(a){return(a-1&255)>>>0<17}function b7(a){a=a|0;return-285139079}function ai(a,b,c){dd(dd(a,b)+12|0,c)}function aJ(a){x[a>>2]=49892;return a}function _B(a,b){jr(a,b,20,214748365)}function ZD(a,b,c){return kr(a,b,c,4)}function Xh(a){a=x[a>>2];if(a){sG(a)}}function Wq(a){a=a|0;return x[a+4>>2]}function VI(a){x[a>>2]=58136;return a}function V6(a){a=a|0;return-284078960}function T5(a,b){a=a|0;b=b|0;return 3}function Rq(a,b,c){return Lo(a,b,c,3)}function RR(a){OH(a);se(x[a+80>>2],a)}function R5(a,b){a=a|0;b=b|0;return 2}function QD(a){a=E(a-a);return E(a/a)}function OD(a,b){jr(a,b,12,357913942)}function O6(a){a=a|0;return-281111764}function Nr(a,b){a=a|0;b=b|0;return-1}function NJ(a,b){a=a|0;b=b|0;return 0}function Mm(a){x[a>>2]=61120;return a}function Ml(a){x[a>>2]=93132;return a}function Jo(a,b,c){return Lo(a,b,c,4)}function JQ(a,b,c){Zk(a,(b<<2)+a|0,c)}function H6(a){a=a|0;return-271958638}function G1(a){a=a|0;return y[a+40|0]}function G$(a){a=a|0;return GG(a,0)|0}function F$(a){a=a|0;return GG(a,1)|0}function Ce(a,b){x[a+4>>2]=b;return a}function BP(a,b,c){return kr(a,b,c,5)}function AJ(a){x[a>>2]=77796;return a}function z7(a,b){a=a|0;b=b|0;Zs(a,b)}function vA(a,b){a=a|0;b=b|0;sJ(a,b)}function uQ(a){return(a&255)>>>0<129}function sx(a,b){a=a|0;b=b|0;DK(a,b)}function qP(a,b,c,d){mP(ec(a,b,c),d)}function mD(a,b){yv(a,b,3,536870912)}function lL(a,b){jr(a,b,52,82595525)}function kj(a,b){a=a|0;b=b|0;nU(a,b)}function jx(a){a=a|0;NE(a,49480,905)}function jk(a,b){a=a|0;b=b|0;An(a,b)}function is(a){return z[a+480192>>1]}function ih(a,b){a=a|0;b=b|0;lg(a,b)}function hs(a){return z[a+480190>>1]}function gia(a){a=a|0;return MT(a)|0}function fL(a,b){return Pj(a,b-a>>2)}function dt(a){return x[Cb(a)>>2]<<5}function daa(a){a=a|0;return Fg(a)|0}function dN(a){return(a+5&255)>>>0<2}function _o(a,b,c,d,e){QI(a,b,c,d,e)}function _D(a,b){yv(a,b,4,268435456)}function Wg(a){fl(a+44|0);fc(a+32|0)}function UJ(a){x[a>>2]=0;x[a+4>>2]=0}function TW(a,b){a=a|0;b=b|0;VD(a,b)}function SD(a,b){a=a|0;b=b|0;pp(a,b)}function Rt(a,b){return y[a+b|0]!=63}function OP(a,b){return D(b,872)+a|0}function OK(a,b,c){a=a|0;b=b|0;c=c|0}function Km(a){x[a+4>>2]=x[a+4>>2]+1}function IS(a,b){jr(a,b,6,715827883)}function IL(a,b){a=a|0;b=b|0;wM(a,b)}function IJ(a){a=a|0;NE(a,49424,903)}function Eha(a){a=a|0;return Jc(a)|0}function ER(a,b){if(!yR(a,b)){Wz(b)}}function Cq(a,b){a=a|0;b=b|0;$u(a,b)}function CY(a){a=a|0;return v[a+8|0]}function CP(a,b){yv(a,b,5,134217728)}function Bg(a){return z[a+480188>>1]}function BY(a){a=a|0;return v[a+9|0]}function An(a,b){a=a|0;b=b|0;ih(a,b)}function A1(a){a=a|0;return y[a+8|0]}function zg(a,b){return D(b,20)+a|0}function w9(a){a=a|0;return hi(a)|0}function vq(a){a=a|0;return Be(a)|0}function vn(a,b){return(b-a|0)/24|0}function u6(a){a=a|0;x[a+4224>>2]=0}function tc(a,b){return(a|0)==(b|0)}function tB(a){a=a|0;return Yu(a)|0}function rp(a){if(y[a+24|0]){_M(a)}}function rS(a,b){return D(b,33)+a|0}function og(a,b){return(a|0)!=(b|0)}function nq(a,b){return(b-a|0)/28|0}function nU(a,b){kU(a,x[a+16>>2]|b)}function mt(a,b){return D(b,36)+a|0}function le(a,b,c){return mG(a,b,c)}function kp(a){return cU(a,251,255)}function il(a,b){return bu(Kc(a,b))}function hW(a){a=a|0;cD(Zb(a,0,36))}function gq(a,b){return(b-a|0)/48|0}function gW(a){a=a|0;return xh(a)|0}function dl(a,b,c){return ah(a,b,c)}function dA(a,b){return Ee(a,0-b|0)}function bl(a,b){return D(b,24)+a|0}function ak(a,b){return(b-a|0)/52|0}function _i(a,b){return _f(a,b)&255}function _b(a,b){return qe(a,b&255)}function Zf(a){return E(F(a))==E(O)}function Zd(a,b){return D(b,12)+a|0}function Yp(a){return(a&255)==1?1:2}function Ru(a){v[a+2|0]=0;w[a>>1]=0}function Qq(a,b){return(b-a|0)/36|0}function Pf(a){return nh(a)<<24>>24}function Ox(a,b){return D(b,28)+a|0}function OS(a,b,c){return pi(a,b,c)}function OG(a){a=a|0;return jv(a)|0}function OC(a){a=a|0;return Cg(a)|0}function Np(a,b){return a>>>0<b>>>0}function Mf(a,b){return Oj(a,Wd(b))}function Lz(a,b){return D(b,56)+a|0}function Kt(a,b){return(b-a|0)/33|0}function Jf(a,b){return D(b,52)+a|0}function Ib(a,b){x[a>>2]=b;return a}function IW(a){a=a|0;return kg(a)|0}function IA(a,b,c){return Ct(a,b,c)}function Hw(a){return!Rb(a,93448,6)}function HT(a,b){return Ee(a,b-a|0)}function Gp(a,b){return(b-a|0)/56|0}function Dd(a,b){return(b-a|0)/12|0}function CJ(a){a=a|0;return Ak(a)|0}function Bf(a,b){return(b-a|0)/20|0}function $$(a){a=a|0;return xk(a)|0}function zs(a,b){return(a-b|0)/6|0}function zq(a){v[a|0]=0;v[a+1|0]=0}function yU(a,b){return tk(a,b,28)}function uv(a,b){return tk(a,b,12)}function un(a,b){x[a+1298464>>2]=b}function re(a){return(a&128)>>>7|0}function qw(a){return tc(a,-1)?0:a}function oS(a,b){return Iv(a,b,18)}function lj(a,b){return D(gk(b),a)}function lT(a){return y[a+1|0]!=63}function lD(a,b){return Iv(a,b,20)}function iD(a,b){return tk(a,b,36)}function gJ(a){return(Ej(a)|0)==-1}function fJ(a,b){a=a|0;b=b|0;fc(b)}function eh(a,b){x[a>>2]=x[a>>2]|b}function eN(a){je(a+8|0);YM(a+4|0)}function eJ(a,b){a=a|0;b=b|0;gm(b)}function ck(a){return a&2147483647}function bi(a){a=a|0;v[a+4202|0]=0}function bM(a,b){x[a>>2]=x[a>>2]+b}function XW(a){a=a|0;Jm(a,1,13315)}function Vo(a,b){return(a|0)<(b|0)}function Vj(a,b){return(b-a|0)/6|0}function Uc(a,b){return rE(a,b,-1)}function UD(a){C[(hb-16|0)+8>>3]=a}function Sl(a){return E(F(a))<E(O)}function Rn(a,b){return(b<<13)+a|0}function Ny(a,b){return(b-a|0)/7|0}function MF(a){return th(a,467784)}function LF(a){return th(a,467776)}function L8(a){a=a|0;wq(a,21502,1)}function Kq(a,b){return(b<<11)+a|0}function JF(a){return th(a,467800)}function IF(a){return th(a,467792)}function I0(a,b){a=a|0;b=b|0;Hb(b)}function Fk(a,b){return(a+b|0)-1|0}function Bh(a,b){a=a|0;b=b|0;Kb(a)}function Bd(a,b){return D(b,6)+a|0}function zc(a){x[a>>2]=0;return a}function zb(a,b){return(b<<2)+a|0}function zX(a){a=a|0;return 10668}function yI(a){x[a>>2]=x[a>>2]+24}function wfa(a){a=a|0;ef(a,16667)}function wf(a){return a!=a?E(0):a}function vh(a){x[a>>2]=1;return a}function vea(a){a=a|0;bS(a,65535)}function uc(a,b){return Pb(a)+b|0}function rh(a){x[a>>2]=x[a>>2]+20}function qe(a,b){return(b<<5)+a|0}function pz(a,b){return tk(a,b,4)}function om(a){x[a>>2]=2;return a}function nG(a,b){return mG(a,0,b)}function jz(a){if(a){Hb(a+-64|0)}}function jha(a){a=a|0;ef(a,16036)}function haa(a){a=a|0;QE(a,46,45)}function fs(a){return fE(a,76472)}function em(a,b){return(b<<8)+a|0}function ce(a,b){return!Rb(a,b,4)}function cc(a,b){return(b<<1)+a|0}function bx(a,b){return EL(a,b)^1}function bd(a,b){return(b<<4)+a|0}function _l(a){w[a>>1]=0;return a}function ZG(a){return fE(a,76536)}function Tc(a){return cU(a,1,120)}function TX(a){a=a|0;return 13013}function Sd(a){return x[jc(a)>>2]}function SX(a){a=a|0;return 10178}function SN(a,b){return tk(a,b,8)}function Q$(a){a=a|0;return 10298}function PC(a){return(a&16)>>>4|0}function Ov(a,b){return x[a+b>>2]}function Ob(a,b){return tc(a,b)^1}function Ne(a,b){return(b<<3)+a|0}function Jn(a){return a+1074328|0}function Gs(a){fc(a+4|0);return a}function Dj(a){return a-48>>>0<10}function AX(a){a=a|0;return 12899}function $p(a,b){return ne(a,b)^1}function yX(a){a=a|0;return 5681}function xfa(a){a=a|0;ef(a,3968)}function vT(a,b,c){qE(a,b,c,256)}function mq(a,b,c){lE(a,b,c,128)}function kq(a){return Zb(a,0,48)}function hU(a){Hv(a,24,92760,23)}function gx(a,b,c,d){px(a,b,c,d)}function gha(a){a=a|0;ef(a,4445)}function cia(a){a=a|0;ef(a,3892)}function cea(a){a=a|0;ef(a,4126)}function cS(a,b){vc(a,b+4|0,256)}function _V(a){a=a|0;rC(a,If(a))}function Sfa(a){a=a|0;ef(a,3883)}function Qp(a){Hv(a,24,92812,26)}function Qfa(a){a=a|0;ef(a,4848)}function PX(a){a=a|0;return 6827}function Ou(a,b){return Nia(a,b)}function OW(a){a=a|0;ef(a,16694)}function MW(a){a=a|0;QE(a,50,72)}function MG(a){x[a+72>>2]=466712}function Kg(a,b,c){fn(a,b,b+c|0)}function Kf(a,b,c,d){df(a,c,d,b)}function KG(a){x[a+72>>2]=466796}function Jy(a){v[a|0]=0;return a}function Iu(a,b,c){qE(a,b,c,128)}function H9(a){a=a|0;eg(a,$i(a))}function EK(a){return(a&8)>>>3|0}function Df(a,b){Ib(zc(a)+4|0,b)}function BX(a){a=a|0;return 9737}function $ga(a){a=a|0;ef(a,4339)}function yf(a){a=a|0;return a|0}function yb(a){be(a+12|0);be(a)}function xi(a,b){return Ju(a,b)}function xg(a,b){return Ob(a,b)}function wd(a,b){return!Eb(a,b)}function ur(a){a=a|0;return 127}function ud(a){return(a&255)!=0}function uI(a,b){return Eg(a,b)}function uG(a){if(vG(a)){Hb(a)}}function rj(a,b){return b-a>>11}function qf(a){xb(a+20|0);xb(a)}function oG(a,b){return Dd(a,b)}function ml(a,b,c){df(a,c,22,b)}function lf(a,b){return Oj(a,b)}function ki(a,b){return(a|b)!=0}function kc(a,b){return qD(a,b)}function ju(a,b,c){df(a,c,30,b)}function jj(a,b,c){df(a,c,20,b)}function ji(a,b){return Rc(a,b)}function ie(a,b){return rc(a,b)}function i1(a){a=a|0;Sw(a-88|0)}function hl(a,b,c){df(a,c,28,b)}function hB(a,b){return no(b,a)}function fj(a,b){return qe(a,b)}function fZ(a){a=a|0;Gc(468100)}function eo(a,b){return rl(a,b)}function ej(a){Rz(a,0);return a}function eV(a){a=a|0;ef(a,4319)}function dm(a){return cm(ee(a))}function dZ(a){a=a|0;Gc(468132)}function ay(a){w[a+480214>>1]=0}function af(a,b){return ig(a,b)}function ac(a,b){return Jf(a,b)}function aZ(a){a=a|0;Gc(468036)}function aQ(a,b){Bv(a,b,12,-12)}function _Y(a){a=a|0;Gc(468068)}function _M(a){XM(a+12|0);WM(a)}function Yv(a){return Cb(a+8|0)}function Yf(a){return li(a)?0:a}function YT(a,b){Bv(a,b,48,-48)}function Xk(a,b){return Ep(a,b)}function Wv(a,b){return Ng(a,b)}function Wk(a){xb(a+12|0);nd(a)}function Wj(a,b,c){df(a,c,12,b)}function We(a,b,c){df(a,c,32,b)}function VB(a){return(a&255)==1}function Sz(a,b,c){df(a,c,64,b)}function SY(a){a=a|0;xb(468084)}function Rs(a,b){return Ly(a,b)}function R0(a){a=a|0;Sw(a-92|0)}function Qc(a,b){return Eb(a,b)}function QY(a){a=a|0;xb(468116)}function Py(a,b){return Kc(a,b)}function Ph(a,b,c){df(a,c,13,b)}function Pg(a){return dN(a&255)}function PW(a){a=a|0;ef(a,4493)}function Os(a){aO(a+12|0);fO(a)}function Oj(a,b){return Ib(a,b)}function OY(a){a=a|0;xb(468020)}function OL(a,b){return ML(a,b)}function Mu(a,b){return zC(a,b)}function Mb(a,b){return(a&b)!=0}function MY(a){a=a|0;xb(468052)}function LT(a,b){return de(b,a)}function IT(a,b){return HT(a,b)}function Gx(a,b){return fL(a,b)}function Gn(a,b){return Cr(a,b)}function Gi(a,b){return a>>>b&1}function Ge(a){return cq(ee(a))}function GF(a,b,c){ec(a,b,1<<c)}function Cc(a,b){return Kq(a,b)}function CC(a,b){return yC(a,b)}function $o(a,b){return zb(a,b)}function $l(a){xb(a+12|0);xb(a)}function zy(a,b){return a<<8|b}function zw(a){a=a|0;Hb(Ak(a))}function yw(a){a=a|0;Hb(yn(a))}function yY(a){a=a|0;Hb(kF(a))}function ww(a){a=a|0;Hb(Mr(a))}function uw(a){a=a|0;Hb(Lr(a))}function uS(a,b){qA(a,Pb(a),b)}function tw(a){a=a|0;Hb(Kr(a))}function tW(a){a=a|0;Hb(pD(a))}function tF(a){a=a|0;Hb(Xv(a))}function tD(a){return a+1024|0}function se(a,b){if(!a){Hb(b)}}function rx(a){a=a|0;Hb(zK(a))}function rc(a,b){return b-a>>2}function pK(a){a=a|0;Hb(qK(a))}function oz(a){return a+4896|0}function o6(a){a=a|0;return 13}function o2(a){a=a|0;Hb(as(a))}function no(a,b){return a-b>>1}function mh(a,b){return b-a>>8}function mH(){return(db()|0)>0}function ln(a){return(a|0)==-1}function io(a){return a>>>0<11}function gc(a,b){x[a+100>>2]=b}function fx(a){a=a|0;Hb(wJ(a))}function fY(a){a=a|0;Hb(fF(a))}function et(a){return a>>>27^a}function ch(a,b){return b-a>>4}function cK(a){a=a|0;Hb(dK(a))}function _f(a,b){return b-a>>5}function ZX(a){a=a|0;Hb(eF(a))}function W$(a){a=a|0;Hb(js(a))}function Sw(a){a=a|0;Hb(Wr(a))}function SG(a){a=a|0;Hb(ap(a))}function Rm(a){a=a|0;Hb(bT(a))}function RG(a){a=a|0;Hb(hf(a))}function QQ(a,b){Dv(a,b,5,3,4)}function QP(a){return a+4096|0}function M1(a){a=a|0;Hb(GI(a))}function Lm(a){a=a|0;Hb(jv(a))}function LK(a){a=a|0;Hb(MK(a))}function Kc(a,b){return b-a>>1}function Jk(a){a=a|0;Hb(uf(a))}function IY(a){a=a|0;Hb(sF(a))}function Ht(a,b){return a-b>>2}function Gd(a){return a&64?2:1}function Eg(a,b){return b-a>>3}function DY(a){a=a|0;Hb(rF(a))}function Cn(a){a=a|0;Hb(xs(a))}function CS(a,b){fn(a,b,sd(b))}function B1(a){a=a|0;Hb(zI(a))}function zp(a,b){x[a+36>>2]=b}function yK(a){a=a|0;return 7}function yB(a,b){hc(a,b,1954)}function xS(a){kq(Zb(a,0,48))}function we(a){a=a|0;return 1}function wT(a,b){df(a,b,40,2)}function ue(a){a=a|0;return 2}function td(a){return(a|0)!=0}function tA(a,b){hc(a,b,4896)}function ro(a){return a>>>0<5}function lc(a){a=a|0;return 0}function lK(a){a=a|0;return 5}function iH(a){a=a|0;return-1}function es(a,b){x[a+32>>2]=b}function de(a,b){return a-b|0}function cR(a,b){hc(a,b,1108)}function aq(a){return a+256|0}function a7(a){a=a|0;return 6}function Xz(a,b){hc(a,b,1024)}function Xe(a,b){w[a+28>>1]=b}function Vz(a){return a+128|0}function V7(a){a=a|0;return 9}function Uo(a){return a>>>0<2}function TQ(a,b){df(a,b,33,1)}function Rc(a,b){return b-a|0}function O5(){return 19924993}function Lj(a){return td(a)^1}function LN(a,b){Bv(a,b,7,-7)}function Kb(a){hv(a);return a}function Hq(a,b){df(a,b,26,3)}function Gb(a,b){return a+b|0}function Fm(a){return a&1?2:1}function DL(a,b,c){Uk(a,b,-c)}function Ck(a){return(a&5)!=0}function CK(a){a=a|0;return 3}function Bn(a){a=a|0;return 4}function $e(a){return F(a)==O}function zl(a,b,c){GF(a,b,c)}function zS(a,b){hc(a,b,128)}function yd(a,b,c){hj(a,b,c)}function yc(a){return a+12|0}function xR(a,b){hc(a,b,130)}function vR(a,b){hc(a,b,600)}function vO(a){return a+48|0}function uN(a,b,c){Vl(a,c,b)}function uC(a,b){hc(a,b,497)}function tU(a,b){hc(a,b,610)}function sq(a,b){hc(a,b,192)}function sd(a){return a+16|0}function qm(a,b){ge(a,b+8|0)}function qT(a,b){hc(a,b,218)}function pR(a,b){hc(a,b,126)}function oe(a,b){x[a+4>>2]=b}function nT(a,b){hc(a,b,157)}function mv(a,b){AD(a,Wd(b))}function lu(a,b){hc(a,b,512)}function lP(a,b){hc(a,b,263)}function lN(a,b,c){Yl(a,c,b)}function ko(a){return a-28|0}function jp(a,b){B[a+8>>2]=b}function jL(a){return a-52|0}function ip(a,b){B[a+4>>2]=b}function iT(a,b){hc(a,b,576)}function hp(a,b){v[a+33|0]=b}function hm(a,b,c){vo(a,b,c)}function hc(a,b,c){ec(a,b,c)}function gQ(a,b){hc(a,b,204)}function fT(a,b){hc(a,b,674)}function dx(a){return a-16|0}function bf(a,b){v[a+11|0]=b}function a0(a){a=a|0;nU(a,1)}function _s(a){return a-32|0}function Wx(a,b){v[a+34|0]=b}function Vx(a,b){v[a+32|0]=b}function Vn(a){return a+32|0}function Ux(a,b){v[a+35|0]=b}function Uh(a){return a-36|0}function Qy(a){v[a+6152|0]=0}function PO(a){OO(a,x[a>>2])}function Op(a){return a+14|0}function Nl(a,b){x[a+8>>2]=b}function NA(a,b){df(a,b,8,2)}function Mz(a){return a-56|0}function Mh(a,b,c){xT(a,b,c)}function Lp(a,b){return a<<b}function Jb(a,b,c){RC(a,b,c)}function Hz(a,b){Rz(a,Wd(b))}function HQ(a,b){hc(a,b,146)}function Go(a){return a+20|0}function Fs(a){mM(a,x[a>>2])}function Fc(a){oe(a,x[a>>2])}function DT(a){return a-20|0}function DQ(a,b){hc(a,b,608)}function Bi(a){return a-12|0}function Ae(a,b){a=a|0;b=b|0}function AF(a){yF(a,x[a>>2])}function $S(a){return a+36|0}function $N(a){_N(a,x[a>>2])}function zx(a){Zb(a,0,2048)}function zT(a,b){hc(a,b,98)}function xB(a){Zb(a,0,1954)}function wi(a){return a+3|0}function uO(a,b){hc(a,b,27)}function uK(a){return 0-a|0}function to(a,b){v[a+1|0]=b}function tT(a,b){hc(a,b,48)}function tP(a,b){return a<b}function pA(a,b){hc(a,b,33)}function nh(a){return a&255}function mp(a){Zb(a,0,8192)}function mj(a){return a&127}function mC(a,b){hc(a,b,38)}function lq(a){x[a+12>>2]=0}function jc(a){return a+4|0}function jC(a,b){Ei(a,b,37)}function iR(a,b){hc(a,b,32)}function hy(a){Zb(a,0,4096)}function hd(a){return a+1|0}function hS(a,b){hc(a,b,52)}function hC(a,b){hc(a,b,41)}function gA(a,b){hc(a,b,40)}function du(a,b){hc(a,b,64)}function dg(){hU(10893);p()}function cu(a,b){hc(a,b,66)}function ZA(a,b){hc(a,b,12)}function VQ(a,b){hc(a,b,96)}function Ut(a,b){hc(a,b,22)}function TB(a,b){hc(a,b,11)}function Rp(){Qp(10893);p()}function Re(a){return a+2|0}function Pu(a,b){ec(a,b,22)}function NB(a,b){ec(a,b,20)}function N5(){return 393223}function Mq(a,b){hc(a,b,36)}function Mk(a){return a-4|0}function Lt(a,b){return a<b}function Lf(a,b){v[a+3|0]=b}function KB(a,b){hc(a,b,17)}function FR(a,b){hc(a,b,30)}function Du(a,b){hc(a,b,65)}function DD(a,b){hc(a,b,24)}function Cm(a,b){ec(a,b,32)}function Cb(a){return a+8|0}function Bu(a,b){hc(a,b,16)}function AU(a){return a-2|0}function AS(a,b){hc(a,b,80)}function $T(a,b){vc(a,b,48)}function zh(a,b){hc(a,b,4)}function xc(a){x[a+8>>2]=0}function xK(a,b){aL(a,3,b)}function uV(a){a=a|0;xh(a)}function uR(a){Zb(a,0,600)}function tz(a){Zb(a,0,256)}function tC(a){Zb(a,0,497)}function sU(a){Zb(a,0,610)}function ql(a,b){hc(a,b,2)}function po(a,b){hc(a,b,7)}function oj(a,b){w[a>>1]=b}function oR(a){Zb(a,0,126)}function nu(a,b){hc(a,b,5)}function mT(a){Zb(a,0,157)}function li(a){return a!=a}function jA(a){hA(a,Sd(a))}function hT(a){Zb(a,0,576)}function fQ(a){Zb(a,0,204)}function cr(a){a=a|0;er(a)}function cT(a){Zb(a,0,192)}function aO(a){vp(a,Sd(a))}function _u(a,b){hc(a,b,3)}function YB(a,b){Mh(a,2,b)}function XM(a){Ks(a,Sd(a))}function Wz(a){Zb(a,0,130)}function WM(a){Ls(a,Sd(a))}function VS(a){yA(a,Sd(a))}function TS(a){zA(a,Sd(a))}function TA(a,b){hc(a,b,6)}function Sk(a){My(a,Sd(a))}function Sc(){hU(7636);p()}function JP(a){wz(a,Sd(a))}function Im(a,b){hc(a,b,8)}function IP(a){xz(a,Sd(a))}function Hu(){Qp(7636);p()}function Gt(a){iA(a,Sd(a))}function GQ(a){Zb(a,0,146)}function GL(a){Sx(a,Sd(a))}function En(a,b){B[a>>2]=b}function Dq(a,b){hc(a,b,1)}function CQ(a){Zb(a,0,608)}function Ad(a,b){x[a>>2]=b}function Ac(a){a=a|0;Hb(a)}function $k(a,b){vo(a,b,0)}function $b(a){Om(x[a>>2])}function yT(a){Zb(a,0,98)}function uT(a){Zb(a,0,48)}function uA(a){Zb(a,0,80)}function rA(a){Zb(a,0,33)}function kC(a){Zb(a,0,38)}function id(a,b){v[a|0]=b}function gS(a){Zb(a,0,52)}function gC(a){Zb(a,0,41)}function fB(a){Zb(a,0,66)}function Zt(a){Zb(a,0,64)}function WQ(a){Zb(a,0,96)}function Vu(a){return a&1}function V2(){return 2048}function RK(a){Tm(a,2048)}function Nq(a){Zb(a,0,36)}function H3(a){a=a|0;ib=a}function G0(a){a=a|0;hb=a}function E1(){return hb|0}function ys(a,b){En(a,b)}function tu(a,b){PB(a,b)}function sk(a,b){id(a,b)}function sR(a){Fv(a,512)}function oA(a,b){kS(a,b)}function nP(a){x[a>>2]=0}function nL(a,b){mM(a,b)}function hr(a,b){dd(a,b)}function gB(a,b){jl(a,b)}function _Q(a,b){ge(a,b)}function ZN(a){je(a+8|0)}function Uu(a){w[a>>1]=0}function Un(a,b){Ad(a,b)}function Tj(a){xb(a+4|0)}function Ss(a,b){WL(a,b)}function Sm(a,b){kU(a,b)}function SA(a,b){kc(a,b)}function Pc(a,b){gs(a,b)}function Nt(a,b){ES(a,b)}function NO(a,b){OO(a,b)}function Md(a){yb(a+8|0)}function Lc(a){fc(a+8|0)}function Id(a,b){oe(a,b)}function IO(a,b){Ff(a,b)}function Bx(a,b){Mf(a,b)}function AB(a,b){xJ(a,b)}function $h(a,b){Eh(a,b)}function $g(a){a=a|0;p()}function yh(a){xv(a,24)}function uo(a){sE(a,11)}function qg(a){v[a|0]=0}function gfa(){va();p()}function br(a){xv(a,36)}function YA(a){sE(a,16)}function XT(a){Tm(a,48)}function XB(a){Fv(a,16)}function TD(a){xv(a,48)}function yi(a){Tm(a,2)}function yS(a){Fv(a,4)}function jy(a){pM(a,0)}function iy(a){oM(a,0)}function ds(a){oJ(a,0)}function bg(a){US(a,0)}function bF(){wa();p()}function Zq(a){AD(a,0)}function Ti(a){pJ(a,0)}function Sq(a){Tm(a,8)}function Si(a){nJ(a,0)}function RL(a){sM(a,0)}function OX(){bF();p()}function Mc(a){Ie(a,0)}function KN(a){Tm(a,7)}function JS(a){Tm(a,6)}function wF(a){zc(a)}function jf(a){a=a|0}function gm(a){sc(a)}function fr(a){yc(a)}function XP(a){Sb(a)}function WI(a){Le(a)}function UN(a){Wn(a)}function Tz(a){dk(a)}function TP(a){Fe(a)}function Db(a){xb(a)}
// EMSCRIPTEN_END_FUNCS
e=y;var mb=c([null,Xb,Vq,lg,jD,Jm,dW,_V,UC,UV,TV,vC,gV,YU,rq,kj,JU,$,Cu,ll,_G,Fg,lo,vha,bT,yf,Yfa,sfa,qfa,gfa,$ea,Rea,Nz,pea,oea,Jaa,Jda,RP,t0,s0,Or,RP,yaa,eaa,ZM,pp,np,R9,Q9,UL,A9,si,$K,lg,Xb,jD,l8,An,DK,sx,ih,MJ,I5,C5,v5,W4,L4,g0,f0,N$,An,J2,pp,v2,s2,Z1,U1,ih,w1,o1,k1,V0,K0,H0,F0,E0,D0,Sr,A0,w0,vw,va,Qb,kX,jX,iX,hX,gX,fX,jk,eX,SD,Sr,dX,cX,ha,aX,$W,ir,ih,_W,ZW,YW,LD,KD,XW,ir,WW,Ho,sv,cr,vj,Zc,ef,RW,Ho,TW,SW,QW,VW,PW,HD,OW,HD,UW,JD,NW,MW,LW,jk,GD,Yc,Qb,IW,lv,HW,Fg,GW,CD,FW,hk,CD,Xq,EW,jv,iv,hW,DW,vW,uW,gW,Fi,aW,$V,Yu,cD,ZV,u9,v9,GN,s9,t9,Tx,As,bc,w9,Ud,$C,WV,VV,OC,RV,QV,OC,MV,Lu,LV,M8,cf,Cfa,faa,SV,vq,Af,_U,daa,nia,W8,L8,DV,eC,CV,BV,dC,AV,fg,zV,yV,Dc,xV,wV,gg,Yg,vV,uV,rV,RB,qV,pV,oV,yu,ON,sC,Zw,nV,mV,lV,kV,jV,Au,iV,GB,Cd,vj,eV,dV,qu,FB,cV,bV,aV,EB,$U,DB,zu,Fu,UU,qq,TU,Nb,zf,ef,SU,ku,RU,Zc,pq,QU,PU,OU,tB,sB,od,NU,rm,MU,LU,KU,pB,oB,Fi,ef,IU,HU,Taa,GU,Zg,Gia,Dia,_j,Fia,SD,Sr,Eia,Sh,Gf,Aia,zia,yia,mU,via,_j,ij,uia,tia,jq,sia,dB,ria,qia,pia,oia,UT,RT,kia,hia,dn,fia,eg,rU,gia,yu,NT,eia,dia,XA,cia,iv,bia,VA,JT,Eda,_ha,qq,go,Zha,Yha,sB,Xha,Wha,Vha,Uha,Tha,xm,Sha,Rha,Qha,Oha,_j,ET,Pha,Sh,Gf,cB,Jha,Gha,wh,Aha,zha,wha,uha,tha,sha,rha,qha,iq,pha,oha,nha,GA,NV,mha,lha,ef,kha,jha,iha,KV,hha,gha,fha,eha,VA,aT,dha,cha,ef,bha,aha,lU,Bha,$ga,_ga,Cha,Zga,Yga,Xga,DA,DA,CA,Wga,Vga,_S,DA,Uga,bZ,Tga,Sga,Rga,Qga,Pga,Oga,Nga,WS,qd,fo,Cga,vA,Mga,x8,w8,v8,u8,t8,s8,Lga,Kga,Ff,Jga,Iga,Hga,Gga,Vq,Saa,Qaa,I8,U8,V8,Fga,Ega,Dga,F9,q8,An,Oaa,Naa,Maa,Laa,yga,xga,wga,vga,uga,tga,sga,rga,qga,pga,oga,nga,mga,kga,jga,lga,lS,Gf,eS,nA,gga,mA,fga,ega,dga,cga,dS,lA,bga,Lu,dC,aga,bS,aS,Gq,kA,$fa,Ue,_fa,Vq,iq,wu,iq,Zfa,Cq,ef,mU,iq,Xaa,dn,Vfa,Ufa,Tfa,Sfa,fA,Dt,Rfa,Qfa,Pfa,Ofa,Nfa,Mfa,Lfa,fC,Kfa,Jfa,Ifa,Hfa,Gfa,Ffa,Efa,Dfa,AA,Bfa,Afa,zfa,yfa,ef,ZS,YS,JA,xfa,wfa,qu,iv,xaa,waa,vaa,jk,vfa,tm,eu,ug,caa,Caa,Ts,QN,baa,aaa,yN,Ps,sN,$9,hN,BO,_9,Zy,Zi,Th,kfa,jfa,xt,tfa,Mt,ffa,tm,efa,dfa,mR,fo,cfa,bfa,lR,afa,_ea,Zea,wt,Yea,Xea,Wea,Vea,Pea,Oz,Oea,Nea,Mea,_j,Sh,Gf,Th,Jea,Iea,Hea,Gea,mA,Dea,Cea,wt,Bea,X8,yea,xea,ij,$Q,Oz,zu,wea,vea,uea,tea,tt,sea,tt,rea,_q,OV,mea,_j,nea,qea,Jz,MQ,Sh,Gf,xt,jea,gea,nA,fea,cea,bea,zQ,lR,GA,aea,qu,ef,Tda,Sda,EB,Rda,Qda,Pda,Oda,cQ,rm,Lda,Kda,Ida,Hda,Gda,Fda,fm,UP,Dda,Cda,Bda,Ada,zda,yda,xda,wda,vda,uda,tda,sda,rda,mA,qda,pda,oda,Mt,nda,mda,qq,naa,lv,tB,uaa,taa,qq,saa,Th,lv,raa,qaa,paa,jda,ida,hda,gda,fda,eda,Fq,bda,ada,$ca,_ca,Zca,Yca,Xca,Wca,Vca,Uca,Tca,Sca,bX,VD,Rca,ef,Qca,Pca,nl,zaa,Yaa,Eha,QO,Vaa,Uaa,Raa,Paa,Zs,Kaa,CO,Haa,Gaa,tO,Faa,Eaa,Daa,Qn,dO,Baa,Aaa,ho,laa,ij,IN,$q,r9,q9,p9,x9,PV,o9,Zu,$q,GB,n9,IN,jaa,m9,oaa,_j,Sh,Gf,maa,_j,Sh,Gf,kaa,_j,Sh,Gf,GD,Sr,jk,Z9,Y9,X9,W9,V9,U9,Waa,Nca,AO,T9,Jc,P9,P8,O9,KW,fW,YV,cW,M9,L9,XV,eW,JW,bW,gM,K9,J9,I9,fM,fy,H9,G9,Iaa,E9,D9,C9,B9,hL,G8,dr,RD,vD,Tx,y9,An,hu,yq,haa,iaa,j9,i9,ij,h9,Oz,g9,f9,e9,xt,d9,Th,c9,b9,a9,$8,_8,_j,Sh,Gf,k9,T8,S8,R8,Q8,Eh,Gl,O8,N8,K8,E8,D8,C8,B8,A8,eL,H8,fp,dL,lk,Eh,Ff,y8,_e,r8,z8,F8,o8,n8,G7,m8,Gj,SK,Wf,bL,Y7,H7,Bl,B7,ih,A7,z7,y7,Tx,Zs,w7,cM,AK,c7,W6,P6,I6,A6,r6,t6,i6,b6,OJ,os,V5,U5,P1,R1,L5,K5,H5,sv,z9,T1,E5,OJ,D5,A2,p2,D2,A5,u1,IJ,jx,y5,Q2,wJ,P2,kJ,w5,X7,s5,Z5,t5,W5,q5,w2,M2,o5,y2,GJ,Vq,FJ,EJ,DJ,e5,c5,IJ,jx,$4,_4,Z4,Y4,X4,V4,U4,T4,S4,R4,Q4,P4,O4,N4,M4,K4,J4,I4,H4,G4,F4,E4,D4,C4,z4,x4,v4,rD,p1,E2,t4,f4,u2,d4,b4,Hk,q1,r1,$3,t1,U3,S3,J8,P3,jx,K3,G3,D3,wn,xI,B3,z3,x3,v3,t3,r3,p3,n3,l3,j3,h3,f3,zJ,a3,_2,$L,yt,yJ,X2,W2,U2,T2,S2,R2,bp,gaa,ar,IL,jh,K2,I2,G2,kh,UL,C2,S9,z2,x2,t2,q2,N9,B2,L2,F2,fv,aa,S1,rJ,qJ,Q1,HI,O1,N1,C1,s1,An,n1,VL,Oca,J0,I0,C0,B0,v0,u0,PG,OG,YX,n0,m0,l0,k0,j0,i0,h0,b0,Fg,a0,yf,QX,XX,O$,OG,L$,Aq,YG,pw,lw,v$,u$,hw,Dh,Ch,Br,Hb,gw,Lg,zk,fw,Hl,m$,l$,Ni,Jg,dG,Mi,sw,bw,Dh,Ch,yr,Fh,$$,ll,kn,Ni,Jg,$F,Mi,T_,O_,UG,J_,Hr,lo,E_,vr,jf,m_,Fr,l_,k_,j_,NF,h_,Bt,f_,e_,wk,d_,NF,b_,a_,_Z,ZZ,WZ,VZ,RZ,QZ,PZ,OZ,NZ,MZ,LZ,KZ,JZ,IZ,HZ,GZ,FZ,EZ,DZ,CZ,BZ,AZ,zZ,yZ,xZ,wZ,vZ,uZ,tZ,sZ,rZ,qZ,pZ,oZ,nZ,mZ,lZ,kZ,XY,YY,ZY,fZ,dZ,aZ,_Y,JY,KY,LY,SY,QY,OY,MY,dj,bF,Lm,Wq,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,nca,mca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Pba,Oba,Nba,Mba,Lba,Kba,Jba,Iba,Hba,Gba,Fba,Eba,Dba,Cba,Bba,Aba,zba,yba,xba,wba,vba,uba,tba,sba,rba,qba,pba,oba,nba,mba,lba,kba,jba,iba,hba,gba,fba,eba,dba,cba,bba,aba,$aa,_aa,Zaa,Lm,dda,cda,yha,xha,eea,dea,Zda,Yda,iga,hga,Uea,Tea,Aga,zga,WU,VU,Nha,Mha,tV,sV,hV,fV,Lea,Kea,iea,hea,lda,kda,xia,wia,mia,lia,HV,GV,FV,EV,Aea,zea,lea,kea,ifa,hfa,Bga,EU,Iha,Hha,Fha,Dha,Cia,Bia,aia,$ha,Fea,Eea,l9,Z8,Y8,mfa,lfa,Nda,Mda,Sea,Qea,Lha,Kha,$da,_da,Vda,Uda,jia,iia,Xda,Wda,ufa,ofa,nfa,JV,IV,ZU,XU,Xfa,Wfa,rfa,pfa,Rm,Wq,iW,Ac,Bo,NJ,Ac,yf,Ac,lc,we,we,lc,lc,jW,yW,xW,kW,Ac,Bo,Ac,pD,tW,sW,rW,qW,pW,oW,nW,mW,lW,xs,Cn,Cn,QK,lc,jf,lc,lc,lc,Ae,Bn,k8,j8,i8,h8,g8,ci,xx,xx,wx,OK,wx,wx,f8,jf,EU,e8,d8,c8,b8,a8,bi,NK,D7,lc,lc,we,vx,ue,ue,we,$7,_7,Ae,jf,Ae,jf,MK,LK,LK,W7,lc,jf,lc,lc,lc,Ae,V7,KK,U7,T7,S7,R7,ci,Q7,P7,O7,N7,M7,L7,K7,J7,I7,bi,HK,lc,lc,we,ue,ue,we,JK,IK,uf,$g,OX,F7,yx,E7,lc,C7,OK,n7,d7,X6,Q6,J6,B6,s6,j6,c6,C6,p8,Z7,x7,xs,Cn,Cn,QK,lc,jf,lc,lc,lc,Ae,CK,v7,u7,t7,s7,r7,ci,q7,bi,BK,lc,lc,we,ue,ue,we,p7,o7,qK,pK,pK,b7,lc,jf,lc,lc,lc,Ae,a7,$6,_6,Z6,ci,Y6,bi,mK,lc,lc,we,ue,ue,Jk,Jk,V6,lc,jf,lc,lc,lc,Ae,lK,U6,T6,S6,ci,R6,bi,jK,lc,lc,we,ue,ue,xs,Cn,Cn,O6,lc,jf,lc,lc,lc,Ae,lK,N6,M6,L6,ci,K6,bi,hK,lc,lc,we,ue,ue,zK,rx,rx,H6,lc,jf,lc,lc,lc,Ae,yK,G6,k7,j7,ci,i7,bi,h7,lc,lc,we,ue,ue,Ae,jf,wK,F6,E6,vK,D6,tK,sK,rx,qs,m7,yK,l7,wK,g7,f7,vK,e7,tK,sK,Jk,Jk,z6,lc,jf,lc,lc,lc,Ae,ue,y6,x6,w6,ci,v6,bi,u6,lc,lc,we,ue,ue,dK,cK,cK,q6,lc,jf,lc,lc,p6,Ae,o6,n6,m6,l6,ci,k6,bi,kx,lc,lc,we,ue,ue,Ae,jf,Jk,Jk,h6,lc,jf,lc,lc,lc,Ae,CK,g6,f6,e6,ci,d6,bi,ZJ,lc,lc,we,ue,ue,Jk,Jk,a6,lc,jf,lc,lc,lc,Ae,Bn,$5,_5,Y5,ci,X5,bi,XJ,lc,lc,we,ue,ue,vJ,Ac,O2,fx,N2,fx,fx,$g,as,o2,H2,yf,$g,yf,Ac,n2,m2,$g,cJ,bJ,cJ,bJ,Ae,bs,Ae,bs,fJ,eJ,fJ,eJ,Ac,r2,yf,Ac,l2,k2,Ac,UI,TI,$g,h2,RI,g2,RI,j2,SI,i2,SI,Ac,f2,e2,Ac,PI,OI,Zr,Zr,Zr,Zr,d2,Xw,Xw,Xw,Ac,c2,b2,Ac,NI,MI,_1,KI,Y1,KI,a2,LI,$1,LI,Ac,X1,W1,Ac,JI,II,Yr,Yr,Yr,Yr,V1,Vw,Vw,Vw,v1,Ac,Bo,Ac,zI,B1,we,we,A1,z1,Wq,y1,x1,$g,$g,D1,Ac,Bo,Ac,GI,M1,we,lc,we,L1,K1,J1,I1,H1,G1,F1,$g,wW,Ac,Bo,Ac,Ac,CW,we,we,Wq,uD,BW,AW,zW,Ae,bs,Ae,bs,Wr,Sw,m1,l1,qI,pI,oI,nI,mI,lI,kI,jI,iI,hI,gI,fI,eI,dI,cI,bI,aI,$H,_H,ZH,YH,XH,j1,i1,h1,g1,f1,e1,d1,c1,b1,a1,$0,_0,Z0,Y0,X0,W0,U0,T0,S0,R0,Q0,P0,O0,N0,M0,L0,yf,$g,yf,$g,yf,$g,z0,y0,x0,yn,yw,Ae,lH,kH,jH,lc,lc,q0,iH,p0,Nr,o0,Nr,Kr,tw,Ae,lH,kH,jH,lc,lc,e0,iH,d0,Nr,c0,Nr,js,W$,X$,V$,_$,Z$,Y$,ap,SG,U$,T$,Lr,uw,aH,$G,hf,RG,S$,R$,Mr,ww,fH,eH,yf,Ac,Q$,WX,VX,UX,P$,Lm,r0,lc,M$,yw,A$,z$,y$,x$,CJ,zw,Ak,zw,yw,D$,HG,C$,B$,tw,H$,G$,F$,E$,Mr,ww,fH,eH,CJ,zw,tw,K$,HG,J$,I$,Lr,uw,aH,$G,eF,ZX,qs,fF,fY,eY,dY,cY,bY,RS,aY,$X,_X,kF,yY,xY,wY,vY,uY,lc,tY,sY,rF,DY,CY,BY,xI,AY,zY,sF,IY,uD,HY,GY,FY,EY,yf,Ac,Ac,qY,pY,oY,nY,mY,lY,kY,jY,RS,iY,hY,gY,Ac,gF,gF,Qo,we,we,rY,we,Ac,nF,mF,Qo,lc,lc,lF,Bn,Ac,nF,mF,Qo,lc,lc,lF,Bn,Ac,qF,pF,Qo,lc,lc,oF,Bn,Ac,qF,pF,Qo,lc,lc,oF,Bn,yf,Ac,t$,s$,r$,yf,Ac,q$,p$,o$,Ac,n$,k$,j$,i$,hG,hG,h$,g$,f$,e$,d$,Ac,c$,b$,a$,$_,_F,_F,__,Z_,Y_,X_,W_,Ac,V_,U_,S_,R_,Q_,P_,N_,M_,Ac,L_,K_,I_,H_,G_,F_,D_,C_,yf,Ac,ue,B_,A_,z_,y_,x_,w_,WY,VY,UY,TY,RY,PY,NY,yf,Ac,ue,v_,u_,t_,s_,r_,q_,jZ,iZ,hZ,gZ,eZ,cZ,$Y,Xv,tF,p_,Xv,tF,o_,Ac,ur,ur,Bh,Bh,Bh,PF,lc,rk,rk,Ac,ur,ur,Bh,Bh,Bh,PF,lc,rk,rk,Ac,tr,tr,Bh,Bh,Bh,OF,lc,rk,rk,Ac,tr,tr,Bh,Bh,Bh,OF,lc,rk,rk,Ac,n_,i_,Ac,g_,c_,Ac,$Z,YZ,Ac,XZ,UZ,Ac,DF,TZ,Ae,Ac,DF,SZ,Ae,yf,$g,Ac,TX,cF,Ac,SX,RX,cF,Lm,$g,Ac,PX,wa,yf,Ac,jf,jf,NX,FX,HX,IX,Ac,AX,Ac,zX,Rm,Lm,Rm,Rm,Rm,Rm,Lm,Ac,yX,Ac,EX,GX,JX,Ac,MX,LX,KX,Ac,BX]);function nb(){return u.byteLength/65536|0}function sb(tb){tb=tb|0;var ob=nb()|0;var pb=ob+tb|0;if(ob<pb&&pb<65536){var qb=new ArrayBuffer(D(pb,65536));var rb=new Int8Array(qb);rb.set(v);v=new Int8Array(qb);w=new Int16Array(qb);x=new Int32Array(qb);y=new Uint8Array(qb);z=new Uint16Array(qb);A=new Uint32Array(qb);B=new Float32Array(qb);C=new Float64Array(qb);u=qb;t.buffer=u;e=y}return ob}return{"va":FU,"wa":N5,"xa":O5,"ya":Ac,"za":Hb,"Aa":M5,"Ba":J5,"Ca":G5,"Da":os,"Ea":Ae,"Fa":Q5,"Ga":P5,"Ha":T5,"Ia":xx,"Ja":R5,"Ka":NJ,"La":S5,"Ma":yf,"Na":QJ,"Oa":PJ,"Pa":QJ,"Qa":V2,"Ra":xX,"Sa":wX,"Ta":vX,"Ua":F5,"Va":KJ,"Wa":B5,"Xa":JJ,"Ya":k5,"Za":c3,"_a":d3,"$a":i5,"ab":h5,"bb":g5,"cb":j5,"db":e3,"eb":F3,"fb":Y2,"gb":J3,"hb":g4,"ib":$2,"jb":M3,"kb":b3,"lb":L3,"mb":Z2,"nb":k3,"ob":g3,"pb":i3,"qb":y3,"rb":u3,"sb":w3,"tb":m3,"ub":o3,"vb":q3,"wb":s3,"xb":a4,"yb":c4,"zb":n4,"Ab":i4,"Bb":h4,"Cb":m4,"Db":l4,"Eb":j4,"Fb":k4,"Gb":r4,"Hb":s4,"Ib":o4,"Jb":q4,"Kb":p4,"Lb":V3,"Mb":_3,"Nb":Y3,"Ob":X3,"Pb":Z3,"Qb":W3,"Rb":E3,"Sb":w4,"Tb":T3,"Ub":Q3,"Vb":e4,"Wb":I3,"Xb":R3,"Yb":O3,"Zb":N3,"_b":y4,"$b":A3,"ac":A4,"bc":C3,"cc":u4,"dc":z5,"ec":x5,"fc":uX,"gc":u5,"hc":r5,"ic":p5,"jc":n5,"kc":tX,"lc":m5,"mc":l5,"nc":f5,"oc":d5,"pc":b5,"qc":B4,"rc":a5,"sc":Ld,"tc":mb,"uc":w$,"vc":H3,"wc":E1,"xc":G0,"yc":DX,"zc":CX,"Ac":sX,"Bc":qX,"Cc":lX,"Dc":rX,"Ec":qX,"Fc":pX,"Gc":mX,"Hc":oX,"Ic":nX,"Jc":mX,"Kc":lX,"Lc":lX}}return ub(wb)}
// EMSCRIPTEN_END_ASM




)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


